<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="Mutbox">
    <meta name="author" content="Daniel Minseok Kwon">
    <!--<link rel="icon" href="../../favicon.ico">-->
    <script src="/static/js/jquery-2.1.1.min.js"></script>
    <script src="/static/js/jquery-ui-1.12.1.min.js"></script>
    <!--<script src="/static/js/jquery.js" type="text/javascript"></script>-->

    <script src="/static/js/bootstrap.3.2.0.min.js"></script>
    <script src="/static/js/bootstrap-table.min.js"></script>
    <script src="/static/js/js.cookie.js"></script>
    <link href="/static/css/bootstrap-table.min.css" rel="stylesheet">
    <link href="/static/css/bootstrap.min.css" rel="stylesheet">

    <link href="/static/css/main.css?randkey={{randkey}}" rel="stylesheet">
    <link href="/static/css/jquery-ui-1.12.1.min.css" rel="stylesheet">
    <!--<link href="/static/css/bootstrap-theme.min.css" rel="stylesheet">-->
    
    <script src="/static/js/d3.v3.min.js"></script>
    <!-- <script src="/static/js/d3.v4.min.js"></script> -->
    <script src="/static/js/main.js"></script>
<!-- 
    <link href="/static/css/jquery.treetable.css" rel="stylesheet" type="text/css" />
    <script src="/static/js/jquery.treetable.js"></script>
 -->
    <link href="/static/css/jquery.treegrid.css" rel="stylesheet">
    <script type="text/javascript" src="/static/js/jquery.treegrid.js"></script>
    <script type="text/javascript" src="/static/js/jquery.treegrid.bootstrap3.js"></script>

    {% block script %}{% endblock %}

    <title>{% block title %}BSM Variant Database{% endblock %}</title>
</head>
<body role="document">
{% block content %}{% endblock %}
<script type="text/javascript">
$(document).ready(function() {
//   $('.sampleSelectorTree').treegrid({
//     expanderExpandedClass: 'glyphicon glyphicon-minus',
//     expanderCollapsedClass: 'glyphicon glyphicon-plus',
//   });

//   $('#treegrid-CH_FB_WGS_1 treegrid-parent-5154').on('click', function (e) {
//     // $(this).toggleClass("glyphicon glyphicon-check");
//     var iSelector = $(this);
//     if(iSelector.hasClass('glyphicon-unchecked')) {
//       iSelector.removeClass('glyphicon-unchecked');iSelector.addClass('glyphicon-check');
//     }else{
//       iSelector.removeClass('glyphicon-check');iSelector.addClass('glyphicon-unchecked');
//     }
//   });
});
</script>

</body>
</html>