#!/usr/bin/env python
# -*- coding: utf-8 -*-

SOURCELIST = ['ANNOVAR', 'SNPEFF', 'VEP']

DATAFILE = {}
DATAFILE['ANNOVAR'] = "ANNOT/b38_chrom/b38_WGSNV.annovar.chr#CHROM#.vcf.gz"
DATAFILE['SNPEFF'] = "ANNOT/b38_chrom/b38_WGSNV.snpeff.chr#CHROM#.vcf.gz"
DATAFILE['VEP'] = "ANNOT/b38_chrom/b38_WGSNV.vep.chr#CHROM#.vcf.gz"

ANNOVAR = ""
SNPEFF = ""
VEP = ""

if __name__ == "__main__":
    pass
