
VEP_CONSEQUENCE_ORDER = {}
VEP_CONSEQUENCE_ORDER['transcript_ablation'] = 1
VEP_CONSEQUENCE_ORDER['splice_acceptor_variant'] = 2
VEP_CONSEQUENCE_ORDER['splice_donor_variant'] = 3
VEP_CONSEQUENCE_ORDER['stop_gained'] = 4
VEP_CONSEQUENCE_ORDER['frameshift_variant'] = 5
VEP_CONSEQUENCE_ORDER['stop_lost'] = 6
VEP_CONSEQUENCE_ORDER['start_lost'] = 7
VEP_CONSEQUENCE_ORDER['transcript_amplification'] = 8
VEP_CONSEQUENCE_ORDER['inframe_insertion'] = 9
VEP_CONSEQUENCE_ORDER['inframe_deletion'] = 10
VEP_CONSEQUENCE_ORDER['missense_variant'] = 11
VEP_CONSEQUENCE_ORDER['protein_altering_variant'] = 12
VEP_CONSEQUENCE_ORDER['splice_region_variant'] = 13
VEP_CONSEQUENCE_ORDER['incomplete_terminal_codon_variant'] = 14
VEP_CONSEQUENCE_ORDER['start_retained_variant'] = 15
VEP_CONSEQUENCE_ORDER['stop_retained_variant'] = 16
VEP_CONSEQUENCE_ORDER['synonymous_variant'] = 17
VEP_CONSEQUENCE_ORDER['coding_sequence_variant'] = 18
VEP_CONSEQUENCE_ORDER['mature_miRNA_variant'] = 19
VEP_CONSEQUENCE_ORDER['5_prime_UTR_variant'] = 20
VEP_CONSEQUENCE_ORDER['3_prime_UTR_variant'] = 21
VEP_CONSEQUENCE_ORDER['non_coding_transcript_exon_variant'] = 22
VEP_CONSEQUENCE_ORDER['intron_variant'] = 23
VEP_CONSEQUENCE_ORDER['NMD_transcript_variant'] = 24
VEP_CONSEQUENCE_ORDER['non_coding_transcript_variant'] = 25
VEP_CONSEQUENCE_ORDER['upstream_gene_variant'] = 26
VEP_CONSEQUENCE_ORDER['downstream_gene_variant'] = 27
VEP_CONSEQUENCE_ORDER['TFBS_ablation'] = 28
VEP_CONSEQUENCE_ORDER['TFBS_amplification'] = 29
VEP_CONSEQUENCE_ORDER['TF_binding_site_variant'] = 30
VEP_CONSEQUENCE_ORDER['regulatory_region_ablation'] = 31
VEP_CONSEQUENCE_ORDER['regulatory_region_amplification'] = 32
VEP_CONSEQUENCE_ORDER['feature_elongation'] = 33
VEP_CONSEQUENCE_ORDER['regulatory_region_variant'] = 34
VEP_CONSEQUENCE_ORDER['feature_truncation'] = 35
VEP_CONSEQUENCE_ORDER['intergenic_variant'] = 36

VEP_BIOTYPE_ORDER = {}
VEP_BIOTYPE_ORDER['protein_coding'] = 1
VEP_BIOTYPE_ORDER['processed_transcript'] = 5
VEP_BIOTYPE_ORDER['transcribed_processed_pseudogene'] = 10
VEP_BIOTYPE_ORDER['processed_pseudogene'] = 12
VEP_BIOTYPE_ORDER['transcribed_unprocessed_pseudogene'] = 15
VEP_BIOTYPE_ORDER['unprocessed_pseudogene'] = 20
VEP_BIOTYPE_ORDER['miRNA'] = 30
VEP_BIOTYPE_ORDER['snRNA'] = 35
VEP_BIOTYPE_ORDER['lncRNA'] = 40
VEP_BIOTYPE_ORDER['enhancer'] = 50
VEP_BIOTYPE_ORDER['promoter'] = 55
VEP_BIOTYPE_ORDER['promoter_flanking_region'] = 60
VEP_BIOTYPE_ORDER['CTCF_binding_site'] = 70
VEP_BIOTYPE_ORDER['TF_binding_site'] = 80
VEP_BIOTYPE_ORDER['open_chromatin_region'] = 99
VEP_BIOTYPE_ORDER[''] = 100