
/* v0.2 */


.float-wrap {
    overflow: hidden
}

[hidden] {
    display: none !important
}

#slot-application {
    height: 100%;
    background-color: #fff
}

#application {
    height: 100%;
    background-color: #fff
}

hr {
    clear: both
}


.sentence-case-block {
    display: inline-block
}

.sentence-case-block::first-letter, .sentence-case-block:first-letter {
    text-transform: uppercase
}

.sentence-case::first-letter, .audit-category::first-letter {
    text-transform: uppercase
}

.sentence-case:first-letter, .audit-category:first-letter {
    text-transform: uppercase
}

.repl-acc {
    margin: -5px 0 15px;
    font-size: 14px;
    font-size: 1rem;
    font-weight: normal;
    color: #808080
}

*, *:after, *:before {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}

.browser-error {
    margin: 10px;
    text-align: center
}


[hidden], template {
    display: none
}

a {
    background: transparent
}

a:active, a:hover {
    outline: 0
}

abbr[title] {
    border-bottom: 1px dotted
}

b, strong {
    font-weight: bold
}

dfn {
    font-style: italic
}

h1 {
    font-size: 2em;
    margin: 0.67em 0
}

mark {
    background: #ff0;
    color: #000
}

small {
    font-size: 80%
}

sub, sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline
}

sup {
    top: -0.5em
}

sub {
    bottom: -0.25em
}

img {
    border: 0
}

svg:not(:root) {
    overflow: hidden
}

figure {
    margin: 1em 40px
}

hr {
    -moz-box-sizing: content-box;
    box-sizing: content-box;
    height: 0
}

pre {
    overflow: auto
}

code, kbd, pre, samp {
    font-family: monospace, monospace;
    font-size: 1em
}

button, input, optgroup, select, textarea {
    color: inherit;
    font: inherit;
    margin: 0
}

button {
    overflow: visible
}

button, select {
    text-transform: none
}

button, html input[type="button"], input[type="reset"], input[type="submit"] {
    -webkit-appearance: button;
    cursor: pointer
}

button[disabled], html input[disabled] {
    cursor: default
}

button::-moz-focus-inner, input::-moz-focus-inner {
    border: 0;
    padding: 0
}

input {
    line-height: normal
}

input[type="checkbox"], input[type="radio"] {
    box-sizing: border-box;
    padding: 0
}

input[type="number"]::-webkit-inner-spin-button, input[type="number"]::-webkit-outer-spin-button {
    height: auto
}

input[type="search"] {
    -webkit-appearance: textfield;
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
    box-sizing: content-box
}

input[type="search"]::-webkit-search-cancel-button, input[type="search"]::-webkit-search-decoration {
    -webkit-appearance: none
}

fieldset {
    border: 1px solid #c0c0c0;
    margin: 0 2px;
    padding: 0.35em 0.625em 0.75em
}

legend {
    border: 0;
    padding: 0
}

textarea {
    overflow: auto
}

optgroup {
    font-weight: bold
}


* {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}

*:before, *:after {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}


input, button, select, textarea {
    font-family: inherit;
    font-size: inherit;
    line-height: inherit
}

a {
    color: #428bca;
    text-decoration: none
}

a:hover, a:focus {
    color: #2a6496;
    text-decoration: underline
}

a:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

img {
    vertical-align: middle
}

.img-responsive {
    display: block;
    margin-left: auto;
    margin-right: auto;
    max-width: 100%;
    height: auto
}

.img-rounded {
    border-radius: 4px
}

.img-thumbnail {
    padding: 4px;
    line-height: 1.42857;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 3px;
    -webkit-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
    display: inline-block;
    margin-left: auto;
    margin-right: auto;
    max-width: 100%;
    height: auto
}

.img-circle {
    border-radius: 50%
}

hr {
    margin-top: 20px;
    margin-bottom: 20px;
    border: 0;
    border-top: 1px solid #eee
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    margin: -1px;
    padding: 0;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0
}

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
    font-family: inherit;
    font-weight: bold;
    line-height: 1.1;
    color: inherit
}

h1 small, h1 .small, h2 small, h2 .small, h3 small, h3 .small, h4 small, h4 .small, h5 small, h5 .small, h6 small, h6 .small, .h1 small, .h1 .small, .h2 small, .h2 .small, .h3 small, .h3 .small, .h4 small, .h4 .small, .h5 small, .h5 .small, .h6 small, .h6 .small {
    font-weight: normal;
    line-height: 1;
    color: #999
}

h1, .h1, h2, .h2, h3, .h3 {
    margin-top: 20px;
    margin-bottom: 10px
}

h1 small, h1 .small, .h1 small, .h1 .small, h2 small, h2 .small, .h2 small, .h2 .small, h3 small, h3 .small, .h3 small, .h3 .small {
    font-size: 65%
}

h4, .h4, h5, .h5, h6, .h6 {
    margin-top: 10px;
    margin-bottom: 10px
}

h4 small, h4 .small, .h4 small, .h4 .small, h5 small, h5 .small, .h5 small, .h5 .small, h6 small, h6 .small, .h6 small, .h6 .small {
    font-size: 75%
}

h1, .h1 {
    font-size: 36px
}

h2, .h2 {
    font-size: 30px
}

h3, .h3 {
    font-size: 24px
}

h4, .h4 {
    font-size: 18px
}

h5, .h5 {
    font-size: 14px
}

h6, .h6 {
    font-size: 12px
}

p {
    margin: 0 0 10px
}

.journal {
    margin: 0 0 14px;
    font-size: 14px;
    font-weight: normal;
    color: #606060
}

.authors {
    font-size: 15px
}

.references {
    margin-top: 10px;
    margin-bottom: 10px
}

.references span {
    font-weight: bold
}

small, .small {
    font-size: 85%
}

cite {
    font-style: normal
}

.text-left {
    text-align: left
}

.text-right {
    text-align: right
}

.text-center {
    text-align: center
}

.text-justify {
    text-align: justify
}

.text-muted {
    color: #999
}

.text-primary {
    color: #428bca
}

a.text-primary:hover {
    color: #3071a9
}

.text-success {
    color: #3c763d
}

a.text-success:hover {
    color: #2b542c
}

.text-info {
    color: #31708f
}

a.text-info:hover {
    color: #245269
}

.text-warning {
    color: #8a6d3b
}

a.text-warning:hover {
    color: #66512c
}

.text-danger {
    color: #a94442
}

a.text-danger:hover {
    color: #843534
}

.bg-primary {
    color: #fff
}

.bg-primary {
    background-color: #428bca
}

a.bg-primary:hover {
    background-color: #3071a9
}

.bg-success {
    background-color: #dff0d8
}

a.bg-success:hover {
    background-color: #c1e2b3
}

.bg-info {
    background-color: #d9edf7
}

a.bg-info:hover {
    background-color: #afd9ee
}

.bg-warning {
    background-color: #fcf8e3
}

a.bg-warning:hover {
    background-color: #f7ecb5
}

.bg-danger {
    background-color: #f2dede
}

a.bg-danger:hover {
    background-color: #e4b9b9
}

.page-header {
    padding-bottom: 9px;
    margin: 40px 0 20px;
    border-bottom: 1px solid #eee
}

ul, ol {
    margin-top: 0;
    margin-bottom: 10px
}

ul ul, ul ol, ol ul, ol ol {
    margin-bottom: 0
}

.list-unstyled, .list-inline {
    padding-left: 0;
    list-style: none
}

.list-inline {
    margin-left: -5px
}

.list-inline > li {
    display: inline-block;
    padding-left: 5px;
    padding-right: 5px
}

dl {
    margin-top: 20px;
    margin-bottom: 20px
}

dt, dd {
    line-height: 1.42857
}

dt {
    font-weight: bold
}

dd {
    margin-left: 0
}

@media (min-width: 768px) {
    .dl-horizontal dt {
        float: left;
        width: 160px;
        clear: left;
        text-align: right;
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap
    }

    .dl-horizontal dd {
        margin-left: 180px
    }

    .dl-horizontal dd:before, .dl-horizontal dd:after {
        content: " ";
        display: table
    }

    .dl-horizontal dd:after {
        clear: both
    }
}

abbr[title], abbr[data-original-title] {
    cursor: help;
    border-bottom: 1px dotted #999
}

.initialism {
    font-size: 90%;
    text-transform: uppercase
}

blockquote {
    padding: 10px 20px;
    margin: 0 0 20px;
    font-size: 17.5px;
    border-left: 5px solid #eee
}

blockquote p:last-child, blockquote ul:last-child, blockquote ol:last-child {
    margin-bottom: 0
}

blockquote footer, blockquote small, blockquote .small {
    display: block;
    font-size: 80%;
    line-height: 1.42857;
    color: #999
}

blockquote footer:before, blockquote small:before, blockquote .small:before {
    content: '\2014 \00A0'
}

.blockquote-reverse, blockquote.pull-right {
    padding-right: 15px;
    padding-left: 0;
    border-right: 5px solid #eee;
    border-left: 0;
    text-align: right
}

.blockquote-reverse footer:before, .blockquote-reverse small:before, .blockquote-reverse .small:before, blockquote.pull-right footer:before, blockquote.pull-right small:before, blockquote.pull-right .small:before {
    content: ''
}

.blockquote-reverse footer:after, .blockquote-reverse small:after, .blockquote-reverse .small:after, blockquote.pull-right footer:after, blockquote.pull-right small:after, blockquote.pull-right .small:after {
    content: '\00A0 \2014'
}

blockquote:before, blockquote:after {
    content: ""
}

address {
    margin-bottom: 20px;
    font-style: normal;
    line-height: 1.42857
}

code, kbd, pre, samp {
    font-family: "Source Code Pro", Consolas, monospace
}

code {
    padding: 2px 4px;
    font-size: 90%;
    color: #c7254e;
    background-color: #f9f2f4;
    white-space: nowrap;
    border-radius: 3px
}

kbd {
    padding: 2px 4px;
    font-size: 90%;
    color: #fff;
    background-color: #333;
    border-radius: 2px;
    box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25)
}

pre {
    display: block;
    padding: 9.5px;
    margin: 0 0 10px;
    font-size: 13px;
    line-height: 1.42857;
    word-break: break-all;
    word-wrap: break-word;
    color: #333;
    background-color: #f5f5f5;
    border: 1px solid #ccc;
    border-radius: 3px
}

pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    white-space: pre-wrap;
    background-color: transparent;
    border-radius: 0
}

.pre-scrollable {
    max-height: 340px;
    overflow-y: scroll
}

.container {
    margin-right: auto;
    margin-left: auto;
    padding-left: 10px;
    padding-right: 10px
}

.container:before, .container:after {
    content: " ";
    display: table
}

.container:after {
    clear: both
}

@media (min-width: 768px) {
    .container {
        width: 740px
    }
}

@media (min-width: 992px) {
    .container {
        width: 960px
    }
}

@media (min-width: 1200px) {
    .container {
        width: 1160px
    }
}

.container-fluid {
    margin-right: auto;
    margin-left: auto;
    padding-left: 10px;
    padding-right: 10px
}

.container-fluid:before, .container-fluid:after {
    content: " ";
    display: table
}

.container-fluid:after {
    clear: both
}

.row, .flexrow {
    margin-left: -10px;
    margin-right: -10px
}

.row:before, .flexrow:before, .row:after, .flexrow:after {
    content: " ";
    display: table
}

.row:after, .flexrow:after {
    clear: both
}

.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, .col-lg-5, .col-xs-6, .col-sm-6, .flexcol-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
    position: relative;
    min-height: 1px;
    padding-left: 10px;
    padding-right: 10px
}

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
    float: left
}

.col-xs-1 {
    width: 8.33333%
}

.col-xs-2 {
    width: 16.66667%
}

.col-xs-3 {
    width: 25%
}

.col-xs-4 {
    width: 33.33333%
}

.col-xs-5 {
    width: 41.66667%
}

.col-xs-6 {
    width: 50%
}

.col-xs-7 {
    width: 58.33333%
}

.col-xs-8 {
    width: 66.66667%
}

.col-xs-9 {
    width: 75%
}

.col-xs-10 {
    width: 83.33333%
}

.col-xs-11 {
    width: 91.66667%
}

.col-xs-12 {
    width: 100%
}

.col-xs-pull-0 {
    right: 0%
}

.col-xs-pull-1 {
    right: 8.33333%
}

.col-xs-pull-2 {
    right: 16.66667%
}

.col-xs-pull-3 {
    right: 25%
}

.col-xs-pull-4 {
    right: 33.33333%
}

.col-xs-pull-5 {
    right: 41.66667%
}

.col-xs-pull-6 {
    right: 50%
}

.col-xs-pull-7 {
    right: 58.33333%
}

.col-xs-pull-8 {
    right: 66.66667%
}

.col-xs-pull-9 {
    right: 75%
}

.col-xs-pull-10 {
    right: 83.33333%
}

.col-xs-pull-11 {
    right: 91.66667%
}

.col-xs-pull-12 {
    right: 100%
}

.col-xs-push-0 {
    left: 0%
}

.col-xs-push-1 {
    left: 8.33333%
}

.col-xs-push-2 {
    left: 16.66667%
}

.col-xs-push-3 {
    left: 25%
}

.col-xs-push-4 {
    left: 33.33333%
}

.col-xs-push-5 {
    left: 41.66667%
}

.col-xs-push-6 {
    left: 50%
}

.col-xs-push-7 {
    left: 58.33333%
}

.col-xs-push-8 {
    left: 66.66667%
}

.col-xs-push-9 {
    left: 75%
}

.col-xs-push-10 {
    left: 83.33333%
}

.col-xs-push-11 {
    left: 91.66667%
}

.col-xs-push-12 {
    left: 100%
}

.col-xs-offset-0 {
    margin-left: 0%
}

.col-xs-offset-1 {
    margin-left: 8.33333%
}

.col-xs-offset-2 {
    margin-left: 16.66667%
}

.col-xs-offset-3 {
    margin-left: 25%
}

.col-xs-offset-4 {
    margin-left: 33.33333%
}

.col-xs-offset-5 {
    margin-left: 41.66667%
}

.col-xs-offset-6 {
    margin-left: 50%
}

.col-xs-offset-7 {
    margin-left: 58.33333%
}

.col-xs-offset-8 {
    margin-left: 66.66667%
}

.col-xs-offset-9 {
    margin-left: 75%
}

.col-xs-offset-10 {
    margin-left: 83.33333%
}

.col-xs-offset-11 {
    margin-left: 91.66667%
}

.col-xs-offset-12 {
    margin-left: 100%
}

@media (min-width: 768px) {
    .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .flexcol-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
        float: left
    }

    .col-sm-1 {
        width: 8.33333%
    }

    .col-sm-2 {
        width: 16.66667%
    }

    .col-sm-3 {
        width: 25%
    }

    .col-sm-4 {
        width: 33.33333%
    }

    .col-sm-5 {
        width: 41.66667%
    }

    .col-sm-6, .flexcol-sm-6 {
        width: 50%
    }

    .col-sm-7 {
        width: 58.33333%
    }

    .col-sm-8 {
        width: 66.66667%
    }

    .col-sm-9 {
        width: 75%
    }

    .col-sm-10 {
        width: 83.33333%
    }

    .col-sm-11 {
        width: 91.66667%
    }

    .col-sm-12 {
        width: 100%
    }

    .col-sm-pull-0 {
        right: 0%
    }

    .col-sm-pull-1 {
        right: 8.33333%
    }

    .col-sm-pull-2 {
        right: 16.66667%
    }

    .col-sm-pull-3 {
        right: 25%
    }

    .col-sm-pull-4 {
        right: 33.33333%
    }

    .col-sm-pull-5 {
        right: 41.66667%
    }

    .col-sm-pull-6 {
        right: 50%
    }

    .col-sm-pull-7 {
        right: 58.33333%
    }

    .col-sm-pull-8 {
        right: 66.66667%
    }

    .col-sm-pull-9 {
        right: 75%
    }

    .col-sm-pull-10 {
        right: 83.33333%
    }

    .col-sm-pull-11 {
        right: 91.66667%
    }

    .col-sm-pull-12 {
        right: 100%
    }

    .col-sm-push-0 {
        left: 0%
    }

    .col-sm-push-1 {
        left: 8.33333%
    }

    .col-sm-push-2 {
        left: 16.66667%
    }

    .col-sm-push-3 {
        left: 25%
    }

    .col-sm-push-4 {
        left: 33.33333%
    }

    .col-sm-push-5 {
        left: 41.66667%
    }

    .col-sm-push-6 {
        left: 50%
    }

    .col-sm-push-7 {
        left: 58.33333%
    }

    .col-sm-push-8 {
        left: 66.66667%
    }

    .col-sm-push-9 {
        left: 75%
    }

    .col-sm-push-10 {
        left: 83.33333%
    }

    .col-sm-push-11 {
        left: 91.66667%
    }

    .col-sm-push-12 {
        left: 100%
    }

    .col-sm-offset-0 {
        margin-left: 0%
    }

    .col-sm-offset-1 {
        margin-left: 8.33333%
    }

    .col-sm-offset-2 {
        margin-left: 16.66667%
    }

    .col-sm-offset-3 {
        margin-left: 25%
    }

    .col-sm-offset-4 {
        margin-left: 33.33333%
    }

    .col-sm-offset-5 {
        margin-left: 41.66667%
    }

    .col-sm-offset-6 {
        margin-left: 50%
    }

    .col-sm-offset-7 {
        margin-left: 58.33333%
    }

    .col-sm-offset-8 {
        margin-left: 66.66667%
    }

    .col-sm-offset-9 {
        margin-left: 75%
    }

    .col-sm-offset-10 {
        margin-left: 83.33333%
    }

    .col-sm-offset-11 {
        margin-left: 91.66667%
    }

    .col-sm-offset-12 {
        margin-left: 100%
    }
}

@media (min-width: 992px) {
    .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
        float: left
    }

    .col-md-1 {
        width: 8.33333%
    }

    .col-md-2 {
        width: 16.66667%
    }

    .col-md-3 {
        width: 25%
    }

    .col-md-4 {
        width: 33.33333%
    }

    .col-md-5 {
        width: 41.66667%
    }

    .col-md-6 {
        width: 50%
    }

    .col-md-7 {
        width: 58.33333%
    }

    .col-md-8 {
        width: 66.66667%
    }

    .col-md-9 {
        width: 75%
    }

    .col-md-10 {
        width: 83.33333%
    }

    .col-md-11 {
        width: 91.66667%
    }

    .col-md-12 {
        width: 100%
    }

    .col-md-pull-0 {
        right: 0%
    }

    .col-md-pull-1 {
        right: 8.33333%
    }

    .col-md-pull-2 {
        right: 16.66667%
    }

    .col-md-pull-3 {
        right: 25%
    }

    .col-md-pull-4 {
        right: 33.33333%
    }

    .col-md-pull-5 {
        right: 41.66667%
    }

    .col-md-pull-6 {
        right: 50%
    }

    .col-md-pull-7 {
        right: 58.33333%
    }

    .col-md-pull-8 {
        right: 66.66667%
    }

    .col-md-pull-9 {
        right: 75%
    }

    .col-md-pull-10 {
        right: 83.33333%
    }

    .col-md-pull-11 {
        right: 91.66667%
    }

    .col-md-pull-12 {
        right: 100%
    }

    .col-md-push-0 {
        left: 0%
    }

    .col-md-push-1 {
        left: 8.33333%
    }

    .col-md-push-2 {
        left: 16.66667%
    }

    .col-md-push-3 {
        left: 25%
    }

    .col-md-push-4 {
        left: 33.33333%
    }

    .col-md-push-5 {
        left: 41.66667%
    }

    .col-md-push-6 {
        left: 50%
    }

    .col-md-push-7 {
        left: 58.33333%
    }

    .col-md-push-8 {
        left: 66.66667%
    }

    .col-md-push-9 {
        left: 75%
    }

    .col-md-push-10 {
        left: 83.33333%
    }

    .col-md-push-11 {
        left: 91.66667%
    }

    .col-md-push-12 {
        left: 100%
    }

    .col-md-offset-0 {
        margin-left: 0%
    }

    .col-md-offset-1 {
        margin-left: 8.33333%
    }

    .col-md-offset-2 {
        margin-left: 16.66667%
    }

    .col-md-offset-3 {
        margin-left: 25%
    }

    .col-md-offset-4 {
        margin-left: 33.33333%
    }

    .col-md-offset-5 {
        margin-left: 41.66667%
    }

    .col-md-offset-6 {
        margin-left: 50%
    }

    .col-md-offset-7 {
        margin-left: 58.33333%
    }

    .col-md-offset-8 {
        margin-left: 66.66667%
    }

    .col-md-offset-9 {
        margin-left: 75%
    }

    .col-md-offset-10 {
        margin-left: 83.33333%
    }

    .col-md-offset-11 {
        margin-left: 91.66667%
    }

    .col-md-offset-12 {
        margin-left: 100%
    }
}

@media (min-width: 1200px) {
    .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
        float: left
    }

    .col-lg-1 {
        width: 8.33333%
    }

    .col-lg-2 {
        width: 16.66667%
    }

    .col-lg-3 {
        width: 25%
    }

    .col-lg-4 {
        width: 33.33333%
    }

    .col-lg-5 {
        width: 41.66667%
    }

    .col-lg-6 {
        width: 50%
    }

    .col-lg-7 {
        width: 58.33333%
    }

    .col-lg-8 {
        width: 66.66667%
    }

    .col-lg-9 {
        width: 75%
    }

    .col-lg-10 {
        width: 83.33333%
    }

    .col-lg-11 {
        width: 91.66667%
    }

    .col-lg-12 {
        width: 100%
    }

    .col-lg-pull-0 {
        right: 0%
    }

    .col-lg-pull-1 {
        right: 8.33333%
    }

    .col-lg-pull-2 {
        right: 16.66667%
    }

    .col-lg-pull-3 {
        right: 25%
    }

    .col-lg-pull-4 {
        right: 33.33333%
    }

    .col-lg-pull-5 {
        right: 41.66667%
    }

    .col-lg-pull-6 {
        right: 50%
    }

    .col-lg-pull-7 {
        right: 58.33333%
    }

    .col-lg-pull-8 {
        right: 66.66667%
    }

    .col-lg-pull-9 {
        right: 75%
    }

    .col-lg-pull-10 {
        right: 83.33333%
    }

    .col-lg-pull-11 {
        right: 91.66667%
    }

    .col-lg-pull-12 {
        right: 100%
    }

    .col-lg-push-0 {
        left: 0%
    }

    .col-lg-push-1 {
        left: 8.33333%
    }

    .col-lg-push-2 {
        left: 16.66667%
    }

    .col-lg-push-3 {
        left: 25%
    }

    .col-lg-push-4 {
        left: 33.33333%
    }

    .col-lg-push-5 {
        left: 41.66667%
    }

    .col-lg-push-6 {
        left: 50%
    }

    .col-lg-push-7 {
        left: 58.33333%
    }

    .col-lg-push-8 {
        left: 66.66667%
    }

    .col-lg-push-9 {
        left: 75%
    }

    .col-lg-push-10 {
        left: 83.33333%
    }

    .col-lg-push-11 {
        left: 91.66667%
    }

    .col-lg-push-12 {
        left: 100%
    }

    .col-lg-offset-0 {
        margin-left: 0%
    }

    .col-lg-offset-1 {
        margin-left: 8.33333%
    }

    .col-lg-offset-2 {
        margin-left: 16.66667%
    }

    .col-lg-offset-3 {
        margin-left: 25%
    }

    .col-lg-offset-4 {
        margin-left: 33.33333%
    }

    .col-lg-offset-5 {
        margin-left: 41.66667%
    }

    .col-lg-offset-6 {
        margin-left: 50%
    }

    .col-lg-offset-7 {
        margin-left: 58.33333%
    }

    .col-lg-offset-8 {
        margin-left: 66.66667%
    }

    .col-lg-offset-9 {
        margin-left: 75%
    }

    .col-lg-offset-10 {
        margin-left: 83.33333%
    }

    .col-lg-offset-11 {
        margin-left: 91.66667%
    }

    .col-lg-offset-12 {
        margin-left: 100%
    }
}


.table {
    width: 100%;
    margin-bottom: 20px
}

.table > thead > tr > th, .table > thead > tr > td, .table > tbody > tr > th, .table > tbody > tr > td, .table > tfoot > tr > th, .table > tfoot > tr > td {
    padding: 8px;
    line-height: 1.42857;
    vertical-align: top
}

.table > thead > tr > th {
    vertical-align: bottom;
    border-bottom: 2px solid #ddd
}

.table > caption + thead > tr:first-child > th, .table > caption + thead > tr:first-child > td, .table > colgroup + thead > tr:first-child > th, .table > colgroup + thead > tr:first-child > td, .table > thead:first-child > tr:first-child > th, .table > thead:first-child > tr:first-child > td {
    border-top: 0
}

.table .table {
    background-color: #fff
}

.table-condensed > thead > tr > th, .table-condensed > thead > tr > td, .table-condensed > tbody > tr > th, .table-condensed > tbody > tr > td, .table-condensed > tfoot > tr > th, .table-condensed > tfoot > tr > td {
    padding: 5px
}

.table-bordered {
    border: 1px solid #ddd
}

.table-bordered > thead > tr > th, .table-bordered > thead > tr > td, .table-bordered > tbody > tr > th, .table-bordered > tbody > tr > td, .table-bordered > tfoot > tr > th, .table-bordered > tfoot > tr > td {
    border: 1px solid #ddd
}

.table-bordered > thead > tr > th, .table-bordered > thead > tr > td {
    border-bottom-width: 2px
}

.table-striped > tbody > tr:nth-child(odd) > td, .table-striped > tbody > tr:nth-child(odd) > th {
    background-color: #f9f9f9
}

.table-hover > tbody > tr:hover > td, .table-hover > tbody > tr:hover > th {
    background-color: #f5f5f5
}

table col[class*="col-"] {
    position: static;
    float: none;
    display: table-column
}

table td[class*="col-"], table th[class*="col-"] {
    position: static;
    float: none;
    display: table-cell
}

.table > thead > tr > td.active, .table > thead > tr > th.active, .table > thead > tr.active > td, .table > thead > tr.active > th, .table > tbody > tr > td.active, .table > tbody > tr > th.active, .table > tbody > tr.active > td, .table > tbody > tr.active > th, .table > tfoot > tr > td.active, .table > tfoot > tr > th.active, .table > tfoot > tr.active > td, .table > tfoot > tr.active > th {
    background-color: #f5f5f5
}

.table-hover > tbody > tr > td.active:hover, .table-hover > tbody > tr > th.active:hover, .table-hover > tbody > tr.active:hover > td, .table-hover > tbody > tr.active:hover > th {
    background-color: #e8e8e8
}

.table > thead > tr > td.success, .table > thead > tr > th.success, .table > thead > tr.success > td, .table > thead > tr.success > th, .table > tbody > tr > td.success, .table > tbody > tr > th.success, .table > tbody > tr.success > td, .table > tbody > tr.success > th, .table > tfoot > tr > td.success, .table > tfoot > tr > th.success, .table > tfoot > tr.success > td, .table > tfoot > tr.success > th {
    background-color: #dff0d8
}

.table-hover > tbody > tr > td.success:hover, .table-hover > tbody > tr > th.success:hover, .table-hover > tbody > tr.success:hover > td, .table-hover > tbody > tr.success:hover > th {
    background-color: #d0e9c6
}

.table > thead > tr > td.info, .table > thead > tr > th.info, .table > thead > tr.info > td, .table > thead > tr.info > th, .table > tbody > tr > td.info, .table > tbody > tr > th.info, .table > tbody > tr.info > td, .table > tbody > tr.info > th, .table > tfoot > tr > td.info, .table > tfoot > tr > th.info, .table > tfoot > tr.info > td, .table > tfoot > tr.info > th {
    background-color: #d9edf7
}

.table-hover > tbody > tr > td.info:hover, .table-hover > tbody > tr > th.info:hover, .table-hover > tbody > tr.info:hover > td, .table-hover > tbody > tr.info:hover > th {
    background-color: #c4e3f3
}

.table > thead > tr > td.warning, .table > thead > tr > th.warning, .table > thead > tr.warning > td, .table > thead > tr.warning > th, .table > tbody > tr > td.warning, .table > tbody > tr > th.warning, .table > tbody > tr.warning > td, .table > tbody > tr.warning > th, .table > tfoot > tr > td.warning, .table > tfoot > tr > th.warning, .table > tfoot > tr.warning > td, .table > tfoot > tr.warning > th {
    background-color: #fcf8e3
}

.table-hover > tbody > tr > td.warning:hover, .table-hover > tbody > tr > th.warning:hover, .table-hover > tbody > tr.warning:hover > td, .table-hover > tbody > tr.warning:hover > th {
    background-color: #faf2cc
}

.table > thead > tr > td.danger, .table > thead > tr > th.danger, .table > thead > tr.danger > td, .table > thead > tr.danger > th, .table > tbody > tr > td.danger, .table > tbody > tr > th.danger, .table > tbody > tr.danger > td, .table > tbody > tr.danger > th, .table > tfoot > tr > td.danger, .table > tfoot > tr > th.danger, .table > tfoot > tr.danger > td, .table > tfoot > tr.danger > th {
    background-color: #f2dede
}

.table-hover > tbody > tr > td.danger:hover, .table-hover > tbody > tr > th.danger:hover, .table-hover > tbody > tr.danger:hover > td, .table-hover > tbody > tr.danger:hover > th {
    background-color: #ebcccc
}

@media (max-width: 767px) {
    .table-responsive {
        width: 100%;
        margin-bottom: 15px;
        overflow-y: hidden;
        overflow-x: scroll;
        -ms-overflow-style: -ms-autohiding-scrollbar;
        border: 1px solid #ddd;
        -webkit-overflow-scrolling: touch
    }

    .table-responsive > .table {
        margin-bottom: 0
    }

    .table-responsive > .table > thead > tr > th, .table-responsive > .table > thead > tr > td, .table-responsive > .table > tbody > tr > th, .table-responsive > .table > tbody > tr > td, .table-responsive > .table > tfoot > tr > th, .table-responsive > .table > tfoot > tr > td {
        white-space: nowrap
    }

    .table-responsive > .table-bordered {
        border: 0
    }

    .table-responsive > .table-bordered > thead > tr > th:first-child, .table-responsive > .table-bordered > thead > tr > td:first-child, .table-responsive > .table-bordered > tbody > tr > th:first-child, .table-responsive > .table-bordered > tbody > tr > td:first-child, .table-responsive > .table-bordered > tfoot > tr > th:first-child, .table-responsive > .table-bordered > tfoot > tr > td:first-child {
        border-left: 0
    }

    .table-responsive > .table-bordered > thead > tr > th:last-child, .table-responsive > .table-bordered > thead > tr > td:last-child, .table-responsive > .table-bordered > tbody > tr > th:last-child, .table-responsive > .table-bordered > tbody > tr > td:last-child, .table-responsive > .table-bordered > tfoot > tr > th:last-child, .table-responsive > .table-bordered > tfoot > tr > td:last-child {
        border-right: 0
    }

    .table-responsive > .table-bordered > tbody > tr:last-child > th, .table-responsive > .table-bordered > tbody > tr:last-child > td, .table-responsive > .table-bordered > tfoot > tr:last-child > th, .table-responsive > .table-bordered > tfoot > tr:last-child > td {
        border-bottom: 0
    }
}

fieldset {
    padding: 0;
    margin: 0;
    border: 0;
    min-width: 0
}

legend {
    display: block;
    width: 100%;
    padding: 0;
    margin-bottom: 20px;
    font-size: 21px;
    line-height: inherit;
    color: #333;
    border: 0;
    border-bottom: 1px solid #e5e5e5
}

label {
    display: inline-block;
    margin-bottom: 5px;
    font-weight: bold
}

input[type="search"] {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}

input[type="radio"], input[type="checkbox"] {
    margin: 4px 0 0;
    margin-top: 1px \9;
    line-height: normal
}

input[type="file"] {
    display: block
}

input[type="range"] {
    display: block;
    width: 100%
}

select[multiple], select[size] {
    height: auto
}

input[type="file"]:focus, input[type="radio"]:focus, input[type="checkbox"]:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

output {
    display: block;
    padding-top: 7px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555
}

.form-control, .rf-Field textarea, .rf-Field input[type="text"], .rf-Field input[type="password"], .rf-Field input[type="datetime"], .rf-Field input[type="datetime-local"], .rf-Field input[type="date"], .rf-Field input[type="month"], .rf-Field input[type="time"], .rf-Field input[type="week"], .rf-Field input[type="number"], .rf-Field input[type="email"], .rf-Field input[type="url"], .rf-Field input[type="search"], .rf-Field input[type="tel"], .rf-Field input[type="color"], .dropzone, .item-picker {
    display: block;
    width: 100%;
    height: 34px;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555;
    background-color: #fff;
    background-image: none;
    border: 1px solid #ccc;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s
}

.form-control:focus, .rf-Field textarea:focus, .rf-Field input[type="text"]:focus, .rf-Field input[type="password"]:focus, .rf-Field input[type="datetime"]:focus, .rf-Field input[type="datetime-local"]:focus, .rf-Field input[type="date"]:focus, .rf-Field input[type="month"]:focus, .rf-Field input[type="time"]:focus, .rf-Field input[type="week"]:focus, .rf-Field input[type="number"]:focus, .rf-Field input[type="email"]:focus, .rf-Field input[type="url"]:focus, .rf-Field input[type="search"]:focus, .rf-Field input[type="tel"]:focus, .rf-Field input[type="color"]:focus, .dropzone:focus, .item-picker:focus {
    border-color: #66afe9;
    outline: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6)
}

.form-control::-moz-placeholder, .rf-Field textarea::-moz-placeholder, .rf-Field input[type="text"]::-moz-placeholder, .rf-Field input[type="password"]::-moz-placeholder, .rf-Field input[type="datetime"]::-moz-placeholder, .rf-Field input[type="datetime-local"]::-moz-placeholder, .rf-Field input[type="date"]::-moz-placeholder, .rf-Field input[type="month"]::-moz-placeholder, .rf-Field input[type="time"]::-moz-placeholder, .rf-Field input[type="week"]::-moz-placeholder, .rf-Field input[type="number"]::-moz-placeholder, .rf-Field input[type="email"]::-moz-placeholder, .rf-Field input[type="url"]::-moz-placeholder, .rf-Field input[type="search"]::-moz-placeholder, .rf-Field input[type="tel"]::-moz-placeholder, .rf-Field input[type="color"]::-moz-placeholder, .dropzone::-moz-placeholder, .item-picker::-moz-placeholder {
    color: #999;
    opacity: 1
}

.form-control:-ms-input-placeholder, .rf-Field textarea:-ms-input-placeholder, .rf-Field input[type="text"]:-ms-input-placeholder, .rf-Field input[type="password"]:-ms-input-placeholder, .rf-Field input[type="datetime"]:-ms-input-placeholder, .rf-Field input[type="datetime-local"]:-ms-input-placeholder, .rf-Field input[type="date"]:-ms-input-placeholder, .rf-Field input[type="month"]:-ms-input-placeholder, .rf-Field input[type="time"]:-ms-input-placeholder, .rf-Field input[type="week"]:-ms-input-placeholder, .rf-Field input[type="number"]:-ms-input-placeholder, .rf-Field input[type="email"]:-ms-input-placeholder, .rf-Field input[type="url"]:-ms-input-placeholder, .rf-Field input[type="search"]:-ms-input-placeholder, .rf-Field input[type="tel"]:-ms-input-placeholder, .rf-Field input[type="color"]:-ms-input-placeholder, .dropzone:-ms-input-placeholder, .item-picker:-ms-input-placeholder {
    color: #999
}

.form-control::-webkit-input-placeholder, .rf-Field textarea::-webkit-input-placeholder, .rf-Field input[type="text"]::-webkit-input-placeholder, .rf-Field input[type="password"]::-webkit-input-placeholder, .rf-Field input[type="datetime"]::-webkit-input-placeholder, .rf-Field input[type="datetime-local"]::-webkit-input-placeholder, .rf-Field input[type="date"]::-webkit-input-placeholder, .rf-Field input[type="month"]::-webkit-input-placeholder, .rf-Field input[type="time"]::-webkit-input-placeholder, .rf-Field input[type="week"]::-webkit-input-placeholder, .rf-Field input[type="number"]::-webkit-input-placeholder, .rf-Field input[type="email"]::-webkit-input-placeholder, .rf-Field input[type="url"]::-webkit-input-placeholder, .rf-Field input[type="search"]::-webkit-input-placeholder, .rf-Field input[type="tel"]::-webkit-input-placeholder, .rf-Field input[type="color"]::-webkit-input-placeholder, .dropzone::-webkit-input-placeholder, .item-picker::-webkit-input-placeholder {
    color: #999
}

.form-control[disabled], .rf-Field textarea[disabled], .rf-Field input[disabled][type="text"], .rf-Field input[disabled][type="password"], .rf-Field input[disabled][type="datetime"], .rf-Field input[disabled][type="datetime-local"], .rf-Field input[disabled][type="date"], .rf-Field input[disabled][type="month"], .rf-Field input[disabled][type="time"], .rf-Field input[disabled][type="week"], .rf-Field input[disabled][type="number"], .rf-Field input[disabled][type="email"], .rf-Field input[disabled][type="url"], .rf-Field input[disabled][type="search"], .rf-Field input[disabled][type="tel"], .rf-Field input[disabled][type="color"], [disabled].dropzone, [disabled].item-picker, .form-control[readonly], .rf-Field textarea[readonly], .rf-Field input[readonly][type="text"], .rf-Field input[readonly][type="password"], .rf-Field input[readonly][type="datetime"], .rf-Field input[readonly][type="datetime-local"], .rf-Field input[readonly][type="date"], .rf-Field input[readonly][type="month"], .rf-Field input[readonly][type="time"], .rf-Field input[readonly][type="week"], .rf-Field input[readonly][type="number"], .rf-Field input[readonly][type="email"], .rf-Field input[readonly][type="url"], .rf-Field input[readonly][type="search"], .rf-Field input[readonly][type="tel"], .rf-Field input[readonly][type="color"], [readonly].dropzone, [readonly].item-picker, fieldset[disabled] .form-control, fieldset[disabled] .rf-Field textarea, .rf-Field fieldset[disabled] textarea, fieldset[disabled] .rf-Field input[type="text"], .rf-Field fieldset[disabled] input[type="text"], fieldset[disabled] .rf-Field input[type="password"], .rf-Field fieldset[disabled] input[type="password"], fieldset[disabled] .rf-Field input[type="datetime"], .rf-Field fieldset[disabled] input[type="datetime"], fieldset[disabled] .rf-Field input[type="datetime-local"], .rf-Field fieldset[disabled] input[type="datetime-local"], fieldset[disabled] .rf-Field input[type="date"], .rf-Field fieldset[disabled] input[type="date"], fieldset[disabled] .rf-Field input[type="month"], .rf-Field fieldset[disabled] input[type="month"], fieldset[disabled] .rf-Field input[type="time"], .rf-Field fieldset[disabled] input[type="time"], fieldset[disabled] .rf-Field input[type="week"], .rf-Field fieldset[disabled] input[type="week"], fieldset[disabled] .rf-Field input[type="number"], .rf-Field fieldset[disabled] input[type="number"], fieldset[disabled] .rf-Field input[type="email"], .rf-Field fieldset[disabled] input[type="email"], fieldset[disabled] .rf-Field input[type="url"], .rf-Field fieldset[disabled] input[type="url"], fieldset[disabled] .rf-Field input[type="search"], .rf-Field fieldset[disabled] input[type="search"], fieldset[disabled] .rf-Field input[type="tel"], .rf-Field fieldset[disabled] input[type="tel"], fieldset[disabled] .rf-Field input[type="color"], .rf-Field fieldset[disabled] input[type="color"], fieldset[disabled] .dropzone, fieldset[disabled] .item-picker {
    cursor: not-allowed;
    background-color: #eee;
    opacity: 1
}

textarea.form-control, .rf-Field textarea, textarea.dropzone, textarea.item-picker {
    height: auto
}

input[type="search"] {
    -webkit-appearance: none
}

input[type="date"] {
    line-height: 34px
}

.form-group, .rf-Field, .rf-Fieldset, .rf-RepeatingFieldset, .rf-RepeatingFieldset__item {
    margin-bottom: 15px
}

.radio, .checkbox {
    display: block;
    min-height: 20px;
    margin-top: 10px;
    margin-bottom: 10px;
    padding-left: 20px
}

.radio label, .checkbox label {
    display: inline;
    font-weight: normal;
    cursor: pointer
}

.radio.disabled label, .checkbox.disabled label {
    cursor: not-allowed
}

.radio input[type="radio"], .radio-inline input[type="radio"], .checkbox input[type="checkbox"], .checkbox-inline input[type="checkbox"] {
    float: left;
    margin-left: -20px
}

.radio + .radio, .checkbox + .checkbox {
    margin-top: -5px
}

.radio-inline, .checkbox-inline {
    display: inline-block;
    padding-left: 20px;
    margin-bottom: 0;
    vertical-align: middle;
    font-weight: normal;
    cursor: pointer
}

.radio-inline + .radio-inline, .checkbox-inline + .checkbox-inline {
    margin-top: 0;
    margin-left: 10px
}

input[type="radio"][disabled], fieldset[disabled] input[type="radio"], input[type="checkbox"][disabled], fieldset[disabled] input[type="checkbox"], .radio[disabled], fieldset[disabled] .radio, .radio-inline[disabled], fieldset[disabled] .radio-inline, .checkbox[disabled], fieldset[disabled] .checkbox, .checkbox-inline[disabled], fieldset[disabled] .checkbox-inline {
    cursor: not-allowed
}

.input-sm, .input-group-sm > .form-control, .rf-Field .input-group-sm > textarea, .rf-Field .input-group-sm > input[type="text"], .rf-Field .input-group-sm > input[type="password"], .rf-Field .input-group-sm > input[type="datetime"], .rf-Field .input-group-sm > input[type="datetime-local"], .rf-Field .input-group-sm > input[type="date"], .rf-Field .input-group-sm > input[type="month"], .rf-Field .input-group-sm > input[type="time"], .rf-Field .input-group-sm > input[type="week"], .rf-Field .input-group-sm > input[type="number"], .rf-Field .input-group-sm > input[type="email"], .rf-Field .input-group-sm > input[type="url"], .rf-Field .input-group-sm > input[type="search"], .rf-Field .input-group-sm > input[type="tel"], .rf-Field .input-group-sm > input[type="color"], .input-group-sm > .dropzone, .input-group-sm > .item-picker, .input-group-sm > .input-group-addon, .input-group-sm > .input-group-btn > .btn, .input-group-sm > .input-group-btn > .rf-RepeatingFieldset__add {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 2px
}

select.input-sm, .input-group-sm > select.form-control, .input-group-sm > select.dropzone, .input-group-sm > select.item-picker, .input-group-sm > select.input-group-addon, .input-group-sm > .input-group-btn > select.btn, .input-group-sm > .input-group-btn > select.rf-RepeatingFieldset__add {
    height: 30px;
    line-height: 30px
}

textarea.input-sm, .input-group-sm > textarea.form-control, .rf-Field .input-group-sm > textarea, .input-group-sm > textarea.dropzone, .input-group-sm > textarea.item-picker, .input-group-sm > textarea.input-group-addon, .input-group-sm > .input-group-btn > textarea.btn, .input-group-sm > .input-group-btn > textarea.rf-RepeatingFieldset__add, select[multiple].input-sm, .input-group-sm > select[multiple].form-control, .input-group-sm > select[multiple].dropzone, .input-group-sm > select[multiple].item-picker, .input-group-sm > select[multiple].input-group-addon, .input-group-sm > .input-group-btn > select[multiple].btn, .input-group-sm > .input-group-btn > select[multiple].rf-RepeatingFieldset__add {
    height: auto
}

.input-lg, .input-group-lg > .form-control, .rf-Field .input-group-lg > textarea, .rf-Field .input-group-lg > input[type="text"], .rf-Field .input-group-lg > input[type="password"], .rf-Field .input-group-lg > input[type="datetime"], .rf-Field .input-group-lg > input[type="datetime-local"], .rf-Field .input-group-lg > input[type="date"], .rf-Field .input-group-lg > input[type="month"], .rf-Field .input-group-lg > input[type="time"], .rf-Field .input-group-lg > input[type="week"], .rf-Field .input-group-lg > input[type="number"], .rf-Field .input-group-lg > input[type="email"], .rf-Field .input-group-lg > input[type="url"], .rf-Field .input-group-lg > input[type="search"], .rf-Field .input-group-lg > input[type="tel"], .rf-Field .input-group-lg > input[type="color"], .input-group-lg > .dropzone, .input-group-lg > .item-picker, .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .btn, .input-group-lg > .input-group-btn > .rf-RepeatingFieldset__add {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33;
    border-radius: 4px
}

select.input-lg, .input-group-lg > select.form-control, .input-group-lg > select.dropzone, .input-group-lg > select.item-picker, .input-group-lg > select.input-group-addon, .input-group-lg > .input-group-btn > select.btn, .input-group-lg > .input-group-btn > select.rf-RepeatingFieldset__add {
    height: 46px;
    line-height: 46px
}

textarea.input-lg, .input-group-lg > textarea.form-control, .rf-Field .input-group-lg > textarea, .input-group-lg > textarea.dropzone, .input-group-lg > textarea.item-picker, .input-group-lg > textarea.input-group-addon, .input-group-lg > .input-group-btn > textarea.btn, .input-group-lg > .input-group-btn > textarea.rf-RepeatingFieldset__add, select[multiple].input-lg, .input-group-lg > select[multiple].form-control, .input-group-lg > select[multiple].dropzone, .input-group-lg > select[multiple].item-picker, .input-group-lg > select[multiple].input-group-addon, .input-group-lg > .input-group-btn > select[multiple].btn, .input-group-lg > .input-group-btn > select[multiple].rf-RepeatingFieldset__add {
    height: auto
}

.has-feedback {
    position: relative
}

.has-feedback .form-control, .has-feedback .rf-Field textarea, .rf-Field .has-feedback textarea, .has-feedback .rf-Field input[type="text"], .rf-Field .has-feedback input[type="text"], .has-feedback .rf-Field input[type="password"], .rf-Field .has-feedback input[type="password"], .has-feedback .rf-Field input[type="datetime"], .rf-Field .has-feedback input[type="datetime"], .has-feedback .rf-Field input[type="datetime-local"], .rf-Field .has-feedback input[type="datetime-local"], .has-feedback .rf-Field input[type="date"], .rf-Field .has-feedback input[type="date"], .has-feedback .rf-Field input[type="month"], .rf-Field .has-feedback input[type="month"], .has-feedback .rf-Field input[type="time"], .rf-Field .has-feedback input[type="time"], .has-feedback .rf-Field input[type="week"], .rf-Field .has-feedback input[type="week"], .has-feedback .rf-Field input[type="number"], .rf-Field .has-feedback input[type="number"], .has-feedback .rf-Field input[type="email"], .rf-Field .has-feedback input[type="email"], .has-feedback .rf-Field input[type="url"], .rf-Field .has-feedback input[type="url"], .has-feedback .rf-Field input[type="search"], .rf-Field .has-feedback input[type="search"], .has-feedback .rf-Field input[type="tel"], .rf-Field .has-feedback input[type="tel"], .has-feedback .rf-Field input[type="color"], .rf-Field .has-feedback input[type="color"], .has-feedback .dropzone, .has-feedback .item-picker {
    padding-right: 42.5px
}

.has-feedback .form-control-feedback {
    position: absolute;
    top: 25px;
    right: 0;
    display: block;
    width: 34px;
    height: 34px;
    line-height: 34px;
    text-align: center
}

.has-success .help-block, .has-success .control-label, .has-success .radio, .has-success .checkbox, .has-success .radio-inline, .has-success .checkbox-inline {
    color: #3c763d
}

.has-success .form-control, .has-success .rf-Field textarea, .rf-Field .has-success textarea, .has-success .rf-Field input[type="text"], .rf-Field .has-success input[type="text"], .has-success .rf-Field input[type="password"], .rf-Field .has-success input[type="password"], .has-success .rf-Field input[type="datetime"], .rf-Field .has-success input[type="datetime"], .has-success .rf-Field input[type="datetime-local"], .rf-Field .has-success input[type="datetime-local"], .has-success .rf-Field input[type="date"], .rf-Field .has-success input[type="date"], .has-success .rf-Field input[type="month"], .rf-Field .has-success input[type="month"], .has-success .rf-Field input[type="time"], .rf-Field .has-success input[type="time"], .has-success .rf-Field input[type="week"], .rf-Field .has-success input[type="week"], .has-success .rf-Field input[type="number"], .rf-Field .has-success input[type="number"], .has-success .rf-Field input[type="email"], .rf-Field .has-success input[type="email"], .has-success .rf-Field input[type="url"], .rf-Field .has-success input[type="url"], .has-success .rf-Field input[type="search"], .rf-Field .has-success input[type="search"], .has-success .rf-Field input[type="tel"], .rf-Field .has-success input[type="tel"], .has-success .rf-Field input[type="color"], .rf-Field .has-success input[type="color"], .has-success .dropzone, .has-success .item-picker {
    border-color: #3c763d;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075)
}

.has-success .form-control:focus, .has-success .rf-Field textarea:focus, .rf-Field .has-success textarea:focus, .has-success .rf-Field input[type="text"]:focus, .rf-Field .has-success input[type="text"]:focus, .has-success .rf-Field input[type="password"]:focus, .rf-Field .has-success input[type="password"]:focus, .has-success .rf-Field input[type="datetime"]:focus, .rf-Field .has-success input[type="datetime"]:focus, .has-success .rf-Field input[type="datetime-local"]:focus, .rf-Field .has-success input[type="datetime-local"]:focus, .has-success .rf-Field input[type="date"]:focus, .rf-Field .has-success input[type="date"]:focus, .has-success .rf-Field input[type="month"]:focus, .rf-Field .has-success input[type="month"]:focus, .has-success .rf-Field input[type="time"]:focus, .rf-Field .has-success input[type="time"]:focus, .has-success .rf-Field input[type="week"]:focus, .rf-Field .has-success input[type="week"]:focus, .has-success .rf-Field input[type="number"]:focus, .rf-Field .has-success input[type="number"]:focus, .has-success .rf-Field input[type="email"]:focus, .rf-Field .has-success input[type="email"]:focus, .has-success .rf-Field input[type="url"]:focus, .rf-Field .has-success input[type="url"]:focus, .has-success .rf-Field input[type="search"]:focus, .rf-Field .has-success input[type="search"]:focus, .has-success .rf-Field input[type="tel"]:focus, .rf-Field .has-success input[type="tel"]:focus, .has-success .rf-Field input[type="color"]:focus, .rf-Field .has-success input[type="color"]:focus, .has-success .dropzone:focus, .has-success .item-picker:focus {
    border-color: #2b542c;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168
}

.has-success .input-group-addon {
    color: #3c763d;
    border-color: #3c763d;
    background-color: #dff0d8
}

.has-success .form-control-feedback {
    color: #3c763d
}

.has-warning .help-block, .has-warning .control-label, .has-warning .radio, .has-warning .checkbox, .has-warning .radio-inline, .has-warning .checkbox-inline {
    color: #8a6d3b
}

.has-warning .form-control, .has-warning .rf-Field textarea, .rf-Field .has-warning textarea, .has-warning .rf-Field input[type="text"], .rf-Field .has-warning input[type="text"], .has-warning .rf-Field input[type="password"], .rf-Field .has-warning input[type="password"], .has-warning .rf-Field input[type="datetime"], .rf-Field .has-warning input[type="datetime"], .has-warning .rf-Field input[type="datetime-local"], .rf-Field .has-warning input[type="datetime-local"], .has-warning .rf-Field input[type="date"], .rf-Field .has-warning input[type="date"], .has-warning .rf-Field input[type="month"], .rf-Field .has-warning input[type="month"], .has-warning .rf-Field input[type="time"], .rf-Field .has-warning input[type="time"], .has-warning .rf-Field input[type="week"], .rf-Field .has-warning input[type="week"], .has-warning .rf-Field input[type="number"], .rf-Field .has-warning input[type="number"], .has-warning .rf-Field input[type="email"], .rf-Field .has-warning input[type="email"], .has-warning .rf-Field input[type="url"], .rf-Field .has-warning input[type="url"], .has-warning .rf-Field input[type="search"], .rf-Field .has-warning input[type="search"], .has-warning .rf-Field input[type="tel"], .rf-Field .has-warning input[type="tel"], .has-warning .rf-Field input[type="color"], .rf-Field .has-warning input[type="color"], .has-warning .dropzone, .has-warning .item-picker {
    border-color: #8a6d3b;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075)
}

.has-warning .form-control:focus, .has-warning .rf-Field textarea:focus, .rf-Field .has-warning textarea:focus, .has-warning .rf-Field input[type="text"]:focus, .rf-Field .has-warning input[type="text"]:focus, .has-warning .rf-Field input[type="password"]:focus, .rf-Field .has-warning input[type="password"]:focus, .has-warning .rf-Field input[type="datetime"]:focus, .rf-Field .has-warning input[type="datetime"]:focus, .has-warning .rf-Field input[type="datetime-local"]:focus, .rf-Field .has-warning input[type="datetime-local"]:focus, .has-warning .rf-Field input[type="date"]:focus, .rf-Field .has-warning input[type="date"]:focus, .has-warning .rf-Field input[type="month"]:focus, .rf-Field .has-warning input[type="month"]:focus, .has-warning .rf-Field input[type="time"]:focus, .rf-Field .has-warning input[type="time"]:focus, .has-warning .rf-Field input[type="week"]:focus, .rf-Field .has-warning input[type="week"]:focus, .has-warning .rf-Field input[type="number"]:focus, .rf-Field .has-warning input[type="number"]:focus, .has-warning .rf-Field input[type="email"]:focus, .rf-Field .has-warning input[type="email"]:focus, .has-warning .rf-Field input[type="url"]:focus, .rf-Field .has-warning input[type="url"]:focus, .has-warning .rf-Field input[type="search"]:focus, .rf-Field .has-warning input[type="search"]:focus, .has-warning .rf-Field input[type="tel"]:focus, .rf-Field .has-warning input[type="tel"]:focus, .has-warning .rf-Field input[type="color"]:focus, .rf-Field .has-warning input[type="color"]:focus, .has-warning .dropzone:focus, .has-warning .item-picker:focus {
    border-color: #66512c;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b
}

.has-warning .input-group-addon {
    color: #8a6d3b;
    border-color: #8a6d3b;
    background-color: #fcf8e3
}

.has-warning .form-control-feedback {
    color: #8a6d3b
}

.has-error .help-block, .has-error .control-label, .has-error .radio, .has-error .checkbox, .has-error .radio-inline, .has-error .checkbox-inline {
    color: #a94442
}

.has-error .form-control, .has-error .rf-Field textarea, .rf-Field .has-error textarea, .has-error .rf-Field input[type="text"], .rf-Field .has-error input[type="text"], .has-error .rf-Field input[type="password"], .rf-Field .has-error input[type="password"], .has-error .rf-Field input[type="datetime"], .rf-Field .has-error input[type="datetime"], .has-error .rf-Field input[type="datetime-local"], .rf-Field .has-error input[type="datetime-local"], .has-error .rf-Field input[type="date"], .rf-Field .has-error input[type="date"], .has-error .rf-Field input[type="month"], .rf-Field .has-error input[type="month"], .has-error .rf-Field input[type="time"], .rf-Field .has-error input[type="time"], .has-error .rf-Field input[type="week"], .rf-Field .has-error input[type="week"], .has-error .rf-Field input[type="number"], .rf-Field .has-error input[type="number"], .has-error .rf-Field input[type="email"], .rf-Field .has-error input[type="email"], .has-error .rf-Field input[type="url"], .rf-Field .has-error input[type="url"], .has-error .rf-Field input[type="search"], .rf-Field .has-error input[type="search"], .has-error .rf-Field input[type="tel"], .rf-Field .has-error input[type="tel"], .has-error .rf-Field input[type="color"], .rf-Field .has-error input[type="color"], .has-error .dropzone, .has-error .item-picker {
    border-color: #a94442;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075)
}

.has-error .form-control:focus, .has-error .rf-Field textarea:focus, .rf-Field .has-error textarea:focus, .has-error .rf-Field input[type="text"]:focus, .rf-Field .has-error input[type="text"]:focus, .has-error .rf-Field input[type="password"]:focus, .rf-Field .has-error input[type="password"]:focus, .has-error .rf-Field input[type="datetime"]:focus, .rf-Field .has-error input[type="datetime"]:focus, .has-error .rf-Field input[type="datetime-local"]:focus, .rf-Field .has-error input[type="datetime-local"]:focus, .has-error .rf-Field input[type="date"]:focus, .rf-Field .has-error input[type="date"]:focus, .has-error .rf-Field input[type="month"]:focus, .rf-Field .has-error input[type="month"]:focus, .has-error .rf-Field input[type="time"]:focus, .rf-Field .has-error input[type="time"]:focus, .has-error .rf-Field input[type="week"]:focus, .rf-Field .has-error input[type="week"]:focus, .has-error .rf-Field input[type="number"]:focus, .rf-Field .has-error input[type="number"]:focus, .has-error .rf-Field input[type="email"]:focus, .rf-Field .has-error input[type="email"]:focus, .has-error .rf-Field input[type="url"]:focus, .rf-Field .has-error input[type="url"]:focus, .has-error .rf-Field input[type="search"]:focus, .rf-Field .has-error input[type="search"]:focus, .has-error .rf-Field input[type="tel"]:focus, .rf-Field .has-error input[type="tel"]:focus, .has-error .rf-Field input[type="color"]:focus, .rf-Field .has-error input[type="color"]:focus, .has-error .dropzone:focus, .has-error .item-picker:focus {
    border-color: #843534;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483
}

.has-error .input-group-addon {
    color: #a94442;
    border-color: #a94442;
    background-color: #f2dede
}

.has-error .form-control-feedback {
    color: #a94442
}

.form-control-static {
    margin-bottom: 0
}

.help-block {
    display: block;
    margin-top: 5px;
    margin-bottom: 10px;
    color: #737373
}

@media (min-width: 768px) {
    .form-inline .form-group, .navbar-form .form-group, .form-inline .rf-Field, .navbar-form .rf-Field, .form-inline .rf-Fieldset, .navbar-form .rf-Fieldset, .form-inline .rf-RepeatingFieldset, .navbar-form .rf-RepeatingFieldset, .form-inline .rf-RepeatingFieldset__item, .navbar-form .rf-RepeatingFieldset__item {
        display: inline-block;
        margin-bottom: 0;
        vertical-align: middle
    }

    .form-inline .form-control, .navbar-form .form-control, .form-inline .rf-Field textarea, .rf-Field .form-inline textarea, .navbar-form .rf-Field textarea, .rf-Field .navbar-form textarea, .form-inline .rf-Field input[type="text"], .rf-Field .form-inline input[type="text"], .navbar-form .rf-Field input[type="text"], .rf-Field .navbar-form input[type="text"], .form-inline .rf-Field input[type="password"], .rf-Field .form-inline input[type="password"], .navbar-form .rf-Field input[type="password"], .rf-Field .navbar-form input[type="password"], .form-inline .rf-Field input[type="datetime"], .rf-Field .form-inline input[type="datetime"], .navbar-form .rf-Field input[type="datetime"], .rf-Field .navbar-form input[type="datetime"], .form-inline .rf-Field input[type="datetime-local"], .rf-Field .form-inline input[type="datetime-local"], .navbar-form .rf-Field input[type="datetime-local"], .rf-Field .navbar-form input[type="datetime-local"], .form-inline .rf-Field input[type="date"], .rf-Field .form-inline input[type="date"], .navbar-form .rf-Field input[type="date"], .rf-Field .navbar-form input[type="date"], .form-inline .rf-Field input[type="month"], .rf-Field .form-inline input[type="month"], .navbar-form .rf-Field input[type="month"], .rf-Field .navbar-form input[type="month"], .form-inline .rf-Field input[type="time"], .rf-Field .form-inline input[type="time"], .navbar-form .rf-Field input[type="time"], .rf-Field .navbar-form input[type="time"], .form-inline .rf-Field input[type="week"], .rf-Field .form-inline input[type="week"], .navbar-form .rf-Field input[type="week"], .rf-Field .navbar-form input[type="week"], .form-inline .rf-Field input[type="number"], .rf-Field .form-inline input[type="number"], .navbar-form .rf-Field input[type="number"], .rf-Field .navbar-form input[type="number"], .form-inline .rf-Field input[type="email"], .rf-Field .form-inline input[type="email"], .navbar-form .rf-Field input[type="email"], .rf-Field .navbar-form input[type="email"], .form-inline .rf-Field input[type="url"], .rf-Field .form-inline input[type="url"], .navbar-form .rf-Field input[type="url"], .rf-Field .navbar-form input[type="url"], .form-inline .rf-Field input[type="search"], .rf-Field .form-inline input[type="search"], .navbar-form .rf-Field input[type="search"], .rf-Field .navbar-form input[type="search"], .form-inline .rf-Field input[type="tel"], .rf-Field .form-inline input[type="tel"], .navbar-form .rf-Field input[type="tel"], .rf-Field .navbar-form input[type="tel"], .form-inline .rf-Field input[type="color"], .rf-Field .form-inline input[type="color"], .navbar-form .rf-Field input[type="color"], .rf-Field .navbar-form input[type="color"], .form-inline .dropzone, .navbar-form .dropzone, .form-inline .item-picker, .navbar-form .item-picker {
        display: inline-block;
        width: auto;
        vertical-align: middle
    }

    .form-inline .input-group > .form-control, .navbar-form .input-group > .form-control, .form-inline .rf-Field .input-group > textarea, .rf-Field .form-inline .input-group > textarea, .navbar-form .rf-Field .input-group > textarea, .rf-Field .navbar-form .input-group > textarea, .form-inline .rf-Field .input-group > input[type="text"], .rf-Field .form-inline .input-group > input[type="text"], .navbar-form .rf-Field .input-group > input[type="text"], .rf-Field .navbar-form .input-group > input[type="text"], .form-inline .rf-Field .input-group > input[type="password"], .rf-Field .form-inline .input-group > input[type="password"], .navbar-form .rf-Field .input-group > input[type="password"], .rf-Field .navbar-form .input-group > input[type="password"], .form-inline .rf-Field .input-group > input[type="datetime"], .rf-Field .form-inline .input-group > input[type="datetime"], .navbar-form .rf-Field .input-group > input[type="datetime"], .rf-Field .navbar-form .input-group > input[type="datetime"], .form-inline .rf-Field .input-group > input[type="datetime-local"], .rf-Field .form-inline .input-group > input[type="datetime-local"], .navbar-form .rf-Field .input-group > input[type="datetime-local"], .rf-Field .navbar-form .input-group > input[type="datetime-local"], .form-inline .rf-Field .input-group > input[type="date"], .rf-Field .form-inline .input-group > input[type="date"], .navbar-form .rf-Field .input-group > input[type="date"], .rf-Field .navbar-form .input-group > input[type="date"], .form-inline .rf-Field .input-group > input[type="month"], .rf-Field .form-inline .input-group > input[type="month"], .navbar-form .rf-Field .input-group > input[type="month"], .rf-Field .navbar-form .input-group > input[type="month"], .form-inline .rf-Field .input-group > input[type="time"], .rf-Field .form-inline .input-group > input[type="time"], .navbar-form .rf-Field .input-group > input[type="time"], .rf-Field .navbar-form .input-group > input[type="time"], .form-inline .rf-Field .input-group > input[type="week"], .rf-Field .form-inline .input-group > input[type="week"], .navbar-form .rf-Field .input-group > input[type="week"], .rf-Field .navbar-form .input-group > input[type="week"], .form-inline .rf-Field .input-group > input[type="number"], .rf-Field .form-inline .input-group > input[type="number"], .navbar-form .rf-Field .input-group > input[type="number"], .rf-Field .navbar-form .input-group > input[type="number"], .form-inline .rf-Field .input-group > input[type="email"], .rf-Field .form-inline .input-group > input[type="email"], .navbar-form .rf-Field .input-group > input[type="email"], .rf-Field .navbar-form .input-group > input[type="email"], .form-inline .rf-Field .input-group > input[type="url"], .rf-Field .form-inline .input-group > input[type="url"], .navbar-form .rf-Field .input-group > input[type="url"], .rf-Field .navbar-form .input-group > input[type="url"], .form-inline .rf-Field .input-group > input[type="search"], .rf-Field .form-inline .input-group > input[type="search"], .navbar-form .rf-Field .input-group > input[type="search"], .rf-Field .navbar-form .input-group > input[type="search"], .form-inline .rf-Field .input-group > input[type="tel"], .rf-Field .form-inline .input-group > input[type="tel"], .navbar-form .rf-Field .input-group > input[type="tel"], .rf-Field .navbar-form .input-group > input[type="tel"], .form-inline .rf-Field .input-group > input[type="color"], .rf-Field .form-inline .input-group > input[type="color"], .navbar-form .rf-Field .input-group > input[type="color"], .rf-Field .navbar-form .input-group > input[type="color"], .form-inline .input-group > .dropzone, .navbar-form .input-group > .dropzone, .form-inline .input-group > .item-picker, .navbar-form .input-group > .item-picker {
        width: 100%
    }

    .form-inline .control-label, .navbar-form .control-label {
        margin-bottom: 0;
        vertical-align: middle
    }

    .form-inline .radio, .navbar-form .radio, .form-inline .checkbox, .navbar-form .checkbox {
        display: inline-block;
        margin-top: 0;
        margin-bottom: 0;
        padding-left: 0;
        vertical-align: middle
    }

    .form-inline .radio input[type="radio"], .navbar-form .radio input[type="radio"], .form-inline .checkbox input[type="checkbox"], .navbar-form .checkbox input[type="checkbox"] {
        float: none;
        margin-left: 0
    }

    .form-inline .has-feedback .form-control-feedback, .navbar-form .has-feedback .form-control-feedback {
        top: 0
    }
}

.form-horizontal .control-label, .form-horizontal .radio, .form-horizontal .checkbox, .form-horizontal .radio-inline, .form-horizontal .checkbox-inline {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 7px
}

.form-horizontal .radio, .form-horizontal .checkbox {
    min-height: 27px
}

.form-horizontal .form-group, .form-horizontal .rf-Field, .form-horizontal .rf-Fieldset, .form-horizontal .rf-RepeatingFieldset, .form-horizontal .rf-RepeatingFieldset__item {
    margin-left: -10px;
    margin-right: -10px
}

.form-horizontal .form-group:before, .form-horizontal .rf-Field:before, .form-horizontal .rf-Fieldset:before, .form-horizontal .rf-RepeatingFieldset:before, .form-horizontal .rf-RepeatingFieldset__item:before, .form-horizontal .form-group:after, .form-horizontal .rf-Field:after, .form-horizontal .rf-Fieldset:after, .form-horizontal .rf-RepeatingFieldset:after, .form-horizontal .rf-RepeatingFieldset__item:after {
    content: " ";
    display: table
}

.form-horizontal .form-group:after, .form-horizontal .rf-Field:after, .form-horizontal .rf-Fieldset:after, .form-horizontal .rf-RepeatingFieldset:after, .form-horizontal .rf-RepeatingFieldset__item:after {
    clear: both
}

.form-horizontal .form-control-static {
    padding-top: 7px
}

@media (min-width: 768px) {
    .form-horizontal .control-label {
        text-align: right
    }
}

.form-horizontal .has-feedback .form-control-feedback {
    top: 0;
    right: 10px
}

.btn, .rf-RepeatingFieldset__add {
    display: inline-block;
    margin-bottom: 0;
    font-weight: normal;
    text-align: center;
    vertical-align: middle;
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent;
    white-space: nowrap;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    border-radius: 3px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.btn:focus, .rf-RepeatingFieldset__add:focus, .btn:active:focus, .rf-RepeatingFieldset__add:active:focus, .btn.active:focus, .active.rf-RepeatingFieldset__add:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px
}

.btn:hover, .rf-RepeatingFieldset__add:hover, .btn:focus, .rf-RepeatingFieldset__add:focus {
    color: #333;
    text-decoration: none
}

.btn:active, .rf-RepeatingFieldset__add:active, .btn.active, .active.rf-RepeatingFieldset__add {
    outline: 0;
    background-image: none;
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125)
}

.btn.disabled, .disabled.rf-RepeatingFieldset__add, .btn[disabled], [disabled].rf-RepeatingFieldset__add, fieldset[disabled] .btn, fieldset[disabled] .rf-RepeatingFieldset__add {
    cursor: not-allowed;
    pointer-events: none;
    opacity: .65;
    filter: alpha(opacity=65);
    -webkit-box-shadow: none;
    box-shadow: none
}

.btn-default {
    color: #333;
    background-color: #fff;
    border-color: #ccc
}

.btn-default:hover, .btn-default:focus, .btn-default:active, .btn-default.active {
    color: #333;
    background-color: #ebebeb;
    border-color: #adadad
}

.open .btn-default.dropdown-toggle {
    color: #333;
    background-color: #ebebeb;
    border-color: #adadad
}

.btn-default:active, .btn-default.active {
    background-image: none
}

.open .btn-default.dropdown-toggle {
    background-image: none
}

.btn-default.disabled, .btn-default.disabled:hover, .btn-default.disabled:focus, .btn-default.disabled:active, .btn-default.disabled.active, .btn-default[disabled], .btn-default[disabled]:hover, .btn-default[disabled]:focus, .btn-default[disabled]:active, .btn-default[disabled].active, fieldset[disabled] .btn-default, fieldset[disabled] .btn-default:hover, fieldset[disabled] .btn-default:focus, fieldset[disabled] .btn-default:active, fieldset[disabled] .btn-default.active {
    background-color: #fff;
    border-color: #ccc
}

.btn-default .badge {
    color: #fff;
    background-color: #333
}

.btn-primary {
    color: #fff;
    background-color: #428bca;
    border-color: #357ebd
}

.btn-primary:hover, .btn-primary:focus, .btn-primary:active, .btn-primary.active {
    color: #fff;
    background-color: #3276b1;
    border-color: #285e8e
}

.open .btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #3276b1;
    border-color: #285e8e
}

.btn-primary:active, .btn-primary.active {
    background-image: none
}

.open .btn-primary.dropdown-toggle {
    background-image: none
}

.btn-primary.disabled, .btn-primary.disabled:hover, .btn-primary.disabled:focus, .btn-primary.disabled:active, .btn-primary.disabled.active, .btn-primary[disabled], .btn-primary[disabled]:hover, .btn-primary[disabled]:focus, .btn-primary[disabled]:active, .btn-primary[disabled].active, fieldset[disabled] .btn-primary, fieldset[disabled] .btn-primary:hover, fieldset[disabled] .btn-primary:focus, fieldset[disabled] .btn-primary:active, fieldset[disabled] .btn-primary.active {
    background-color: #428bca;
    border-color: #357ebd
}

.btn-primary .badge {
    color: #428bca;
    background-color: #fff
}

.btn-success, .rf-RepeatingFieldset__add {
    color: #fff;
    background-color: #4C994C;
    border-color: #484
}

.btn-success:hover, .rf-RepeatingFieldset__add:hover, .btn-success:focus, .rf-RepeatingFieldset__add:focus, .btn-success:active, .rf-RepeatingFieldset__add:active, .btn-success.active, .active.rf-RepeatingFieldset__add {
    color: #fff;
    background-color: #3e7e3e;
    border-color: #2f5f2f
}

.open .btn-success.dropdown-toggle, .open .dropdown-toggle.rf-RepeatingFieldset__add {
    color: #fff;
    background-color: #3e7e3e;
    border-color: #2f5f2f
}

.btn-success:active, .rf-RepeatingFieldset__add:active, .btn-success.active, .active.rf-RepeatingFieldset__add {
    background-image: none
}

.open .btn-success.dropdown-toggle, .open .dropdown-toggle.rf-RepeatingFieldset__add {
    background-image: none
}

.btn-success.disabled, .disabled.rf-RepeatingFieldset__add, .btn-success.disabled:hover, .disabled.rf-RepeatingFieldset__add:hover, .btn-success.disabled:focus, .disabled.rf-RepeatingFieldset__add:focus, .btn-success.disabled:active, .disabled.rf-RepeatingFieldset__add:active, .btn-success.disabled.active, .disabled.active.rf-RepeatingFieldset__add, .btn-success[disabled], [disabled].rf-RepeatingFieldset__add, .btn-success[disabled]:hover, [disabled].rf-RepeatingFieldset__add:hover, .btn-success[disabled]:focus, [disabled].rf-RepeatingFieldset__add:focus, .btn-success[disabled]:active, [disabled].rf-RepeatingFieldset__add:active, .btn-success[disabled].active, [disabled].active.rf-RepeatingFieldset__add, fieldset[disabled] .btn-success, fieldset[disabled] .rf-RepeatingFieldset__add, fieldset[disabled] .btn-success:hover, fieldset[disabled] .rf-RepeatingFieldset__add:hover, fieldset[disabled] .btn-success:focus, fieldset[disabled] .rf-RepeatingFieldset__add:focus, fieldset[disabled] .btn-success:active, fieldset[disabled] .rf-RepeatingFieldset__add:active, fieldset[disabled] .btn-success.active, fieldset[disabled] .active.rf-RepeatingFieldset__add {
    background-color: #4C994C;
    border-color: #484
}

.btn-success .badge, .rf-RepeatingFieldset__add .badge {
    color: #4C994C;
    background-color: #fff
}

.btn-info {
    color: #fff;
    background-color: #4F689E;
    border-color: #475d8d
}

.btn-info:hover, .btn-info:focus, .btn-info:active, .btn-info.active {
    color: #fff;
    background-color: #415683;
    border-color: #324264
}

.open .btn-info.dropdown-toggle {
    color: #fff;
    background-color: #415683;
    border-color: #324264
}

.btn-info:active, .btn-info.active {
    background-image: none
}

.open .btn-info.dropdown-toggle {
    background-image: none
}

.btn-info.disabled, .btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled:active, .btn-info.disabled.active, .btn-info[disabled], .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled]:active, .btn-info[disabled].active, fieldset[disabled] .btn-info, fieldset[disabled] .btn-info:hover, fieldset[disabled] .btn-info:focus, fieldset[disabled] .btn-info:active, fieldset[disabled] .btn-info.active {
    background-color: #4F689E;
    border-color: #475d8d
}

.btn-info .badge {
    color: #4F689E;
    background-color: #fff
}

.btn-warning {
    color: #fff;
    background-color: #E59545;
    border-color: #e2882f
}

.btn-warning:hover, .btn-warning:focus, .btn-warning:active, .btn-warning.active {
    color: #fff;
    background-color: #e08121;
    border-color: #b96a1a
}

.open .btn-warning.dropdown-toggle {
    color: #fff;
    background-color: #e08121;
    border-color: #b96a1a
}

.btn-warning:active, .btn-warning.active {
    background-image: none
}

.open .btn-warning.dropdown-toggle {
    background-image: none
}

.btn-warning.disabled, .btn-warning.disabled:hover, .btn-warning.disabled:focus, .btn-warning.disabled:active, .btn-warning.disabled.active, .btn-warning[disabled], .btn-warning[disabled]:hover, .btn-warning[disabled]:focus, .btn-warning[disabled]:active, .btn-warning[disabled].active, fieldset[disabled] .btn-warning, fieldset[disabled] .btn-warning:hover, fieldset[disabled] .btn-warning:focus, fieldset[disabled] .btn-warning:active, fieldset[disabled] .btn-warning.active {
    background-color: #E59545;
    border-color: #e2882f
}

.btn-warning .badge {
    color: #E59545;
    background-color: #fff
}

.btn-danger {
    color: #fff;
    background-color: #B24342;
    border-color: #9f3c3b
}

.btn-danger:hover, .btn-danger:focus, .btn-danger:active, .btn-danger.active {
    color: #fff;
    background-color: #943837;
    border-color: #732b2b
}

.open .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #943837;
    border-color: #732b2b
}

.btn-danger:active, .btn-danger.active {
    background-image: none
}

.open .btn-danger.dropdown-toggle {
    background-image: none
}

.btn-danger.disabled, .btn-danger.disabled:hover, .btn-danger.disabled:focus, .btn-danger.disabled:active, .btn-danger.disabled.active, .btn-danger[disabled], .btn-danger[disabled]:hover, .btn-danger[disabled]:focus, .btn-danger[disabled]:active, .btn-danger[disabled].active, fieldset[disabled] .btn-danger, fieldset[disabled] .btn-danger:hover, fieldset[disabled] .btn-danger:focus, fieldset[disabled] .btn-danger:active, fieldset[disabled] .btn-danger.active {
    background-color: #B24342;
    border-color: #9f3c3b
}

.btn-danger .badge {
    color: #B24342;
    background-color: #fff
}

.btn-link {
    color: #428bca;
    font-weight: normal;
    cursor: pointer;
    border-radius: 0
}

.btn-link, .btn-link:active, .btn-link[disabled], fieldset[disabled] .btn-link {
    background-color: transparent;
    -webkit-box-shadow: none;
    box-shadow: none
}

.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
    border-color: transparent
}

.btn-link:hover, .btn-link:focus {
    color: #2a6496;
    text-decoration: underline;
    background-color: transparent
}

.btn-link[disabled]:hover, .btn-link[disabled]:focus, fieldset[disabled] .btn-link:hover, fieldset[disabled] .btn-link:focus {
    color: #999;
    text-decoration: none
}

.btn-lg, .btn-group-lg > .btn, .btn-group-lg > .rf-RepeatingFieldset__add {
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33;
    border-radius: 4px
}

.btn-sm, .btn-group-sm > .btn, .btn-group-sm > .rf-RepeatingFieldset__add, .rf-RepeatingFieldset__add {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 2px
}

.btn-xs, .btn-group-xs > .btn, .btn-group-xs > .rf-RepeatingFieldset__add {
    padding: 1px 5px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 2px;
    padding: 2px 5px 0
}

.btn.btn-xs, .btn-group-xs > .btn, .btn-group-xs > .rf-RepeatingFieldset__add, .btn-xs.rf-RepeatingFieldset__add {
    font-weight: 400
}

.btn-block {
    display: block;
    width: 100%;
    padding-left: 0;
    padding-right: 0
}

.btn-block + .btn-block {
    margin-top: 5px
}

input[type="submit"].btn-block, input[type="reset"].btn-block, input[type="button"].btn-block {
    width: 100%
}

.fade {
    opacity: 0;
    -webkit-transition: opacity 0.15s linear;
    transition: opacity 0.15s linear
}

.fade.in {
    opacity: 1
}

.collapse {
    display: none
}

.collapse.in {
    display: block
}

.collapsing {
    position: relative;
    height: 0;
    overflow: hidden;
    -webkit-transition: height 0.35s ease;
    transition: height 0.35s ease
}

.caret {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: 2px;
    vertical-align: middle;
    border-top: 4px solid;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent
}

.dropdown {
    position: relative
}

.dropdown-toggle:focus {
    outline: 0
}

.dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 160px;
    padding: 5px 0;
    margin: 2px 0 0;
    list-style: none;
    font-size: 14px;
    background-color: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 3px;
    -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
    box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
    background-clip: padding-box
}

.dropdown-menu.pull-right {
    right: 0;
    left: auto
}

.dropdown-menu .divider {
    height: 1px;
    margin: 9px 0;
    overflow: hidden;
    background-color: #e5e5e5
}

.dropdown-menu > li > a {
    display: block;
    padding: 3px 20px;
    clear: both;
    font-weight: normal;
    line-height: 1.42857;
    color: #333;
    white-space: nowrap
}

.dropdown-menu > li > a:hover, .dropdown-menu > li > a:focus {
    text-decoration: none;
    color: #262626;
    background-color: #f5f5f5
}

.dropdown-menu > .active > a, .dropdown-menu > .active > a:hover, .dropdown-menu > .active > a:focus {
    color: #fff;
    text-decoration: none;
    outline: 0;
    background-color: #428bca
}

.dropdown-menu > .disabled > a, .dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
    color: #999
}

.dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
    text-decoration: none;
    background-color: transparent;
    background-image: none;
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
    cursor: not-allowed
}

.open > .dropdown-menu {
    display: block
}

.open > a {
    outline: 0
}

.dropdown-menu-right {
    left: auto;
    right: 0
}

.dropdown-menu-left {
    left: 0;
    right: auto
}

.dropdown-header {
    display: block;
    padding: 3px 20px;
    font-size: 12px;
    line-height: 1.42857;
    color: #999
}

.dropdown-backdrop {
    position: fixed;
    left: 0;
    right: 0;
    bottom: 0;
    top: 0;
    z-index: 990
}

.pull-right > .dropdown-menu {
    right: 0;
    left: auto
}

.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
    border-top: 0;
    border-bottom: 4px solid;
    content: ""
}

.dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 1px
}

@media (min-width: 768px) {
    .navbar-right .dropdown-menu {
        right: 0;
        left: auto
    }

    .navbar-right .dropdown-menu-left {
        left: 0;
        right: auto
    }
}

.btn-group, .btn-group-vertical {
    position: relative;
    display: inline-block;
    vertical-align: middle
}

.btn-group > .btn, .btn-group > .rf-RepeatingFieldset__add, .btn-group-vertical > .btn, .btn-group-vertical > .rf-RepeatingFieldset__add {
    position: relative;
    float: left
}

.btn-group > .btn:hover, .btn-group > .rf-RepeatingFieldset__add:hover, .btn-group > .btn:focus, .btn-group > .rf-RepeatingFieldset__add:focus, .btn-group > .btn:active, .btn-group > .rf-RepeatingFieldset__add:active, .btn-group > .btn.active, .btn-group > .active.rf-RepeatingFieldset__add, .btn-group-vertical > .btn:hover, .btn-group-vertical > .rf-RepeatingFieldset__add:hover, .btn-group-vertical > .btn:focus, .btn-group-vertical > .rf-RepeatingFieldset__add:focus, .btn-group-vertical > .btn:active, .btn-group-vertical > .rf-RepeatingFieldset__add:active, .btn-group-vertical > .btn.active, .btn-group-vertical > .active.rf-RepeatingFieldset__add {
    z-index: 2
}

.btn-group > .btn:focus, .btn-group > .rf-RepeatingFieldset__add:focus, .btn-group-vertical > .btn:focus, .btn-group-vertical > .rf-RepeatingFieldset__add:focus {
    outline: none
}

.btn-group .btn + .btn, .btn-group .rf-RepeatingFieldset__add + .btn, .btn-group .btn + .rf-RepeatingFieldset__add, .btn-group .rf-RepeatingFieldset__add + .rf-RepeatingFieldset__add, .btn-group .btn + .btn-group, .btn-group .rf-RepeatingFieldset__add + .btn-group, .btn-group .btn-group + .btn, .btn-group .btn-group + .rf-RepeatingFieldset__add, .btn-group .btn-group + .btn-group {
    margin-left: -1px
}

.btn-toolbar {
    margin-left: -5px
}

.btn-toolbar:before, .btn-toolbar:after {
    content: " ";
    display: table
}

.btn-toolbar:after {
    clear: both
}

.btn-toolbar .btn-group, .btn-toolbar .input-group {
    float: left
}

.btn-toolbar > .btn, .btn-toolbar > .rf-RepeatingFieldset__add, .btn-toolbar > .btn-group, .btn-toolbar > .input-group {
    margin-left: 5px
}

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle), .btn-group > .rf-RepeatingFieldset__add:not(:first-child):not(:last-child):not(.dropdown-toggle) {
    border-radius: 0
}

.btn-group > .btn:first-child, .btn-group > .rf-RepeatingFieldset__add:first-child {
    margin-left: 0
}

.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle), .btn-group > .rf-RepeatingFieldset__add:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.btn-group > .btn:last-child:not(:first-child), .btn-group > .rf-RepeatingFieldset__add:last-child:not(:first-child), .btn-group > .dropdown-toggle:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.btn-group > .btn-group {
    float: left
}

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn, .btn-group > .btn-group:not(:first-child):not(:last-child) > .rf-RepeatingFieldset__add {
    border-radius: 0
}

.btn-group > .btn-group:first-child > .btn:last-child, .btn-group > .btn-group:first-child > .rf-RepeatingFieldset__add:last-child, .btn-group > .btn-group:first-child > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.btn-group > .btn-group:last-child > .btn:first-child, .btn-group > .btn-group:last-child > .rf-RepeatingFieldset__add:first-child {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.btn-group .dropdown-toggle:active, .btn-group.open .dropdown-toggle {
    outline: 0
}

.btn-group > .btn + .dropdown-toggle, .btn-group > .rf-RepeatingFieldset__add + .dropdown-toggle {
    padding-left: 8px;
    padding-right: 8px
}

.btn-group > .btn-lg + .dropdown-toggle, .btn-group-lg.btn-group > .btn + .dropdown-toggle, .btn-group-lg.btn-group > .rf-RepeatingFieldset__add + .dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px
}

.btn-group.open .dropdown-toggle {
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125)
}

.btn-group.open .dropdown-toggle.btn-link {
    -webkit-box-shadow: none;
    box-shadow: none
}

.btn .caret, .rf-RepeatingFieldset__add .caret {
    margin-left: 0
}

.btn-lg .caret, .btn-group-lg > .btn .caret, .btn-group-lg > .rf-RepeatingFieldset__add .caret {
    border-width: 5px 5px 0;
    border-bottom-width: 0
}

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret, .dropup .btn-group-lg > .rf-RepeatingFieldset__add .caret {
    border-width: 0 5px 5px
}

.btn-group-vertical > .btn, .btn-group-vertical > .rf-RepeatingFieldset__add, .btn-group-vertical > .btn-group, .btn-group-vertical > .btn-group > .btn, .btn-group-vertical > .btn-group > .rf-RepeatingFieldset__add {
    display: block;
    float: none;
    width: 100%;
    max-width: 100%
}

.btn-group-vertical > .btn-group:before, .btn-group-vertical > .btn-group:after {
    content: " ";
    display: table
}

.btn-group-vertical > .btn-group:after {
    clear: both
}

.btn-group-vertical > .btn-group > .btn, .btn-group-vertical > .btn-group > .rf-RepeatingFieldset__add {
    float: none
}

.btn-group-vertical > .btn + .btn, .btn-group-vertical > .rf-RepeatingFieldset__add + .btn, .btn-group-vertical > .btn + .rf-RepeatingFieldset__add, .btn-group-vertical > .rf-RepeatingFieldset__add + .rf-RepeatingFieldset__add, .btn-group-vertical > .btn + .btn-group, .btn-group-vertical > .rf-RepeatingFieldset__add + .btn-group, .btn-group-vertical > .btn-group + .btn, .btn-group-vertical > .btn-group + .rf-RepeatingFieldset__add, .btn-group-vertical > .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0
}

.btn-group-vertical > .btn:not(:first-child):not(:last-child), .btn-group-vertical > .rf-RepeatingFieldset__add:not(:first-child):not(:last-child) {
    border-radius: 0
}

.btn-group-vertical > .btn:first-child:not(:last-child), .btn-group-vertical > .rf-RepeatingFieldset__add:first-child:not(:last-child) {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.btn-group-vertical > .btn:last-child:not(:first-child), .btn-group-vertical > .rf-RepeatingFieldset__add:last-child:not(:first-child) {
    border-bottom-left-radius: 3px;
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn, .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .rf-RepeatingFieldset__add {
    border-radius: 0
}

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child, .btn-group-vertical > .btn-group:first-child:not(:last-child) > .rf-RepeatingFieldset__add:last-child, .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child, .btn-group-vertical > .btn-group:last-child:not(:first-child) > .rf-RepeatingFieldset__add:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.btn-group-justified {
    display: table;
    width: 100%;
    table-layout: fixed;
    border-collapse: separate
}

.btn-group-justified > .btn, .btn-group-justified > .rf-RepeatingFieldset__add, .btn-group-justified > .btn-group {
    float: none;
    display: table-cell;
    width: 1%
}

.btn-group-justified > .btn-group .btn, .btn-group-justified > .btn-group .rf-RepeatingFieldset__add {
    width: 100%
}

[data-toggle="buttons"] > .btn > input[type="radio"], [data-toggle="buttons"] > .rf-RepeatingFieldset__add > input[type="radio"], [data-toggle="buttons"] > .btn > input[type="checkbox"], [data-toggle="buttons"] > .rf-RepeatingFieldset__add > input[type="checkbox"] {
    display: none
}

.input-group {
    position: relative;
    display: table;
    border-collapse: separate
}

.input-group[class*="col-"] {
    float: none;
    padding-left: 0;
    padding-right: 0
}

.input-group .form-control, .input-group .rf-Field textarea, .rf-Field .input-group textarea, .input-group .rf-Field input[type="text"], .rf-Field .input-group input[type="text"], .input-group .rf-Field input[type="password"], .rf-Field .input-group input[type="password"], .input-group .rf-Field input[type="datetime"], .rf-Field .input-group input[type="datetime"], .input-group .rf-Field input[type="datetime-local"], .rf-Field .input-group input[type="datetime-local"], .input-group .rf-Field input[type="date"], .rf-Field .input-group input[type="date"], .input-group .rf-Field input[type="month"], .rf-Field .input-group input[type="month"], .input-group .rf-Field input[type="time"], .rf-Field .input-group input[type="time"], .input-group .rf-Field input[type="week"], .rf-Field .input-group input[type="week"], .input-group .rf-Field input[type="number"], .rf-Field .input-group input[type="number"], .input-group .rf-Field input[type="email"], .rf-Field .input-group input[type="email"], .input-group .rf-Field input[type="url"], .rf-Field .input-group input[type="url"], .input-group .rf-Field input[type="search"], .rf-Field .input-group input[type="search"], .input-group .rf-Field input[type="tel"], .rf-Field .input-group input[type="tel"], .input-group .rf-Field input[type="color"], .rf-Field .input-group input[type="color"], .input-group .dropzone, .input-group .item-picker {
    position: relative;
    z-index: 2;
    float: left;
    width: 100%;
    margin-bottom: 0
}

.input-group-addon, .input-group-btn, .input-group .form-control, .input-group .rf-Field textarea, .rf-Field .input-group textarea, .input-group .rf-Field input[type="text"], .rf-Field .input-group input[type="text"], .input-group .rf-Field input[type="password"], .rf-Field .input-group input[type="password"], .input-group .rf-Field input[type="datetime"], .rf-Field .input-group input[type="datetime"], .input-group .rf-Field input[type="datetime-local"], .rf-Field .input-group input[type="datetime-local"], .input-group .rf-Field input[type="date"], .rf-Field .input-group input[type="date"], .input-group .rf-Field input[type="month"], .rf-Field .input-group input[type="month"], .input-group .rf-Field input[type="time"], .rf-Field .input-group input[type="time"], .input-group .rf-Field input[type="week"], .rf-Field .input-group input[type="week"], .input-group .rf-Field input[type="number"], .rf-Field .input-group input[type="number"], .input-group .rf-Field input[type="email"], .rf-Field .input-group input[type="email"], .input-group .rf-Field input[type="url"], .rf-Field .input-group input[type="url"], .input-group .rf-Field input[type="search"], .rf-Field .input-group input[type="search"], .input-group .rf-Field input[type="tel"], .rf-Field .input-group input[type="tel"], .input-group .rf-Field input[type="color"], .rf-Field .input-group input[type="color"], .input-group .dropzone, .input-group .item-picker {
    display: table-cell
}

.input-group-addon:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child), .input-group .form-control:not(:first-child):not(:last-child), .input-group .rf-Field textarea:not(:first-child):not(:last-child), .rf-Field .input-group textarea:not(:first-child):not(:last-child), .input-group .rf-Field input[type="text"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="text"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="password"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="password"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="datetime"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="datetime"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="datetime-local"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="datetime-local"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="date"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="date"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="month"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="month"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="time"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="time"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="week"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="week"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="number"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="number"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="email"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="email"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="url"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="url"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="search"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="search"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="tel"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="tel"]:not(:first-child):not(:last-child), .input-group .rf-Field input[type="color"]:not(:first-child):not(:last-child), .rf-Field .input-group input[type="color"]:not(:first-child):not(:last-child), .input-group .dropzone:not(:first-child):not(:last-child), .input-group .item-picker:not(:first-child):not(:last-child) {
    border-radius: 0
}

.input-group-addon, .input-group-btn {
    width: 1%;
    white-space: nowrap;
    vertical-align: middle
}

.input-group-addon {
    padding: 6px 12px;
    font-size: 14px;
    font-weight: normal;
    line-height: 1;
    color: #555;
    text-align: center;
    background-color: #eee;
    border: 1px solid #ccc;
    border-radius: 3px
}

.input-group-addon.input-sm, .rf-Field .input-group-sm > textarea.input-group-addon, .rf-Field .input-group-sm > input.input-group-addon[type="text"], .rf-Field .input-group-sm > input.input-group-addon[type="password"], .rf-Field .input-group-sm > input.input-group-addon[type="datetime"], .rf-Field .input-group-sm > input.input-group-addon[type="datetime-local"], .rf-Field .input-group-sm > input.input-group-addon[type="date"], .rf-Field .input-group-sm > input.input-group-addon[type="month"], .rf-Field .input-group-sm > input.input-group-addon[type="time"], .rf-Field .input-group-sm > input.input-group-addon[type="week"], .rf-Field .input-group-sm > input.input-group-addon[type="number"], .rf-Field .input-group-sm > input.input-group-addon[type="email"], .rf-Field .input-group-sm > input.input-group-addon[type="url"], .rf-Field .input-group-sm > input.input-group-addon[type="search"], .rf-Field .input-group-sm > input.input-group-addon[type="tel"], .rf-Field .input-group-sm > input.input-group-addon[type="color"], .input-group-sm > .input-group-addon, .input-group-sm > .input-group-btn > .input-group-addon.btn, .input-group-sm > .input-group-btn > .input-group-addon.rf-RepeatingFieldset__add {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 2px
}

.input-group-addon.input-lg, .rf-Field .input-group-lg > textarea.input-group-addon, .rf-Field .input-group-lg > input.input-group-addon[type="text"], .rf-Field .input-group-lg > input.input-group-addon[type="password"], .rf-Field .input-group-lg > input.input-group-addon[type="datetime"], .rf-Field .input-group-lg > input.input-group-addon[type="datetime-local"], .rf-Field .input-group-lg > input.input-group-addon[type="date"], .rf-Field .input-group-lg > input.input-group-addon[type="month"], .rf-Field .input-group-lg > input.input-group-addon[type="time"], .rf-Field .input-group-lg > input.input-group-addon[type="week"], .rf-Field .input-group-lg > input.input-group-addon[type="number"], .rf-Field .input-group-lg > input.input-group-addon[type="email"], .rf-Field .input-group-lg > input.input-group-addon[type="url"], .rf-Field .input-group-lg > input.input-group-addon[type="search"], .rf-Field .input-group-lg > input.input-group-addon[type="tel"], .rf-Field .input-group-lg > input.input-group-addon[type="color"], .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .input-group-addon.btn, .input-group-lg > .input-group-btn > .input-group-addon.rf-RepeatingFieldset__add {
    padding: 10px 16px;
    font-size: 18px;
    border-radius: 4px
}

.input-group-addon input[type="radio"], .input-group-addon input[type="checkbox"] {
    margin-top: 0
}

.input-group .form-control:first-child, .input-group .rf-Field textarea:first-child, .rf-Field .input-group textarea:first-child, .input-group .rf-Field input[type="text"]:first-child, .rf-Field .input-group input[type="text"]:first-child, .input-group .rf-Field input[type="password"]:first-child, .rf-Field .input-group input[type="password"]:first-child, .input-group .rf-Field input[type="datetime"]:first-child, .rf-Field .input-group input[type="datetime"]:first-child, .input-group .rf-Field input[type="datetime-local"]:first-child, .rf-Field .input-group input[type="datetime-local"]:first-child, .input-group .rf-Field input[type="date"]:first-child, .rf-Field .input-group input[type="date"]:first-child, .input-group .rf-Field input[type="month"]:first-child, .rf-Field .input-group input[type="month"]:first-child, .input-group .rf-Field input[type="time"]:first-child, .rf-Field .input-group input[type="time"]:first-child, .input-group .rf-Field input[type="week"]:first-child, .rf-Field .input-group input[type="week"]:first-child, .input-group .rf-Field input[type="number"]:first-child, .rf-Field .input-group input[type="number"]:first-child, .input-group .rf-Field input[type="email"]:first-child, .rf-Field .input-group input[type="email"]:first-child, .input-group .rf-Field input[type="url"]:first-child, .rf-Field .input-group input[type="url"]:first-child, .input-group .rf-Field input[type="search"]:first-child, .rf-Field .input-group input[type="search"]:first-child, .input-group .rf-Field input[type="tel"]:first-child, .rf-Field .input-group input[type="tel"]:first-child, .input-group .rf-Field input[type="color"]:first-child, .rf-Field .input-group input[type="color"]:first-child, .input-group .dropzone:first-child, .input-group .item-picker:first-child, .input-group-addon:first-child, .input-group-btn:first-child > .btn, .input-group-btn:first-child > .rf-RepeatingFieldset__add, .input-group-btn:first-child > .btn-group > .btn, .input-group-btn:first-child > .btn-group > .rf-RepeatingFieldset__add, .input-group-btn:first-child > .dropdown-toggle, .input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle), .input-group-btn:last-child > .rf-RepeatingFieldset__add:not(:last-child):not(.dropdown-toggle), .input-group-btn:last-child > .btn-group:not(:last-child) > .btn, .input-group-btn:last-child > .btn-group:not(:last-child) > .rf-RepeatingFieldset__add {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0
}

.input-group-addon:first-child {
    border-right: 0
}

.input-group .form-control:last-child, .input-group .rf-Field textarea:last-child, .rf-Field .input-group textarea:last-child, .input-group .rf-Field input[type="text"]:last-child, .rf-Field .input-group input[type="text"]:last-child, .input-group .rf-Field input[type="password"]:last-child, .rf-Field .input-group input[type="password"]:last-child, .input-group .rf-Field input[type="datetime"]:last-child, .rf-Field .input-group input[type="datetime"]:last-child, .input-group .rf-Field input[type="datetime-local"]:last-child, .rf-Field .input-group input[type="datetime-local"]:last-child, .input-group .rf-Field input[type="date"]:last-child, .rf-Field .input-group input[type="date"]:last-child, .input-group .rf-Field input[type="month"]:last-child, .rf-Field .input-group input[type="month"]:last-child, .input-group .rf-Field input[type="time"]:last-child, .rf-Field .input-group input[type="time"]:last-child, .input-group .rf-Field input[type="week"]:last-child, .rf-Field .input-group input[type="week"]:last-child, .input-group .rf-Field input[type="number"]:last-child, .rf-Field .input-group input[type="number"]:last-child, .input-group .rf-Field input[type="email"]:last-child, .rf-Field .input-group input[type="email"]:last-child, .input-group .rf-Field input[type="url"]:last-child, .rf-Field .input-group input[type="url"]:last-child, .input-group .rf-Field input[type="search"]:last-child, .rf-Field .input-group input[type="search"]:last-child, .input-group .rf-Field input[type="tel"]:last-child, .rf-Field .input-group input[type="tel"]:last-child, .input-group .rf-Field input[type="color"]:last-child, .rf-Field .input-group input[type="color"]:last-child, .input-group .dropzone:last-child, .input-group .item-picker:last-child, .input-group-addon:last-child, .input-group-btn:last-child > .btn, .input-group-btn:last-child > .rf-RepeatingFieldset__add, .input-group-btn:last-child > .btn-group > .btn, .input-group-btn:last-child > .btn-group > .rf-RepeatingFieldset__add, .input-group-btn:last-child > .dropdown-toggle, .input-group-btn:first-child > .btn:not(:first-child), .input-group-btn:first-child > .rf-RepeatingFieldset__add:not(:first-child), .input-group-btn:first-child > .btn-group:not(:first-child) > .btn, .input-group-btn:first-child > .btn-group:not(:first-child) > .rf-RepeatingFieldset__add {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}

.input-group-addon:last-child {
    border-left: 0
}

.input-group-btn {
    position: relative;
    font-size: 0;
    white-space: nowrap
}

.input-group-btn > .btn, .input-group-btn > .rf-RepeatingFieldset__add {
    position: relative
}

.input-group-btn > .btn + .btn, .input-group-btn > .rf-RepeatingFieldset__add + .btn, .input-group-btn > .btn + .rf-RepeatingFieldset__add, .input-group-btn > .rf-RepeatingFieldset__add + .rf-RepeatingFieldset__add {
    margin-left: -1px
}

.input-group-btn > .btn:hover, .input-group-btn > .rf-RepeatingFieldset__add:hover, .input-group-btn > .btn:focus, .input-group-btn > .rf-RepeatingFieldset__add:focus, .input-group-btn > .btn:active, .input-group-btn > .rf-RepeatingFieldset__add:active {
    z-index: 2
}

.input-group-btn:first-child > .btn, .input-group-btn:first-child > .rf-RepeatingFieldset__add, .input-group-btn:first-child > .btn-group {
    margin-right: -1px
}

.input-group-btn:last-child > .btn, .input-group-btn:last-child > .rf-RepeatingFieldset__add, .input-group-btn:last-child > .btn-group {
    margin-left: -1px
}

.nav {
    margin-bottom: 0;
    padding-left: 0;
    list-style: none
}

.nav:before, .nav:after {
    content: " ";
    display: table
}

.nav:after {
    clear: both
}

.nav > li {
    position: relative;
    display: block
}

.nav > li > a {
    position: relative;
    display: block;
    padding: 10px 15px
}

.nav > li > a:hover, .nav > li > a:focus {
    text-decoration: none;
    background-color: #eee
}

.nav > li.disabled > a {
    color: #999
}

.nav > li.disabled > a:hover, .nav > li.disabled > a:focus {
    color: #999;
    text-decoration: none;
    background-color: transparent;
    cursor: not-allowed
}

.nav .open > a, .nav .open > a:hover, .nav .open > a:focus {
    background-color: #eee;
    border-color: #428bca
}

.nav .nav-divider {
    height: 1px;
    margin: 9px 0;
    overflow: hidden;
    background-color: #e5e5e5
}

.nav > li > a > img {
    max-width: none
}

.nav-tabs {
    border-bottom: 1px solid #ddd
}

.nav-tabs > li {
    float: left;
    margin-bottom: -1px
}

.nav-tabs > li > a {
    margin-right: 2px;
    line-height: 1.42857;
    border: 1px solid transparent;
    border-radius: 3px 3px 0 0
}

.nav-tabs > li > a:hover {
    border-color: #eee #eee #ddd
}

.nav-tabs > li.active > a, .nav-tabs > li.active > a:hover, .nav-tabs > li.active > a:focus {
    color: #555;
    background-color: #fff;
    border: 1px solid #ddd;
    border-bottom-color: transparent;
    cursor: default
}

.nav-pills > li {
    float: left
}

.nav-pills > li > a {
    border-radius: 3px
}

.nav-pills > li + li {
    margin-left: 2px
}

.nav-pills > li.active > a, .nav-pills > li.active > a:hover, .nav-pills > li.active > a:focus {
    color: #fff;
    background-color: #428bca
}

.nav-stacked > li {
    float: none
}

.nav-stacked > li + li {
    margin-top: 2px;
    margin-left: 0
}

.nav-justified, .nav-tabs.nav-justified {
    width: 100%
}

.nav-justified > li, .nav-tabs.nav-justified > li {
    float: none
}

.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
    text-align: center;
    margin-bottom: 5px
}

.nav-justified > .dropdown .dropdown-menu {
    top: auto;
    left: auto
}

.nav-tabs-justified, .nav-tabs.nav-justified {
    border-bottom: 0
}

.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
    margin-right: 0;
    border-radius: 3px
}

.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a, .nav-tabs-justified > .active > a:hover, .nav-tabs.nav-justified > .active > a:hover, .nav-tabs-justified > .active > a:focus, .nav-tabs.nav-justified > .active > a:focus {
    border: 1px solid #ddd
}


.tab-content > .tab-pane {
    display: none
}

.tab-content > .active {
    display: block
}

.nav-tabs .dropdown-menu {
    margin-top: -1px;
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.navbar {
    position: relative;
    min-height: 80px;
    margin-bottom: 20px;
    border: 1px solid transparent
}

.navbar:before, .navbar:after {
    content: " ";
    display: table
}

.navbar:after {
    clear: both
}

.navbar-header:before, .navbar-header:after {
    content: " ";
    display: table
}

.navbar-header:after {
    clear: both
}

.navbar-collapse {
    max-height: 340px;
    overflow-x: visible;
    padding-right: 10px;
    padding-left: 10px;
    border-top: 1px solid transparent;
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
    -webkit-overflow-scrolling: touch
}

.navbar-collapse:before, .navbar-collapse:after {
    content: " ";
    display: table
}

.navbar-collapse:after {
    clear: both
}

.navbar-collapse.in {
    overflow-y: auto
}

.container > .navbar-header, .container > .navbar-collapse, .container-fluid > .navbar-header, .container-fluid > .navbar-collapse {
    margin-right: -10px;
    margin-left: -10px
}

@media (min-width: 768px) {
    .container > .navbar-header, .container > .navbar-collapse, .container-fluid > .navbar-header, .container-fluid > .navbar-collapse {
        margin-right: 0;
        margin-left: 0
    }
}

.navbar-static-top {
    z-index: 1000;
    border-width: 0 0 1px
}

@media (min-width: 768px) {
    .navbar-static-top {
        border-radius: 0
    }
}

.navbar-fixed-top, .navbar-fixed-bottom {
    position: fixed;
    right: 0;
    left: 0;
    z-index: 1030
}

@media (min-width: 768px) {
    .navbar-fixed-top, .navbar-fixed-bottom {
        border-radius: 0
    }
}

.navbar-fixed-top {
    top: 0;
    border-width: 0 0 1px
}

.navbar-fixed-bottom {
    bottom: 0;
    margin-bottom: 0;
    border-width: 1px 0 0
}

.navbar-brand {
    float: left;
    padding: 30px 10px;
    font-size: 18px;
    line-height: 20px;
    height: 80px
}

.navbar-brand:hover, .navbar-brand:focus {
    text-decoration: none
}

@media (min-width: 768px) {
    .navbar > .container .navbar-brand, .navbar > .container-fluid .navbar-brand {
        margin-left: -10px
    }
}

.navbar-toggle {
    position: relative;
    float: right;
    margin-right: 10px;
    padding: 9px 10px;
    margin-top: 23px;
    margin-bottom: 23px;
    background-color: transparent;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 3px
}

.navbar-toggle:focus {
    outline: none
}

.navbar-toggle .icon-bar {
    display: block;
    width: 22px;
    height: 2px;
    border-radius: 1px
}

.navbar-toggle .icon-bar + .icon-bar {
    margin-top: 4px
}

@media (min-width: 768px) {
    .navbar-toggle {
        display: none
    }
}

.navbar-nav {
    margin: 15px -10px
}

.navbar-nav > li > a {
    padding-top: 10px;
    padding-bottom: 10px;
    line-height: 20px
}

@media (max-width: 767px) {
    .navbar-nav .open .dropdown-menu {
        position: static;
        float: none;
        width: auto;
        margin-top: 0;
        background-color: transparent;
        border: 0;
        box-shadow: none
    }

    .navbar-nav .open .dropdown-menu > li > a, .navbar-nav .open .dropdown-menu .dropdown-header {
        padding: 5px 15px 5px 25px
    }

    .navbar-nav .open .dropdown-menu > li > a {
        line-height: 20px
    }

    .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-nav .open .dropdown-menu > li > a:focus {
        background-image: none
    }
}

@media (min-width: 768px) {
    .navbar-nav {
        float: left;
        margin: 0
    }

    .navbar-nav > li {
        float: left
    }

    .navbar-nav > li > a {
        padding-top: 30px;
        padding-bottom: 30px
    }

    .navbar-nav.navbar-right:last-child {
        margin-right: -10px
    }
}

@media (min-width: 768px) {
    .navbar-left {
        float: left !important
    }

    .navbar-right {
        float: right !important
    }
}

.navbar-form {
    margin-left: -10px;
    margin-right: -10px;
    padding: 10px 10px;
    -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
    margin-top: 23px;
    margin-bottom: 23px
}

@media (max-width: 767px) {
    .navbar-form .form-group, .navbar-form .rf-Field, .navbar-form .rf-Fieldset, .navbar-form .rf-RepeatingFieldset, .navbar-form .rf-RepeatingFieldset__item {
        margin-bottom: 5px
    }
}

@media (min-width: 768px) {
    .navbar-form {
        width: auto;
        border: 0;
        margin-left: 0;
        margin-right: 0;
        padding-top: 0;
        padding-bottom: 0;
        -webkit-box-shadow: none;
        box-shadow: none
    }

    .navbar-form.navbar-right:last-child {
        margin-right: -10px
    }
}

.navbar-nav > li > .dropdown-menu {
    margin-top: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0
}

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0
}

.navbar-btn {
    margin-top: 23px;
    margin-bottom: 23px
}

.navbar-btn.btn-sm, .btn-group-sm > .navbar-btn.btn, .navbar-btn.rf-RepeatingFieldset__add {
    margin-top: 25px;
    margin-bottom: 25px
}

.navbar-btn.btn-xs, .btn-group-xs > .navbar-btn.btn, .btn-group-xs > .navbar-btn.rf-RepeatingFieldset__add {
    margin-top: 29px;
    margin-bottom: 29px
}

.navbar-text {
    margin-top: 30px;
    margin-bottom: 30px
}

@media (min-width: 768px) {
    .navbar-text {
        float: left;
        margin-left: 10px;
        margin-right: 10px
    }

    .navbar-text.navbar-right:last-child {
        margin-right: 0
    }
}

.navbar-default {
    background-color: #f8f8f8;
    border-color: #e7e7e7
}

.navbar-default .navbar-brand {
    color: #999
}

.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
    color: gray;
    background-color: transparent
}

.navbar-default .navbar-text {
    color: #777
}

.navbar-default .navbar-nav > li > a {
    color: #777
}

.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
    color: #333;
    background-color: transparent
}

.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:hover, .navbar-default .navbar-nav > .active > a:focus {
    color: #555;
    background-color: #e7e7e7
}

.navbar-default .navbar-nav > .disabled > a, .navbar-default .navbar-nav > .disabled > a:hover, .navbar-default .navbar-nav > .disabled > a:focus {
    color: #ccc;
    background-color: transparent
}

.navbar-default .navbar-toggle {
    border-color: #ddd
}

.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
    background-color: #ddd
}

.navbar-default .navbar-toggle .icon-bar {
    background-color: #888
}

.navbar-default .navbar-collapse, .navbar-default .navbar-form {
    border-color: #e7e7e7
}

.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus {
    background-color: #e7e7e7;
    color: #555
}

@media (max-width: 767px) {
    .navbar-default .navbar-nav .open .dropdown-menu > li > a {
        color: #777
    }

    .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
        color: #333;
        background-color: transparent
    }

    .navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
        color: #555;
        background-color: #e7e7e7
    }

    .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
        color: #ccc;
        background-color: transparent
    }
}

.navbar-default .navbar-link {
    color: #777
}

.navbar-default .navbar-link:hover {
    color: #333
}

.navbar-inverse {
    background-color: #222;
    border-color: #090909
}

.navbar-inverse .navbar-brand {
    color: #999
}

.navbar-inverse .navbar-brand:hover, .navbar-inverse .navbar-brand:focus {
    color: #fff;
    background-color: transparent
}

.navbar-inverse .navbar-text {
    color: #999
}

.navbar-inverse .navbar-nav > li > a {
    color: #999
}

.navbar-inverse .navbar-nav > li > a:hover, .navbar-inverse .navbar-nav > li > a:focus {
    color: #fff;
    background-color: transparent
}

.navbar-inverse .navbar-nav > .active > a, .navbar-inverse .navbar-nav > .active > a:hover, .navbar-inverse .navbar-nav > .active > a:focus {
    color: #000;
    background-color: #fff
}

.navbar-inverse .navbar-nav > .disabled > a, .navbar-inverse .navbar-nav > .disabled > a:hover, .navbar-inverse .navbar-nav > .disabled > a:focus {
    color: #444;
    background-color: transparent
}

.navbar-inverse .navbar-toggle {
    border-color: #999
}

.navbar-inverse .navbar-toggle:hover {
    background-color: #fff
}

.navbar-inverse .navbar-toggle .icon-bar {
    background-color: #fff
}

.navbar-inverse .navbar-collapse, .navbar-inverse .navbar-form {
    border-color: #101010
}

.navbar-inverse .navbar-nav > .open > a, .navbar-inverse .navbar-nav > .open > a:hover, .navbar-inverse .navbar-nav > .open > a:focus {
    background-color: #fff;
    color: #000
}

@media (max-width: 767px) {
    .navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
        border-color: #090909
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu .divider {
        background-color: #090909
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
        color: #999
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
        color: #fff;
        background-color: transparent
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
        color: #000;
        background-color: #fff
    }

    .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
        color: #444;
        background-color: transparent
    }
}

.navbar-inverse .navbar-link {
    color: #999
}

.navbar-inverse .navbar-link:hover {
    color: #fff
}

.breadcrumb {
    padding: 8px 15px;
    margin-bottom: 20px;
    list-style: none;
    background-color: #f5f5f5;
    border-radius: 3px
}

.breadcrumb > li {
    display: inline-block
}

.breadcrumb > li + li:before {
    content: "/ ";
    padding: 0 5px;
    color: #ccc
}

.breadcrumb > .active {
    color: #999
}

.label {
    display: inline;
    padding: .2em .6em .3em;
    font-size: 75%;
    font-weight: bold;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: .25em
}

.label[href]:hover, .label[href]:focus {
    color: #fff;
    text-decoration: none;
    cursor: pointer
}

.label:empty {
    display: none
}

.btn .label, .rf-RepeatingFieldset__add .label {
    position: relative;
    top: -1px
}

.label-default {
    background-color: #999
}

.label-default[href]:hover, .label-default[href]:focus {
    background-color: gray
}

.label-primary {
    background-color: #428bca
}

.label-primary[href]:hover, .label-primary[href]:focus {
    background-color: #3071a9
}

.label-success {
    background-color: #4C994C
}

.label-success[href]:hover, .label-success[href]:focus {
    background-color: #3b773b
}

.label-info {
    background-color: #4F689E
}

.label-info[href]:hover, .label-info[href]:focus {
    background-color: #3e527c
}

.label-warning {
    background-color: #E59545
}

.label-warning[href]:hover, .label-warning[href]:focus {
    background-color: #d97c1e
}

.label-danger {
    background-color: #B24342
}

.label-danger[href]:hover, .label-danger[href]:focus {
    background-color: #8d3534
}

.badge {
    display: inline-block;
    min-width: 10px;
    padding: 3px 7px;
    font-size: 12px;
    font-weight: bold;
    color: #fff;
    line-height: 1;
    vertical-align: baseline;
    white-space: nowrap;
    text-align: center;
    background-color: #999;
    border-radius: 10px
}

.badge:empty {
    display: none
}

.btn .badge, .rf-RepeatingFieldset__add .badge {
    position: relative;
    top: -1px
}

.btn-xs .badge, .btn-group-xs > .btn .badge, .btn-group-xs > .rf-RepeatingFieldset__add .badge {
    top: 0;
    padding: 2px 5px 0px
}

a.badge:hover, a.badge:focus {
    color: #fff;
    text-decoration: none;
    cursor: pointer
}

a.list-group-item.active > .badge, .nav-pills > .active > a > .badge {
    color: #428bca;
    background-color: #fff
}

.nav-pills > li > a > .badge {
    margin-left: 3px
}

.thumbnail {
    display: block;
    padding: 4px;
    margin-bottom: 20px;
    line-height: 1.42857;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 3px;
    -webkit-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out
}

.thumbnail > img, .thumbnail a > img {
    display: block;
    margin-left: auto;
    margin-right: auto;
    max-width: 100%;
    height: auto;
    margin-left: auto;
    margin-right: auto
}

.thumbnail .caption {
    padding: 9px;
    color: #333
}

a.thumbnail:hover, a.thumbnail:focus, a.thumbnail.active {
    border-color: #428bca
}

.alert {
    padding: 15px;
    margin-bottom: 20px;
    border: 1px solid transparent;
    border-radius: 3px
}

.alert h4 {
    margin-top: 0;
    color: inherit
}

.alert .alert-link {
    font-weight: bold
}

.alert > p, .alert > ul {
    margin-bottom: 0
}

.alert > p + p {
    margin-top: 5px
}

.alert-dismissable {
    padding-right: 35px
}

.alert-dismissable .close, .alert-dismissable .rf-RepeatingFieldset__remove {
    position: relative;
    top: -2px;
    right: -21px;
    color: inherit
}

.alert-success {
    background-color: #dff0d8;
    border-color: #d6e9c6;
    color: #3c763d
}

.alert-success hr {
    border-top-color: #c9e2b3
}

.alert-success .alert-link {
    color: #2b542c
}

.alert-info {
    background-color: #d9edf7;
    border-color: #bce8f1;
    color: #31708f
}

.alert-info hr {
    border-top-color: #a6e1ec
}

.alert-info .alert-link {
    color: #245269
}

.alert-warning {
    background-color: #fcf8e3;
    border-color: #faebcc;
    color: #8a6d3b
}

.alert-warning hr {
    border-top-color: #f7e1b5
}

.alert-warning .alert-link {
    color: #66512c
}

.alert-danger {
    background-color: #f2dede;
    border-color: #ebccd1;
    color: #a94442
}

.alert-danger hr {
    border-top-color: #e4b9c0
}

.alert-danger .alert-link {
    color: #843534
}

.panel, .panel-full, .table-panel {
    margin-bottom: 20px;
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 3px;
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05)
}

.panel-body {
    padding: 15px
}

.panel-body:before, .panel-body:after {
    content: " ";
    display: table
}

.panel-body:after {
    clear: both
}

.panel-heading {
    padding: 10px 15px;
    border-bottom: 1px solid transparent;
    border-top-right-radius: 2px;
    border-top-left-radius: 2px
}

.panel-heading > .dropdown .dropdown-toggle {
    color: inherit
}

.panel-title {
    margin-top: 0;
    margin-bottom: 0;
    font-size: 16px;
    color: inherit
}

.panel-title > a {
    color: inherit
}

.panel-footer {
    padding: 10px 15px;
    background-color: #f5f5f5;
    border-top: 1px solid #ddd;
    border-bottom-right-radius: 2px;
    border-bottom-left-radius: 2px
}

.panel > .list-group, .panel-full > .list-group, .table-panel > .list-group {
    margin-bottom: 0
}

.panel > .list-group .list-group-item, .panel-full > .list-group .list-group-item, .table-panel > .list-group .list-group-item {
    border-width: 1px 0;
    border-radius: 0
}

.panel > .list-group:first-child .list-group-item:first-child, .panel-full > .list-group:first-child .list-group-item:first-child, .table-panel > .list-group:first-child .list-group-item:first-child {
    border-top: 0;
    border-top-right-radius: 2px;
    border-top-left-radius: 2px
}

.panel > .list-group:last-child .list-group-item:last-child, .panel-full > .list-group:last-child .list-group-item:last-child, .table-panel > .list-group:last-child .list-group-item:last-child {
    border-bottom: 0;
    border-bottom-right-radius: 2px;
    border-bottom-left-radius: 2px
}

.panel-heading + .list-group .list-group-item:first-child {
    border-top-width: 0
}

.panel > .table, .panel-full > .table, .table-panel > .table, .panel > .table-responsive > .table, .panel-full > .table-responsive > .table, .table-panel > .table-responsive > .table {
    margin-bottom: 0
}

.panel > .table:first-child, .panel-full > .table:first-child, .table-panel > .table:first-child, .panel > .table-responsive:first-child > .table:first-child, .panel-full > .table-responsive:first-child > .table:first-child, .table-panel > .table-responsive:first-child > .table:first-child {
    border-top-right-radius: 2px;
    border-top-left-radius: 2px
}

.panel > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel-full > .table:first-child > thead:first-child > tr:first-child td:first-child, .table-panel > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel-full > .table:first-child > thead:first-child > tr:first-child th:first-child, .table-panel > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel-full > .table:first-child > tbody:first-child > tr:first-child td:first-child, .table-panel > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel-full > .table:first-child > tbody:first-child > tr:first-child th:first-child, .table-panel > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel-full > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, .table-panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel-full > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, .table-panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel-full > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, .table-panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel-full > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child, .table-panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child {
    border-top-left-radius: 2px
}

.panel > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel-full > .table:first-child > thead:first-child > tr:first-child td:last-child, .table-panel > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel-full > .table:first-child > thead:first-child > tr:first-child th:last-child, .table-panel > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel-full > .table:first-child > tbody:first-child > tr:first-child td:last-child, .table-panel > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel-full > .table:first-child > tbody:first-child > tr:first-child th:last-child, .table-panel > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel-full > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, .table-panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel-full > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, .table-panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel-full > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, .table-panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel-full > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child, .table-panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child {
    border-top-right-radius: 2px
}

.panel > .table:last-child, .panel-full > .table:last-child, .table-panel > .table:last-child, .panel > .table-responsive:last-child > .table:last-child, .panel-full > .table-responsive:last-child > .table:last-child, .table-panel > .table-responsive:last-child > .table:last-child {
    border-bottom-right-radius: 2px;
    border-bottom-left-radius: 2px
}

.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel-full > .table:last-child > tbody:last-child > tr:last-child td:first-child, .table-panel > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel-full > .table:last-child > tbody:last-child > tr:last-child th:first-child, .table-panel > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel-full > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .table-panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel-full > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .table-panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel-full > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, .table-panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel-full > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, .table-panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel-full > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .table-panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel-full > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .table-panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
    border-bottom-left-radius: 2px
}

.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel-full > .table:last-child > tbody:last-child > tr:last-child td:last-child, .table-panel > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel-full > .table:last-child > tbody:last-child > tr:last-child th:last-child, .table-panel > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel-full > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .table-panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel-full > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .table-panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel-full > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, .table-panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel-full > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, .table-panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel-full > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .table-panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel-full > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .table-panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
    border-bottom-right-radius: 2px
}

.panel > .panel-body + .table, .panel-full > .panel-body + .table, .table-panel > .panel-body + .table, .panel > .panel-body + .table-responsive, .panel-full > .panel-body + .table-responsive, .table-panel > .panel-body + .table-responsive {
    border-top: 1px solid #ddd
}

.panel > .table > tbody:first-child > tr:first-child th, .panel-full > .table > tbody:first-child > tr:first-child th, .table-panel > .table > tbody:first-child > tr:first-child th, .panel > .table > tbody:first-child > tr:first-child td, .panel-full > .table > tbody:first-child > tr:first-child td, .table-panel > .table > tbody:first-child > tr:first-child td {
    border-top: 0
}

.panel > .table-bordered, .panel-full > .table-bordered, .table-panel > .table-bordered, .panel > .table-responsive > .table-bordered, .panel-full > .table-responsive > .table-bordered, .table-panel > .table-responsive > .table-bordered {
    border: 0
}

.panel > .table-bordered > thead > tr > th:first-child, .panel-full > .table-bordered > thead > tr > th:first-child, .table-panel > .table-bordered > thead > tr > th:first-child, .panel > .table-bordered > thead > tr > td:first-child, .panel-full > .table-bordered > thead > tr > td:first-child, .table-panel > .table-bordered > thead > tr > td:first-child, .panel > .table-bordered > tbody > tr > th:first-child, .panel-full > .table-bordered > tbody > tr > th:first-child, .table-panel > .table-bordered > tbody > tr > th:first-child, .panel > .table-bordered > tbody > tr > td:first-child, .panel-full > .table-bordered > tbody > tr > td:first-child, .table-panel > .table-bordered > tbody > tr > td:first-child, .panel > .table-bordered > tfoot > tr > th:first-child, .panel-full > .table-bordered > tfoot > tr > th:first-child, .table-panel > .table-bordered > tfoot > tr > th:first-child, .panel > .table-bordered > tfoot > tr > td:first-child, .panel-full > .table-bordered > tfoot > tr > td:first-child, .table-panel > .table-bordered > tfoot > tr > td:first-child, .panel > .table-responsive > .table-bordered > thead > tr > th:first-child, .panel-full > .table-responsive > .table-bordered > thead > tr > th:first-child, .table-panel > .table-responsive > .table-bordered > thead > tr > th:first-child, .panel > .table-responsive > .table-bordered > thead > tr > td:first-child, .panel-full > .table-responsive > .table-bordered > thead > tr > td:first-child, .table-panel > .table-responsive > .table-bordered > thead > tr > td:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:first-child, .panel-full > .table-responsive > .table-bordered > tbody > tr > th:first-child, .table-panel > .table-responsive > .table-bordered > tbody > tr > th:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:first-child, .panel-full > .table-responsive > .table-bordered > tbody > tr > td:first-child, .table-panel > .table-responsive > .table-bordered > tbody > tr > td:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child, .panel-full > .table-responsive > .table-bordered > tfoot > tr > th:first-child, .table-panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child, .panel-full > .table-responsive > .table-bordered > tfoot > tr > td:first-child, .table-panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child {
    border-left: 0
}

.panel > .table-bordered > thead > tr > th:last-child, .panel-full > .table-bordered > thead > tr > th:last-child, .table-panel > .table-bordered > thead > tr > th:last-child, .panel > .table-bordered > thead > tr > td:last-child, .panel-full > .table-bordered > thead > tr > td:last-child, .table-panel > .table-bordered > thead > tr > td:last-child, .panel > .table-bordered > tbody > tr > th:last-child, .panel-full > .table-bordered > tbody > tr > th:last-child, .table-panel > .table-bordered > tbody > tr > th:last-child, .panel > .table-bordered > tbody > tr > td:last-child, .panel-full > .table-bordered > tbody > tr > td:last-child, .table-panel > .table-bordered > tbody > tr > td:last-child, .panel > .table-bordered > tfoot > tr > th:last-child, .panel-full > .table-bordered > tfoot > tr > th:last-child, .table-panel > .table-bordered > tfoot > tr > th:last-child, .panel > .table-bordered > tfoot > tr > td:last-child, .panel-full > .table-bordered > tfoot > tr > td:last-child, .table-panel > .table-bordered > tfoot > tr > td:last-child, .panel > .table-responsive > .table-bordered > thead > tr > th:last-child, .panel-full > .table-responsive > .table-bordered > thead > tr > th:last-child, .table-panel > .table-responsive > .table-bordered > thead > tr > th:last-child, .panel > .table-responsive > .table-bordered > thead > tr > td:last-child, .panel-full > .table-responsive > .table-bordered > thead > tr > td:last-child, .table-panel > .table-responsive > .table-bordered > thead > tr > td:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:last-child, .panel-full > .table-responsive > .table-bordered > tbody > tr > th:last-child, .table-panel > .table-responsive > .table-bordered > tbody > tr > th:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:last-child, .panel-full > .table-responsive > .table-bordered > tbody > tr > td:last-child, .table-panel > .table-responsive > .table-bordered > tbody > tr > td:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child, .panel-full > .table-responsive > .table-bordered > tfoot > tr > th:last-child, .table-panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child, .panel-full > .table-responsive > .table-bordered > tfoot > tr > td:last-child, .table-panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child {
    border-right: 0
}

.panel > .table-bordered > thead > tr:first-child > td, .panel-full > .table-bordered > thead > tr:first-child > td, .table-panel > .table-bordered > thead > tr:first-child > td, .panel > .table-bordered > thead > tr:first-child > th, .panel-full > .table-bordered > thead > tr:first-child > th, .table-panel > .table-bordered > thead > tr:first-child > th, .panel > .table-bordered > tbody > tr:first-child > td, .panel-full > .table-bordered > tbody > tr:first-child > td, .table-panel > .table-bordered > tbody > tr:first-child > td, .panel > .table-bordered > tbody > tr:first-child > th, .panel-full > .table-bordered > tbody > tr:first-child > th, .table-panel > .table-bordered > tbody > tr:first-child > th, .panel > .table-responsive > .table-bordered > thead > tr:first-child > td, .panel-full > .table-responsive > .table-bordered > thead > tr:first-child > td, .table-panel > .table-responsive > .table-bordered > thead > tr:first-child > td, .panel > .table-responsive > .table-bordered > thead > tr:first-child > th, .panel-full > .table-responsive > .table-bordered > thead > tr:first-child > th, .table-panel > .table-responsive > .table-bordered > thead > tr:first-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > td, .panel-full > .table-responsive > .table-bordered > tbody > tr:first-child > td, .table-panel > .table-responsive > .table-bordered > tbody > tr:first-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > th, .panel-full > .table-responsive > .table-bordered > tbody > tr:first-child > th, .table-panel > .table-responsive > .table-bordered > tbody > tr:first-child > th {
    border-bottom: 0
}

.panel > .table-bordered > tbody > tr:last-child > td, .panel-full > .table-bordered > tbody > tr:last-child > td, .table-panel > .table-bordered > tbody > tr:last-child > td, .panel > .table-bordered > tbody > tr:last-child > th, .panel-full > .table-bordered > tbody > tr:last-child > th, .table-panel > .table-bordered > tbody > tr:last-child > th, .panel > .table-bordered > tfoot > tr:last-child > td, .panel-full > .table-bordered > tfoot > tr:last-child > td, .table-panel > .table-bordered > tfoot > tr:last-child > td, .panel > .table-bordered > tfoot > tr:last-child > th, .panel-full > .table-bordered > tfoot > tr:last-child > th, .table-panel > .table-bordered > tfoot > tr:last-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > td, .panel-full > .table-responsive > .table-bordered > tbody > tr:last-child > td, .table-panel > .table-responsive > .table-bordered > tbody > tr:last-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > th, .panel-full > .table-responsive > .table-bordered > tbody > tr:last-child > th, .table-panel > .table-responsive > .table-bordered > tbody > tr:last-child > th, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td, .panel-full > .table-responsive > .table-bordered > tfoot > tr:last-child > td, .table-panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th, .panel-full > .table-responsive > .table-bordered > tfoot > tr:last-child > th, .table-panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
    border-bottom: 0
}

.panel > .table-responsive, .panel-full > .table-responsive, .table-panel > .table-responsive {
    border: 0;
    margin-bottom: 0
}

.panel-group {
    margin-bottom: 20px
}

.panel-group .panel, .panel-group .panel-full, .panel-group .table-panel {
    margin-bottom: 0;
    border-radius: 3px;
    overflow: hidden
}

.panel-group .panel + .panel, .panel-group .panel-full + .panel, .panel-group .table-panel + .panel, .panel-group .panel + .panel-full, .panel-group .panel-full + .panel-full, .panel-group .table-panel + .panel-full, .panel-group .panel + .table-panel, .panel-group .panel-full + .table-panel, .panel-group .table-panel + .table-panel {
    margin-top: 5px
}

.panel-group .panel-heading {
    border-bottom: 0
}

.panel-group .panel-heading + .panel-collapse .panel-body {
    border-top: 1px solid #ddd
}

.panel-group .panel-footer {
    border-top: 0
}

.panel-group .panel-footer + .panel-collapse .panel-body {
    border-bottom: 1px solid #ddd
}

.panel-default {
    border-color: #ddd
}

.panel-default > .panel-heading {
    color: #333;
    background-color: #f5f5f5;
    border-color: #ddd
}

.panel-default > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #ddd
}

.panel-default > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #ddd
}

.panel-primary {
    border-color: #428bca
}

.panel-primary > .panel-heading {
    color: #fff;
    background-color: #428bca;
    border-color: #428bca
}

.panel-primary > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #428bca
}

.panel-primary > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #428bca
}

.panel-success {
    border-color: #d6e9c6
}

.panel-success > .panel-heading {
    color: #3c763d;
    background-color: #dff0d8;
    border-color: #d6e9c6
}

.panel-success > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #d6e9c6
}

.panel-success > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #d6e9c6
}

.panel-info {
    border-color: #bce8f1
}

.panel-info > .panel-heading {
    color: #31708f;
    background-color: #d9edf7;
    border-color: #bce8f1
}

.panel-info > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #bce8f1
}

.panel-info > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #bce8f1
}

.panel-warning {
    border-color: #faebcc
}

.panel-warning > .panel-heading {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc
}

.panel-warning > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #faebcc
}

.panel-warning > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #faebcc
}

.panel-danger {
    border-color: #ebccd1
}

.panel-danger > .panel-heading {
    color: #a94442;
    background-color: #f2dede;
    border-color: #ebccd1
}

.panel-danger > .panel-heading + .panel-collapse .panel-body {
    border-top-color: #ebccd1
}

.panel-danger > .panel-footer + .panel-collapse .panel-body {
    border-bottom-color: #ebccd1
}

.well {
    min-height: 20px;
    padding: 19px;
    margin-bottom: 20px;
    background-color: #f5f5f5;
    border: 1px solid #e3e3e3;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05)
}

.well blockquote {
    border-color: #ddd;
    border-color: rgba(0, 0, 0, 0.15)
}

.well-lg {
    padding: 24px;
    border-radius: 4px
}

.well-sm {
    padding: 9px;
    border-radius: 2px
}

.close, .rf-RepeatingFieldset__remove {
    float: right;
    font-size: 21px;
    font-weight: bold;
    line-height: 1;
    color: #000;
    text-shadow: 0 1px 0 #fff;
    opacity: .2;
    filter: alpha(opacity=20)
}

.close:hover, .rf-RepeatingFieldset__remove:hover, .close:focus, .rf-RepeatingFieldset__remove:focus {
    color: #000;
    text-decoration: none;
    cursor: pointer;
    opacity: .5;
    filter: alpha(opacity=50)
}

button.close, button.rf-RepeatingFieldset__remove {
    padding: 0;
    cursor: pointer;
    background: transparent;
    border: 0;
    -webkit-appearance: none
}

.modal-open {
    overflow: hidden
}

.modal {
    display: none;
    overflow: auto;
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1050;
    -webkit-overflow-scrolling: touch;
    outline: 0
}

.modal.fade .modal-dialog {
    -webkit-transform: translate(0, -25%);
    -ms-transform: translate(0, -25%);
    transform: translate(0, -25%);
    -webkit-transition: -webkit-transform 0.3s ease-out;
    -moz-transition: -moz-transform 0.3s ease-out;
    -o-transition: -o-transform 0.3s ease-out;
    transition: transform 0.3s ease-out
}

.modal.in .modal-dialog {
    -webkit-transform: translate(0, 0);
    -ms-transform: translate(0, 0);
    transform: translate(0, 0)
}

.modal-dialog {
    position: relative;
    width: auto;
    margin: 10px
}

.modal-content {
    position: relative;
    background-color: #fff;
    border: 1px solid #999;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 4px;
    -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    background-clip: padding-box;
    outline: none
}

.modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    background: -webkit-radial-gradient(#40404b, #111118) rgba(34, 34, 40, 0.94);
    background: radial-gradient(#40404b, #111118) rgba(34, 34, 40, 0.94)
}

.modal-backdrop.fade {
    opacity: 0;
    filter: alpha(opacity=0)
}

.modal-backdrop.in {
    opacity: .8;
    filter: alpha(opacity=80)
}

.modal-header {
    padding: 15px;
    border-bottom: 1px solid #e5e5e5;
    min-height: 16.42857px
}

.modal-header .close, .modal-header .rf-RepeatingFieldset__remove {
    margin-top: -2px
}

.modal-title {
    margin: 0;
    line-height: 1.42857
}

h1.modal-title, h2.modal-title {
    font-weight: 300
}

h5.modal-title, h4.modal-title, h3.modal-title {
    font-weight: 600
}

.modal-body {
    position: relative;
    padding: 20px
}

.modal-footer {
    margin-top: 15px;
    padding: 19px 20px 20px;
    text-align: right;
    border-top: 1px solid #e5e5e5
}

.modal-footer:before, .modal-footer:after {
    content: " ";
    display: table
}

.modal-footer:after {
    clear: both
}

.modal-footer .btn + .btn, .modal-footer .rf-RepeatingFieldset__add + .btn, .modal-footer .btn + .rf-RepeatingFieldset__add, .modal-footer .rf-RepeatingFieldset__add + .rf-RepeatingFieldset__add {
    margin-left: 5px;
    margin-bottom: 0
}

.modal-footer .btn-group .btn + .btn, .modal-footer .btn-group .rf-RepeatingFieldset__add + .btn, .modal-footer .btn-group .btn + .rf-RepeatingFieldset__add, .modal-footer .btn-group .rf-RepeatingFieldset__add + .rf-RepeatingFieldset__add {
    margin-left: -1px
}

.modal-footer .btn-block + .btn-block {
    margin-left: 0
}

@media (min-width: 768px) {
    .modal-dialog {
        width: 600px;
        margin: 30px auto
    }

    .modal-content {
        -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
        box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5)
    }

    .modal-sm {
        width: 300px
    }
}

@media (min-width: 992px) {
    .modal-lg {
        width: 900px
    }
}

.tooltip {
    position: absolute;
    z-index: 1030;
    display: block;
    visibility: visible;
    font-size: 12px;
    line-height: 1.4;
    opacity: 0;
    filter: alpha(opacity=0)
}

.tooltip.in {
    opacity: .9;
    filter: alpha(opacity=90)
}

.tooltip.top {
    margin-top: -3px;
    padding: 5px 0
}

.tooltip.right {
    margin-left: 3px;
    padding: 0 5px
}

.tooltip.bottom {
    margin-top: 3px;
    padding: 5px 0
}

.tooltip.left {
    margin-left: -3px;
    padding: 0 5px
}

.tooltip-inner {
    max-width: 200px;
    padding: 3px 8px;
    color: #fff;
    text-align: center;
    text-decoration: none;
    background-color: #000;
    border-radius: 3px
}

.tooltip-arrow {
    position: absolute;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid
}

.tooltip.top .tooltip-arrow {
    bottom: 0;
    left: 50%;
    margin-left: -5px;
    border-width: 5px 5px 0;
    border-top-color: #000
}

.tooltip.top-left .tooltip-arrow {
    bottom: 0;
    left: 5px;
    border-width: 5px 5px 0;
    border-top-color: #000
}

.tooltip.top-right .tooltip-arrow {
    bottom: 0;
    right: 5px;
    border-width: 5px 5px 0;
    border-top-color: #000
}

.tooltip.right .tooltip-arrow {
    top: 50%;
    left: 0;
    margin-top: -5px;
    border-width: 5px 5px 5px 0;
    border-right-color: #000
}

.tooltip.left .tooltip-arrow {
    top: 50%;
    right: 0;
    margin-top: -5px;
    border-width: 5px 0 5px 5px;
    border-left-color: #000
}

.tooltip.bottom .tooltip-arrow {
    top: 0;
    left: 50%;
    margin-left: -5px;
    border-width: 0 5px 5px;
    border-bottom-color: #000
}

.tooltip.bottom-left .tooltip-arrow {
    top: 0;
    left: 5px;
    border-width: 0 5px 5px;
    border-bottom-color: #000
}

.tooltip.bottom-right .tooltip-arrow {
    top: 0;
    right: 5px;
    border-width: 0 5px 5px;
    border-bottom-color: #000
}

.popover {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 1010;
    display: none;
    max-width: 276px;
    padding: 1px;
    text-align: left;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 4px;
    -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    white-space: normal
}

.popover.top {
    margin-top: -10px
}

.popover.right {
    margin-left: 10px
}

.popover.bottom {
    margin-top: 10px
}

.popover.left {
    margin-left: -10px
}

.popover-title {
    margin: 0;
    padding: 8px 14px;
    font-size: 14px;
    font-weight: normal;
    line-height: 18px;
    background-color: #f7f7f7;
    border-bottom: 1px solid #ebebeb;
    border-radius: 5px 5px 0 0
}

.popover-content {
    padding: 9px 14px
}

.popover > .arrow, .popover > .arrow:after {
    position: absolute;
    display: block;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid
}

.popover > .arrow {
    border-width: 11px
}

.popover > .arrow:after {
    border-width: 10px;
    content: ""
}

.popover.top > .arrow {
    left: 50%;
    margin-left: -11px;
    border-bottom-width: 0;
    border-top-color: #999;
    border-top-color: fadein(rgba(0, 0, 0, 0.2), 5%);
    bottom: -11px
}

.popover.top > .arrow:after {
    content: " ";
    bottom: 1px;
    margin-left: -10px;
    border-bottom-width: 0;
    border-top-color: #fff
}

.popover.right > .arrow {
    top: 50%;
    left: -11px;
    margin-top: -11px;
    border-left-width: 0;
    border-right-color: #999;
    border-right-color: fadein(rgba(0, 0, 0, 0.2), 5%)
}

.popover.right > .arrow:after {
    content: " ";
    left: 1px;
    bottom: -10px;
    border-left-width: 0;
    border-right-color: #fff
}

.popover.bottom > .arrow {
    left: 50%;
    margin-left: -11px;
    border-top-width: 0;
    border-bottom-color: #999;
    border-bottom-color: fadein(rgba(0, 0, 0, 0.2), 5%);
    top: -11px
}

.popover.bottom > .arrow:after {
    content: " ";
    top: 1px;
    margin-left: -10px;
    border-top-width: 0;
    border-bottom-color: #fff
}

.popover.left > .arrow {
    top: 50%;
    right: -11px;
    margin-top: -11px;
    border-right-width: 0;
    border-left-color: #999;
    border-left-color: fadein(rgba(0, 0, 0, 0.2), 5%)
}

.popover.left > .arrow:after {
    content: " ";
    right: 1px;
    border-right-width: 0;
    border-left-color: #fff;
    bottom: -10px
}

/*!
 *  Font Awesome 4.7.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
@font-face {
    font-family: 'FontAwesome';
    src: url("../font/fontawesome-webfont.eot?v=4.7.0");
    src: url("../font/fontawesome-webfont.eot?#iefix&v=4.7.0") format("embedded-opentype"), url("../font/fontawesome-webfont.woff2?v=4.7.0") format("woff2"), url("../font/fontawesome-webfont.woff?v=4.7.0") format("woff"), url("../font/fontawesome-webfont.ttf?v=4.7.0") format("truetype"), url("../font/fontawesome-webfont.svg?v=4.7.0#fontawesomeregular") format("svg");
    font-weight: normal;
    font-style: normal;
    font-display: block
}

.icon, .tcell-sort, .tcell-asc, .tcell-desc {
    display: inline-block;
    font: normal normal normal 14px/1 FontAwesome;
    font-size: inherit;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale
}

.icon-lg {
    font-size: 1.33333em;
    line-height: .75em;
    vertical-align: -15%
}

.icon-2x {
    font-size: 2em
}

.icon-3x {
    font-size: 3em
}

.icon-4x {
    font-size: 4em
}

.icon-5x {
    font-size: 5em
}

.icon-fw {
    width: 1.28571em;
    text-align: center
}

.icon-ul {
    padding-left: 0;
    margin-left: 2.14286em;
    list-style-type: none
}

.icon-ul > li {
    position: relative
}

.icon-li {
    position: absolute;
    left: -2.14286em;
    width: 2.14286em;
    top: .14286em;
    text-align: center
}

.icon-li.icon-lg {
    left: -1.85714em
}

.icon-border {
    padding: .2em .25em .15em;
    border: solid 0.08em #eee;
    border-radius: .1em
}

.icon-pull-left {
    float: left
}

.icon-pull-right {
    float: right
}

.icon.icon-pull-left, .icon-pull-left.tcell-sort, .icon-pull-left.tcell-asc, .icon-pull-left.tcell-desc {
    margin-right: .3em
}

.icon.icon-pull-right, .icon-pull-right.tcell-sort, .icon-pull-right.tcell-asc, .icon-pull-right.tcell-desc {
    margin-left: .3em
}

.pull-right {
    float: right
}

.pull-left {
    float: left
}

.icon.pull-left, .pull-left.tcell-sort, .pull-left.tcell-asc, .pull-left.tcell-desc {
    margin-right: .3em
}

.icon.pull-right, .pull-right.tcell-sort, .pull-right.tcell-asc, .pull-right.tcell-desc {
    margin-left: .3em
}

.icon-spin {
    -webkit-animation: fa-spin 2s infinite linear;
    animation: fa-spin 2s infinite linear
}

.icon-pulse {
    -webkit-animation: fa-spin 1s infinite steps(8);
    animation: fa-spin 1s infinite steps(8)
}

@-webkit-keyframes fa-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg)
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg)
    }
}

@keyframes fa-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg)
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg)
    }
}

.icon-rotate-90 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg)
}

.icon-rotate-180 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}

.icon-rotate-270 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
    -webkit-transform: rotate(270deg);
    -ms-transform: rotate(270deg);
    transform: rotate(270deg)
}

.icon-flip-horizontal {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
    -webkit-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1)
}

.icon-flip-vertical {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
    -webkit-transform: scale(1, -1);
    -ms-transform: scale(1, -1);
    transform: scale(1, -1)
}

:root .icon-rotate-90, :root .icon-rotate-180, :root .icon-rotate-270, :root .icon-flip-horizontal, :root .icon-flip-vertical {
    filter: none
}

.icon-stack {
    position: relative;
    display: inline-block;
    width: 2em;
    height: 2em;
    line-height: 2em;
    vertical-align: middle
}

.icon-stack-1x, .icon-stack-2x {
    position: absolute;
    left: 0;
    width: 100%;
    text-align: center
}

.icon-stack-1x {
    line-height: inherit
}

.icon-stack-2x {
    font-size: 2em
}

.icon-inverse {
    color: #fff
}

.icon-glass:before {
    content: ""
}

.icon-music:before {
    content: ""
}

.icon-search:before {
    content: ""
}

.icon-envelope-o:before {
    content: ""
}

.icon-heart:before {
    content: ""
}

.icon-star:before {
    content: ""
}

.icon-star-o:before {
    content: ""
}

.icon-user:before {
    content: ""
}

.icon-film:before {
    content: ""
}

.icon-th-large:before {
    content: ""
}

.icon-th:before {
    content: ""
}

.icon-th-list:before {
    content: ""
}

.icon-check:before, .audit-icon-ok:before, .audit-icon-ok-badged:before, .audit-activeicon-ok:before {
    content: ""
}

.icon-remove:before, .icon-close:before, .icon-times:before {
    content: ""
}

.icon-search-plus:before {
    content: ""
}

.icon-search-minus:before {
    content: ""
}

.icon-power-off:before {
    content: ""
}

.icon-signal:before {
    content: ""
}

.icon-gear:before, .icon-cog:before {
    content: ""
}

.icon-trash-o:before {
    content: ""
}

.icon-home:before {
    content: ""
}

.icon-file-o:before {
    content: ""
}

.icon-clock-o:before {
    content: ""
}

.icon-road:before {
    content: ""
}

.icon-download:before {
    content: ""
}

.icon-arrow-circle-o-down:before {
    content: ""
}

.icon-arrow-circle-o-up:before {
    content: ""
}

.icon-inbox:before {
    content: ""
}

.icon-play-circle-o:before {
    content: ""
}

.icon-rotate-right:before, .icon-repeat:before {
    content: ""
}

.icon-refresh:before {
    content: ""
}

.icon-list-alt:before {
    content: ""
}

.icon-lock:before {
    content: ""
}

.icon-flag:before {
    content: ""
}

.icon-headphones:before {
    content: ""
}

.icon-volume-off:before {
    content: ""
}

.icon-volume-down:before {
    content: ""
}

.icon-volume-up:before {
    content: ""
}

.icon-qrcode:before {
    content: ""
}

.icon-barcode:before {
    content: ""
}

.icon-tag:before {
    content: ""
}

.icon-tags:before {
    content: ""
}

.icon-book:before {
    content: ""
}

.icon-bookmark:before {
    content: ""
}

.icon-print:before {
    content: ""
}

.icon-camera:before {
    content: ""
}

.icon-font:before {
    content: ""
}

.icon-bold:before {
    content: ""
}

.icon-italic:before {
    content: ""
}

.icon-text-height:before {
    content: ""
}

.icon-text-width:before {
    content: ""
}

.icon-align-left:before {
    content: ""
}

.icon-align-center:before {
    content: ""
}

.icon-align-right:before {
    content: ""
}

.icon-align-justify:before {
    content: ""
}

.icon-list:before {
    content: ""
}

.icon-dedent:before, .icon-outdent:before {
    content: ""
}

.icon-indent:before {
    content: ""
}

.icon-video-camera:before {
    content: ""
}

.icon-photo:before, .icon-image:before, .icon-picture-o:before {
    content: ""
}

.icon-pencil:before {
    content: ""
}

.icon-map-marker:before {
    content: ""
}

.icon-adjust:before {
    content: ""
}

.icon-tint:before {
    content: ""
}

.icon-edit:before, .icon-pencil-square-o:before {
    content: ""
}

.icon-share-square-o:before {
    content: ""
}

.icon-check-square-o:before {
    content: ""
}

.icon-arrows:before {
    content: ""
}

.icon-step-backward:before {
    content: ""
}

.icon-fast-backward:before {
    content: ""
}

.icon-backward:before {
    content: ""
}

.icon-play:before {
    content: ""
}

.icon-pause:before {
    content: ""
}

.icon-stop:before {
    content: ""
}

.icon-forward:before {
    content: ""
}

.icon-fast-forward:before {
    content: ""
}

.icon-step-forward:before {
    content: ""
}

.icon-eject:before {
    content: ""
}

.icon-chevron-left:before {
    content: ""
}

.icon-chevron-right:before {
    content: ""
}

.icon-plus-circle:before {
    content: ""
}

.icon-minus-circle:before {
    content: ""
}

.icon-times-circle:before {
    content: ""
}

.icon-check-circle:before {
    content: ""
}

.icon-question-circle:before {
    content: ""
}

.icon-info-circle:before {
    content: ""
}

.icon-crosshairs:before {
    content: ""
}

.icon-times-circle-o:before {
    content: ""
}

.icon-check-circle-o:before {
    content: ""
}

.icon-ban:before {
    content: ""
}

.icon-arrow-left:before {
    content: ""
}

.icon-arrow-right:before {
    content: ""
}

.icon-arrow-up:before {
    content: ""
}

.icon-arrow-down:before {
    content: ""
}

.icon-mail-forward:before, .icon-share:before {
    content: ""
}

.icon-expand:before {
    content: ""
}

.icon-compress:before {
    content: ""
}

.icon-plus:before {
    content: ""
}

.icon-minus:before {
    content: ""
}

.icon-asterisk:before {
    content: ""
}

.icon-exclamation-circle:before, .audit-icon-warning:before, .audit-icon-warning-badged:before, .audit-activeicon-warning:before {
    content: ""
}

.icon-gift:before {
    content: ""
}

.icon-leaf:before {
    content: ""
}

.icon-fire:before {
    content: ""
}

.icon-eye:before {
    content: ""
}

.icon-eye-slash:before {
    content: ""
}

.icon-warning:before, .audit-icon-error:before, .audit-icon-error-badged:before, .audit-activeicon-error:before, .icon-exclamation-triangle:before {
    content: ""
}

.icon-plane:before {
    content: ""
}

.icon-calendar:before {
    content: ""
}

.icon-random:before {
    content: ""
}

.icon-comment:before {
    content: ""
}

.icon-magnet:before {
    content: ""
}

.icon-chevron-up:before {
    content: ""
}

.icon-chevron-down:before {
    content: ""
}

.icon-retweet:before {
    content: ""
}

.icon-shopping-cart:before {
    content: ""
}

.icon-folder:before {
    content: ""
}

.icon-folder-open:before {
    content: ""
}

.icon-arrows-v:before {
    content: ""
}

.icon-arrows-h:before {
    content: ""
}

.icon-bar-chart-o:before, .icon-bar-chart:before {
    content: ""
}

.icon-twitter-square:before {
    content: ""
}

.icon-facebook-square:before {
    content: ""
}

.icon-camera-retro:before {
    content: ""
}

.icon-key:before {
    content: ""
}

.icon-gears:before, .icon-cogs:before {
    content: ""
}

.icon-comments:before {
    content: ""
}

.icon-thumbs-o-up:before {
    content: ""
}

.icon-thumbs-o-down:before {
    content: ""
}

.icon-star-half:before {
    content: ""
}

.icon-heart-o:before {
    content: ""
}

.icon-sign-out:before {
    content: ""
}

.icon-linkedin-square:before {
    content: ""
}

.icon-thumb-tack:before {
    content: ""
}

.icon-external-link:before {
    content: ""
}

.icon-sign-in:before {
    content: ""
}

.icon-trophy:before {
    content: ""
}

.icon-github-square:before {
    content: ""
}

.icon-upload:before {
    content: ""
}

.icon-lemon-o:before {
    content: ""
}

.icon-phone:before {
    content: ""
}

.icon-square-o:before {
    content: ""
}

.icon-bookmark-o:before {
    content: ""
}

.icon-phone-square:before {
    content: ""
}

.icon-twitter:before {
    content: ""
}

.icon-facebook-f:before, .icon-facebook:before {
    content: ""
}

.icon-github:before {
    content: ""
}

.icon-unlock:before {
    content: ""
}

.icon-credit-card:before {
    content: ""
}

.icon-feed:before, .icon-rss:before {
    content: ""
}

.icon-hdd-o:before {
    content: ""
}

.icon-bullhorn:before {
    content: ""
}

.icon-bell:before {
    content: ""
}

.icon-certificate:before {
    content: ""
}

.icon-hand-o-right:before {
    content: ""
}

.icon-hand-o-left:before {
    content: ""
}

.icon-hand-o-up:before {
    content: ""
}

.icon-hand-o-down:before {
    content: ""
}

.icon-arrow-circle-left:before {
    content: ""
}

.icon-arrow-circle-right:before {
    content: ""
}

.icon-arrow-circle-up:before {
    content: ""
}

.icon-arrow-circle-down:before {
    content: ""
}

.icon-globe:before {
    content: ""
}

.icon-wrench:before {
    content: ""
}

.icon-tasks:before {
    content: ""
}

.icon-filter:before {
    content: ""
}

.icon-briefcase:before {
    content: ""
}

.icon-arrows-alt:before {
    content: ""
}

.icon-group:before, .icon-users:before {
    content: ""
}

.icon-chain:before, .icon-link:before {
    content: ""
}

.icon-cloud:before {
    content: ""
}

.icon-flask:before {
    content: ""
}

.icon-cut:before, .icon-scissors:before {
    content: ""
}

.icon-copy:before, .icon-files-o:before {
    content: ""
}

.icon-paperclip:before {
    content: ""
}

.icon-save:before, .icon-floppy-o:before {
    content: ""
}

.icon-square:before {
    content: ""
}

.icon-navicon:before, .icon-reorder:before, .icon-bars:before {
    content: ""
}

.icon-list-ul:before {
    content: ""
}

.icon-list-ol:before {
    content: ""
}

.icon-strikethrough:before {
    content: ""
}

.icon-underline:before {
    content: ""
}

.icon-table:before {
    content: ""
}

.icon-magic:before {
    content: ""
}

.icon-truck:before {
    content: ""
}

.icon-pinterest:before {
    content: ""
}

.icon-pinterest-square:before {
    content: ""
}

.icon-google-plus-square:before {
    content: ""
}

.icon-google-plus:before {
    content: ""
}

.icon-money:before {
    content: ""
}

.icon-caret-down:before, .detail-trigger:before, .audit-detail-trigger-icon:before {
    content: ""
}

.icon-caret-up:before {
    content: ""
}

.icon-caret-left:before {
    content: ""
}

.icon-caret-right:before {
    content: ""
}

.icon-columns:before {
    content: ""
}

.icon-unsorted:before, .icon-sort:before, .tcell-sort:before {
    content: ""
}

.icon-sort-down:before, .icon-sort-desc:before, .tcell-desc:before {
    content: ""
}

.icon-sort-up:before, .icon-sort-asc:before, .tcell-asc:before {
    content: ""
}

.icon-envelope:before {
    content: ""
}

.icon-linkedin:before {
    content: ""
}

.icon-rotate-left:before, .icon-undo:before {
    content: ""
}

.icon-legal:before, .icon-gavel:before {
    content: ""
}

.icon-dashboard:before, .icon-tachometer:before {
    content: ""
}

.icon-comment-o:before {
    content: ""
}

.icon-comments-o:before {
    content: ""
}

.icon-flash:before, .icon-bolt:before {
    content: ""
}

.icon-sitemap:before {
    content: ""
}

.icon-umbrella:before {
    content: ""
}

.icon-paste:before, .icon-clipboard:before {
    content: ""
}

.icon-lightbulb-o:before {
    content: ""
}

.icon-exchange:before {
    content: ""
}

.icon-cloud-download:before {
    content: ""
}

.icon-cloud-upload:before {
    content: ""
}

.icon-user-md:before {
    content: ""
}

.icon-stethoscope:before {
    content: ""
}

.icon-suitcase:before {
    content: ""
}

.icon-bell-o:before {
    content: ""
}

.icon-coffee:before {
    content: ""
}

.icon-cutlery:before {
    content: ""
}

.icon-file-text-o:before {
    content: ""
}

.icon-building-o:before {
    content: ""
}

.icon-hospital-o:before {
    content: ""
}

.icon-ambulance:before, .audit-icon-dcc_action:before, .audit-icon-dcc_action-badged:before, .audit-activeicon-dcc_action:before {
    content: ""
}

.icon-medkit:before {
    content: ""
}

.icon-fighter-jet:before {
    content: ""
}

.icon-beer:before {
    content: ""
}

.icon-h-square:before {
    content: ""
}

.icon-plus-square:before {
    content: ""
}

.icon-angle-double-left:before {
    content: ""
}

.icon-angle-double-right:before {
    content: ""
}

.icon-angle-double-up:before {
    content: ""
}

.icon-angle-double-down:before {
    content: ""
}

.icon-angle-left:before {
    content: ""
}

.icon-angle-right:before {
    content: ""
}

.icon-angle-up:before {
    content: ""
}

.icon-angle-down:before {
    content: ""
}

.icon-desktop:before {
    content: ""
}

.icon-laptop:before {
    content: ""
}

.icon-tablet:before {
    content: ""
}

.icon-mobile-phone:before, .icon-mobile:before {
    content: ""
}

.icon-circle-o:before {
    content: ""
}

.icon-quote-left:before {
    content: ""
}

.icon-quote-right:before {
    content: ""
}

.icon-spinner:before {
    content: ""
}

.icon-circle:before {
    content: ""
}

.icon-mail-reply:before, .icon-reply:before {
    content: ""
}

.icon-github-alt:before {
    content: ""
}

.icon-folder-o:before {
    content: ""
}

.icon-folder-open-o:before {
    content: ""
}

.icon-smile-o:before {
    content: ""
}

.icon-frown-o:before {
    content: ""
}

.icon-meh-o:before {
    content: ""
}

.icon-gamepad:before {
    content: ""
}

.icon-keyboard-o:before {
    content: ""
}

.icon-flag-o:before {
    content: ""
}

.icon-flag-checkered:before {
    content: ""
}

.icon-terminal:before {
    content: ""
}

.icon-code:before {
    content: ""
}

.icon-mail-reply-all:before, .icon-reply-all:before {
    content: ""
}

.icon-star-half-empty:before, .icon-star-half-full:before, .icon-star-half-o:before {
    content: ""
}

.icon-location-arrow:before {
    content: ""
}

.icon-crop:before {
    content: ""
}

.icon-code-fork:before {
    content: ""
}

.icon-unlink:before, .icon-chain-broken:before {
    content: ""
}

.icon-question:before {
    content: ""
}

.icon-info:before {
    content: ""
}

.icon-exclamation:before {
    content: ""
}

.icon-superscript:before {
    content: ""
}

.icon-subscript:before {
    content: ""
}

.icon-eraser:before {
    content: ""
}

.icon-puzzle-piece:before {
    content: ""
}

.icon-microphone:before {
    content: ""
}

.icon-microphone-slash:before {
    content: ""
}

.icon-shield:before {
    content: ""
}

.icon-calendar-o:before {
    content: ""
}

.icon-fire-extinguisher:before {
    content: ""
}

.icon-rocket:before {
    content: ""
}

.icon-maxcdn:before {
    content: ""
}

.icon-chevron-circle-left:before {
    content: ""
}

.icon-chevron-circle-right:before {
    content: ""
}

.icon-chevron-circle-up:before {
    content: ""
}

.icon-chevron-circle-down:before {
    content: ""
}

.icon-html5:before {
    content: ""
}

.icon-css3:before {
    content: ""
}

.icon-anchor:before {
    content: ""
}

.icon-unlock-alt:before {
    content: ""
}

.icon-bullseye:before {
    content: ""
}

.icon-ellipsis-h:before {
    content: ""
}

.icon-ellipsis-v:before {
    content: ""
}

.icon-rss-square:before {
    content: ""
}

.icon-play-circle:before {
    content: ""
}

.icon-ticket:before {
    content: ""
}

.icon-minus-square:before {
    content: ""
}

.icon-minus-square-o:before {
    content: ""
}

.icon-level-up:before {
    content: ""
}

.icon-level-down:before {
    content: ""
}

.icon-check-square:before {
    content: ""
}

.icon-pencil-square:before {
    content: ""
}

.icon-external-link-square:before {
    content: ""
}

.icon-share-square:before {
    content: ""
}

.icon-compass:before {
    content: ""
}

.icon-toggle-down:before, .icon-caret-square-o-down:before {
    content: ""
}

.icon-toggle-up:before, .icon-caret-square-o-up:before {
    content: ""
}

.icon-toggle-right:before, .icon-caret-square-o-right:before {
    content: ""
}

.icon-euro:before, .icon-eur:before {
    content: ""
}

.icon-gbp:before {
    content: ""
}

.icon-dollar:before, .icon-usd:before {
    content: ""
}

.icon-rupee:before, .icon-inr:before {
    content: ""
}

.icon-cny:before, .icon-rmb:before, .icon-yen:before, .icon-jpy:before {
    content: ""
}

.icon-ruble:before, .icon-rouble:before, .icon-rub:before {
    content: ""
}

.icon-won:before, .icon-krw:before {
    content: ""
}

.icon-bitcoin:before, .icon-btc:before {
    content: ""
}

.icon-file:before {
    content: ""
}

.icon-file-text:before, .audit-icon-not_compliant:before, .audit-icon-not_compliant-badged:before, .audit-activeicon-not_compliant:before {
    content: ""
}

.icon-sort-alpha-asc:before {
    content: ""
}

.icon-sort-alpha-desc:before {
    content: ""
}

.icon-sort-amount-asc:before {
    content: ""
}

.icon-sort-amount-desc:before {
    content: ""
}

.icon-sort-numeric-asc:before {
    content: ""
}

.icon-sort-numeric-desc:before {
    content: ""
}

.icon-thumbs-up:before {
    content: ""
}

.icon-thumbs-down:before {
    content: ""
}

.icon-youtube-square:before {
    content: ""
}

.icon-youtube:before {
    content: ""
}

.icon-xing:before {
    content: ""
}

.icon-xing-square:before {
    content: ""
}

.icon-youtube-play:before {
    content: ""
}

.icon-dropbox:before {
    content: ""
}

.icon-stack-overflow:before {
    content: ""
}

.icon-instagram:before {
    content: ""
}

.icon-flickr:before {
    content: ""
}

.icon-adn:before {
    content: ""
}

.icon-bitbucket:before {
    content: ""
}

.icon-bitbucket-square:before {
    content: ""
}

.icon-tumblr:before {
    content: ""
}

.icon-tumblr-square:before {
    content: ""
}

.icon-long-arrow-down:before {
    content: ""
}

.icon-long-arrow-up:before {
    content: ""
}

.icon-long-arrow-left:before {
    content: ""
}

.icon-long-arrow-right:before {
    content: ""
}

.icon-apple:before {
    content: ""
}

.icon-windows:before {
    content: ""
}

.icon-android:before {
    content: ""
}

.icon-linux:before {
    content: ""
}

.icon-dribbble:before {
    content: ""
}

.icon-skype:before {
    content: ""
}

.icon-foursquare:before {
    content: ""
}

.icon-trello:before {
    content: ""
}

.icon-female:before {
    content: ""
}

.icon-male:before {
    content: ""
}

.icon-gittip:before, .icon-gratipay:before {
    content: ""
}

.icon-sun-o:before {
    content: ""
}

.icon-moon-o:before {
    content: ""
}

.icon-archive:before {
    content: ""
}

.icon-bug:before {
    content: ""
}

.icon-vk:before {
    content: ""
}

.icon-weibo:before {
    content: ""
}

.icon-renren:before {
    content: ""
}

.icon-pagelines:before {
    content: ""
}

.icon-stack-exchange:before {
    content: ""
}

.icon-arrow-circle-o-right:before {
    content: ""
}

.icon-arrow-circle-o-left:before {
    content: ""
}

.icon-toggle-left:before, .icon-caret-square-o-left:before {
    content: ""
}

.icon-dot-circle-o:before {
    content: ""
}

.icon-wheelchair:before {
    content: ""
}

.icon-vimeo-square:before {
    content: ""
}

.icon-turkish-lira:before, .icon-try:before {
    content: ""
}

.icon-plus-square-o:before {
    content: ""
}

.icon-space-shuttle:before {
    content: ""
}

.icon-slack:before {
    content: ""
}

.icon-envelope-square:before {
    content: ""
}

.icon-wordpress:before {
    content: ""
}

.icon-openid:before {
    content: ""
}

.icon-institution:before, .icon-bank:before, .icon-university:before {
    content: ""
}

.icon-mortar-board:before, .icon-graduation-cap:before {
    content: ""
}

.icon-yahoo:before {
    content: ""
}

.icon-google:before {
    content: ""
}

.icon-reddit:before {
    content: ""
}

.icon-reddit-square:before {
    content: ""
}

.icon-stumbleupon-circle:before {
    content: ""
}

.icon-stumbleupon:before {
    content: ""
}

.icon-delicious:before {
    content: ""
}

.icon-digg:before {
    content: ""
}

.icon-pied-piper-pp:before {
    content: ""
}

.icon-pied-piper-alt:before {
    content: ""
}

.icon-drupal:before {
    content: ""
}

.icon-joomla:before {
    content: ""
}

.icon-language:before {
    content: ""
}

.icon-fax:before {
    content: ""
}

.icon-building:before {
    content: ""
}

.icon-child:before {
    content: ""
}

.icon-paw:before {
    content: ""
}

.icon-spoon:before {
    content: ""
}

.icon-cube:before {
    content: ""
}

.icon-cubes:before {
    content: ""
}

.icon-behance:before {
    content: ""
}

.icon-behance-square:before {
    content: ""
}

.icon-steam:before {
    content: ""
}

.icon-steam-square:before {
    content: ""
}

.icon-recycle:before {
    content: ""
}

.icon-automobile:before, .icon-car:before {
    content: ""
}

.icon-cab:before, .icon-taxi:before {
    content: ""
}

.icon-tree:before {
    content: ""
}

.icon-spotify:before {
    content: ""
}

.icon-deviantart:before {
    content: ""
}

.icon-soundcloud:before {
    content: ""
}

.icon-database:before {
    content: ""
}

.icon-file-pdf-o:before {
    content: ""
}

.icon-file-word-o:before {
    content: ""
}

.icon-file-excel-o:before {
    content: ""
}

.icon-file-powerpoint-o:before {
    content: ""
}

.icon-file-photo-o:before, .icon-file-picture-o:before, .icon-file-image-o:before {
    content: ""
}

.icon-file-zip-o:before, .icon-file-archive-o:before {
    content: ""
}

.icon-file-sound-o:before, .icon-file-audio-o:before {
    content: ""
}

.icon-file-movie-o:before, .icon-file-video-o:before {
    content: ""
}

.icon-file-code-o:before {
    content: ""
}

.icon-vine:before {
    content: ""
}

.icon-codepen:before {
    content: ""
}

.icon-jsfiddle:before {
    content: ""
}

.icon-life-bouy:before, .icon-life-buoy:before, .icon-life-saver:before, .icon-support:before, .icon-life-ring:before {
    content: ""
}

.icon-circle-o-notch:before {
    content: ""
}

.icon-ra:before, .icon-resistance:before, .icon-rebel:before {
    content: ""
}

.icon-ge:before, .icon-empire:before {
    content: ""
}

.icon-git-square:before {
    content: ""
}

.icon-git:before {
    content: ""
}

.icon-y-combinator-square:before, .icon-yc-square:before, .icon-hacker-news:before {
    content: ""
}

.icon-tencent-weibo:before {
    content: ""
}

.icon-qq:before {
    content: ""
}

.icon-wechat:before, .icon-weixin:before {
    content: ""
}

.icon-send:before, .icon-paper-plane:before {
    content: ""
}

.icon-send-o:before, .icon-paper-plane-o:before {
    content: ""
}

.icon-history:before {
    content: ""
}

.icon-circle-thin:before {
    content: ""
}

.icon-header:before {
    content: ""
}

.icon-paragraph:before {
    content: ""
}

.icon-sliders:before {
    content: ""
}

.icon-share-alt:before {
    content: ""
}

.icon-share-alt-square:before {
    content: ""
}

.icon-bomb:before {
    content: ""
}

.icon-soccer-ball-o:before, .icon-futbol-o:before {
    content: ""
}

.icon-tty:before {
    content: ""
}

.icon-binoculars:before {
    content: ""
}

.icon-plug:before {
    content: ""
}

.icon-slideshare:before {
    content: ""
}

.icon-twitch:before {
    content: ""
}

.icon-yelp:before {
    content: ""
}

.icon-newspaper-o:before {
    content: ""
}

.icon-wifi:before {
    content: ""
}

.icon-calculator:before {
    content: ""
}

.icon-paypal:before {
    content: ""
}

.icon-google-wallet:before {
    content: ""
}

.icon-cc-visa:before {
    content: ""
}

.icon-cc-mastercard:before {
    content: ""
}

.icon-cc-discover:before {
    content: ""
}

.icon-cc-amex:before {
    content: ""
}

.icon-cc-paypal:before {
    content: ""
}

.icon-cc-stripe:before {
    content: ""
}

.icon-bell-slash:before {
    content: ""
}

.icon-bell-slash-o:before {
    content: ""
}

.icon-trash:before {
    content: ""
}

.icon-copyright:before {
    content: ""
}

.icon-at:before {
    content: ""
}

.icon-eyedropper:before {
    content: ""
}

.icon-paint-brush:before {
    content: ""
}

.icon-birthday-cake:before {
    content: ""
}

.icon-area-chart:before {
    content: ""
}

.icon-pie-chart:before {
    content: ""
}

.icon-line-chart:before {
    content: ""
}

.icon-lastfm:before {
    content: ""
}

.icon-lastfm-square:before {
    content: ""
}

.icon-toggle-off:before {
    content: ""
}

.icon-toggle-on:before {
    content: ""
}

.icon-bicycle:before {
    content: ""
}

.icon-bus:before {
    content: ""
}

.icon-ioxhost:before {
    content: ""
}

.icon-angellist:before {
    content: ""
}

.icon-cc:before {
    content: ""
}

.icon-shekel:before, .icon-sheqel:before, .icon-ils:before {
    content: ""
}

.icon-meanpath:before {
    content: ""
}

.icon-buysellads:before {
    content: ""
}

.icon-connectdevelop:before {
    content: ""
}

.icon-dashcube:before {
    content: ""
}

.icon-forumbee:before {
    content: ""
}

.icon-leanpub:before {
    content: ""
}

.icon-sellsy:before {
    content: ""
}

.icon-shirtsinbulk:before {
    content: ""
}

.icon-simplybuilt:before {
    content: ""
}

.icon-skyatlas:before {
    content: ""
}

.icon-cart-plus:before {
    content: ""
}

.icon-cart-arrow-down:before {
    content: ""
}

.icon-diamond:before {
    content: ""
}

.icon-ship:before {
    content: ""
}

.icon-user-secret:before {
    content: ""
}

.icon-motorcycle:before {
    content: ""
}

.icon-street-view:before {
    content: ""
}

.icon-heartbeat:before {
    content: ""
}

.icon-venus:before {
    content: ""
}

.icon-mars:before {
    content: ""
}

.icon-mercury:before {
    content: ""
}

.icon-intersex:before, .icon-transgender:before {
    content: ""
}

.icon-transgender-alt:before {
    content: ""
}

.icon-venus-double:before {
    content: ""
}

.icon-mars-double:before {
    content: ""
}

.icon-venus-mars:before {
    content: ""
}

.icon-mars-stroke:before {
    content: ""
}

.icon-mars-stroke-v:before {
    content: ""
}

.icon-mars-stroke-h:before {
    content: ""
}

.icon-neuter:before {
    content: ""
}

.icon-genderless:before {
    content: ""
}

.icon-facebook-official:before {
    content: ""
}

.icon-pinterest-p:before {
    content: ""
}

.icon-whatsapp:before {
    content: ""
}

.icon-server:before {
    content: ""
}

.icon-user-plus:before {
    content: ""
}

.icon-user-times:before {
    content: ""
}

.icon-hotel:before, .icon-bed:before {
    content: ""
}

.icon-viacoin:before {
    content: ""
}

.icon-train:before {
    content: ""
}

.icon-subway:before {
    content: ""
}

.icon-medium:before {
    content: ""
}

.icon-yc:before, .icon-y-combinator:before {
    content: ""
}

.icon-optin-monster:before {
    content: ""
}

.icon-opencart:before {
    content: ""
}

.icon-expeditedssl:before {
    content: ""
}

.icon-battery-4:before, .icon-battery:before, .icon-battery-full:before {
    content: ""
}

.icon-battery-3:before, .icon-battery-three-quarters:before {
    content: ""
}

.icon-battery-2:before, .icon-battery-half:before {
    content: ""
}

.icon-battery-1:before, .icon-battery-quarter:before {
    content: ""
}

.icon-battery-0:before, .icon-battery-empty:before {
    content: ""
}

.icon-mouse-pointer:before {
    content: ""
}

.icon-i-cursor:before {
    content: ""
}

.icon-object-group:before {
    content: ""
}

.icon-object-ungroup:before {
    content: ""
}

.icon-sticky-note:before {
    content: ""
}

.icon-sticky-note-o:before {
    content: ""
}

.icon-cc-jcb:before {
    content: ""
}

.icon-cc-diners-club:before {
    content: ""
}

.icon-clone:before {
    content: ""
}

.icon-balance-scale:before {
    content: ""
}

.icon-hourglass-o:before {
    content: ""
}

.icon-hourglass-1:before, .icon-hourglass-start:before {
    content: ""
}

.icon-hourglass-2:before, .icon-hourglass-half:before {
    content: ""
}

.icon-hourglass-3:before, .icon-hourglass-end:before {
    content: ""
}

.icon-hourglass:before {
    content: ""
}

.icon-hand-grab-o:before, .icon-hand-rock-o:before {
    content: ""
}

.icon-hand-stop-o:before, .icon-hand-paper-o:before {
    content: ""
}

.icon-hand-scissors-o:before {
    content: ""
}

.icon-hand-lizard-o:before {
    content: ""
}

.icon-hand-spock-o:before {
    content: ""
}

.icon-hand-pointer-o:before {
    content: ""
}

.icon-hand-peace-o:before {
    content: ""
}

.icon-trademark:before {
    content: ""
}

.icon-registered:before {
    content: ""
}

.icon-creative-commons:before {
    content: ""
}

.icon-gg:before {
    content: ""
}

.icon-gg-circle:before {
    content: ""
}

.icon-tripadvisor:before {
    content: ""
}

.icon-odnoklassniki:before {
    content: ""
}

.icon-odnoklassniki-square:before {
    content: ""
}

.icon-get-pocket:before {
    content: ""
}

.icon-wikipedia-w:before {
    content: ""
}

.icon-safari:before {
    content: ""
}

.icon-chrome:before {
    content: ""
}

.icon-firefox:before {
    content: ""
}

.icon-opera:before {
    content: ""
}

.icon-internet-explorer:before {
    content: ""
}

.icon-tv:before, .icon-television:before {
    content: ""
}

.icon-contao:before {
    content: ""
}

.icon-500px:before {
    content: ""
}

.icon-amazon:before {
    content: ""
}

.icon-calendar-plus-o:before {
    content: ""
}

.icon-calendar-minus-o:before {
    content: ""
}

.icon-calendar-times-o:before {
    content: ""
}

.icon-calendar-check-o:before {
    content: ""
}

.icon-industry:before {
    content: ""
}

.icon-map-pin:before {
    content: ""
}

.icon-map-signs:before {
    content: ""
}

.icon-map-o:before {
    content: ""
}

.icon-map:before {
    content: ""
}

.icon-commenting:before {
    content: ""
}

.icon-commenting-o:before {
    content: ""
}

.icon-houzz:before {
    content: ""
}

.icon-vimeo:before {
    content: ""
}

.icon-black-tie:before {
    content: ""
}

.icon-fonticons:before {
    content: ""
}

.icon-reddit-alien:before {
    content: ""
}

.icon-edge:before {
    content: ""
}

.icon-credit-card-alt:before {
    content: ""
}

.icon-codiepie:before {
    content: ""
}

.icon-modx:before {
    content: ""
}

.icon-fort-awesome:before {
    content: ""
}

.icon-usb:before {
    content: ""
}

.icon-product-hunt:before {
    content: ""
}

.icon-mixcloud:before {
    content: ""
}

.icon-scribd:before {
    content: ""
}

.icon-pause-circle:before {
    content: ""
}

.icon-pause-circle-o:before {
    content: ""
}

.icon-stop-circle:before {
    content: ""
}

.icon-stop-circle-o:before {
    content: ""
}

.icon-shopping-bag:before {
    content: ""
}

.icon-shopping-basket:before {
    content: ""
}

.icon-hashtag:before {
    content: ""
}

.icon-bluetooth:before {
    content: ""
}

.icon-bluetooth-b:before {
    content: ""
}

.icon-percent:before {
    content: ""
}

.icon-gitlab:before {
    content: ""
}

.icon-wpbeginner:before {
    content: ""
}

.icon-wpforms:before {
    content: ""
}

.icon-envira:before {
    content: ""
}

.icon-universal-access:before {
    content: ""
}

.icon-wheelchair-alt:before {
    content: ""
}

.icon-question-circle-o:before {
    content: ""
}

.icon-blind:before {
    content: ""
}

.icon-audio-description:before {
    content: ""
}

.icon-volume-control-phone:before {
    content: ""
}

.icon-braille:before {
    content: ""
}

.icon-assistive-listening-systems:before {
    content: ""
}

.icon-asl-interpreting:before, .icon-american-sign-language-interpreting:before {
    content: ""
}

.icon-deafness:before, .icon-hard-of-hearing:before, .icon-deaf:before {
    content: ""
}

.icon-glide:before {
    content: ""
}

.icon-glide-g:before {
    content: ""
}

.icon-signing:before, .icon-sign-language:before {
    content: ""
}

.icon-low-vision:before {
    content: ""
}

.icon-viadeo:before {
    content: ""
}

.icon-viadeo-square:before {
    content: ""
}

.icon-snapchat:before {
    content: ""
}

.icon-snapchat-ghost:before {
    content: ""
}

.icon-snapchat-square:before {
    content: ""
}

.icon-pied-piper:before {
    content: ""
}

.icon-first-order:before {
    content: ""
}

.icon-yoast:before {
    content: ""
}

.icon-themeisle:before {
    content: ""
}

.icon-google-plus-circle:before, .icon-google-plus-official:before {
    content: ""
}

.icon-fa:before, .icon-font-awesome:before {
    content: ""
}

.icon-handshake-o:before {
    content: ""
}

.icon-envelope-open:before {
    content: ""
}

.icon-envelope-open-o:before {
    content: ""
}

.icon-linode:before {
    content: ""
}

.icon-address-book:before {
    content: ""
}

.icon-address-book-o:before {
    content: ""
}

.icon-vcard:before, .icon-address-card:before {
    content: ""
}

.icon-vcard-o:before, .icon-address-card-o:before {
    content: ""
}

.icon-user-circle:before {
    content: ""
}

.icon-user-circle-o:before {
    content: ""
}

.icon-user-o:before {
    content: ""
}

.icon-id-badge:before {
    content: ""
}

.icon-drivers-license:before, .icon-id-card:before {
    content: ""
}

.icon-drivers-license-o:before, .icon-id-card-o:before {
    content: ""
}

.icon-quora:before {
    content: ""
}

.icon-free-code-camp:before {
    content: ""
}

.icon-telegram:before {
    content: ""
}

.icon-thermometer-4:before, .icon-thermometer:before, .icon-thermometer-full:before {
    content: ""
}

.icon-thermometer-3:before, .icon-thermometer-three-quarters:before {
    content: ""
}

.icon-thermometer-2:before, .icon-thermometer-half:before {
    content: ""
}

.icon-thermometer-1:before, .icon-thermometer-quarter:before {
    content: ""
}

.icon-thermometer-0:before, .icon-thermometer-empty:before {
    content: ""
}

.icon-shower:before {
    content: ""
}

.icon-bathtub:before, .icon-s15:before, .icon-bath:before {
    content: ""
}

.icon-podcast:before {
    content: ""
}

.icon-window-maximize:before {
    content: ""
}

.icon-window-minimize:before {
    content: ""
}

.icon-window-restore:before {
    content: ""
}

.icon-times-rectangle:before, .icon-window-close:before {
    content: ""
}

.icon-times-rectangle-o:before, .icon-window-close-o:before {
    content: ""
}

.icon-bandcamp:before {
    content: ""
}

.icon-grav:before {
    content: ""
}

.icon-etsy:before {
    content: ""
}

.icon-imdb:before {
    content: ""
}

.icon-ravelry:before {
    content: ""
}

.icon-eercast:before {
    content: ""
}

.icon-microchip:before {
    content: ""
}

.icon-snowflake-o:before {
    content: ""
}

.icon-superpowers:before {
    content: ""
}

.icon-wpexplorer:before {
    content: ""
}

.icon-meetup:before {
    content: ""
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0
}

.sr-only-focusable:active, .sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto
}

.rf-Field {
    margin-bottom: 10px
}

.rf-Field--invalid textarea, .rf-Field--invalid input[type="text"], .rf-Field--invalid input[type="password"], .rf-Field--invalid input[type="datetime"], .rf-Field--invalid input[type="datetime-local"], .rf-Field--invalid input[type="date"], .rf-Field--invalid input[type="month"], .rf-Field--invalid input[type="time"], .rf-Field--invalid input[type="week"], .rf-Field--invalid input[type="number"], .rf-Field--invalid input[type="email"], .rf-Field--invalid input[type="url"], .rf-Field--invalid input[type="search"], .rf-Field--invalid input[type="tel"], .rf-Field--invalid input[type="color"], .rf-Field--invalid .item-picker {
    border-color: #a94442;
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075)
}

.rf-Field--invalid textarea:focus, .rf-Field--invalid input[type="text"]:focus, .rf-Field--invalid input[type="password"]:focus, .rf-Field--invalid input[type="datetime"]:focus, .rf-Field--invalid input[type="datetime-local"]:focus, .rf-Field--invalid input[type="date"]:focus, .rf-Field--invalid input[type="month"]:focus, .rf-Field--invalid input[type="time"]:focus, .rf-Field--invalid input[type="week"]:focus, .rf-Field--invalid input[type="number"]:focus, .rf-Field--invalid input[type="email"]:focus, .rf-Field--invalid input[type="url"]:focus, .rf-Field--invalid input[type="search"]:focus, .rf-Field--invalid input[type="tel"]:focus, .rf-Field--invalid input[type="color"]:focus, .rf-Field--invalid .item-picker:focus {
    border-color: #843534;
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483
}

.rf-Field--invalid .rf-Label {
    color: #843534
}

.rf-Fieldset {
    border: 1px solid #ccc;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    padding: 5px 10px;
    margin-bottom: 10px
}

.rf-RepeatingFieldset__add {
    display: block
}

.rf-RepeatingFieldset__item {
    background: #fbfbfb;
    position: relative;
    border: 1px solid #ccc;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    padding: 5px 30px 5px 10px;
    margin-bottom: 10px
}

.rf-RepeatingFieldset__item > .rf-Fieldset {
    padding: 0;
    border: none;
    -moz-border-radius: none;
    -webkit-border-radius: none;
    border-radius: none;
    margin-bottom: 0
}

.rf-RepeatingFieldset__remove {
    border: none;
    background: transparent;
    position: absolute;
    top: 5px;
    right: 10px
}

.rf-Label {
    padding-right: 10px
}

.required .rf-Label > span:first-child:after {
    content: " *";
    color: red
}

form > .rf-Fieldset > .rf-Label {
    font-size: 150%
}

.rf-Hint {
    font-size: 70%;
    font-weight: normal;
    display: block
}

.rf-Message {
    margin: 5px;
    font-size: 80%;
    color: #a94442;
    display: block
}

#layout {
    height: auto !important;
    margin: 0 auto-50px;
    min-height: 100%;
    background-color: #fff
}

.homepage-main-box {
    min-height: 400px;
    background: url("/static/img/encode-bg-gray.png") no-repeat center
}

.project-info {
    margin-bottom: 10px;
    display: block;
    font-size: 18px;
    font-size: 1.3rem
}

.project-info h1, .project-info h2, .project-info h3, .project-info h4 {
    text-shadow: #fff 1px 1px 0
}

.text-panel {
    margin-top: 10px
}

.static-page {
    width: 75%;
    margin: 0;
    margin-top: 30px
}

.static-page.row, .static-page.flexrow {
    width: auto
}

.static-page.row > div > .help-entry:first-child, .static-page.flexrow > div > .help-entry:first-child {
    margin-top: 5px
}

.static-page.row > div > .help-entry:first-child > .fourDN-content:first-child > div:first-child > h2:first-child, .static-page.flexrow > div > .help-entry:first-child > .fourDN-content:first-child > div:first-child > h2:first-child {
    margin-top: 20px
}

.static-page .help-entry {
    margin: 50px 0px 50px 0px
}

.static-page .help-entry:first-of-type {
    margin-top: 27px
}

#content {
    padding-top: 0px
}

@media (min-width: 992px) {
    #content {
        padding-bottom: 20px
    }
}

#content > .alerts {
    margin-top: 20px
}

#content > .alerts .alert.no-close-button > button.close, #content > .alerts .alert.no-close-button > button.rf-RepeatingFieldset__remove {
    display: none
}

#pre-content-placeholder {
    display: none;
    height: 0px
}

@media (min-width: 992px) {
    #pre-content-placeholder {
        display: block;
        height: 81px
    }
}

body.is-full-screen {
    overflow: hidden
}

body.is-full-screen::-webkit-scrollbar {
    display: none
}

body.is-full-screen #top-nav > .test-warning {
    display: none
}

h1.page-title {
    font-weight: 200;
    margin-top: 32px;
    margin-bottom: 32px
}

h1.page-title.top-of-page {
    margin-top: 36px;
    margin-bottom: 0px
}

@media screen and (min-width: 768px) {
    body[data-pathname="/"] h1.page-title.top-of-page, body[data-pathname="/home"] h1.page-title.top-of-page, h1.page-title.top-of-page.home-page-title {
        height: 64px;
        margin-bottom: -3px
    }
}

body[data-pathname="/"] h1.page-title.top-of-page .subtitle, body[data-pathname="/home"] h1.page-title.top-of-page .subtitle, h1.page-title.top-of-page.home-page-title .subtitle {
    font-size: 1.7rem
}

.row > h1.page-title, .flexrow > h1.page-title {
    margin-top: 0px
}

.row > div > h1.page-title, .flexrow > div > h1.page-title {
    margin-top: 0px
}

h1.page-title .page-subtitle {
    margin-left: 2px;
    margin-top: 0px;
    font-size: 18px
}

h1.page-title .subtitle.prominent {
    font-weight: 300;
    font-size: 0.875em;
    display: inline-block;
    margin-left: 9px
}

h1.page-title + .page-subtitle {
    margin-top: -27px;
    margin-bottom: 15px
}

.page-subtitle {
    font-weight: 400
}

h3.submission-subtitle {
    font-weight: 400;
    display: inline-block
}

.submission-page-heading {
    border-radius: 2px;
    border: 1px solid #ddd;
    min-height: 42px;
    padding: 10px 15px 8px
}

.submission-btn {
    background-color: #f4f4f4;
    border-color: #f4f4f4;
    margin-left: 5px;
    padding-left: 5px;
    padding-right: 5px;
    box-shadow: none
}

.submission-btn:hover, .submission-btn:focus {
    background-color: #ddd;
    border-color: #f4f4f4
}

.page-footer {
    background-color: #f8f8f8;
    text-align: center;
    overflow: hidden
}

.page-footer a {
    color: #bfbfbf
}

.page-footer ul {
    list-style: none;
    list-style-position: outside;
    padding: 0
}

.page-footer .footer-section {
    display: block;
    text-align: center;
    color: #bfbfbf;
    padding: 16px 0px 14px
}

@media (min-width: 992px) {
    .page-footer .footer-section {
        text-align: right
    }

    .page-footer .footer-section.copy-notice {
        text-align: left
    }

    .page-footer .footer-section li:last-child {
        padding-right: 0
    }
}

.page-footer .footer-section a {
    color: #b0b0b0
}

.page-footer .footer-section a:hover, .page-footer .footer-section a:active {
    text-decoration: none !important;
    color: #000000
}

@media screen and (min-width: 768px) {
    .flexbox .flexrow {
        display: flex
    }
}

@media screen and (min-width: 768px) {
    .flexbox .flexcol-sm-6 {
        flex: 1 1 0px;
        width: auto
    }
}

.column-margin-offset {
    margin-left: -10px;
    margin-right: 10px
}

.column-padding {
    padding-left: 10px;
    padding-right: 10px
}

.text-capitalize {
    text-transform: capitalize
}

.text-uppercase {
    text-transform: uppercase
}

.text-justify {
    text-align: justify
}

.text-200 {
    font-weight: 200
}

.text-300 {
    font-weight: 300
}

.text-400 {
    font-weight: 400
}

.text-500 {
    font-weight: 500
}

.text-600 {
    font-weight: 600
}

.text-normal {
    font-size: 1rem
}

.text-small {
    font-size: 0.9rem
}

.text-smaller {
    font-size: 0.75rem
}

.text-medium {
    font-size: 15px
}

.text-large {
    font-size: 17.5px
}

.text-larger {
    font-size: 20px;
    line-height: 25px
}

.left {
    float: left
}

.right {
    float: right
}

.mono-text, .accession {
    font-family: "Source Code Pro", Consolas, monospace
}

.inline-block {
    display: inline-block
}

.overflow-hidden {
    overflow: hidden
}

@media screen and (max-width: 767px) {
    .text-left-xs {
        text-align: left !important
    }
}

.text-ellipsis-container {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

@media screen {
    .col-xs-float-right {
        float: right
    }
}

@media screen and (min-width: 768px) {
    .col-sm-float-right {
        float: right
    }
}

@media screen and (min-width: 992px) {
    .col-md-float-right {
        float: right
    }
}

@media screen and (min-width: 1200px) {
    .col-lg-float-right {
        float: right
    }
}

.row.row-eq-height-xs, .row-eq-height-xs.flexrow {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex
}

@media screen and (min-width: 768px) {
    .row.row-eq-height-sm, .row-eq-height-sm.flexrow {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex
    }

    .row.row-eq-height-sm .panel, .row-eq-height-sm.flexrow .panel, .row.row-eq-height-sm .panel-full, .row-eq-height-sm.flexrow .panel-full, .row.row-eq-height-sm .table-panel, .row-eq-height-sm.flexrow .table-panel {
        margin-top: 0;
        margin-bottom: 0;
        height: 100%
    }
}

@media screen and (min-width: 992px) {
    .row.row-eq-height-md, .row-eq-height-md.flexrow {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex
    }

    .row.row-eq-height-md .panel, .row-eq-height-md.flexrow .panel, .row.row-eq-height-md .panel-full, .row-eq-height-md.flexrow .panel-full, .row.row-eq-height-md .table-panel, .row-eq-height-md.flexrow .table-panel {
        margin-top: 0;
        margin-bottom: 0;
        height: 100%
    }
}

@media screen and (min-width: 1200px) {
    .row.row-eq-height-lg, .row-eq-height-lg.flexrow {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex
    }

    .row.row-eq-height-lg .panel, .row-eq-height-lg.flexrow .panel, .row.row-eq-height-lg .panel-full, .row-eq-height-lg.flexrow .panel-full, .row.row-eq-height-lg .table-panel, .row-eq-height-lg.flexrow .table-panel {
        margin-top: 0;
        margin-bottom: 0;
        height: 100%
    }
}

.off-screen {
    position: absolute !important;
    left: -9999px !important
}

#slow-load-container {
    position: fixed;
    left: 0;
    top: 0;
    right: 0;
    bottom: 0;
    pointer-events: none;
    z-index: -10;
    background-color: rgba(255, 255, 255, 0.8);
    opacity: 0;
    transition: opacity .5s, z-index 0s 0.5s
}

#slow-load-container .inner {
    position: absolute;
    top: 50%;
    margin-top: -20px;
    left: 0;
    right: 0;
    text-align: center;
    color: #999
}

#slow-load-container .inner > i.icon, #slow-load-container .inner > i.tcell-sort, #slow-load-container .inner > i.tcell-asc, #slow-load-container .inner > i.tcell-desc {
    font-size: 3rem
}

#slow-load-container.visible {
    opacity: 1;
    z-index: 100;
    transition: opacity .25s, z-index 0s 0s
}

#slow-load-container.visible .inner > i.icon, #slow-load-container.visible .inner > i.tcell-sort, #slow-load-container.visible .inner > i.tcell-asc, #slow-load-container.visible .inner > i.tcell-desc {
    -webkit-animation: fa-spin 2s infinite linear;
    animation: fa-spin 2s infinite linear
}

.mb-0, * > .mb-0 {
    margin-bottom: 0px !important
}

.mt-0, * > .mt-0 {
    margin-top: 0px !important
}

.mb-1, * > .mb-1 {
    margin-bottom: 10px !important
}

.mt-1, * > .mt-1 {
    margin-top: 10px !important
}

.mb-2, * > .mb-2 {
    margin-bottom: 20px !important
}

.mt-2, * > .mt-2 {
    margin-top: 20px !important
}

.mb-3, * > .mb-3 {
    margin-bottom: 30px !important
}

.mt-3, * > .mt-3 {
    margin-top: 30px !important
}

.mb-4, * > .mb-4 {
    margin-bottom: 40px !important
}

.mt-4, * > .mt-4 {
    margin-top: 40px !important
}

.mb-5, * > .mb-5 {
    margin-bottom: 50px !important
}

.mt-5, * > .mt-5 {
    margin-top: 50px !important
}

.mb-02, * > .mb-02 {
    margin-bottom: 2px !important
}

.mt-02, * > .mt-02 {
    margin-top: 2px !important
}

.mb-03, * > .mb-03 {
    margin-bottom: 3px !important
}

.mt-03, * > .mt-03 {
    margin-top: 3px !important
}

.mb-05, * > .mb-05 {
    margin-bottom: 5px !important
}

.mt-05, * > .mt-05 {
    margin-top: 5px !important
}

.mb-07, * > .mb-07 {
    margin-bottom: 7px !important
}

.mt-07, * > .mt-07 {
    margin-top: 7px !important
}

.mb-08, * > .mb-08 {
    margin-bottom: 8px !important
}

.mt-08, * > .mt-08 {
    margin-top: 8px !important
}

.modal-dialog .modal-header > button.close, .modal-dialog .modal-header > button.rf-RepeatingFieldset__remove {
    margin-top: 2px;
    margin-right: 5px
}

.modal-dialog .modal-body p {
    font-family: inherit
}

.btn.btn-secondary, .btn-secondary.rf-RepeatingFieldset__add {
    color: #000;
    background-color: #e4e4e4;
    border-color: rgba(0, 0, 0, 0.125)
}

.btn.btn-secondary:hover, .btn-secondary.rf-RepeatingFieldset__add:hover, .btn.btn-secondary:focus, .btn-secondary.rf-RepeatingFieldset__add:focus, .btn.btn-secondary:active, .btn-secondary.rf-RepeatingFieldset__add:active, .btn.btn-secondary.active, .btn-secondary.active.rf-RepeatingFieldset__add {
    color: #000;
    background-color: #d0d0d0;
    border-color: rgba(0, 0, 0, 0.125)
}

.open .btn.btn-secondary.dropdown-toggle, .open .btn-secondary.dropdown-toggle.rf-RepeatingFieldset__add {
    color: #000;
    background-color: #d0d0d0;
    border-color: rgba(0, 0, 0, 0.125)
}

.btn.btn-secondary:active, .btn-secondary.rf-RepeatingFieldset__add:active, .btn.btn-secondary.active, .btn-secondary.active.rf-RepeatingFieldset__add {
    background-image: none
}

.open .btn.btn-secondary.dropdown-toggle, .open .btn-secondary.dropdown-toggle.rf-RepeatingFieldset__add {
    background-image: none
}

.btn.btn-secondary.disabled, .btn-secondary.disabled.rf-RepeatingFieldset__add, .btn.btn-secondary.disabled:hover, .btn-secondary.disabled.rf-RepeatingFieldset__add:hover, .btn.btn-secondary.disabled:focus, .btn-secondary.disabled.rf-RepeatingFieldset__add:focus, .btn.btn-secondary.disabled:active, .btn-secondary.disabled.rf-RepeatingFieldset__add:active, .btn.btn-secondary.disabled.active, .btn-secondary.disabled.active.rf-RepeatingFieldset__add, .btn.btn-secondary[disabled], .btn-secondary[disabled].rf-RepeatingFieldset__add, .btn.btn-secondary[disabled]:hover, .btn-secondary[disabled].rf-RepeatingFieldset__add:hover, .btn.btn-secondary[disabled]:focus, .btn-secondary[disabled].rf-RepeatingFieldset__add:focus, .btn.btn-secondary[disabled]:active, .btn-secondary[disabled].rf-RepeatingFieldset__add:active, .btn.btn-secondary[disabled].active, .btn-secondary[disabled].active.rf-RepeatingFieldset__add, fieldset[disabled] .btn.btn-secondary, fieldset[disabled] .btn-secondary.rf-RepeatingFieldset__add, fieldset[disabled] .btn.btn-secondary:hover, fieldset[disabled] .btn-secondary.rf-RepeatingFieldset__add:hover, fieldset[disabled] .btn.btn-secondary:focus, fieldset[disabled] .btn-secondary.rf-RepeatingFieldset__add:focus, fieldset[disabled] .btn.btn-secondary:active, fieldset[disabled] .btn-secondary.rf-RepeatingFieldset__add:active, fieldset[disabled] .btn.btn-secondary.active, fieldset[disabled] .btn-secondary.active.rf-RepeatingFieldset__add {
    background-color: #e4e4e4;
    border-color: rgba(0, 0, 0, 0.125)
}

.btn.btn-secondary .badge, .btn-secondary.rf-RepeatingFieldset__add .badge {
    color: #e4e4e4;
    background-color: #000
}

.btn.btn-secondary:active, .btn-secondary.rf-RepeatingFieldset__add:active, .btn.btn-secondary:focus, .btn-secondary.rf-RepeatingFieldset__add:focus {
    background-color: #e4e4e4
}

.dropdown-toggle.btn, .dropdown-toggle.rf-RepeatingFieldset__add {
    position: relative;
    padding-right: 24px;
    padding-left: 10px
}

.dropdown-toggle.btn span.caret, .dropdown-toggle.rf-RepeatingFieldset__add span.caret {
    position: absolute;
    top: 50%;
    margin-top: -2px;
    right: 10px
}

body .__react_component_tooltip {
    padding: 6px 15px
}

.login-box {
    width: inherit;
    height: inherit;
    border: 2px solid #000000;
    background-color: #ffffff;
    padding: 5px;
    display: block;
    margin-left: auto;
    margin-right: auto
}

.sexy-btn {
    background-color: #ffffff;
    color: #b3b3b3;
    border: 2px solid #b3b3b3;
    padding: 5px 10px;
    text-align: center;
    font-size: 16px;
    cursor: pointer;
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif
}

.sexy-btn:hover, .sexy-btn:focus {
    color: #000000;
    border: 2px solid #000000
}

.sexy-btn span {
    display: inline-block;
    position: relative;
    transition: 0.5s
}

.sexy-btn span:after {
    content: '»';
    position: absolute;
    opacity: 0;
    top: 0;
    right: -20px;
    transition: 0.5s
}

.sexy-btn:hover span, .sexy-btn:focus span {
    padding-right: 25px
}

.sexy-btn:hover span:after, .sexy-btn:focus span:after {
    opacity: 1;
    right: 0
}

.links {
    padding-left: 0px
}

.links li {
    margin-top: 20px;
    margin-bottom: 20px;
    text-align: center;
    display: block;
    margin-left: auto;
    margin-right: auto
}

.fill-label {
    display: block;
    text-align: center
}

.text-box {
    padding: 12px 20px;
    margin: 8px 0 8px;
    box-sizing: border-box;
    width: 70%;
    border: 2px solid #b3b3b3 !important;
    display: block;
    margin-left: auto;
    margin-right: auto;
    font-size: 14px;
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif
}

.text-box:hover, .text-box:focus {
    outline: none;
    border: 2px solid #000000 !important
}

.title {
    text-align: center
}

.error {
    text-align: center;
    color: red
}

.invis {
    display: none !important
}

.placeholder {
    visibility: hidden !important
}

.item-icon {
    padding-left: 4px
}

h1, h2, h3, h4, h5, h6, td, th, span {
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif
}

h1, h2, h3, h4, h5, h6, th {
    color: #111
}

h1, h2, h3, h4, h5, h6 {
    margin: 10px 0px 10px 0px
}

p, input {
    font-family: 'Yrsa', serif
}

.inline-subheader {
    display: inline;
    color: #999999 !important
}

.impersonate-user {
    display: block;
    margin-top: 15px
}

.impersonate-user-field {
    width: 400px;
    border: 2px solid #999999
}

.submission-field-header {
    background-color: #e7e7e7;
    border: 1px solid #ccc;
    border-radius: 2px;
    margin-bottom: 0px !important
}

.submission-field-header span {
    margin-left: 12px
}

.submission-nav-tree {
    border: 1px solid #ccc;
    border-radius: 2px;
    background-color: #fff
}

.submission-nav-tree > h4 {
    text-align: center;
    font-weight: 300;
    margin-top: 0px
}

.submission-nav-leaf {
    width: 100%
}

.submission-nav-leaf > div > button {
    border: none;
    border-radius: 0px;
    width: 20px;
    height: 19px;
    opacity: 1 !important
}

.submission-pop-icon {
    background-color: #fff;
    padding: 1px 5px
}

.submission-pop-icon a:hover, .submission-pop-icon a:active {
    text-decoration: none !important;
    color: #000000
}

.submission-pop-icon a {
    padding: 3px 5px 0px 5px
}

.submission-field-title {
    border: none !important;
    padding-bottom: 0px !important;
    margin-bottom: 0px !important;
    padding-top: 5px !important
}

.submission-working-title {
    display: inline;
    font-weight: 300
}

.submission-working-title > .working-subtitle {
    font-weight: 200;
    color: #8b8b8b;
    padding-right: 10px
}

.submission-hidden-nav {
    display: none
}

.breadcrumb {
    padding: 5px 0;
    background-color: transparent;
    border-bottom: 1px solid #c0c0c0
}

.breadcrumb > li {
    text-transform: uppercase;
    font-weight: bold;
    font-size: 12px;
    color: #808080
}

.breadcrumb > li + li:before {
    padding: 0 5px 0 10px
}

.rc-tabs {
    box-sizing: border-box;
    position: relative
}

.rc-tabs-bar, .rc-tabs-nav-container {
    font-size: 14px;
    line-height: 1.5;
    box-sizing: border-box;
    overflow: hidden;
    position: relative;
    white-space: nowrap;
    outline: none;
    zoom: 1
}

.rc-tabs-ink-bar {
    z-index: 1;
    position: absolute;
    box-sizing: border-box;
    margin-top: -3px;
    background-color: #22656d;
    -webkit-transform-origin: 0 0;
    transform-origin: 0 0
}

.rc-tabs-ink-bar-animated {
    -webkit-transition: -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), width 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), width 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), width 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), width 0.3s cubic-bezier(0.35, 0, 0.25, 1)
}

.rc-tabs-tab-prev, .rc-tabs-tab-next {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    z-index: 1;
    line-height: 36px;
    cursor: pointer;
    border: none;
    background-color: transparent;
    position: absolute
}

.rc-tabs-tab-prev-icon, .rc-tabs-tab-next-icon {
    position: relative;
    display: inline-block;
    font-style: normal;
    font-weight: normal;
    font-variant: normal;
    line-height: inherit;
    vertical-align: baseline;
    text-align: center;
    text-transform: none;
    font-smoothing: antialiased;
    text-stroke-width: 0;
    font-family: sans-serif
}

.rc-tabs-tab-prev-icon:before, .rc-tabs-tab-next-icon:before {
    display: block
}

.rc-tabs-tab-btn-disabled {
    cursor: default;
    color: #ccc
}

.rc-tabs-nav-wrap {
    overflow: hidden
}

.rc-tabs-nav {
    box-sizing: border-box;
    padding-left: 0;
    position: relative;
    margin: 0;
    float: left;
    list-style: none;
    display: inline-block;
    -webkit-transform-origin: 0 0;
    transform-origin: 0 0
}

.rc-tabs-nav-animated {
    -webkit-transition: -webkit-transform 0.5s cubic-bezier(0.35, 0, 0.25, 1);
    transition: -webkit-transform 0.5s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.5s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.5s cubic-bezier(0.35, 0, 0.25, 1), -webkit-transform 0.5s cubic-bezier(0.35, 0, 0.25, 1)
}

.rc-tabs-nav:before, .rc-tabs-nav:after {
    display: table;
    content: " "
}

.rc-tabs-nav:after {
    clear: both
}

.rc-tabs-tab {
    box-sizing: border-box;
    position: relative;
    display: block;
    -webkit-transition: color 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: color 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    padding: 8px 20px;
    font-weight: 400;
    color: #444;
    cursor: pointer;
    border: 1px solid transparent;
    border-bottom: none
}

.rc-tabs-tab:hover {
    color: #000
}

.rc-tabs-tab-active, .rc-tabs-tab-active:hover {
    color: #000;
    cursor: default;
    -webkit-transform: translateZ(0);
    transform: translateZ(0)
}

.rc-tabs-tab-disabled {
    cursor: default;
    color: #ccc
}

.rc-tabs-tab-disabled:hover {
    color: #ccc
}

.rc-tabs-content {
    zoom: 1
}

.rc-tabs-content .rc-tabs-tabpane {
    overflow: auto
}

.rc-tabs-content-animated {
    -webkit-transition: margin-left 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-top 0.3s cubic-bezier(0.35, 0, 0.25, 1), -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: margin-left 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-top 0.3s cubic-bezier(0.35, 0, 0.25, 1), -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-left 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-top 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    transition: transform 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-left 0.3s cubic-bezier(0.35, 0, 0.25, 1), margin-top 0.3s cubic-bezier(0.35, 0, 0.25, 1), -webkit-transform 0.3s cubic-bezier(0.35, 0, 0.25, 1);
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    will-change: transform
}

.rc-tabs-content-animated .rc-tabs-tabpane {
    -ms-flex-negative: 0;
    flex-shrink: 0
}

.no-flexbox .rc-tabs-content {
    -webkit-transform: none !important;
    transform: none !important;
    overflow: auto
}

.no-csstransitions .rc-tabs-tabpane-inactive, .no-flexbox .rc-tabs-tabpane-inactive, .rc-tabs-content-no-animated .rc-tabs-tabpane-inactive {
    display: none
}

.rc-tabs-left {
    border-right: 2px solid #f3f3f3;
    overflow-y: hidden
}

.rc-tabs-left .rc-tabs-bar {
    float: left;
    height: 100%;
    margin-right: 10px;
    border-right: 1px solid #f3f3f3
}

.rc-tabs-left .rc-tabs-nav-container {
    height: 100%
}

.rc-tabs-left .rc-tabs-nav-container-scrolling {
    padding-top: 32px;
    padding-bottom: 32px
}

.rc-tabs-left .rc-tabs-nav-wrap {
    height: 100%
}

.rc-tabs-left .rc-tabs-content-animated {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column
}

.rc-tabs-left .rc-tabs-content-animated .rc-tabs-tabpane {
    height: 100%
}

.rc-tabs-left .rc-tabs-nav-scroll {
    height: 99999px
}

.rc-tabs-left .rc-tabs-nav-swipe {
    position: relative;
    top: 0
}

.rc-tabs-left .rc-tabs-nav-swipe .rc-tabs-nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    height: 100%
}

.rc-tabs-left .rc-tabs-nav-swipe .rc-tabs-nav .rc-tabs-tab {
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center
}

.rc-tabs-left .rc-tabs-tab-prev, .rc-tabs-left .rc-tabs-tab-next {
    margin-top: -2px;
    height: 32px;
    line-height: 32px;
    width: 100%;
    display: block;
    text-align: center
}

.rc-tabs-left .rc-tabs-tab-next {
    bottom: 0
}

.rc-tabs-left .rc-tabs-tab-next-icon {
    -webkit-transform: rotate(90deg);
    transform: rotate(90deg);
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1)
}

.rc-tabs-left .rc-tabs-tab-next-icon:before {
    content: ">"
}

.rc-tabs-left .rc-tabs-tab-prev {
    top: 2px
}

.rc-tabs-left .rc-tabs-tab-prev-icon {
    -webkit-transform: rotate(270deg);
    transform: rotate(270deg);
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3)
}

.rc-tabs-left .rc-tabs-tab-prev-icon:before {
    content: ">"
}

.rc-tabs-left .rc-tabs-ink-bar {
    width: 2px;
    right: 0
}

.rc-tabs-left .rc-tabs-tab {
    padding: 16px 24px
}

.rc-tabs-right {
    border-left: 2px solid #f3f3f3;
    overflow-y: hidden
}

.rc-tabs-right .rc-tabs-bar {
    float: right;
    height: 100%;
    margin-left: 10px;
    border-left: 1px solid #f3f3f3
}

.rc-tabs-right .rc-tabs-nav-container {
    height: 100%
}

.rc-tabs-right .rc-tabs-nav-container-scrolling {
    padding-top: 32px;
    padding-bottom: 32px
}

.rc-tabs-right .rc-tabs-nav-wrap {
    height: 100%
}

.rc-tabs-right .rc-tabs-nav-scroll {
    height: 99999px
}

.rc-tabs-right .rc-tabs-nav-swipe {
    position: relative
}

.rc-tabs-right .rc-tabs-nav-swipe .rc-tabs-nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column;
    height: 100%
}

.rc-tabs-right .rc-tabs-nav-swipe .rc-tabs-nav .rc-tabs-tab {
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center
}

.rc-tabs-right .rc-tabs-tab-prev, .rc-tabs-right .rc-tabs-tab-next {
    margin-top: -2px;
    height: 32px;
    width: 100%;
    display: block;
    text-align: center;
    line-height: 32px
}

.rc-tabs-right .rc-tabs-tab-next {
    bottom: 0
}

.rc-tabs-right .rc-tabs-tab-next-icon {
    -webkit-transform: rotate(90deg);
    transform: rotate(90deg);
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1)
}

.rc-tabs-right .rc-tabs-tab-next-icon:before {
    content: ">"
}

.rc-tabs-right .rc-tabs-tab-prev {
    top: 2px
}

.rc-tabs-right .rc-tabs-tab-prev-icon {
    -webkit-transform: rotate(270deg);
    transform: rotate(270deg);
    filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3)
}

.rc-tabs-right .rc-tabs-tab-prev-icon:before {
    content: ">"
}

.rc-tabs-right .rc-tabs-content-animated {
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
    -ms-flex-direction: column;
    flex-direction: column
}

.rc-tabs-right .rc-tabs-content-animated .rc-tabs-tabpane {
    height: 100%
}

.rc-tabs-right .rc-tabs-ink-bar {
    width: 2px;
    left: 0
}

.rc-tabs-right .rc-tabs-tab {
    padding: 16px 24px
}

.rc-tabs-bottom {
    border-top: 2px solid #f3f3f3;
    overflow-x: hidden
}

.rc-tabs-bottom .rc-tabs-content {
    width: 100%
}

.rc-tabs-bottom .rc-tabs-bar {
    border-top: 1px solid #f3f3f3
}

.rc-tabs-bottom .rc-tabs-nav-container-scrolling {
    padding-left: 32px;
    padding-right: 32px
}

.rc-tabs-bottom .rc-tabs-nav-scroll {
    width: 99999px
}

.rc-tabs-bottom .rc-tabs-nav-swipe {
    position: relative;
    left: 0
}

.rc-tabs-bottom .rc-tabs-nav-swipe .rc-tabs-nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    width: 100%
}

.rc-tabs-bottom .rc-tabs-nav-swipe .rc-tabs-nav .rc-tabs-tab {
    margin-right: 0;
    padding: 8px 0;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center
}

.rc-tabs-bottom .rc-tabs-nav-wrap {
    width: 100%
}

.rc-tabs-bottom .rc-tabs-content-animated {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row
}

.rc-tabs-bottom .rc-tabs-content-animated .rc-tabs-tabpane {
    width: 100%
}

.rc-tabs-bottom .rc-tabs-tab-next {
    right: 2px
}

.rc-tabs-bottom .rc-tabs-tab-next-icon:before {
    content: ">"
}

.rc-tabs-bottom .rc-tabs-tab-prev {
    left: 0
}

.rc-tabs-bottom .rc-tabs-tab-prev-icon:before {
    content: "<"
}

.rc-tabs-bottom .rc-tabs-tab-prev, .rc-tabs-bottom .rc-tabs-tab-next {
    margin-right: -2px;
    width: 32px;
    height: 100%;
    top: 0;
    text-align: center
}

.rc-tabs-bottom .rc-tabs-ink-bar {
    height: 2px;
    top: 3px;
    left: 0
}

.rc-tabs-bottom .rc-tabs-tab {
    float: left;
    height: 100%;
    margin-right: 10px
}

.rc-tabs-bottom .rc-tabs-tabpane-inactive {
    height: 0;
    overflow: visible
}

.rc-tabs-top {
    overflow-y: hidden;
    overflow-x: hidden
}

.rc-tabs-top .rc-tabs-content {
    width: 100%
}

.rc-tabs-top .rc-tabs-bar {
    border-bottom: 1px solid #eee
}

.rc-tabs-top .rc-tabs-nav-container-scrolling {
    padding-left: 32px;
    padding-right: 32px
}

.rc-tabs-top .rc-tabs-nav-scroll {
    width: 99999px
}

.rc-tabs-top .rc-tabs-nav-swipe {
    position: relative;
    left: 0
}

.rc-tabs-top .rc-tabs-nav-swipe .rc-tabs-nav {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-flex: 1;
    -ms-flex: 1;
    flex: 1;
    width: 100%
}

.rc-tabs-top .rc-tabs-nav-swipe .rc-tabs-nav .rc-tabs-tab {
    margin-right: 0;
    padding: 8px 0;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center
}

.rc-tabs-top .rc-tabs-nav-wrap {
    width: 100%
}

.rc-tabs-top .rc-tabs-content-animated {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
    -ms-flex-direction: row;
    flex-direction: row
}

.rc-tabs-top .rc-tabs-content-animated .rc-tabs-tabpane {
    width: 100%
}

.rc-tabs-top .rc-tabs-tab-next {
    right: 2px
}

.rc-tabs-top .rc-tabs-tab-next-icon:before {
    content: ">"
}

.rc-tabs-top .rc-tabs-tab-prev {
    left: 0
}

.rc-tabs-top .rc-tabs-tab-prev-icon:before {
    content: "<"
}

.rc-tabs-top .rc-tabs-tab-prev, .rc-tabs-top .rc-tabs-tab-next {
    margin-right: -2px;
    width: 32px;
    height: 100%;
    top: 4px;
    text-align: center
}

.rc-tabs-top .rc-tabs-ink-bar {
    height: 2px;
    bottom: 0;
    left: 0
}

.rc-tabs-top .rc-tabs-tab {
    float: left;
    height: 100%;
    margin-right: 30px
}

.rc-tabs-top .rc-tabs-tabpane-inactive {
    height: 0;
    overflow: visible
}

.tab-section-title {
    font-weight: 300;
    margin: 0;
    padding: 27px 0 16px
}

.tab-section-title-horiz-divider {
    margin-top: 0;
    margin-bottom: 0;
    border-top-color: #ccc
}

.rc-tabs-top {
    box-shadow: 0 -4px 5px -5px rgba(0, 0, 0, 0.33)
}

.rc-tabs-top .rc-tabs-bar {
    border-bottom: 1px solid #bbb;
    border-bottom-color: #22656d;
    border-top: 1px solid #ccc;
    border-top-color: #22656d;
    border-top: none;
    border-bottom: none;
    background: #22656d
}

.rc-tabs-top .rc-tabs-bar .rc-tabs-nav {
    padding: 4px 0px 4px
}

.rc-tabs-bar .rc-tabs-tab {
    padding-left: 18px;
    padding-right: 18px;
    margin-right: 0px;
    height: 38px;
    line-height: 36px;
    padding-top: 0px;
    padding-bottom: 0px;
    border-bottom: 1px solid transparent;
    position: relative;
    z-index: 10;
    transition: border-color .1s ease-out;
    color: #fff
}

.rc-tabs-bar .rc-tabs-tab:not(:nth-child(1)):not(:nth-child(2)) {
    border-left: 1px solid rgba(255, 255, 255, 0.33)
}

.rc-tabs-bar .rc-tabs-tab:hover:not(.rc-tabs-tab-active):not(.rc-tabs-tab-disabled) {
    transition: none;
    border-color: rgba(255, 255, 255, 0.33);
    border-bottom-color: transparent;
    border-top-color: transparent;
    background-color: rgba(255, 255, 255, 0.1)
}

.rc-tabs-bar .rc-tabs-tab.rc-tabs-tab-disabled {
    color: rgba(255, 255, 255, 0.66) !important
}

.rc-tabs-bar .rc-tabs-tab:hover.rc-tabs-tab-active {
    transition: border-color .6s ease-out, color .3s .1s ease-out, background-color .3s .2s ease-out
}

.rc-tabs-bar .rc-tabs-tab.rc-tabs-tab-active {
    border-color: transparent;
    color: #000
}

.rc-tabs-bar .rc-tabs-tab:hover:not(.rc-tabs-tab-disabled) + .rc-tabs-tab:not(.rc-tabs-tab-active) {
    border-left-color: transparent
}

.rc-tabs-bar .rc-tabs-tab.rc-tabs-tab-active + .rc-tabs-tab:not(:hover) {
    border-left-color: transparent
}

.rc-tabs-bar .tab {
    user-select: none;
    font-weight: 500;
    font-size: 1.05rem
}

.rc-tabs-bar .tab i.icon, .rc-tabs-bar .tab i.tcell-sort, .rc-tabs-bar .tab i.tcell-asc, .rc-tabs-bar .tab i.tcell-desc {
    margin-right: 3px
}

.rc-tabs-bar .tab i.icon.icon-warning, .rc-tabs-bar .tab i.icon-warning.tcell-sort, .rc-tabs-bar .tab i.tcell-sort.audit-icon-error, .rc-tabs-bar .tab i.tcell-sort.audit-icon-error-badged, .rc-tabs-bar .tab i.tcell-sort.audit-activeicon-error, .rc-tabs-bar .tab i.icon-warning.tcell-asc, .rc-tabs-bar .tab i.tcell-asc.audit-icon-error, .rc-tabs-bar .tab i.tcell-asc.audit-icon-error-badged, .rc-tabs-bar .tab i.tcell-asc.audit-activeicon-error, .rc-tabs-bar .tab i.icon-warning.tcell-desc, .rc-tabs-bar .tab i.tcell-desc.audit-icon-error, .rc-tabs-bar .tab i.tcell-desc.audit-icon-error-badged, .rc-tabs-bar .tab i.tcell-desc.audit-activeicon-error, .rc-tabs-bar .tab i.icon.audit-icon-error, .rc-tabs-bar .tab i.icon.audit-icon-error-badged, .rc-tabs-bar .tab i.icon.audit-activeicon-error, .rc-tabs-bar .tab i.icon.icon-check, .rc-tabs-bar .tab i.icon-check.tcell-sort, .rc-tabs-bar .tab i.tcell-sort.audit-icon-ok, .rc-tabs-bar .tab i.tcell-sort.audit-icon-ok-badged, .rc-tabs-bar .tab i.tcell-sort.audit-activeicon-ok, .rc-tabs-bar .tab i.icon-check.tcell-asc, .rc-tabs-bar .tab i.tcell-asc.audit-icon-ok, .rc-tabs-bar .tab i.tcell-asc.audit-icon-ok-badged, .rc-tabs-bar .tab i.tcell-asc.audit-activeicon-ok, .rc-tabs-bar .tab i.icon-check.tcell-desc, .rc-tabs-bar .tab i.tcell-desc.audit-icon-ok, .rc-tabs-bar .tab i.tcell-desc.audit-icon-ok-badged, .rc-tabs-bar .tab i.tcell-desc.audit-activeicon-ok, .rc-tabs-bar .tab i.icon.audit-icon-ok, .rc-tabs-bar .tab i.icon.audit-icon-ok-badged, .rc-tabs-bar .tab i.icon.audit-activeicon-ok {
    opacity: 0.25
}

.rc-tabs-bar .tab i.icon.icon-th, .rc-tabs-bar .tab i.icon-th.tcell-sort, .rc-tabs-bar .tab i.icon-th.tcell-asc, .rc-tabs-bar .tab i.icon-th.tcell-desc {
    position: relative;
    top: 0.5px
}

.rc-tabs-bar .tab span.active > i.icon, .rc-tabs-bar .tab span.active > i.tcell-sort, .rc-tabs-bar .tab span.active > i.tcell-asc, .rc-tabs-bar .tab span.active > i.tcell-desc {
    opacity: 1
}

.rc-tabs-bar .tab span.active > i.icon.icon-warning, .rc-tabs-bar .tab span.active > i.icon-warning.tcell-sort, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-icon-error, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-icon-error-badged, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-activeicon-error, .rc-tabs-bar .tab span.active > i.icon-warning.tcell-asc, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-icon-error, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-icon-error-badged, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-activeicon-error, .rc-tabs-bar .tab span.active > i.icon-warning.tcell-desc, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-icon-error, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-icon-error-badged, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-activeicon-error, .rc-tabs-bar .tab span.active > i.icon.audit-icon-error, .rc-tabs-bar .tab span.active > i.icon.audit-icon-error-badged, .rc-tabs-bar .tab span.active > i.icon.audit-activeicon-error {
    color: #e29302
}

.rc-tabs-bar .tab span.active > i.icon.icon-ban, .rc-tabs-bar .tab span.active > i.icon-ban.tcell-sort, .rc-tabs-bar .tab span.active > i.icon-ban.tcell-asc, .rc-tabs-bar .tab span.active > i.icon-ban.tcell-desc, .rc-tabs-bar .tab span.active > i.icon.icon-exclamation-circle, .rc-tabs-bar .tab span.active > i.icon-exclamation-circle.tcell-sort, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-icon-warning, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-icon-warning-badged, .rc-tabs-bar .tab span.active > i.tcell-sort.audit-activeicon-warning, .rc-tabs-bar .tab span.active > i.icon-exclamation-circle.tcell-asc, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-icon-warning, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-icon-warning-badged, .rc-tabs-bar .tab span.active > i.tcell-asc.audit-activeicon-warning, .rc-tabs-bar .tab span.active > i.icon-exclamation-circle.tcell-desc, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-icon-warning, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-icon-warning-badged, .rc-tabs-bar .tab span.active > i.tcell-desc.audit-activeicon-warning, .rc-tabs-bar .tab span.active > i.icon.audit-icon-warning, .rc-tabs-bar .tab span.active > i.icon.audit-icon-warning-badged, .rc-tabs-bar .tab span.active > i.icon.audit-activeicon-warning {
    color: #ff5757
}

.rc-tabs-bar .rc-tabs-tab-next, .rc-tabs-bar .rc-tabs-tab-prev {
    color: #fff
}

.rc-tabs-bar .rc-tabs-tab-next.rc-tabs-tab-btn-disabled, .rc-tabs-bar .rc-tabs-tab-prev.rc-tabs-tab-btn-disabled {
    opacity: 0.25
}

.rc-tabs-bar .rc-tabs-tab-next > .rc-tabs-tab-next-icon:before, .rc-tabs-bar .rc-tabs-tab-prev > .rc-tabs-tab-next-icon:before {
    font-family: FontAwesome;
    content: "\f105"
}

.rc-tabs-bar .rc-tabs-tab-next > .rc-tabs-tab-prev-icon:before, .rc-tabs-bar .rc-tabs-tab-prev > .rc-tabs-tab-prev-icon:before {
    font-family: FontAwesome;
    content: "\f104"
}

.rc-tabs-top .rc-tabs-ink-bar.extra-style-1 {
    height: 38px;
    background: none;
    border: 2px solid #22656d;
    border-radius: 5px
}

.rc-tabs-top .rc-tabs-ink-bar.extra-style-2 {
    height: 48px;
    background: none;
    border: 2px solid #22656d;
    box-shadow: 0 0 10px rgba(0, 0, 0, 0.5);
    border-bottom: none;
    border-left: none;
    border-right: none;
    background-color: #fcfcfc
}

#content form {
    margin-bottom: 1em
}

#content form:before, #content form:after {
    content: " ";
    display: table
}

#content form:after {
    clear: both
}

.form-control, .rf-Field textarea, .rf-Field input[type="text"], .rf-Field input[type="password"], .rf-Field input[type="datetime"], .rf-Field input[type="datetime-local"], .rf-Field input[type="date"], .rf-Field input[type="month"], .rf-Field input[type="time"], .rf-Field input[type="week"], .rf-Field input[type="number"], .rf-Field input[type="email"], .rf-Field input[type="url"], .rf-Field input[type="search"], .rf-Field input[type="tel"], .rf-Field input[type="color"], .dropzone, .item-picker {
    padding: 4px 6px
}

input[type="text"], input[type="password"], input[type="date"], input[type="datetime"], input[type="email"], input[type="number"], input[type="search"], input[type="tel"], input[type="time"], input[type="url"], textarea, select {
    font-family: inherit;
    font-size: 14px;
    font-size: 1rem;
    font-weight: normal;
    -webkit-transition: all 0.15s linear;
    transition: all 0.15s linear
}

input[type="text"][disabled], input[type="password"][disabled], input[type="date"][disabled], input[type="datetime"][disabled], input[type="email"][disabled], input[type="number"][disabled], input[type="search"][disabled], input[type="tel"][disabled], input[type="time"][disabled], input[type="url"][disabled], textarea[disabled], select[disabled] {
    background-color: #ddd
}

@media (min-width: 768px) {
    input[type="text"], input[type="password"], input[type="date"], input[type="datetime"], input[type="email"], input[type="number"], input[type="search"], input[type="tel"], input[type="time"], input[type="url"], textarea, select {
        font-size: inherit
    }
}

.navbar-form.navbar-right {
    position: relative;
    margin-top: -1px
}

.navbar-form.navbar-right #navbar-search {
    font-size: 1em;
    width: 140px;
    color: rgba(0, 0, 0, 0.5);
    border-radius: 3px;
    border: 1px solid #7d7d7d;
    height: inherit;
    padding: 4px 5px 3px 5px;
    -ms-transition: width 0.3s ease-out;
    -moz-transition: width 0.3s ease-out;
    -webkit-transition: width 0.3s ease-out;
    transition: width 0.3s ease-out
}

@media (max-width: 767px) {
    .navbar-form.navbar-right #navbar-search {
        width: 100%;
        display: block
    }
}

@media (max-width: 991px) {
    .navbar-form.navbar-right {
        line-height: normal;
        padding-top: 15px;
        padding-bottom: 15px;
        border-top: 1px solid #ccc
    }
}

@media (min-width: 768px) {
    .navbar-form.navbar-right {
        margin-left: -20px
    }

    .navbar-form.navbar-right #navbar-search {
        margin-top: 0px;
        font-size: 1em;
        margin-left: 5px;
        border: 1px solid rgba(125, 125, 125, 0.5)
    }

    .navbar-form.navbar-right.has-input #navbar-search, .navbar-form.navbar-right #navbar-search:focus {
        width: 180px;
        color: #000;
        border-color: #7d7d7d;
        -webkit-transition: width 0.3s ease-out;
        transition: width 0.3s ease-out
    }
}

@media (min-width: 1200px) {
    .navbar-form.navbar-right.has-input #navbar-search, .navbar-form.navbar-right #navbar-search:focus {
        width: 300px
    }
}

.navbar-form.navbar-right i.reset-button {
    position: absolute;
    top: 50%;
    margin-top: -6px;
    right: 18px;
    opacity: 0.33;
    cursor: pointer
}

.navbar-form.navbar-right i.reset-button:hover {
    opacity: 1
}

@media (max-width: 767px) {
    .navbar-form.navbar-right i.reset-button {
        right: 32px
    }
}

.navbar-form.navbar-right .search-icon-button {
    display: none
}

.navbar-form.navbar-right:not(.has-query) .search-icon-button {
    display: block;
    line-height: 14px;
    position: absolute;
    top: 50%;
    margin-top: -11px;
    right: 12px;
    opacity: 0.25;
    border: none;
    background: none;
    padding: 4px 4px 2px
}

@media (max-width: 767px) {
    .navbar-form.navbar-right:not(.has-query) .search-icon-button {
        right: 32px
    }
}

@media (max-width: 767px) {
    .navbar-form.navbar-right {
        padding-left: 25px;
        padding-right: 25px
    }
}

@media (max-width: 767px) {
    .navbar-form.navbar-right .dropdown.btn-group {
        display: none
    }
}

.navbar-form.navbar-right .dropdown.btn-group #search-item-type-selector {
    display: inline-block;
    z-index: -1000;
    border-radius: 3px;
    padding: 4px 24px 4px 10px;
    max-width: 118px
}

.navbar-form.navbar-right .dropdown.btn-group #search-item-type-selector .caret {
    margin-left: 2px
}

.navbar-form.navbar-right .dropdown:not(.open) #search-item-type-selector:not(:hover):not(:active):not(.active) {
    background-color: transparent;
    border-color: #ddd
}

@media (min-width: 768px) {
    .navbar-form.navbar-right.has-query .dropdown.btn-group #search-item-type-selector, .navbar-form.navbar-right.has-input .dropdown.btn-group #search-item-type-selector {
        display: inline-block;
        margin-left: 0px;
        z-index: 1
    }
}

.form-inline .form-control, .navbar-form .form-control, .form-inline .rf-Field textarea, .rf-Field .form-inline textarea, .navbar-form .rf-Field textarea, .rf-Field .navbar-form textarea, .form-inline .rf-Field input[type="text"], .rf-Field .form-inline input[type="text"], .navbar-form .rf-Field input[type="text"], .rf-Field .navbar-form input[type="text"], .form-inline .rf-Field input[type="password"], .rf-Field .form-inline input[type="password"], .navbar-form .rf-Field input[type="password"], .rf-Field .navbar-form input[type="password"], .form-inline .rf-Field input[type="datetime"], .rf-Field .form-inline input[type="datetime"], .navbar-form .rf-Field input[type="datetime"], .rf-Field .navbar-form input[type="datetime"], .form-inline .rf-Field input[type="datetime-local"], .rf-Field .form-inline input[type="datetime-local"], .navbar-form .rf-Field input[type="datetime-local"], .rf-Field .navbar-form input[type="datetime-local"], .form-inline .rf-Field input[type="date"], .rf-Field .form-inline input[type="date"], .navbar-form .rf-Field input[type="date"], .rf-Field .navbar-form input[type="date"], .form-inline .rf-Field input[type="month"], .rf-Field .form-inline input[type="month"], .navbar-form .rf-Field input[type="month"], .rf-Field .navbar-form input[type="month"], .form-inline .rf-Field input[type="time"], .rf-Field .form-inline input[type="time"], .navbar-form .rf-Field input[type="time"], .rf-Field .navbar-form input[type="time"], .form-inline .rf-Field input[type="week"], .rf-Field .form-inline input[type="week"], .navbar-form .rf-Field input[type="week"], .rf-Field .navbar-form input[type="week"], .form-inline .rf-Field input[type="number"], .rf-Field .form-inline input[type="number"], .navbar-form .rf-Field input[type="number"], .rf-Field .navbar-form input[type="number"], .form-inline .rf-Field input[type="email"], .rf-Field .form-inline input[type="email"], .navbar-form .rf-Field input[type="email"], .rf-Field .navbar-form input[type="email"], .form-inline .rf-Field input[type="url"], .rf-Field .form-inline input[type="url"], .navbar-form .rf-Field input[type="url"], .rf-Field .navbar-form input[type="url"], .form-inline .rf-Field input[type="search"], .rf-Field .form-inline input[type="search"], .navbar-form .rf-Field input[type="search"], .rf-Field .navbar-form input[type="search"], .form-inline .rf-Field input[type="tel"], .rf-Field .form-inline input[type="tel"], .navbar-form .rf-Field input[type="tel"], .rf-Field .navbar-form input[type="tel"], .form-inline .rf-Field input[type="color"], .rf-Field .form-inline input[type="color"], .navbar-form .rf-Field input[type="color"], .rf-Field .navbar-form input[type="color"], .form-inline .dropzone, .navbar-form .dropzone, .form-inline .item-picker, .navbar-form .item-picker, .navbar-form .form-control, .navbar-form .rf-Field textarea, .rf-Field .navbar-form textarea, .navbar-form .rf-Field input[type="text"], .rf-Field .navbar-form input[type="text"], .navbar-form .rf-Field input[type="password"], .rf-Field .navbar-form input[type="password"], .navbar-form .rf-Field input[type="datetime"], .rf-Field .navbar-form input[type="datetime"], .navbar-form .rf-Field input[type="datetime-local"], .rf-Field .navbar-form input[type="datetime-local"], .navbar-form .rf-Field input[type="date"], .rf-Field .navbar-form input[type="date"], .navbar-form .rf-Field input[type="month"], .rf-Field .navbar-form input[type="month"], .navbar-form .rf-Field input[type="time"], .rf-Field .navbar-form input[type="time"], .navbar-form .rf-Field input[type="week"], .rf-Field .navbar-form input[type="week"], .navbar-form .rf-Field input[type="number"], .rf-Field .navbar-form input[type="number"], .navbar-form .rf-Field input[type="email"], .rf-Field .navbar-form input[type="email"], .navbar-form .rf-Field input[type="url"], .rf-Field .navbar-form input[type="url"], .navbar-form .rf-Field input[type="search"], .rf-Field .navbar-form input[type="search"], .navbar-form .rf-Field input[type="tel"], .rf-Field .navbar-form input[type="tel"], .navbar-form .rf-Field input[type="color"], .rf-Field .navbar-form input[type="color"], .navbar-form .dropzone, .navbar-form .item-picker {
    display: inline-block;
    outline: none !important;
    box-shadow: none
}

.input-lg, .input-group-lg > .form-control, .rf-Field .input-group-lg > textarea, .rf-Field .input-group-lg > input[type="text"], .rf-Field .input-group-lg > input[type="password"], .rf-Field .input-group-lg > input[type="datetime"], .rf-Field .input-group-lg > input[type="datetime-local"], .rf-Field .input-group-lg > input[type="date"], .rf-Field .input-group-lg > input[type="month"], .rf-Field .input-group-lg > input[type="time"], .rf-Field .input-group-lg > input[type="week"], .rf-Field .input-group-lg > input[type="number"], .rf-Field .input-group-lg > input[type="email"], .rf-Field .input-group-lg > input[type="url"], .rf-Field .input-group-lg > input[type="search"], .rf-Field .input-group-lg > input[type="tel"], .rf-Field .input-group-lg > input[type="color"], .input-group-lg > .dropzone, .input-group-lg > .item-picker, .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .btn, .input-group-lg > .input-group-btn > .rf-RepeatingFieldset__add {
    font-size: 20px !important;
    font-size: 1.42rem !important;
    font-weight: normal;
    height: 36px !important;
    line-height: 30px !important;
    padding: 4px 6px !important
}

.filter {
    padding-right: 30px !important
}

.clear-input-icon {
    position: absolute;
    right: 10px;
    top: 11px;
    z-index: 100;
    line-height: 100%;
    height: 100%;
    color: #dfdfdf;
    font-size: 15px;
    font-size: 1.1rem;
    cursor: pointer
}

.clear-input-icon:active {
    color: #cbcbcb
}

.red {
    border-color: red !important;
    color: red
}

.dropzone {
    height: auto;
    text-align: center
}

.dropzone .drop {
    min-height: 50px
}

.dropzone input[type="file"] {
    display: inline
}

.item-picker {
    height: auto
}

.item-picker:before, .item-picker:after {
    content: " ";
    display: table
}

.item-picker:after {
    clear: both
}

.item-picker .item-picker-preview {
    overflow: hidden
}

.item-picker .item-picker-preview .result-table > li {
    margin: 4px 6px;
    border: none
}

.item-picker .item-picker-preview .clear {
    float: right
}

.item-picker > .btn, .item-picker > .rf-RepeatingFieldset__add {
    margin-left: 1em
}

.item-picker.disabled {
    cursor: not-allowed;
    background-color: #eee
}

.collapsible {
    padding-left: 20px;
    position: relative
}

.collapsible .collapsible-trigger {
    position: absolute;
    top: 12px;
    left: 0;
    cursor: pointer
}

.fieldset.editable-fields.editing .editable-field-entry:not(.editing), .editable-fields-container.editing .editable-field-entry:not(.editing) {
    filter: blur(0.75px) grayscale(75%);
    opacity: 0.75;
    pointer-events: none
}

div.fieldset.editable-fields {
    padding-bottom: 15px
}

@media screen and (min-width: 992px) {
    div.fieldset.editable-fields {
        transition: padding-bottom .5s linear
    }
}

div.fieldset.editable-fields.editing {
    padding-bottom: 0px
}

.editable-field-entry label, .field-entry label {
    margin-bottom: 0;
    font-weight: 500
}

.editable-field-entry .value, .field-entry .value {
    word-break: break-all;
    padding-bottom: 10px
}

.editable-field-entry .value .not-set, .field-entry .value .not-set {
    color: #bbb
}

.editable-field-entry.row > ul, .editable-field-entry.flexrow > ul, .editable-field-entry.row > div.value > ul, .editable-field-entry.flexrow > div.value > ul, .field-entry.row > ul, .field-entry.flexrow > ul, .field-entry.row > div.value > ul, .field-entry.flexrow > div.value > ul {
    margin: 0;
    padding: 0;
    padding-left: 20px
}

.editable-field-entry.row > ul > li, .editable-field-entry.flexrow > ul > li, .editable-field-entry.row > div.value > ul > li, .editable-field-entry.flexrow > div.value > ul > li, .field-entry.row > ul > li, .field-entry.flexrow > ul > li, .field-entry.row > div.value > ul > li, .field-entry.flexrow > div.value > ul > li {
    list-style-position: outside
}

.editable-field-entry.row > ul > li > i.icon, .editable-field-entry.flexrow > ul > li > i.icon, .editable-field-entry.row > ul > li > i.tcell-sort, .editable-field-entry.flexrow > ul > li > i.tcell-sort, .editable-field-entry.row > ul > li > i.tcell-asc, .editable-field-entry.flexrow > ul > li > i.tcell-asc, .editable-field-entry.row > ul > li > i.tcell-desc, .editable-field-entry.flexrow > ul > li > i.tcell-desc, .editable-field-entry.row > div.value > ul > li > i.icon, .editable-field-entry.flexrow > div.value > ul > li > i.icon, .editable-field-entry.row > div.value > ul > li > i.tcell-sort, .editable-field-entry.flexrow > div.value > ul > li > i.tcell-sort, .editable-field-entry.row > div.value > ul > li > i.tcell-asc, .editable-field-entry.flexrow > div.value > ul > li > i.tcell-asc, .editable-field-entry.row > div.value > ul > li > i.tcell-desc, .editable-field-entry.flexrow > div.value > ul > li > i.tcell-desc, .field-entry.row > ul > li > i.icon, .field-entry.flexrow > ul > li > i.icon, .field-entry.row > ul > li > i.tcell-sort, .field-entry.flexrow > ul > li > i.tcell-sort, .field-entry.row > ul > li > i.tcell-asc, .field-entry.flexrow > ul > li > i.tcell-asc, .field-entry.row > ul > li > i.tcell-desc, .field-entry.flexrow > ul > li > i.tcell-desc, .field-entry.row > div.value > ul > li > i.icon, .field-entry.flexrow > div.value > ul > li > i.icon, .field-entry.row > div.value > ul > li > i.tcell-sort, .field-entry.flexrow > div.value > ul > li > i.tcell-sort, .field-entry.row > div.value > ul > li > i.tcell-asc, .field-entry.flexrow > div.value > ul > li > i.tcell-asc, .field-entry.row > div.value > ul > li > i.tcell-desc, .field-entry.flexrow > div.value > ul > li > i.tcell-desc {
    position: relative;
    top: 1px;
    color: #d2d2d2
}

.editable-field-entry {
    opacity: 1;
    min-height: 30px
}

@media screen and (min-width: 768px) {
    .editable-field-entry {
        transition: filter .75s, opacity .5s, min-height .5s linear
    }
}

.editable-field-entry .value .edit-button, .editable-field-entry .value .cancel-button, .editable-field-entry .value .save-button, .editable-field-entry .value .field-loading-icon {
    padding: 0 6px;
    line-height: 100%;
    height: 100%;
    vertical-align: middle
}

.editable-field-entry .value .edit-button.right, .editable-field-entry .value .cancel-button.right, .editable-field-entry .value .save-button.right, .editable-field-entry .value .field-loading-icon.right {
    display: block
}

.editable-field-entry .value .edit-button > i.icon, .editable-field-entry .value .edit-button > i.tcell-sort, .editable-field-entry .value .edit-button > i.tcell-asc, .editable-field-entry .value .edit-button > i.tcell-desc, .editable-field-entry .value .cancel-button > i.icon, .editable-field-entry .value .cancel-button > i.tcell-sort, .editable-field-entry .value .cancel-button > i.tcell-asc, .editable-field-entry .value .cancel-button > i.tcell-desc, .editable-field-entry .value .save-button > i.icon, .editable-field-entry .value .save-button > i.tcell-sort, .editable-field-entry .value .save-button > i.tcell-asc, .editable-field-entry .value .save-button > i.tcell-desc, .editable-field-entry .value .field-loading-icon > i.icon, .editable-field-entry .value .field-loading-icon > i.tcell-sort, .editable-field-entry .value .field-loading-icon > i.tcell-asc, .editable-field-entry .value .field-loading-icon > i.tcell-desc {
    vertical-align: inherit;
    height: inherit;
    line-height: inherit
}

.editable-field-entry .value .cancel-button, .editable-field-entry .value .save-button {
    padding-top: 9px;
    font-size: 1.1em;
    margin-bottom: -10px;
    position: relative;
    z-index: 4
}

.editable-field-entry .value .cancel-button:hover, .editable-field-entry .value .save-button:hover {
    color: #000
}

.editable-field-entry .value .cancel-button {
    color: #a94442
}

.editable-field-entry .value .save-button {
    color: #3c763d
}

.editable-field-entry .value .field-loading-icon {
    color: #bbb
}

.editable-field-entry .value.editing .field-loading-icon {
    padding-top: 9px;
    margin-bottom: -10px
}

.editable-field-entry .value .edit-button {
    color: transparent
}

.editable-field-entry .value .edit-button.right {
    transform: translateY(2px)
}

.editable-field-entry .value .edit-button.inline {
    position: absolute;
    margin-top: -5px;
    padding: 0;
    height: 20px;
    width: 20px;
    text-align: center;
    border-radius: 50%
}

.editable-field-entry .value:hover .edit-button {
    color: #aaa
}

.editable-field-entry .value:hover .edit-button.inline {
    background-color: rgba(255, 255, 255, 0.5)
}

.editable-field-entry .value:hover .edit-button:hover {
    color: #000
}

.editable-field-entry.editing:not(.inline) {
    min-height: 45px
}

.editable-field-entry.editing .edit-button {
    visibility: hidden
}

.editable-field-entry.editing span.input-wrapper {
    margin-right: 75px;
    display: block;
    position: relative;
    z-index: 2
}

@media screen and (min-width: 768px) {
    .editable-field-entry.editing span.input-wrapper {
        margin-bottom: -100px
    }
}

.editable-field-entry.editing span.input-wrapper input[type=text], .editable-field-entry.editing span.input-wrapper input[type=number], .editable-field-entry.editing span.input-wrapper input[type=email], .editable-field-entry.editing span.input-wrapper input[type=tel] {
    margin-top: 3px;
    display: block;
    margin-bottom: 0px;
    width: 100%;
    position: relative;
    z-index: 3
}

.editable-field-entry.editing span.input-wrapper span.help-block {
    font-size: .85rem;
    padding: 5px 3px 7px;
    margin: 0;
    background-color: #fff;
    border-bottom: 1px solid #eee;
    box-shadow: 0 10px 15px 0px rgba(255, 255, 255, 0.75);
    word-break: break-word;
    transition: opacity .35s .15s
}

.editable-field-entry.editing span.input-wrapper span.tip-block {
    font-size: .85rem;
    padding: 5px 3px 7px;
    margin: 0;
    background-color: #fff;
    border-bottom: 1px solid #eee;
    box-shadow: 0 10px 15px 0px rgba(255, 255, 255, 0.75);
    word-break: break-word;
    transition: opacity .35s .15s
}

.editable-field-entry.editing.inline {
    display: inline-block;
    position: relative
}

.editable-field-entry.editing.inline span.input-wrapper {
    display: inline-block;
    margin-bottom: 0px;
    vertical-align: top
}

.editable-field-entry.editing.inline span.input-wrapper span.help-block {
    position: absolute;
    width: 100%
}

.editable-field-entry.editing.inline span.input-wrapper span.tip_block {
    position: absolute;
    width: 100%
}

.editable-field-entry.editing.inline.block-style .value.ghost {
    opacity: 0.5
}

.editable-field-entry.editing.inline.block-style .value.editing {
    position: absolute;
    z-index: 10;
    width: 280px;
    top: -2px;
    background: rgba(250, 250, 250, 0.9);
    padding-bottom: 3px;
    padding: 0 2px 2px 2px;
    border-radius: 5px;
    border: 1px solid #eee
}

.editable-field-entry.editing.inline.block-style span.input-wrapper span.help-block span.tip-block {
    position: absolute;
    background: none;
    border-bottom: none;
    box-shadow: none;
    padding: 8px 5px 6px
}

.editable-field-entry.editing.inline.block-style.has-error span.input-wrapper span.help-block span.tip-block {
    position: relative
}

.editable-field-entry.editing.inline .save-button, .editable-field-entry.editing.inline .field-loading-icon {
    position: absolute;
    right: 36px
}

.editable-field-entry.editing.inline .cancel-button {
    position: absolute;
    right: 6px
}

.editable-field-entry.editing.inline.input-size-lg .save-button, .editable-field-entry.editing.inline.input-size-lg .cancel-button, .editable-field-entry.editing.inline.input-size-lg .field-loading-icon {
    padding-top: 12px;
    font-size: 1.25rem
}

.editable-field-entry.editing.inline.input-size-lg .field-loading-icon {
    height: auto;
    padding-top: 11px
}

.editable-field-entry.editing.row.has-error, .editable-field-entry.editing.has-error.flexrow, .editable-field-entry.editing.inline.has-error:not(.block-style) {
    min-height: 80px
}

.editable-field-entry.editing.row.has-error span.help-block, .editable-field-entry.editing.has-error.flexrow span.help-block, .editable-field-entry.editing.inline.has-error:not(.block-style) span.help-block {
    opacity: 1
}

.editable-field-entry.editing:not(.has-error) span.help-block {
    opacity: 0;
    position: absolute;
    transition: opacity .35s, color .5s .5s !important
}

.onoffswitch {
    position: relative;
    width: 40px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.onoffswitch-checkbox {
    display: none
}

.onoffswitch-label {
    display: block;
    overflow: hidden;
    cursor: pointer;
    border: 2px solid #E3E3E3;
    border-radius: 20px;
    height: 20px;
    margin: 0
}

.onoffswitch-inner {
    display: block;
    width: 200%;
    margin-left: -100%;
    transition: margin 0.3s ease-in 0s
}

.onoffswitch-inner:before, .onoffswitch-inner:after {
    display: block;
    float: left;
    width: 50%;
    height: 20px;
    padding: 0;
    line-height: 20px;
    font-size: 11px;
    color: white;
    font-family: Trebuchet, Arial, sans-serif;
    font-weight: bold;
    box-sizing: border-box
}

.onoffswitch-inner:before {
    content: "";
    padding-left: 10px;
    background-color: #46A9EB;
    color: #FFFFFF
}

.onoffswitch-inner:after {
    content: "";
    padding-right: 10px;
    background-color: #FFFFFF;
    color: #666666;
    text-align: right
}

.onoffswitch-switch {
    display: block;
    width: 20px;
    margin: 0px;
    background: #FFFFFF;
    position: absolute;
    top: 0;
    bottom: 0;
    right: 20px;
    border: 2px solid #E3E3E3;
    border-radius: 20px;
    transition: all 0.3s ease-in 0s
}

.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-inner {
    margin-left: 0
}

.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch {
    right: 0px
}

dt.h3, dt.h4, dd.h3, dd.h4 {
    margin-top: 0;
    font-size: 14px;
    font-size: 1rem
}

dd.h3, dd.h4 {
    font-weight: normal
}

dl.key-value, dl.key-value-left, dl.key-value-doc {
    margin: 0
}

dl.key-value dt, dl.key-value-left dt, dl.key-value dd, dl.key-value-left dd, dl.key-value-doc dt, dl.key-value-doc dd {
    display: block;
    float: none;
    margin: 0;
    padding: 0;
    line-height: 1.3;
    text-align: left;
    vertical-align: top;
    word-wrap: break-word
}

dl.key-value dt, dl.key-value-left dt, dl.key-value-doc dt {
    font-weight: bold
}

dl.key-value dt span, dl.key-value-left dt span, dl.key-value-doc dt span {
    margin-right: 5px
}

dl.key-value dt .cancel-button, dl.key-value-left dt .cancel-button, dl.key-value-doc dt .cancel-button {
    color: #a94442
}

dl.key-value dd.sequence, dl.key-value-left dd.sequence, dl.key-value-doc dd.sequence {
    overflow-wrap: break-word;
    word-break: break-all
}

dl.key-value dd .display-tip, dl.key-value-left dd .display-tip, dl.key-value-doc dd .display-tip {
    padding-top: 4px;
    color: #808080
}

dl.key-value dd .display-message, dl.key-value-left dd .display-message, dl.key-value-doc dd .display-message {
    padding-top: 4px;
    color: #a94442
}

dl.key-value dd .display-message .display-bold, dl.key-value-left dd .display-message .display-bold, dl.key-value-doc dd .display-message .display-bold {
    font-weight: bold
}

dl.key-value dd .input-wrapper input, dl.key-value-left dd .input-wrapper input, dl.key-value-doc dd .input-wrapper input {
    width: 85%
}

dl.key-value.extra-footspace, dl.extra-footspace.key-value-left, dl.key-value-doc.extra-footspace {
    margin-bottom: 15px
}

dl.key-value [data-test], dl.key-value-left [data-test], dl.key-value-doc [data-test] {
    clear: both;
    margin: 6px 0
}

@media screen and (min-width: 480px) {
    dl.key-value, dl.key-value-left {
        display: table;
        width: 100%
    }

    dl.key-value dt, dl.key-value-left dt, dl.key-value dd, dl.key-value-left dd {
        display: table-cell
    }

    dl.key-value dt, dl.key-value-left dt {
        min-width: 140px;
        padding: 8px 0
    }

    dl.key-value dd, dl.key-value-left dd {
        padding: 8px 0 8px 10px
    }

    dl.key-value [data-test], dl.key-value-left [data-test] {
        clear: none;
        display: table-row
    }
}

.key-value-flex {
    margin: 0
}

.key-value-flex dt, .key-value-flex dd {
    display: block;
    margin: 0
}

.key-value-flex dt {
    font-weight: bold
}

.key-value-flex dt:after {
    content: ": "
}

.key-value-flex div {
    clear: both;
    margin: 6px 0
}

@media screen and (min-width: 480px) {
    .key-value-flex {
        display: table
    }

    .key-value-flex dt, .key-value-flex dd {
        display: table-cell;
        vertical-align: bottom
    }

    .key-value-flex dt {
        padding: 6px 20px 6px 0
    }

    .key-value-flex dd {
        padding: 6px 0
    }

    .key-value-flex div {
        clear: none;
        display: table-row
    }
}

.key-value-left dt, .key-value-left dd {
    width: auto;
    padding-top: 0 !important
}

.key-value-left dt {
    float: none !important;
    display: block !important;
    text-align: left !important;
    margin-bottom: 0px !important
}

.key-value-left dd {
    margin-left: 0 !important
}

.key-value-left dd.key-value-left-indent {
    margin-left: 20px !important
}

.line-item:before {
    content: ' ';
    display: block
}

.unit::before {
    content: " "
}

dd ul, .multi-value {
    display: block;
    list-style: none;
    margin: 0;
    padding: 0
}

dd ul li, .multi-value li {
    display: inline-block;
    margin-right: 5px
}

dd ul li span, .multi-value li span {
    font-weight: normal
}

.multi-comma {
    margin-right: 0
}

.multi-comma:after {
    content: ",\00a0"
}

.multi-comma:last-child:after {
    content: normal
}

.multi-dd {
    margin-bottom: 10px
}

.para-text {
    line-height: 1.6 !important
}

.sw-step-versions {
    display: inline-block;
    margin-top: 8px
}

.sw-step-versions:first-child {
    margin-top: 0
}

.software-version-list {
    display: inline
}

.software-version {
    display: inline-block;
    padding: 0;
    margin-right: 5px;
    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    border-radius: 2px;
    border: 1px solid #c0c0c0;
    color: #333;
    font-size: 13px;
    font-size: .9rem;
    text-decoration: none
}

.software-version:hover {
    color: #eee;
    background-color: #333
}

.software-version:hover .version {
    color: #fff;
    background-color: #808080
}

.software-version .software {
    padding: 0 5px
}

.software-version .version {
    padding: 0 5px;
    font-weight: bold;
    background-color: #e0e0e0
}

.input-wrapper input {
    width: 70%
}

.lightbox {
    visibility: hidden;
    position: fixed;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    background-color: #fff;
    background-color: rgba(255, 255, 255, 0.8);
    opacity: 0;
    z-index: 1100;
    -webkit-transition: all 200ms;
    transition: all 200ms;
    text-align: center;
    cursor: pointer
}

.lightbox.active {
    visibility: visible;
    opacity: 1;
    -webkit-transition: all 200ms;
    transition: all 200ms
}

.lightbox img {
    display: block;
    border: 1px solid #808080
}

.lightbox-img {
    position: relative;
    display: inline-block;
    margin-top: 20px;
    text-align: center;
    max-width: 90%
}

.lightbox-img a {
    position: relative;
    display: block;
    vertical-align: middle;
    margin: 0 auto;
    text-align: left
}

.lightbox-img a img {
    display: block;
    width: auto;
    height: auto;
    margin: 0 auto;
    max-width: 100%;
    line-height: 0
}

.lightbox-close {
    position: absolute;
    top: -12px;
    right: -12px;
    width: 24px;
    height: 24px;
    background: transparent;
    border: none;
    background-image: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij48c3R5bGUgdHlwZT0idGV4dC9jc3MiPi5zdDB7ZmlsbDojRkZGRkZGO308L3N0eWxlPjxjaXJjbGUgY3g9IjEyIiBjeT0iMTIiIHI9IjEwLjkiLz48Y2lyY2xlIGNsYXNzPSJzdDAiIGN4PSIxMiIgY3k9IjEyIiByPSIxMC4yIi8+PGNpcmNsZSBjeD0iMTIiIGN5PSIxMiIgcj0iOC43Ii8+PHBhdGggY2xhc3M9InN0MCIgZD0iTTE3LjEgOC42bC0xLjctMS43LTMuNCAzLjQtMy40LTMuNC0xLjcgMS43IDMuNCAzLjQtMy40IDMuNCAxLjcgMS43IDMuNC0zLjQgMy40IDMuNCAxLjctMS43LTMuNC0zLjR6Ii8+PC9zdmc+')
}

.no-svg .lightbox-close {
    background-image: url('data:image/png;base64,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')
}

.hubs-controls {
    margin-left: 28px;
    padding: 10px 0 20px
}

.hubs-controls-button {
    display: inline-block
}

.matrix-view-container-wrapper .matrix-title {
    font-weight: 500
}

.matrix-view-container-wrapper .matrix-title.no-x-axis-title {
    position: absolute;
    bottom: 42px;
    font-weight: 700
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis {
    float: left;
    display: flex;
    flex-direction: column
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label {
    display: block;
    position: relative;
    margin: 1px 0;
    margin-right: 10px;
    border-bottom: 1px dotted #ddd;
    border-top: 1px dotted #ddd
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner {
    position: relative
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container {
    position: relative
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container > .part-1 {
    font-weight: 500
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container > .part-2 {
    font-size: 0.85rem;
    float: right;
    margin-left: 7px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container > .part-1 + .part-2 {
    max-width: 40%;
    margin-top: 2px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container:not(.height-at-least-64) > .part-1 {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}

.matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container.height-at-least-0 > .part-2, .matrix-view-container-wrapper .matrix-view-container .matrix-y-axis .y-axis-matrix-label > .inner .label-container.height-at-least-30 > .part-2 {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 50%
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis {
    display: flex;
    flex-direction: row
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix {
    position: relative
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title {
    position: absolute;
    white-space: nowrap;
    overflow: hidden;
    font-weight: 600
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.icon, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-sort, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-asc, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-desc, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.icon, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-sort, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-asc, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-desc {
    font-size: 0.75rem;
    color: rgba(0, 0, 0, 0.33)
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title {
    position: relative;
    float: right;
    margin-right: 5px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.icon, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-sort, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-asc, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-x-axis-title small > i.tcell-desc {
    margin-left: 5px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title {
    bottom: 5px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.icon, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-sort, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-asc, .matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .prefix .matrix-y-axis-title small > i.tcell-desc {
    margin-left: 5px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .x-axis-matrix-label-container {
    position: relative;
    margin: 0 1px
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .x-axis-matrix-label-container .x-axis-matrix-label {
    position: absolute;
    bottom: 0;
    transform-origin: 0 100%;
    transform: rotate(-45deg)
}

.matrix-view-container-wrapper .matrix-view-container .matrix-x-axis .x-axis-matrix-label-container .x-axis-matrix-label > .inner {
    position: relative
}

.matrix-view-container-wrapper .matrix-view-container .matrix-grid-container {
    float: left
}

.matrix-view-container-wrapper .matrix-view-container .matrix-grid-container .rm-cell {
    border-radius: 0px
}

.non-dl-list {
    list-style: none;
    margin: 0 0 0 60px
}

.non-dl-item {
    margin-left: 60px
}

.black-overlay {
    display: none;
    background-color: black;
    left: 0%;
    opacity: 0.5;
    position: absolute;
    height: 100%;
    top: 0%;
    width: 100%;
    z-index: 1001
}

.loading-spinner {
    background: url("../img/spinner1.gif") no-repeat;
    display: none;
    left: 50%;
    overflow: auto;
    position: absolute;
    top: 9%;
    width: 30px;
    height: 30px;
    z-index: 1002
}

.communicating .black-overlay, .communicating .loading-spinner {
    display: block
}

#top-nav {
    background: #ffffff;
    margin-bottom: 0;
    transform: translate3d(0, 0, 0)
}

#top-nav > nav.navbar-main {
    border-radius: 0;
    border: none;
    box-sizing: content-box;
    min-height: 80px;
    line-height: 80px;
    position: relative
}

@media screen and (min-width: 992px) {
    #top-nav > nav.navbar-main {
        min-height: 40px;
        height: 80px;
        z-index: 10
    }

    .navbar-container.nav-initialized #top-nav > nav.navbar-main {
        -webkit-backface-visibility: hidden;
        -moz-backface-visibility: hidden;
        backface-visibility: hidden;
        transform: translate3d(0, 0, 0);
        transition: height .3s ease-out, line-height .3s ease-out
    }

    .navbar-container.scrolled-past-top #top-nav > nav.navbar-main, body.is-full-screen .navbar-container #top-nav > nav.navbar-main {
        height: 40px;
        line-height: 40px
    }
}

#top-nav > nav.navbar-main > .container {
    height: inherit;
    line-height: inherit
}

#top-nav > nav.navbar-main > .container > .navbar-header {
    margin-left: 0px;
    margin-right: 0px;
    height: inherit;
    line-height: inherit
}

#top-nav .navbar-brand {
    padding: 0px !important;
    display: block;
    color: #999;
    min-width: 270px;
    height: inherit;
    line-height: inherit;
    max-height: 80px;
    margin-left: 0px;
    white-space: nowrap
}

@media screen and (min-width: 992px) and (max-width: 1199px) {
    #top-nav .navbar-brand {
        min-width: 300px
    }
}

@media screen and (min-width: 768px) and (max-width: 991px) {
    #top-nav .navbar-brand {
        min-width: 290px
    }
}

@media screen and (max-width: 767px) {
    #top-nav .navbar-brand {
        min-width: 225px;
        max-width: 240px
    }
}

#top-nav .navbar-brand > a {
    display: block;
    line-height: inherit;
    height: inherit;
    text-decoration: none;
    position: relative
}

#top-nav .navbar-brand > a > .img-container {
    height: inherit;
    display: block;
    font-size: 0rem;
    float: left;
    margin-right: 15px;
    text-align: center
}

#top-nav .navbar-brand > a > .img-container > img, #top-nav .navbar-brand > a > .img-container > .navbar-logo-img {
    vertical-align: middle;
    display: inline-block;
    height: 100%;
    padding-bottom: 10px;
    padding-top: 10px
}

.navbar-container.nav-initialized #top-nav .navbar-brand > a > .img-container > img, .navbar-container.nav-initialized #top-nav .navbar-brand > a > .img-container > .navbar-logo-img {
    transition: padding .3s
}

.navbar-container.scrolled-past-top #top-nav .navbar-brand > a > .img-container > img, .navbar-container.scrolled-past-top #top-nav .navbar-brand > a > .img-container > .navbar-logo-img {
    padding-top: 6px;
    padding-bottom: 6px
}

#top-nav .navbar-brand > a > .navbar-title {
    font-weight: 300;
    color: #444;
    margin-right: 15px;
    font-size: 1.7rem;
    display: inline-block;
    transform: translate3d(0px, 0, 0)
}

.navbar-container.nav-initialized #top-nav .navbar-brand > a > .navbar-title {
    transition: font-size .3s, transform .3s
}

.navbar-container.scrolled-past-top #top-nav .navbar-brand > a > .navbar-title {
    font-size: 1.25rem;
    transform: translate3d(-5px, 0, 0)
}

#top-nav .navbar-brand > a:hover .navbar-title {
    color: #000;
    text-shadow: 0 0 0 #000
}

#top-nav .navbar-brand > a:hover .navbar-title:after {
    content: "\f105";
    font-family: FontAwesome;
    margin-left: 12px;
    font-size: 1.25rem;
    line-height: inherit;
    vertical-align: bottom;
    color: #e7e7e7
}

#top-nav .nav > li > a {
    font-size: 1.125rem;
    font-weight: 400;
    color: #777
}

#top-nav .nav > li > a i.icon, #top-nav .nav > li > a i.tcell-sort, #top-nav .nav > li > a i.tcell-asc, #top-nav .nav > li > a i.tcell-desc {
    font-size: 1.15rem
}

#top-nav .nav > li.active > a {
    color: #000;
    background-color: #eee
}

#top-nav .nav > li.active > a i.icon, #top-nav .nav > li.active > a i.tcell-sort, #top-nav .nav > li.active > a i.tcell-asc, #top-nav .nav > li.active > a i.tcell-desc {
    text-shadow: none
}

#top-nav .nav > li > a:focus, #top-nav .nav > li > a:hover {
    color: #000;
    text-shadow: 0 0 0px #000;
    background-color: #e7e7e7
}

#top-nav .nav > li > a:focus i.icon, #top-nav .nav > li > a:focus i.tcell-sort, #top-nav .nav > li > a:focus i.tcell-asc, #top-nav .nav > li > a:focus i.tcell-desc, #top-nav .nav > li > a:hover i.icon, #top-nav .nav > li > a:hover i.tcell-sort, #top-nav .nav > li > a:hover i.tcell-asc, #top-nav .nav > li > a:hover i.tcell-desc {
    text-shadow: none
}

#top-nav .nav > li > a[disabled] {
    color: #999
}

#top-nav .nav > li > a[disabled]:focus, #top-nav .nav > li > a[disabled]:hover {
    background-color: transparent;
    color: #999;
    cursor: default
}

#top-nav #stats {
    opacity: 1;
    transition: opacity .5s
}

#top-nav #stats.invisible {
    visibility: visible;
    opacity: 0;
    z-index: -1;
    border-bottom-width: 0
}

#top-nav #stats.invisible .inner.container {
    height: 0px
}

#top-nav #stats .inner.container {
    text-align: left;
    display: block;
    height: 38px;
    transition: height .3s;
    overflow: hidden
}

#top-nav #stats .inner.container.showing.showing-filters {
    height: 108px
}

#top-nav #stats .inner.container.showing.showing-charts {
    height: 210px
}

#top-nav #stats .inner.container.showing .bottom-side {
    opacity: 1
}

#top-nav #stats .inner.container .glance-label {
    display: inline-block;
    width: 32px;
    text-align: center;
    position: relative;
    padding-top: 10px;
    height: 38px;
    border-right: 1px solid #f4f4f4
}

#top-nav #stats .inner.container .bottom-side {
    opacity: 0;
    transition: opacity 0.75s;
    padding-top: 10px;
    border-top: 1px solid #f4f4f4;
    position: relative
}

#top-nav #stats .inner.container .bottom-side .crumbs-label {
    float: left;
    width: 72px;
    font-size: .85rem;
    margin-top: 4px
}

#top-nav #stats .inner.container .bottom-side .graph-icon {
    position: absolute;
    right: 0;
    top: 5px;
    width: 20px;
    line-height: 20px
}

#top-nav #stats .inner.container .stat {
    float: left;
    padding: 5px 12px 5px 12px;
    height: 38px;
    border-right: 1px solid #f4f4f4;
    min-width: 125px;
    text-align: right
}

#top-nav #stats .inner.container .stat .stat-value {
    font-size: 1.5rem;
    line-height: 2rem;
    font-weight: 300;
    color: #646464;
    transition: color 0.3s;
    display: inline-block;
    min-width: 40px
}

#top-nav #stats .inner.container .stat .stat-value small {
    opacity: 0.75;
    font-size: 72%
}

#top-nav #stats .inner.container .stat .stat-label {
    line-height: 1rem;
    display: inline-block;
    margin-left: 5px;
    color: rgba(100, 100, 100, 0.5)
}

#top-nav #stats .inner.container .stat .stat-label > a {
    color: inherit;
    display: inline-block
}

#top-nav #stats .inner.container .stat .stat-label > a:hover {
    color: #646464;
    text-decoration: none
}

.navbar-fixed-top {
    position: relative;
    top: 0;
    border: none;
    border-bottom: 1px solid #eee;
    box-shadow: 0 0 3px transparent;
    transition: border-color .3s, box-shadow .3s
}

@media (min-width: 992px) {
    .navbar-fixed-top {
        position: fixed
    }

    .navbar-container.nav-initialized.scrolled-past-top .navbar-fixed-top, body.is-full-screen .navbar-container .navbar-fixed-top {
        border-color: #d4d4d4;
        box-shadow: 0 0 3px rgba(0, 0, 0, 0.2)
    }
}

.navbar-toggle {
    margin-top: 20px;
    margin-bottom: 20px;
    height: 40px;
    line-height: 40px;
    padding-top: 0;
    padding-bottom: 0;
    padding-left: 8px;
    padding-right: 8px;
    font-size: 1.5rem;
    border: none
}

@media screen and (max-width: 400px) {
    .navbar-toggle {
        margin-right: 0px
    }
}

.navbar-toggle .icon-bar {
    background-color: #999999 !important
}

.navbar-toggle:hover {
    border-color: #000000
}

.navbar-toggle:hover .icon-bar {
    background-color: #000000 !important
}

.navbar-main {
    margin-bottom: 0
}

.navbar-main:active {
    color: #000000 !important
}

.test-warning {
    position: relative;
    padding: 8px 0 15px;
    color: #fff;
    background-color: #7e4544;
    height: 52px;
    line-height: 17px;
    overflow: hidden;
    transition: margin-top .3s ease-out;
    transform: translate3d(0, 0, 0)
}

body.scrolled-past-80 .test-warning {
    margin-top: -52px
}

.test-warning > .container > div > span {
    position: relative
}

.test-warning > .container > div > span:before {
    content: ' ';
    display: block;
    position: absolute;
    left: -1080px;
    top: -270px;
    height: 600px;
    width: 600px;
    transform: rotate3d(0, 0, 1, -40deg);
    background: rgba(255, 255, 255, 0.08);
    background: #4e2828;
    box-shadow: 0 0 200px rgba(0, 0, 0, 0.5)
}

@media screen and (min-width: 768px) {
    .test-warning {
        padding-top: 11px;
        line-height: 28px;
        padding-bottom: 12px
    }
}

.test-warning p, .test-warning div {
    margin: 0;
    width: 90%;
    font-size: 12px;
    font-size: .85rem
}

@media screen and (min-width: 992px) {
    .test-warning p, .test-warning div {
        width: 100%;
        text-align: center
    }
}

.icon-fw.icon-info.circle-icon {
    font-size: 20px;
    vertical-align: middle;
    text-align: center;
    border: 2px solid #fff;
    border-radius: 50%;
    height: 27px;
    line-height: 25px;
    width: 27px
}

.test-warning-close {
    position: absolute;
    width: 23px;
    height: 22px;
    top: 50%;
    right: 5px;
    margin-top: -13px;
    font-size: 17px;
    font-size: 1.2rem;
    line-height: 23px !important;
    color: #fff;
    vertical-align: middle;
    cursor: pointer;
    transform: scale3d(1, 1, 1);
    transition: transform .3s
}

.test-warning-close:hover, .test-warning:hover .test-warning-close {
    color: #fff;
    text-decoration: none;
    transform: scale3d(1.5, 1.5, 1.5) translate3d(0, 0, 0)
}

@media screen and (min-width: 992px) {
    .test-warning-close {
        position: static;
        margin-top: -4px;
        margin-left: 30px;
        margin-right: 3px
    }
}

@media (min-width: 992px) {
    .navbar-container.scrolled-at-top {
        transition: padding-bottom .5s ease-out
    }

    .navbar-container.test-warning-visible {
        padding-bottom: 52px
    }
}

@media (max-width: 767px) {
    ul.navbar-nav {
        margin-bottom: 10px !important;
        margin-top: 10px
    }
}

.custom-entry {
    margin-top: 4px
}

.custom-entry > div {
    height: 19px !important;
    padding-top: 4px;
    margin-bottom: 10px
}

.dropdown-menu {
    background-color: #fafafa;
    border-top: 1px solid #e7e7e7;
    -webkit-box-shadow: 0 5px 12px -2px rgba(0, 0, 0, 0.175);
    box-shadow: 0 5px 12px -2px rgba(0, 0, 0, 0.175)
}

.dropdown-menu > li > a {
    font-weight: 400;
    font-size: 0.95rem;
    padding: 5px 24px
}

.dropdown-menu > li.active > a {
    background-color: #34959d
}

.dropdown-menu > li > a:hover {
    background-color: #5d8a8e !important;
    color: #fff
}

.dropdown-menu > li > div > a {
    font-weight: 300
}

@media screen and (min-width: 768px) {
    .dropdown-menu {
        padding: 10px 0
    }

    .dropdown-menu > li.global-entry {
        letter-spacing: 1px;
        letter-spacing: 0.5px;
        text-decoration: none;
        white-space: nowrap !important
    }
}

.navbar-nav {
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif;
    margin-left: 20px;
    margin-right: 20px;
    margin-top: 0;
    margin-bottom: 0;
    line-height: inherit
}

@media screen and (max-width: 767px) {
    .navbar-nav {
        line-height: 40px
    }
}

.navbar-nav > li {
    line-height: inherit
}

.navbar-nav > li > a {
    line-height: inherit;
    padding-top: 0px;
    padding-bottom: 0px
}

@media (max-width: 767px) {
    .navbar-nav {
        margin-bottom: 0px !important
    }

    .navbar-nav .open .dropdown-menu {
        position: static;
        float: none;
        width: auto;
        margin-top: 0;
        background-color: transparent;
        border: 0;
        box-shadow: none
    }

    .navbar-nav .open .dropdown-menu > li > a, .navbar-nav .open .dropdown-menu .dropdown-header {
        padding: 5px 15px 5px 25px
    }

    .navbar-nav .open .dropdown-menu > li > div > a, .navbar-nav .open .dropdown-menu .dropdown-header {
        color: #777;
        padding: 5px 15px 5px 25px
    }

    .navbar-nav .open .dropdown-menu > li > div > div > a, .navbar-nav .open .dropdown-menu .dropdown-header {
        color: #777;
        padding: 5px 15px 5px 25px
    }

    .navbar-nav .open .dropdown-menu > li > a {
        line-height: 20px
    }

    .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-nav .open .dropdown-menu > li > a:focus {
        color: #000000 !important
    }

    .navbar-nav .open .dropdown-menu > li > div > a {
        line-height: 20px
    }

    .navbar-nav .open .dropdown-menu > li > div > a:hover, .navbar-nav .open .dropdown-menu > li > div > a:focus {
        text-decoration: none !important;
        color: #000000 !important
    }

    .navbar-nav .open .dropdown-menu > li > div > div > a {
        line-height: 20px
    }

    .navbar-nav .open .dropdown-menu > li > div > div > a:hover, .navbar-nav .open .dropdown-menu > li > div > div > a:focus {
        text-decoration: none !important;
        color: #000000 !important
    }
}

.nav-solo {
    padding: 10px 15px 10px 25px;
    line-height: 20px
}

.nav-solo .global-entry {
    font-size: 1.4em;
    color: #999999;
    font-weight: 300
}

.nav-solo .global-entry:hover, .nav-solo .global-entry:focus {
    text-decoration: none !important;
    color: #000000 !important
}

.navbar-form {
    margin: 0px
}

#user-inactive:hover {
    stroke: #000000 !important
}

#user-active:hover {
    fill: #000000;
    stroke: #000000
}

.panel, .panel-full, .table-panel {
    background-color: inherit;
    margin-top: 15px;
    margin-bottom: 15px;
    padding: 15px 20px;
    overflow: visible;
    border: 1px solid transparent;
    -moz-box-shadow: 0px 0px 0px transparent;
    -webkit-box-shadow: 0px 0px 0px transparent;
    box-shadow: 0px 0px 0px transparent
}

.panel.panel-create-obj, .panel-create-obj.panel-full, .panel-create-obj.table-panel {
    margin-top: 4px !important;
    margin-bottom: 4px !important;
    border: 1px solid #ccc !important;
    width: 100%;
    text-align: left
}

.panel.panel-create-obj > .panel-heading, .panel-create-obj.panel-full > .panel-heading, .panel-create-obj.table-panel > .panel-heading {
    padding: 2px 2px 2px 5px !important;
    background-color: #ffffff !important;
    color: #808080 !important
}

.panel.panel-create-obj > table > tbody, .panel-create-obj.panel-full > table > tbody, .panel-create-obj.table-panel > table > tbody {
    display: block;
    max-height: 280px;
    overflow-y: auto
}

.panel.panel-create-obj > table > tbody > tr, .panel-create-obj.panel-full > table > tbody > tr, .panel-create-obj.table-panel > table > tbody > tr {
    display: block;
    width: 100%
}

.panel.panel-create-obj > table > tbody > tr > td, .panel-create-obj.panel-full > table > tbody > tr > td, .panel-create-obj.table-panel > table > tbody > tr > td {
    border-top: 0px !important;
    border-bottom: 1px solid #ccc !important;
    display: inline-block;
    width: 100%;
    padding: 2px 2px 2px 5px !important
}

.panel.panel-create-obj > table > tbody > tr > td.active-object, .panel-create-obj.panel-full > table > tbody > tr > td.active-object, .panel-create-obj.table-panel > table > tbody > tr > td.active-object {
    background-color: #d9edf7
}

.panel.panel-create-obj > table > tbody > tr > td > a.cancel-button-inline, .panel-create-obj.panel-full > table > tbody > tr > td > a.cancel-button-inline, .panel-create-obj.table-panel > table > tbody > tr > td > a.cancel-button-inline {
    color: #a94442 !important;
    display: inline-block;
    float: right;
    padding-right: 14px
}

.panel.panel-create-obj > table > tbody > tr > td > a.tab-right, .panel-create-obj.panel-full > table > tbody > tr > td > a.tab-right, .panel-create-obj.table-panel > table > tbody > tr > td > a.tab-right {
    display: inline-block;
    float: right
}

.panel.panel-create-obj > table > tbody > tr > td > a.tab-left, .panel-create-obj.panel-full > table > tbody > tr > td > a.tab-left, .panel-create-obj.table-panel > table > tbody > tr > td > a.tab-left {
    display: inline-block;
    float: left
}

.panel.panel-default, .panel-default.panel-full, .panel-default.table-panel {
    padding: 0
}

.panel.panel-default > .panel-heading, .panel-default.panel-full > .panel-heading, .panel-default.table-panel > .panel-heading {
    background-color: #d8d8d8
}

.panel.panel-default > .panel-heading h1, .panel-default.panel-full > .panel-heading h1, .panel-default.table-panel > .panel-heading h1, .panel.panel-default > .panel-heading h2, .panel-default.panel-full > .panel-heading h2, .panel-default.table-panel > .panel-heading h2, .panel.panel-default > .panel-heading h3, .panel-default.panel-full > .panel-heading h3, .panel-default.table-panel > .panel-heading h3, .panel.panel-default > .panel-heading h4, .panel-default.panel-full > .panel-heading h4, .panel-default.table-panel > .panel-heading h4, .panel.panel-default > .panel-heading h5, .panel-default.panel-full > .panel-heading h5, .panel-default.table-panel > .panel-heading h5, .panel.panel-default > .panel-heading h6, .panel-default.panel-full > .panel-heading h6, .panel-default.table-panel > .panel-heading h6 {
    margin: 0
}

.panel > h1:first-child, .panel-full > h1:first-child, .table-panel > h1:first-child, .panel > h2:first-child, .panel-full > h2:first-child, .table-panel > h2:first-child, .panel > h3:first-child, .panel-full > h3:first-child, .table-panel > h3:first-child, .panel > h4:first-child, .panel-full > h4:first-child, .table-panel > h4:first-child, .panel > h5:first-child, .panel-full > h5:first-child, .table-panel > h5:first-child, .panel > h6:first-child, .panel-full > h6:first-child, .table-panel > h6:first-child {
    margin-top: 0;
    padding-top: 2px
}

.shadow-border {
    border: 1px solid #ddd;
    border-bottom-color: #c8c8c8;
    box-shadow: 0px 1px 9px -3px rgba(0, 0, 0, 0.5);
    background-color: #fff
}

.panel-heading {
    padding: 10px
}

.panel-body {
    padding: 10px
}

.panel-body-with-header {
    padding-top: 0
}

.item-row {
    margin-top: 10px;
    margin-bottom: 10px
}

.panel-full {
    padding: 0
}

.panel-insert {
    padding: 15px 20px
}

.panel-blue {
    background-color: #4284d8;
    border: 1px solid #3276ca;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
    -moz-box-shadow: 0 0 6px rgba(195, 202, 211, 0.5);
    -webkit-box-shadow: 0 0 6px rgba(195, 202, 211, 0.5);
    box-shadow: 0 0 6px rgba(195, 202, 211, 0.5);
    margin: 10px 0 20px;
    padding: 15px 30px;
    overflow: hidden
}

.panel-gray {
    margin: 10px 0 20px;
    padding: 15px 30px;
    overflow: hidden
}

.panel h3, .panel-full h3, .table-panel h3, .panel h4, .panel-full h4, .table-panel h4 {
    color: #0A253D
}

.view-detail h3 {
    line-height: 24.5px
}

.panel a[href^="http"]:after, .panel-full a[href^="http"]:after, .table-panel a[href^="http"]:after, td a[href^="http"]:after {
    content: " \f08e";
    font-family: FontAwesome;
    font-weight: normal;
    font-style: normal;
    text-decoration: none;
    -webkit-font-smoothing: antialiased;
    display: inline;
    width: auto;
    height: auto;
    line-height: normal;
    vertical-align: baseline;
    background-image: none;
    background-position: 0% 0%;
    background-repeat: repeat;
    margin-top: 0
}

a[href^="http"]:empty:after {
    content: none
}

a[href^="http://encodedcc.sdsc.edu/warehouse/"]:after {
    content: none !important
}

.type-antibody-status .status-status-row {
    padding-top: 5px;
    padding-bottom: 5px;
    border-top: 1px solid #e0e0e0
}

.type-antibody-status .status-status-row:first-child {
    border-top: none
}

.type-antibody-status .status-organism-row {
    margin: 5px 0
}

.type-antibody-status .status-organism {
    padding: 0;
    font-style: italic;
    font-weight: bold
}

.type-antibody-status .status-terms {
    padding: 0;
    color: #808080
}

.type-antibody-status .status-status {
    position: relative;
    padding: 0;
    margin-bottom: 10px;
    text-align: left;
    font-weight: bold
}

@media screen and (min-width: 768px) {
    .type-antibody-status .status-status {
        padding: 0 25px 0 0;
        margin-bottom: 0;
        text-align: right
    }
}

.type-antibody-status .icon, .type-antibody-status .tcell-sort, .type-antibody-status .tcell-asc, .type-antibody-status .tcell-desc {
    position: relative;
    top: 3px;
    font-size: 20px;
    font-size: 1.4rem;
    margin-right: 5px
}

@media screen and (min-width: 768px) {
    .type-antibody-status .icon, .type-antibody-status .tcell-sort, .type-antibody-status .tcell-asc, .type-antibody-status .tcell-desc {
        position: absolute;
        top: 0;
        right: 0
    }
}

.panel-body-doc {
    padding-bottom: 0 !important
}

.sub-panel {
    padding-bottom: 15px;
    padding-left: 25px
}

#signin-box {
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIwLjEiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiMwMDAwMDAiIHN0b3Atb3BhY2l0eT0iMC4xIi8+PC9saW5lYXJHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
    background-size: 100%;
    background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, rgba(255, 255, 255, 0.1)), color-stop(100%, rgba(0, 0, 0, 0.1)));
    background-image: -moz-linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    background-image: -webkit-linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    background-image: linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    border: 1px solid #cacaca;
    display: inline-block;
    padding: 20px;
    float: right;
    -moz-box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset;
    -webkit-box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset;
    box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset
}

#signin-box h4 {
    margin: 0 0 10px 0;
    padding: 0
}

.signin-button {
    display: block !important;
    font-size: 20px;
    font-size: 1.4rem;
    font-weight: bold;
    margin-bottom: 7px
}

.three-d-box {
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIwLjEiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiMwMDAwMDAiIHN0b3Atb3BhY2l0eT0iMC4xIi8+PC9saW5lYXJHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
    background-size: 100%;
    background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, rgba(255, 255, 255, 0.1)), color-stop(100%, rgba(0, 0, 0, 0.1)));
    background-image: -moz-linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    background-image: -webkit-linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    background-image: linear-gradient(rgba(255, 255, 255, 0.1), rgba(0, 0, 0, 0.1));
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    border-radius: 5px;
    border: 1px solid #cacaca;
    display: block;
    padding: 20px;
    -moz-box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset;
    -webkit-box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset;
    box-shadow: rgba(180, 180, 180, 0.9) 0 2px 10px, 0 1px 0 #fff inset;
    margin-bottom: 20px
}

.three-d-box form {
    margin: 0
}

.three-d-box form input {
    margin: 0;
    width: 98.5%
}

table {
    font-size: 13px;
    font-size: .9rem
}

thead, tfoot {
    background: none repeat scroll 0 0 #f5f5f5
}

table > thead > tr > th {
    background-color: #eee;
    border-top: none;
    border-bottom: 1px solid #ddd;
    border-left: 1px solid #ddd;
    padding: 5px 3px 5px;
    font-weight: bold;
    font-weight: 600;
    white-space: nowrap;
    text-align: center;
    vertical-align: middle !important
}

table > thead > tr > th:first-child {
    border-left: none !important
}

table > tbody > tr > td {
    border-top: 0px;
    padding: 2px 3px;
    text-align: center;
    vertical-align: middle !important
}

.table-panel {
    padding: 0;
    margin: 0;
    border-collapse: separate
}

.table-panel tr:last-child td:first-child {
    -moz-border-radius-bottomleft: 3px;
    -webkit-border-bottom-left-radius: 3px;
    border-bottom-left-radius: 3px
}

.table-panel tr:last-child td:last-child {
    -moz-border-radius-bottomright: 3px;
    -webkit-border-bottom-right-radius: 3px;
    border-bottom-right-radius: 3px
}

.table-striped > tbody > tr:nth-child(odd) > td {
    background-color: #fff;
    border-top: none
}

.table-striped > tbody > tr:nth-child(even) > td {
    background-color: #f9f9f9;
    border-top: none
}

.table-tbody-striped > tbody:nth-child(odd) {
    background-color: #f9f9f9
}

.table-tbody-striped > tbody:nth-child(even) {
    background-color: #ffffff
}

@media (max-width: 767px) {
    .table-responsive th, .table-responsive td {
        max-width: 250px !important;
        white-space: normal !important
    }
}

.table-responsive {
    position: relative;
    overflow-x: auto;
    background-image: url('data:image/svg+xml;base64,PHN2ZyBpZD0iTGF5ZXJfMSIgZGF0YS1uYW1lPSJMYXllciAxIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAxNiAxNiI+PGRlZnM+PHN0eWxlPi5jbHMtMXtmaWxsOiNlMGUwZTA7fTwvc3R5bGU+PC9kZWZzPjx0aXRsZT5jaGVja2VyPC90aXRsZT48cmVjdCBjbGFzcz0iY2xzLTEiIHdpZHRoPSI4IiBoZWlnaHQ9IjgiLz48cmVjdCBjbGFzcz0iY2xzLTEiIHg9IjgiIHk9IjgiIHdpZHRoPSI4IiBoZWlnaHQ9IjgiLz48L3N2Zz4=');
    background-size: 16px 16px
}

table thead tr th button {
    float: left
}

form.table-filter {
    display: inline-block;
    float: right;
    margin-bottom: 0px !important
}

#table-filter {
    display: inline-block;
    width: 265px;
    font-size: 17px;
    font-size: 1.2rem
}

.table-count {
    font-size: 14px !important;
    font-size: 1rem !important;
    display: inline-block !important;
    padding: 0.5em 2em !important;
    margin-right: 1em
}

.spinner-warning {
    background: #F89406 url("../img/spinner-orange-bg.gif") no-repeat;
    background-position: 7px 9px
}

.table-meta-data {
    height: 34px;
    display: block;
    float: left
}

.table-actions {
    margin-left: 1em
}

.table-actions button {
    float: none
}

#total-records {
    font-weight: normal
}

.collection-table tbody span {
    display: block
}

.col-headers th:hover {
    cursor: pointer
}

.tcell-sortable {
    cursor: pointer
}

.table-file {
    margin-bottom: 20px
}

.table-file .table {
    margin-bottom: 0
}

.table-sortable thead tr {
    border-bottom: 1px solid #e0e0e0
}

.table-sortable thead tr th {
    position: relative;
    height: 4em;
    vertical-align: middle;
    border-left: 1px solid #e0e0e0 !important;
    border-bottom: 1px solid #e0e0e0 !important
}

.table-sortable thead tr th:first-child {
    border-left: none !important
}

.table-section {
    font-size: 18px;
    font-size: 1.3rem;
    font-weight: bold;
    background-color: #e8e8e8
}

.table-section th {
    height: auto !important
}

.tcell-sortable:hover {
    background-color: #e0e0e0
}

.tcell-sort, .tcell-asc, .tcell-desc {
    position: absolute;
    right: 5px;
    top: 1.6em
}

.highlight-row td {
    background-color: #606060 !important;
    color: #fff;
    font-weight: bold
}

.highlight-row td a {
    color: #fff !important
}

th.rotate30 {
    height: 130px;
    width: 20px;
    min-width: 20px;
    max-width: 20px;
    position: relative;
    vertical-align: bottom;
    padding: 0 !important;
    border: none !important
}

th.rotate30 > div {
    position: relative;
    top: 0;
    left: 37.52777px;
    height: 100%;
    -webkit-transform: skew(-30deg, 0deg);
    transform: skew(-30deg, 0deg);
    background-color: #ddd;
    border-left: solid 1px #fff;
    border-right: solid 1px #fff
}

th.rotate30 > div > span {
    -webkit-transform: skew(30deg, 0deg) rotate(300deg);
    transform: skew(30deg, 0deg) rotate(300deg);
    position: absolute;
    bottom: 59px;
    left: -57px;
    display: inline-block;
    width: 132.79056px;
    text-align: left;
    line-height: 1.2;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden
}

th.rotate90 {
    vertical-align: top
}

th.rotate90 > div {
    position: relative
}

th.rotate90 > div > span {
    position: absolute;
    -webkit-transform: rotate(-90deg);
    transform: rotate(-90deg);
    -webkit-transform-origin: left bottom 0;
    transform-origin: left bottom 0;
    top: 80px;
    left: 16px
}

table.matrix {
    width: auto
}

table.matrix th {
    text-align: right;
    padding: 0 .5em
}

table.matrix td {
    vertical-align: middle;
    text-align: center;
    padding: 0 !important;
    border: solid 1px #f9f9f9
}

table.matrix tfoot {
    background: transparent
}

.expset-button {
    padding: 0px !important;
    text-align: center;
    box-shadow: none !important
}

.expset-table-container {
    overflow-x: auto;
    position: relative;
    margin-bottom: 80px;
    padding-right: 0px;
    border-right: 10px solid #fff
}

.expset-table-container .expset-panel {
    margin: 0px;
    border: none
}

.expset-table-container .expset-panel > div > .panel-body {
    padding: 0;
    padding-left: 30px
}

.expset-table, .expsets-table {
    border: none !important
}

.expset-table > thead > tr > :first-child, .expset-table > tbody > tr > :first-child, .expsets-table > thead > tr > :first-child, .expsets-table > tbody > tr > :first-child {
    border-left: none
}

.expset-table > thead > tr > :last-child, .expset-table > tbody > tr > :last-child, .expsets-table > thead > tr > :last-child, .expsets-table > tbody > tr > :last-child {
    border-right: none
}

.expset-table > thead > tr > th, .expsets-table > thead > tr > th {
    border: none;
    padding: 8px
}

.expset-table > tbody.expset-section > tr > td, .expsets-table > tbody.expset-section > tr > td {
    border-top: 1px solid #ddd;
    border-bottom: none;
    max-width: 160px
}

.expset-table > tbody.expset-section > tr > td.dropdown-button-cell, .expsets-table > tbody.expset-section > tr > td.dropdown-button-cell {
    padding: 0 !important;
    width: 38px
}

.expset-hits {
    padding: 0px 10px 0px 10px
}

.expset-sublist-entry {
    margin-bottom: 2px
}

.expset-sublist-empty {
    margin-left: 50px;
    margin-bottom: 2px;
    color: #999999
}

.expset-checkbox-sub {
    margin: 0px -6px -3px 0px !important;
    display: inline-block
}

.expset-checkbox-cell {
    text-align: center
}

.expset-file {
    margin-left: 25px
}

.expset-whole-selector {
    padding: 10px
}

@media (min-width: 768px) {
    .expset-file-selector {
        border-right: 1px #ccc solid;
        padding-right: 10px;
        margin-right: 10px
    }
}

.expset-selector-header > h5 {
    margin: 0px !important
}

.expset-selector-button {
    margin-top: 5px
}

.browse-title {
    text-align: left;
    margin-bottom: 10px;
    font-weight: 400;
    color: #999999 !important
}

.table {
    margin-bottom: 0px
}

.control-cell {
    white-space: nowrap
}

.experiment-set-info-wrapper {
    position: relative;
    z-index: 1
}

.experiment-set-info-wrapper .expset-addinfo {
    text-align: left;
    position: relative;
    overflow: hidden;
    min-height: 62px
}

.experiment-set-info-wrapper .expset-addinfo .addinfo-description-section, .experiment-set-info-wrapper .expset-addinfo .addinfo-properties-section {
    padding-top: 12px;
    padding-bottom: 8px;
    position: static
}

.experiment-set-info-wrapper .expset-addinfo .expset-addinfo-row {
    margin-bottom: 5px
}

@media screen and (min-width: 768px) {
    .experiment-set-info-wrapper .expset-addinfo .addinfo-properties-section.col-sm-6, .experiment-set-info-wrapper .expset-addinfo .addinfo-properties-section.flexcol-sm-6 {
        padding-left: 18px
    }

    .experiment-set-info-wrapper .expset-addinfo .row > .addinfo-description-section.col-sm-6:after, .experiment-set-info-wrapper .expset-addinfo .flexrow > .addinfo-description-section.col-sm-6:after, .experiment-set-info-wrapper .expset-addinfo .row > .addinfo-description-section.flexcol-sm-6:after, .experiment-set-info-wrapper .expset-addinfo .flexrow > .addinfo-description-section.flexcol-sm-6:after {
        content: "";
        width: 1px;
        height: 100%;
        position: absolute;
        left: 50%;
        top: 0;
        margin-left: -1px;
        border-left: 1px solid #f4f4f4
    }

    .experiment-set-info-wrapper .expset-addinfo label.description-label {
        font-weight: 500;
        margin-bottom: 2px;
        display: block
    }
}

.experiment-set-info-wrapper .expset-addinfo .expset-addinfo-key {
    font-weight: 500
}

.experiment-set-info-wrapper .expset-addinfo .expset-addinfo-val {
    padding-right: 25px
}

.experiment-set-info-wrapper .files-tables-container .raw-files-table-section, .experiment-set-info-wrapper .files-tables-container .processed-files-table-section {
    border-top: 1px solid #ddd
}

.experiment-set-info-wrapper .files-tables-container h4.pane-section-title {
    font-weight: 300;
    margin-top: 12px;
    margin-bottom: 12px;
    cursor: pointer
}

.experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.icon, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.tcell-sort, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.tcell-asc, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.tcell-desc {
    font-size: 0.875rem;
    margin-right: 3px;
    position: relative;
    top: -1px
}

.experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.icon.toggle-open-icon, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.toggle-open-icon.tcell-sort, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.toggle-open-icon.tcell-asc, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title i.toggle-open-icon.tcell-desc {
    cursor: pointer;
    margin-right: 6px;
    padding: 2px 0;
    opacity: 0.66
}

.experiment-set-info-wrapper .files-tables-container h4.pane-section-title:hover {
    text-shadow: 0 0 0
}

.experiment-set-info-wrapper .files-tables-container h4.pane-section-title:hover i.icon.toggle-open-icon, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title:hover i.toggle-open-icon.tcell-sort, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title:hover i.toggle-open-icon.tcell-asc, .experiment-set-info-wrapper .files-tables-container h4.pane-section-title:hover i.toggle-open-icon.tcell-desc {
    opacity: 1
}

.invis-cell {
    background-color: #fff !important;
    border: 0px !important
}

.exptype-box {
    padding: 10px 0;
    height: 38px
}

.exptype-box > div > .btn-group > button {
    width: 240px;
    text-align: left
}

.exptype-box > div > .btn-group > ul {
    width: 240px;
    text-align: left;
    padding: 10px
}

.above-chart-row {
    min-height: 38px
}

@media screen and (min-width: 768px) {
    .expset-result-table-fix .above-chart-row {
        margin-top: -38px
    }
}

.stacked-block-table {
    position: relative;
    display: block;
    min-width: 750px;
    transition: opacity .35s
}

.stacked-block-table.fade-in:not(.mounted) {
    opacity: 0
}

.stacked-block-table .headers {
    display: block;
    text-align: right;
    height: 42px;
    text-overflow: ellipsis;
    white-space: nowrap
}

.stacked-block-table .headers > .heading-block {
    text-align: center;
    overflow: hidden;
    text-overflow: ellipsis;
    display: inline-block;
    vertical-align: middle;
    height: inherit;
    padding: 12px 6px;
    background: inherit;
    font-weight: 500;
    font-size: 0.9rem;
    border-top: 1px solid #e8e8e8
}

.rc-tabs-tabpane .stacked-block-table .headers > .heading-block {
    border-top-color: #ccc
}

.stacked-block-table .headers > .heading-block.text-left {
    text-align: left;
    padding-left: 0
}

.stacked-block-table .headers > .heading-block.text-right {
    text-align: right;
    padding-right: 0
}

.stacked-block-table .headers > .heading-block > i.icon, .stacked-block-table .headers > .heading-block > i.tcell-sort, .stacked-block-table .headers > .heading-block > i.tcell-asc, .stacked-block-table .headers > .heading-block > i.tcell-desc {
    font-size: 1rem
}

.stacked-block-table .col-file-detail:not(.heading-block) {
    text-align: center
}

.stacked-block-table > .body {
    font-size: 0.9rem;
    transform: translate3d(0, 0, 0)
}

.stacked-block-table > .body .s-block-list {
    display: inline-block;
    vertical-align: middle
}

.stacked-block-table > .body .s-block-list .collapsible-s-block-ext {
    transform: translate3d(0, 0, 0)
}

.stacked-block-table > .body .s-block-list .collapsible-s-block-ext.transition-med {
    transition: height .5s ease
}

.stacked-block-table > .body .s-block-list .collapsible-s-block-ext.transition-slow {
    transition: height 1s ease
}

.stacked-block-table > .body .s-block-list .view-more-button {
    text-align: left;
    padding: 0px 12px;
    line-height: 32px;
    cursor: pointer;
    border-top: 1px solid #888;
    border-top-color: rgba(0, 0, 0, 0.5);
    margin-top: -1px;
    font-weight: 500;
    font-size: 0.85rem;
    position: relative;
    z-index: 10
}

.stacked-block-table > .body .s-block {
    display: block;
    position: relative;
    overflow-y: hidden
}

.stacked-block-table > .body .s-block > .name {
    display: inline-block;
    vertical-align: middle;
    position: relative;
    padding: 7px 12px;
    text-align: center;
    line-height: 20px
}

.stacked-block-table > .body .s-block > .name > .name-title.mono-text {
    font-size: 0.85rem
}

.stacked-block-table > .body .s-block > .name.col-experiment > .name-title.mono-text {
    text-shadow: 0 0 0
}

.stacked-block-table > .body .s-block > .name:after, .stacked-block-table > .body .s-block > .name > .label-ext-info {
    position: absolute;
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif;
    left: 0;
    top: 2px;
    font-size: 0.625rem;
    text-transform: uppercase;
    text-align: left
}

.stacked-block-table > .body .s-block .label-ext-info {
    text-align: left;
    line-height: 9px
}

.stacked-block-table > .body .s-block .label-ext-info > .ext {
    font-weight: 400;
    opacity: 0.1
}

.stacked-block-table > .body .s-block .label-ext-info > .ext.is-accession {
    font-size: .75rem
}

.stacked-block-table > .body .s-block .label-ext-info > .ext.is-accession i.icon-copy {
    opacity: 0;
    transition: opacity .25s;
    font-size: 9px;
    cursor: pointer
}

.stacked-block-table > .body .s-block .exp-table-checkbox {
    display: inline-block;
    margin-right: -7px;
    margin-top: 17px
}

.stacked-block-table > .body .s-block.odd {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(245, 235, 235, 0) 0%), color-stop(rgba(245, 240, 240, 0.4) 30%));
    background-image: linear-gradient(to right, rgba(245, 235, 235, 0) 0%, rgba(245, 240, 240, 0.4) 30%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00F5EBEB', endColorstr='#66F5F0F0', GradientType=1)
}

.stacked-block-table > .body .s-block.odd.s-block-list-collapsing.collapsing-child {
    background: #f6f5f5;
    background: #fffcfa
}

.stacked-block-table > .body .s-block.odd:hover {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(245, 235, 235, 0) 0%), color-stop(#fffcfa 12%));
    background-image: linear-gradient(to right, rgba(245, 235, 235, 0) 0%, #fffcfa 12%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00F5EBEB', endColorstr='#FFFFFCFA', GradientType=1)
}

.stacked-block-table > .body .s-block.odd:not(.collapsing-child) > .file-pairs > .view-more-button {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#fff 25%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #ffffff 25%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFFFFFFF', GradientType=1)
}

.stacked-block-table > .body .s-block.even {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 250, 250, 0) 0%), color-stop(rgba(255, 250, 250, 0.4) 30%));
    background-image: linear-gradient(to right, rgba(255, 250, 250, 0) 0%, rgba(255, 250, 250, 0.4) 30%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFAFA', endColorstr='#66FFFAFA', GradientType=1)
}

.stacked-block-table > .body .s-block.even.s-block-list-collapsing.collapsing-child {
    background: #faf9f9;
    background: #fffcfa
}

.stacked-block-table > .body .s-block.even:hover {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 250, 250, 0) 0%), color-stop(#fffcfa 12%));
    background-image: linear-gradient(to right, rgba(255, 250, 250, 0) 0%, #fffcfa 12%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFAFA', endColorstr='#FFFFFCFA', GradientType=1)
}

.stacked-block-table > .body .s-block.even:not(.collapsing-child) > .file-pairs > .view-more-button {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#fff 25%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #ffffff 25%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFFFFFFF', GradientType=1)
}

.stacked-block-table > .body .s-block > .name:after, .stacked-block-table > .body .s-block > .name > .label-ext-info {
    opacity: 0.4;
    font-weight: 600;
    transform: scale3d(0.75, 0.75, 1) translate3d(0, 0, 0);
    transform-origin: 0px 0px;
    transition: opacity .4s, transform .4s, top .4s, margin-top .4s
}

.stacked-block-table > .body .s-block > .name > .label-ext-info > .ext {
    opacity: 0;
    transform: translate3d(0, 0, 0);
    transition: opacity .4s, transform .4s
}

.stacked-block-table > .body .s-block > .name > .label-ext-info.subtitle-visible {
    opacity: 0.75
}

.stacked-block-table > .body .s-block > .name > .label-ext-info.subtitle-visible > .ext {
    opacity: 1
}

.stacked-block-table > .body .s-block > .name > .label-ext-info:not(.subtitle-visible) > div.ext {
    transform: translate3d(0, -7px, 0)
}

.stacked-block-table > .body .s-block > .name > .label-ext-info > span.ext {
    display: inline-block;
    transform: translate3d(0px, 0, 0)
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover > .name > .name-title {
    opacity: 1;
    transition: opacity .4s
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover:not(.single-item):hover > .name:not(:hover) > .name-title {
    opacity: 0
}

.stacked-block-table > .body .s-block:hover .s-block > .name:after, .stacked-block-table > .body .s-block:hover .s-block > .name > .label-ext-info {
    opacity: 0.5
}

.stacked-block-table > .body .s-block:hover > .name > .label-ext-info {
    opacity: 1 !important;
    color: #000;
    transform: scale3d(1, 1, 1) translate3d(0, 0, 0)
}

.stacked-block-table > .body .s-block:hover > .name:not(:hover) > .label-ext-info {
    transform: scale3d(1, 1, 1) translate3d(0, 0, 0)
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover:hover > .name:not(:hover) > .label-ext-info {
    top: 50%;
    margin-top: -9px;
    transform: scale3d(1, 1, 1) translate3d(0, 0, 0)
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover:hover > .name:not(:hover) > .label-ext-info.has-subtitle {
    margin-top: -13px
}

.stacked-block-table > .body .s-block:hover > .name > .label-ext-info > .ext {
    opacity: 0.75
}

.stacked-block-table > .body .s-block:hover > .name > .label-ext-info > div.ext, .stacked-block-table > .body .s-block:hover .s-block > .name > .label-ext-info > div.ext {
    transform: translate3d(0px, 0px, 0)
}

.stacked-block-table > .body .s-block:hover > .name > .label-ext-info > span.ext, .stacked-block-table > .body .s-block:hover .s-block > .name > .label-ext-info > span.ext {
    transform: translate3d(0px, 0, 0)
}

.stacked-block-table > .body .s-block > .name > .label-ext-info > .label-title {
    transition: opacity .25s, margin-top .25s
}

.stacked-block-table > .body .s-block:hover > .name:hover > .label-ext-info.has-subtitle > div.label-title {
    opacity: 0;
    margin-top: -9px
}

.stacked-block-table > .body .s-block:hover > .name:hover > .label-ext-info > .ext {
    opacity: 1;
    transform: scale3d(1, 1, 1);
    font-weight: 600
}

.stacked-block-table > .body .s-block:hover > .name:hover > .label-ext-info > .ext i.icon-copy {
    opacity: 1;
    cursor: pointer
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover .name.col-file > .exp-table-checkbox {
    transition: opacity .4s;
    opacity: 1
}

.stacked-block-table > .body .s-block.hide-name-on-block-hover:hover > .name.col-file:not(:hover) > .exp-table-checkbox {
    opacity: 0
}

.stacked-block-table > .body .s-block > .item {
    padding: 9px 8px;
    line-height: 16px;
    display: inline-block;
    text-align: center;
    vertical-align: middle
}

.stacked-block-table > .body > .stack-depth-0.s-block-list {
    float: right;
    display: block
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1:first-child {
    border-top: 1px solid #b5b5b5
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list > .collapsible-s-block-ext > .s-block.stack-depth-1:not(:last-child) {
    border-bottom: 1px solid #606060
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1 > .name, .stacked-block-table > .body > .stack-depth-0.s-block-list > .collapsible-s-block-ext > .s-block.stack-depth-1 > .name {
    text-align: center;
    line-height: 16px;
    padding-top: 27px;
    padding-bottom: 27px;
    min-height: 70px
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2, .stacked-block-table > .body > .stack-depth-0.s-block-list > .collapsible-s-block-ext > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2 {
    padding: 0;
    text-align: left;
    transform: translate3d(0px, 0px, 0px)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list > .collapsible-s-block-ext > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2:not(:last-child) {
    border-bottom: 1px solid #888;
    border-color: rgba(0, 0, 0, 0.5)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2 > .name, .stacked-block-table > .body > .stack-depth-0.s-block-list > .collapsible-s-block-ext > .s-block.stack-depth-1 > .stack-depth-1.s-block-list .s-block.stack-depth-2 > .name {
    font-weight: 500;
    line-height: 20px;
    padding-top: 25px;
    padding-bottom: 25px;
    min-height: 70px
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file-pair:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file-pair:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file-pair:not(:last-child) {
    border-bottom: 1px solid #888;
    border-color: rgba(0, 0, 0, 0.5)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file-pair > .s-block-list.files > .s-block.file:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file-pair > .s-block-list.files > .s-block.file:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file-pair > .s-block-list.files > .s-block.file:not(:last-child) {
    border-bottom-style: dotted
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file-pair > .s-block-list.files > .s-block.file:last-child:not(:first-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file-pair > .s-block-list.files > .s-block.file:last-child:not(:first-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file-pair > .s-block-list.files > .s-block.file:last-child:not(:first-child) {
    border-top: 1px solid transparent
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file-pair .name.col-file-pair, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file-pair .name.col-file-pair, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file-pair .name.col-file-pair {
    line-height: 25px;
    white-space: nowrap
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file:not(:last-child), .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file:not(:last-child) {
    border-bottom: 1px solid #ccc;
    border-color: rgba(0, 0, 0, 0.2)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file.single-item .name.col-file, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file.single-item .name.col-file, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file.single-item .name.col-file {
    line-height: 55px;
    white-space: nowrap
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file:not(.single-item) .name.col-file, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file:not(.single-item) .name.col-file, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file:not(.single-item) .name.col-file {
    line-height: 20px;
    white-space: nowrap
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.files .s-block.file .name.col-file > .exp-table-checkbox, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.file-pairs .s-block.file .name.col-file > .exp-table-checkbox, .stacked-block-table > .body > .stack-depth-0.s-block-list .s-block-list.stack-depth-2 .s-block.file .name.col-file > .exp-table-checkbox {
    margin-bottom: 0;
    display: inline-block;
    margin-right: 2px;
    vertical-align: middle;
    margin-top: -3px
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-1) {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#f7f9f8 12%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #f7f9f8 12%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFF7F9F8', GradientType=1)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-1).s-block-list-collapsing.collapsing-child {
    background: #f7f9f8;
    transform: translate3d(0px, 0px, 0px)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-1):not(.collapsing-child) > .experiments > .view-more-button {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#fff 25%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #ffffff 25%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFFFFFFF', GradientType=1)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-2) {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#f8f9f7 12%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #f8f9f7 12%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFF8F9F7', GradientType=1)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-2).s-block-list-collapsing.collapsing-child {
    background: #f8f9f7;
    transform: translate3d(0px, 0px, 0px)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.biosample.stack-depth-1:nth-child(2n-2):not(.collapsing-child) > .experiments > .view-more-button {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#fff 25%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #ffffff 25%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFFFFFFF', GradientType=1)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.experiment.stack-depth-1 {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#f7f8f9 12%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #f7f8f9 12%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFF7F8F9', GradientType=1)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.experiment.stack-depth-1.s-block-list-collapsing.collapsing-child {
    background: #f7f8f9;
    transform: translate3d(0px, 0px, 0px)
}

.stacked-block-table > .body > .stack-depth-0.s-block-list .s-block.experiment.stack-depth-1:not(.collapsing-child) > .experiments > .view-more-button {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(255, 255, 255, 0) 0%), color-stop(#fff 25%));
    background-image: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, #ffffff 25%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00FFFFFF', endColorstr='#FFFFFFFF', GradientType=1)
}

.search-results-outer-container {
    margin-bottom: -20px
}

.search-results-outer-container .search-results-container {
    position: relative
}

.search-results-outer-container .search-results-container .shadow-border-layer {
    position: absolute;
    pointer-events: none;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    box-shadow: inset 10px 0 10px -10px transparent, inset -10px 0 10px -10px transparent;
    transition: box-shadow .35s ease
}

.search-results-outer-container .search-results-container .shadow-border-layer.shadow-right {
    box-shadow: inset 10px 0 10px -10px transparent, inset -10px 0 10px -10px rgba(0, 0, 0, 0.125)
}

.search-results-outer-container .search-results-container .shadow-border-layer.shadow-left {
    box-shadow: inset 10px 0 10px -10px rgba(0, 0, 0, 0.125), inset -10px 0 10px -10px transparent
}

.search-results-outer-container .search-results-container .shadow-border-layer.shadow-left.shadow-right {
    box-shadow: inset 10px 0 10px -10px rgba(0, 0, 0, 0.125), inset -10px 0 10px -10px rgba(0, 0, 0, 0.125)
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button {
    position: absolute;
    top: 0;
    bottom: 0;
    background: #f8f8f8;
    width: 15px;
    pointer-events: all;
    opacity: 1;
    transition: opacity .3s ease-out;
    cursor: pointer;
    text-align: center;
    padding-top: 16px
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button.right-edge {
    right: -15px;
    border-radius: 0 4px 4px 0;
    box-shadow: inset -5px 0 10px #fff
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button.left-edge {
    left: -15px;
    border-radius: 4px 0 0 4px;
    box-shadow: inset 5px 0 10px #fff
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button.faded-out {
    opacity: 0;
    transition: opacity .6s ease-out;
    pointer-events: none
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button > i.icon, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button > i.tcell-sort, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button > i.tcell-asc, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button > i.tcell-desc {
    position: absolute;
    display: block;
    width: 15px;
    opacity: 0.5
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button:hover {
    background-color: #f4f4f4;
    box-shadow: none
}

.search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button:hover > i.icon, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button:hover > i.tcell-sort, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button:hover > i.tcell-asc, .search-results-outer-container .search-results-container .shadow-border-layer > .edge-scroll-button:hover > i.tcell-desc {
    opacity: 0.8
}

body.scrolled-past-top .search-results-outer-container .search-results-container .shadow-border-layer.short > .edge-scroll-button > i.icon, body.scrolled-past-top .search-results-outer-container .search-results-container .shadow-border-layer.short > .edge-scroll-button > i.tcell-sort, body.scrolled-past-top .search-results-outer-container .search-results-container .shadow-border-layer.short > .edge-scroll-button > i.tcell-asc, body.scrolled-past-top .search-results-outer-container .search-results-container .shadow-border-layer.short > .edge-scroll-button > i.tcell-desc {
    margin-top: -5px;
    top: 50%
}

body.scrolled-past-80 .search-results-outer-container .search-results-container .shadow-border-layer.tall.fixed-position-arrows > .edge-scroll-button > i.icon, body.scrolled-past-80 .search-results-outer-container .search-results-container .shadow-border-layer.tall.fixed-position-arrows > .edge-scroll-button > i.tcell-sort, body.scrolled-past-80 .search-results-outer-container .search-results-container .shadow-border-layer.tall.fixed-position-arrows > .edge-scroll-button > i.tcell-asc, body.scrolled-past-80 .search-results-outer-container .search-results-container .shadow-border-layer.tall.fixed-position-arrows > .edge-scroll-button > i.tcell-desc {
    position: fixed;
    margin-top: -5px;
    top: 50%
}

.search-results-outer-container .search-results-container .inner-container {
    overflow-x: auto
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container {
    overflow: hidden;
    width: auto
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row {
    border-bottom: 1px solid rgba(0, 0, 0, 0.125);
    position: relative;
    transform: translate3d(0, 0, 0)
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns {
    display: flex
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block {
    float: left
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block > .inner {
    height: 46px;
    padding: 15px 8px;
    line-height: 16px;
    text-align: center;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] > .inner, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="@type"] > .inner, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="lab.display_title"] > .inner {
    text-align: left
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="lab.display_title"] i.user-icon {
    margin-right: 5px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block > .inner {
    height: 46px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block:not(:last-child) {
    border-right: 1px dotted rgba(0, 0, 0, 0.075)
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] {
    padding-left: 40px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container {
    position: absolute;
    top: 5px;
    bottom: 5px;
    left: 0;
    z-index: 10
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button {
    padding-left: 0;
    padding-right: 0;
    position: relative;
    height: 100%;
    width: 36px;
    border: 1px solid transparent;
    background: transparent;
    border-radius: 3px;
    outline: none
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container {
    position: absolute;
    top: 10px;
    width: 100%;
    text-align: center
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container > i.icon, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container > i.tcell-sort, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container > i.tcell-asc, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container > i.tcell-desc {
    position: relative;
    display: block;
    margin: 0 auto
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button:hover {
    background-color: #eee
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container {
    float: left;
    margin-top: -10px;
    margin-left: -7px;
    margin-right: 15px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button {
    padding-left: 0;
    padding-right: 0;
    height: 36px;
    width: 36px;
    border: 1px solid transparent;
    border-radius: 3px;
    outline: none;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.3);
    background-color: #eee;
    color: #000
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button > i.icon, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button > i.tcell-sort, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button > i.tcell-asc, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button > i.tcell-desc {
    position: relative;
    top: 1px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .select-button-container > button:hover {
    background-color: #428bca;
    color: #fff;
    box-shadow: none
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .expset-checkbox {
    float: left;
    margin-right: 15px;
    margin-top: 3px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row > .columns > .search-result-column-block[data-field="display_title"] .mono-text {
    letter-spacing: 0.5px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns {
    background-color: rgba(255, 255, 255, 0.75);
    box-shadow: 0 1px 6px rgba(0, 0, 0, 0.33)
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns > .search-result-column-block > .inner {
    padding-top: 20px;
    padding-bottom: 20px;
    height: 56px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container {
    top: 0px;
    bottom: 1px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button {
    border-radius: 0px;
    background-color: #f8f8f8;
    border-left-color: rgba(0, 0, 0, 0.125);
    border-right-color: #fdfdfd
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button > .icon-container {
    top: 20px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.open > .columns > .search-result-column-block[data-field="display_title"] .toggle-detail-button-container > button:hover {
    background-color: #eee
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.loading {
    height: 67px;
    line-height: 46px;
    transition: transform .5s ease;
    border-bottom: none
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row.empty-block {
    height: 20px;
    border-bottom: none;
    background-color: #fff
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container {
    border-top: 1px solid rgba(0, 0, 0, 0.075);
    position: relative;
    background: #fdfdfd
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container.closed {
    display: none
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail {
    padding-left: 47px;
    padding-right: 0px;
    border-bottom: 1px solid;
    transition: border-bottom .3s ease-out;
    border-bottom-color: #808080;
    font-size: 12px;
    font-size: .85rem
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail > .close-button-container {
    position: absolute;
    left: 8px;
    top: 10px;
    width: 28px;
    margin-left: 1px;
    height: 28px;
    line-height: 28px;
    font-size: 1rem;
    cursor: pointer;
    border-radius: 3px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail > .close-button-container:hover {
    background-color: rgba(0, 0, 0, 0.075)
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container {
    margin-top: 16px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container > .flexible-description-box {
    margin-left: 28px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container .description-expand-button {
    margin-top: -2px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container > h5, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container > h6 {
    margin-bottom: 5px;
    margin-top: 0;
    font-weight: 500
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .flex-description-container > .desc-separator {
    margin-top: 15px;
    margin-bottom: 0;
    border-top-color: #ddd
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .item-page-detail {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 10px;
    padding-bottom: 10px
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .item-page-detail .expandable-list {
    margin-bottom: 0
}

.search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .item-page-detail > .expandable-list, .search-results-outer-container .search-results-container .inner-container .scrollable-container .search-result-row .result-table-detail-container .result-table-detail .item-page-detail > .array-group-row > .expandable-list {
    margin-left: 28px
}

.search-results-outer-container div.fin {
    text-align: center;
    height: 67px;
    line-height: 47px;
    font-style: italic;
    border-bottom: none;
    background-color: #fff
}

.search-results-outer-container div.fin > .inner {
    transition: transform .5s ease
}

.search-results-outer-container div.fin > .inner > span {
    font-family: serif
}

.search-headers-row {
    background-color: #22656d;
    z-index: 10;
    transform: translate3d(0, 0, 0) !important;
    overflow-x: hidden
}

.search-headers-row.stickied {
    top: 40px
}

.browse-page-container .search-headers-row.stickied {
    top: 80px
}

.search-headers-row > .columns {
    display: -webkit-box;
    display: flex;
    position: relative;
    transition: left .025s linear
}

.search-headers-row > .columns > .search-headers-column-block {
    float: left;
    flex-shrink: 0;
    position: relative;
    transform: translate3d(0, 0, 0)
}

.search-headers-row > .columns > .search-headers-column-block > .inner {
    height: 46px;
    padding: 15px 8px;
    line-height: 16px;
    text-align: center;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

.search-headers-row > .columns > .search-headers-column-block[data-field="display_title"] > .inner, .search-headers-row > .columns > .search-headers-column-block[data-field="@type"] > .inner, .search-headers-row > .columns > .search-headers-column-block[data-field="lab.display_title"] > .inner {
    text-align: left
}

.search-headers-row > .columns > .search-headers-column-block[data-field="lab.display_title"] i.user-icon {
    margin-right: 5px
}

.search-headers-row > .columns > .search-headers-column-block.no-sort > .inner {
    padding-right: 8px
}

.search-headers-row > .columns > .search-headers-column-block > .inner {
    color: #fff;
    font-weight: 500;
    padding-right: 32px
}

.search-headers-row > .columns > .search-headers-column-block > .inner .column-sort-icon {
    color: rgba(255, 255, 255, 0.5);
    text-decoration: none !important;
    margin-left: 10px;
    margin-right: 5px;
    display: inline-block;
    position: absolute;
    cursor: pointer;
    right: 9px
}

.search-headers-row > .columns > .search-headers-column-block > .inner .column-sort-icon:hover, .search-headers-row > .columns > .search-headers-column-block > .inner .column-sort-icon:active, .search-headers-row > .columns > .search-headers-column-block > .inner .column-sort-icon:focus {
    color: #fff
}

.search-headers-row > .columns > .search-headers-column-block > .inner .column-sort-icon.active {
    color: #fff;
    text-shadow: 0 0 0 #fff
}

.search-headers-row > .columns > .search-headers-column-block:hover {
    z-index: 10
}

.search-headers-row > .columns > .search-headers-column-block[data-field="display_title"] {
    padding-left: 40px
}

.search-headers-row > .columns > .search-headers-column-block > .width-adjuster {
    position: absolute;
    color: #fff;
    padding-left: 10px;
    padding-right: 15px;
    left: 0;
    top: 0;
    margin-left: -12px;
    z-index: 10;
    cursor: col-resize;
    width: 28px;
    height: 100%
}

.search-headers-row > .columns > .search-headers-column-block > .width-adjuster:after {
    content: ' ';
    border-left: 1px dotted rgba(255, 255, 255, 0.6);
    border-right: 1px dotted rgba(255, 255, 255, 0.6);
    width: 3px;
    left: 10px;
    top: 9.5px;
    bottom: 9.5px;
    position: absolute
}

.search-headers-row > .columns > .search-headers-column-block > .width-adjuster:hover:after {
    border-color: #fff
}

.search-headers-row.non-adjustable > .columns > .search-headers-column-block > .inner {
    padding-right: 8px
}

.rc-tabs-tabpane .search-headers-row {
    background-color: #476265
}

.search-headers-row.no-detail-pane > .columns > .search-headers-column-block[data-field="display_title"] {
    padding-left: 10px
}

.above-results-table-row {
    min-height: 40px;
    padding-bottom: 5px;
    margin-top: 7px
}

.above-results-table-row .search-result-config-panel {
    margin-top: 7px
}

.above-results-table-row .search-result-config-panel > .inner {
    padding: 0 0;
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd
}

.above-results-table-row .search-result-config-panel > .inner > div.row, .above-results-table-row .search-result-config-panel > .inner > div.flexrow {
    padding-top: 5px;
    padding-left: 5px;
    padding-right: 5px;
    padding-bottom: 5px
}

.above-results-table-row .search-result-config-panel > .inner > div.row > div > .checkbox, .above-results-table-row .search-result-config-panel > .inner > div.flexrow > div > .checkbox {
    margin: 0;
    margin-bottom: 10px;
    margin-top: 5px;
    margin-bottom: 5px;
    margin-left: -5px;
    margin-right: -5px;
    padding-left: 32px;
    background: #f9f9f9;
    border-radius: 2px
}

.above-results-table-row .search-result-config-panel > .inner > div.row > div > .checkbox label, .above-results-table-row .search-result-config-panel > .inner > div.flexrow > div > .checkbox label {
    display: inline-block;
    margin: 0;
    padding-top: 10px;
    padding-bottom: 10px;
    width: 100%
}

.above-results-table-row .search-result-config-panel > .inner > div.row > div > .checkbox:hover, .above-results-table-row .search-result-config-panel > .inner > div.flexrow > div > .checkbox:hover {
    background-color: #f5f5f5
}

.above-results-table-row .search-result-config-panel > .inner .panel-title {
    padding-bottom: 13px;
    padding-top: 12px;
    padding-left: 10px;
    padding-right: 10px;
    font-weight: 500;
    background-color: #f8f8f8;
    border-bottom: 1px solid #eee
}

.above-results-table-row .search-result-config-panel > .inner .panel-title .close-button {
    font-weight: 400;
    display: block;
    cursor: pointer;
    float: right;
    font-size: 1rem
}

.above-results-table-row .search-result-config-panel > .inner .panel-title .close-button:hover {
    text-decoration: none
}

.above-results-table-row .search-result-config-panel > .inner .panel-title .icon-fw {
    margin-right: 5px
}

.above-results-table-row button {
    transition: opacity .5s, background-color .5s, box-shadow .25s, color .5s;
    box-shadow: none
}

.above-results-table-row button:focus, .above-results-table-row button:active, .above-results-table-row button.active, .above-results-table-row button.active:focus, .above-results-table-row button:active:focus {
    outline: none
}

.above-results-table-row button i.icon, .above-results-table-row button i.tcell-sort, .above-results-table-row button i.tcell-asc, .above-results-table-row button i.tcell-desc {
    position: relative;
    top: 1px
}

.above-results-table-row button.panel-active {
    box-shadow: inset 0 2px 18px rgba(0, 0, 0, 0.6);
    border-color: rgba(0, 0, 0, 0.5)
}

.above-results-table-row .box {
    min-height: 33px;
    line-height: 33px
}

.above-results-table-row .box.selection-buttons {
    margin-right: 7px
}

.above-results-table-row .right-buttons > button {
    margin-left: 5px
}

@media screen and (max-width: 1220px) {
    .above-results-table-row .right-buttons .expand-layout-button:not(.expanded) {
        display: none
    }
}

.popover.file-format-selection-popover .popover-content {
    min-width: 240px
}

.popover.file-format-selection-popover .popover-content div:not(:last-child) {
    margin-bottom: 2px
}

.popover.file-format-selection-popover .popover-content div > button {
    width: 100%
}

.item-page-table-container .item-page-table-row-container {
    position: relative;
    border-bottom: 1px solid #eee
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper {
    padding-left: 0;
    border-top: 1px solid #eee
}

@media screen and (min-width: 768px) {
    .item-page-table-container .item-page-table-row-container > .inner-wrapper {
        padding-left: 10px
    }
}

@media screen and (min-width: 992px) {
    .item-page-table-container .item-page-table-row-container > .inner-wrapper {
        padding-left: 47px
    }
}

@media screen and (min-width: 1200px) {
    .item-page-table-container .item-page-table-row-container > .inner-wrapper {
        padding-left: 47px
    }
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container {
    margin-top: 16px
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container > .flexible-description-box {
    margin-left: 28px
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container .description-expand-button {
    margin-top: -2px
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container > h5, .item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container > h6 {
    margin-bottom: 5px;
    margin-top: 0;
    font-weight: 500
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .flex-description-container > .desc-separator {
    margin-top: 15px;
    margin-bottom: 0;
    border-top-color: #ddd
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .item-page-detail {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 10px;
    padding-bottom: 10px
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .item-page-detail .expandable-list {
    margin-bottom: 0
}

.item-page-table-container .item-page-table-row-container > .inner-wrapper .item-page-detail > .expandable-list, .item-page-table-container .item-page-table-row-container > .inner-wrapper .item-page-detail > .array-group-row > .expandable-list {
    margin-left: 28px
}

.item-page-table-container .item-page-table-row-container .table-row .column {
    float: left;
    float: none;
    display: inline-block;
    vertical-align: middle
}

.item-page-table-container .item-page-table-row-container .table-row .column > .inner {
    height: 46px;
    padding: 15px 8px;
    line-height: 16px;
    text-align: center;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="@type"] > .inner, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="lab.display_title"] > .inner {
    text-align: left
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="lab.display_title"] i.user-icon {
    margin-right: 5px
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner {
    height: auto;
    white-space: normal;
    padding-left: 40px
}

@media screen and (min-width: 992px) {
    .item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner {
        padding-left: 47px;
        padding-right: 0
    }
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .icon-container {
    padding-bottom: 8px;
    cursor: pointer;
    font-size: 1.25rem
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .has-type-title .icon-container, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.has-type-title .icon-container {
    padding-top: 8px
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .title-container {
    padding-right: 0
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container {
    position: absolute;
    top: 5px;
    bottom: 5px;
    left: 0;
    z-index: 10
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button {
    padding-left: 0;
    padding-right: 0;
    position: relative;
    height: 100%;
    width: 36px;
    border: 1px solid transparent;
    background: transparent;
    border-radius: 3px;
    outline: none
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button > .icon-container {
    position: absolute;
    top: 10px;
    width: 100%;
    text-align: center
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button > .icon-container > i.icon, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button > .icon-container > i.tcell-sort, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button > .icon-container > i.tcell-asc, .item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button > .icon-container > i.tcell-desc {
    position: relative;
    display: block;
    margin: 0 auto
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner .toggle-detail-button-container > button:hover {
    background-color: #eee
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .toggle-detail-button-container {
    top: 0px;
    bottom: 1px
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .toggle-detail-button-container > button {
    border-radius: 0px;
    background-color: #f8f8f8;
    border-left-color: rgba(0, 0, 0, 0.125);
    border-right-color: #fdfdfd
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .toggle-detail-button-container > button > .icon-container {
    top: 20px
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .toggle-detail-button-container > button:hover {
    background-color: #eee
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .toggle-detail-button-container {
    bottom: 0px
}

.item-page-table-container .item-page-table-row-container .table-row .column[data-field="display_title"] > .inner.open .icon-container {
    top: 15px !important
}

.item-page-table-container .item-page-table-row-container .table-row .column.block {
    padding: 0;
    padding-left: 10px;
    padding-right: 10px;
    margin: 0
}

.item-page-table-container .item-page-table-row-container .table-row .column.block .label-for-field {
    padding-top: 8px;
    margin-bottom: -8px
}

.item-page-table-container .item-page-table-row-container .table-row .column.block > .inner {
    height: auto;
    padding: 8px 0;
    border-bottom: 1px solid #f4f4f4;
    text-align: left
}

.item-page-table-container .item-page-table-row-container .table-row .column.block > .inner .icon-container {
    padding-top: 0;
    padding-bottom: 0;
    font-size: 1rem;
    width: auto;
    padding-right: 0
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] {
    margin-bottom: 10px
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner {
    background-color: #f4f4f4;
    padding-top: 12px;
    padding-bottom: 11px;
    padding-left: 40px
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner .title-container {
    font-size: 1.1rem
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner .icon-container {
    padding-left: 20px
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner .toggle-detail-button-container .toggle-detail-button {
    width: 45px;
    padding-right: 5px
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner .toggle-detail-button-container .toggle-detail-button .icon-container {
    position: relative;
    top: 1px !important
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner.open .toggle-detail-button-container .toggle-detail-button {
    border-color: transparent;
    background-color: transparent
}

.item-page-table-container .item-page-table-row-container .table-row .column.block[data-field="display_title"] > .inner.open .toggle-detail-button-container .toggle-detail-button .icon-container {
    position: relative;
    top: 1px !important
}

@media screen and (min-width: 992px) {
    .item-page-table-container .item-page-table-row-container .table-row.no-detail-pane .column[data-field="display_title"] > .inner {
        padding-left: 17px;
        padding-right: 0
    }
}

@media screen and (max-width: 991px) {
    .item-page-table-container .item-page-table-row-container {
        margin-bottom: 20px;
        margin-top: 10px;
        border-bottom: none
    }
}

.result-table {
    position: relative;
    z-index: 10;
    list-style-type: none;
    margin: 0;
    padding: 0;
    overflow: hidden
}

.result-table .result-table-result {
    border-bottom: 1px solid #E8E8E8;
    font-size: 13px;
    font-size: .9rem
}

.result-table .result-table-result:first {
    margin-top: 0px;
    border-bottom: 1px solid #ccc;
    font-size: 13px;
    font-size: .9rem
}

.result-table .result-table-result .result-table-entry-div {
    text-align: center;
    line-height: 1.5em;
    padding-top: 15px;
    height: 48px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    margin-bottom: 0
}

.result-table .result-table-result .result-table-entry-div .icon-container.btn, .result-table .result-table-result .result-table-entry-div .icon-container.rf-RepeatingFieldset__add {
    margin: 0;
    width: 40px;
    height: 40px;
    margin-top: -11px;
    margin-right: 4px;
    margin-left: 2px;
    border: none
}

.result-table .result-table-result-heading {
    background-color: #f4f4f4;
    border: 1px solid #eee;
    border-radius: 2px;
    padding: 5px 15px 5px 15px
}

.result-table:before {
    content: none;
    display: block
}

.result-table .pull-right {
    position: relative;
    z-index: 2
}

.result-table-header-row-container {
    background-color: #22656d
}

.result-table-header-row-container .result-table-header-row {
    font-weight: 400
}

.result-table-header-row-container .result-table-header-row .result-table-entry-div > div {
    margin-bottom: 0px;
    padding-top: 10px;
    padding-bottom: 10px;
    color: #fff;
    height: 46px;
    line-height: 26px;
    text-align: center
}

.facets-container {
    padding-top: 0;
    padding-bottom: 2px;
    padding-left: 10px;
    padding-right: 10px;
    border: 1px solid #e8e8e8;
    border-bottom: 1px solid rgba(0, 0, 0, 0.15)
}

.facets-container .facets-header {
    padding-top: 10px;
    padding-bottom: 10px;
    border-bottom: 1px solid #eee;
    border-top-left-radius: inherit;
    border-top-right-radius: inherit;
    color: #111
}

.facets-container .facets-header .facets-title-column {
    top: -1px
}

.facets-container .facets-header .facets-title {
    font-weight: 300;
    margin: 0;
    line-height: inherit;
    color: inherit;
    display: inline
}

.facets-container.with-header-bg .facets-header {
    background-color: #22656d;
    border-top: inherit;
    border-left: inherit;
    border-right: inherit;
    border-bottom: none;
    color: #fff;
    height: 46px
}

.facets-container.with-header-bg .facets-header.row, .facets-container.with-header-bg .facets-header.flexrow {
    margin-left: -11px;
    margin-right: -11px;
    margin-top: -1px
}

@media screen and (max-width: 768px) {
    .sm-no-padding {
        padding-left: 0 !important;
        padding-right: 0 !important
    }

    .facets.horizontal .facet {
        width: auto !important
    }
}

@media screen and (min-width: 768px) {
    .facets.horizontal .facet {
        width: 50% !important;
        padding: 0 10px;
        float: left
    }
}

@media screen and (min-width: 1200px) {
    .facets.horizontal {
        display: table;
        width: 100%
    }

    .facets.horizontal .facet {
        width: initial !important;
        display: table-cell;
        float: none
    }

    .facets.horizontal .facet[hidden] {
        display: table-cell !important;
        visibility: hidden
    }
}

.clear-filters-control, .clear-filters-control-matrix {
    margin: 1px 0;
    text-align: right;
    font-size: 0.9rem;
    opacity: 1;
    transition: opacity .25s;
    position: relative
}

.clear-filters-control > a:not(.btn):not(.rf-RepeatingFieldset__add), .clear-filters-control-matrix > a:not(.btn):not(.rf-RepeatingFieldset__add) {
    color: #999999;
    text-decoration: none
}

.clear-filters-control.placeholder, .placeholder.clear-filters-control-matrix {
    opacity: 0;
    visibility: visible !important;
    z-index: -10
}

.clear-filters-control-matrix {
    text-align: center;
    margin-top: 5px
}

.facet {
    overflow: hidden;
    padding-top: 9px;
    padding-bottom: 8px
}

.facet.row, .facet.flexrow {
    padding-left: 10px;
    padding-right: 10px
}

.facet.row.active-submission-row, .facet.active-submission-row.flexrow {
    position: relative;
    z-index: 5
}

.facet:not(:last-child) {
    border-bottom: 1px solid #f4f4f4
}

.facet:last-child {
    margin-bottom: 0
}

.facet:last-child.static {
    margin-bottom: -2px
}

.facet h5.facet-title {
    margin: 0 0 3px;
    font-weight: 500;
    line-height: inherit;
    font-size: 13px;
    font-size: .925rem
}

.facet h5.facet-title > i.icon-info-circle {
    margin-left: 6px;
    opacity: 0.25;
    transition: opacity .5s
}

.facet h5.facet-title > i.icon-info-circle:hover {
    opacity: 0.75
}

.facet.static {
    padding-bottom: 5px
}

.facet:not(.static) {
    transition: padding-bottom .35s ease, background-color .35s ease;
    transform: translate3d(0, 0, 0);
    background-color: transparent
}

.facet:not(.static) h5.facet-title {
    margin: -1px 0 0;
    padding: 0 0 8px;
    border-bottom: 1px solid #f8f8f8;
    cursor: pointer
}

.facet:not(.static) h5.facet-title > span.expand-toggle > i.icon, .facet:not(.static) h5.facet-title > span.expand-toggle > i.tcell-sort, .facet:not(.static) h5.facet-title > span.expand-toggle > i.tcell-asc, .facet:not(.static) h5.facet-title > span.expand-toggle > i.tcell-desc {
    font-size: 0.7rem;
    margin-right: 7px
}

.facet:not(.static) h5.facet-title .closed-terms-count {
    position: relative;
    transition: top .35s ease-out, opacity .35s ease;
    top: 1px;
    font-weight: 300;
    color: #707070;
    font-size: 0.75rem;
    line-height: 1.25rem;
    margin-right: 5px
}

.facet:not(.static) h5.facet-title .closed-terms-count > i {
    margin-right: 2px;
    margin-right: 1.5px
}

.facet:not(.static).open:not(.closing) h5.facet-title .closed-terms-count {
    top: 9px
}

.facet:not(.static).closed, .facet:not(.static).closing {
    padding-bottom: 0px;
    background-color: #fcfcfc;
    border-bottom-color: #f0f0f0
}

.facet:not(.static).closed h5.facet-title, .facet:not(.static).closing h5.facet-title {
    font-weight: 400
}

.facet:not(.static).closed h5.facet-title {
    border-bottom: none
}

.facet .facet-static-row .facet-title, .facet .facet-static-row .facet-item {
    display: inline-block;
    margin-bottom: 4px;
    width: 50%
}

.facet .facet-static-row .facet-title {
    padding-right: 10px;
    margin-top: 0;
    float: left;
    min-width: 33%
}

.facet .facet-static-row .facet-title:after {
    content: ""
}

.facet .facet-static-row .facet-item {
    padding-left: 12px;
    padding-left: 12.5px;
    vertical-align: top;
    float: right;
    text-align: right;
    font-size: 13px;
    font-size: .925rem;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.facet .facet-static-row .facet-item span {
    cursor: pointer
}

.facet .facet-static-row .facet-item span i.icon, .facet .facet-static-row .facet-item span i.tcell-sort, .facet .facet-static-row .facet-item span i.tcell-asc, .facet .facet-static-row .facet-item span i.tcell-desc {
    font-size: .5rem;
    vertical-align: text-top;
    line-height: 1.15rem;
    opacity: 0.05;
    width: 25px;
    margin-left: -25px
}

.facet .facet-static-row .facet-item span:hover {
    text-shadow: 0 0 0
}

.facet .facet-static-row .facet-item span:hover i.icon, .facet .facet-static-row .facet-item span:hover i.tcell-sort, .facet .facet-static-row .facet-item span:hover i.tcell-asc, .facet .facet-static-row .facet-item span:hover i.tcell-desc {
    opacity: 0.5
}

.facet .facet-static-row .facet-item.selected span i.icon, .facet .facet-static-row .facet-item.selected span i.tcell-sort, .facet .facet-static-row .facet-item.selected span i.tcell-asc, .facet .facet-static-row .facet-item.selected span i.tcell-desc {
    opacity: 1 !important;
    color: #248bac;
    font-size: 0.825rem
}

.facet .facet-static-row .facet-item.filtering span i.icon, .facet .facet-static-row .facet-item.filtering span i.tcell-sort, .facet .facet-static-row .facet-item.filtering span i.tcell-asc, .facet .facet-static-row .facet-item.filtering span i.tcell-desc {
    opacity: 0.33 !important;
    color: #888 !important;
    font-size: 0.825rem
}

.facet.all-single-term .facet-item {
    text-align: left;
    width: 50%
}

.facet .facet-list {
    margin: 0;
    padding-top: 8px
}

.facet .facet-list li {
    margin-bottom: 1px;
    position: relative;
    font-size: 12px;
    font-size: .875rem;
    line-height: 1rem
}

.facet .facet-list li i {
    line-height: 14px
}

.facet .facet-list li > a {
    border-radius: 3px;
    padding: 4px 3px 2px 21px;
    text-decoration: none;
    display: block;
    position: relative;
    color: #888
}

.facet .facet-list li > a i.icon.icon-circle-o-notch, .facet .facet-list li > a i.icon-circle-o-notch.tcell-sort, .facet .facet-list li > a i.icon-circle-o-notch.tcell-asc, .facet .facet-list li > a i.icon-circle-o-notch.tcell-desc {
    opacity: 0.33
}

.facet .facet-list li > a:hover {
    color: #000000;
    background-color: #f1f7f9
}

.facet .facet-list li > a.highlight {
    color: #fff !important;
    transition: background-color .5s
}

.facet .facet-list li > a .facet-selector {
    margin-left: -17px;
    font-size: 90%
}

.facet .facet-list li > a .facet-count {
    position: absolute;
    right: 0;
    padding-right: inherit
}

.facet .facet-list li.selected > a {
    text-decoration: none;
    color: #f8f8f8;
    background-color: #248bac
}

.facet .facet-list li.selected > a:hover {
    color: #fff
}

.facet .facet-list li.selected > a:hover .facet-item, .facet .facet-list li.selected > a:hover .facet-count {
    text-shadow: 0px 0px 0px #fff
}

.facet .facet-list li .facet-item {
    display: inline-block;
    vertical-align: middle;
    overflow: hidden;
    margin-right: 30px;
    white-space: nowrap;
    text-overflow: ellipsis;
    max-width: 85%
}

.facet .facet-list .view-more-button {
    cursor: pointer;
    font-size: 0.85rem;
    border: 1px solid #888;
    padding: 2px 6px 1px;
    line-height: 20px;
    margin-top: -5px;
    border-radius: 2px
}

.facet .facet-list .view-more-button:hover {
    border-color: #000
}

.facet .facet-list .view-more-button i.icon, .facet .facet-list .view-more-button i.tcell-sort, .facet .facet-list .view-more-button i.tcell-asc, .facet .facet-list .view-more-button i.tcell-desc {
    font-size: 0.8rem;
    position: relative;
    top: 1px;
    left: -2px
}

.facet[data-field="type"] .facet-list li[data-key="Item"] {
    display: none
}

.facet[data-field="experiments_in_set.biosample.biosource.individual.organism.name"] .term, .facet[data-field="experiments_in_set.biosample.biosource.biosource_type"] .term, .facet[data-field="experiments_in_set.biosample.biosource_summary"] .term {
    text-transform: capitalize
}

.facet-entry > a {
    text-decoration: none;
    display: block;
    color: #999999;
    margin-left: 10px
}

.facet-entry > a:hover {
    color: #000000
}

.facet-entry-container.selected {
    background-color: #87c487
}

.facet-entry a.selected {
    color: #000000 !important
}

.facet-count {
    margin-left: 10px;
    margin-right: 5px
}

.facet-list button {
    padding: 0
}

.facet-list button.btn.collapsed:before, .facet-list button.collapsed.rf-RepeatingFieldset__add:before {
    content: "+ VIEW ALL";
    text-decoration: none;
    color: #999999;
    font-size: 12px;
    font-size: .85rem;
    float: left
}

.facet-list button.btn.collapsed:before:hover, .facet-list button.collapsed.rf-RepeatingFieldset__add:before:hover {
    text-decoration: none
}

.facet-list button.btn:before, .facet-list button.rf-RepeatingFieldset__add:before {
    content: "- VIEW FEWER";
    text-decoration: none;
    color: #999999;
    font-size: 12px;
    font-size: .85rem;
    float: left
}

.facet-list button.btn:before:hover, .facet-list button.rf-RepeatingFieldset__add:before:hover {
    text-decoration: none
}

.facet-list label {
    margin: 0
}

.accession {
    position: relative;
    font-size: 17px;
    font-size: 1.2rem;
    font-weight: bold;
    z-index: 0
}

.accession a:hover {
    text-decoration: none
}

.accession-note {
    font-size: 13px;
    font-size: .9rem;
    font-weight: normal
}

.accession-note a[href^="http"]:after {
    font-size: 13px;
    font-size: .9rem
}

.type {
    font-size: 13px;
    font-size: .9rem;
    font-weight: normal;
    color: #808080
}

.search-meta {
    position: relative;
    padding: 2px 5px;
    text-align: right;
    z-index: 1
}

.search-meta p {
    color: #909090;
    margin: 0;
    line-height: 1.2;
    text-align: right
}

.search-meta p.meta-audit {
    margin: 3px 0
}

.search-meta p.meta-audit .audit {
    margin: 0 3px;
    padding: 0;
    border: none;
    background-color: transparent;
    font-size: 18px;
    font-size: 1.3rem
}

.meta-title {
    margin-bottom: 7px !important;
    font-size: 15px;
    font-size: 1.1rem;
    color: #606060 !important
}

.meta-status {
    font-weight: bold
}

div.meta-status {
    text-align: right
}

.highlight-row {
    font-size: 1.1rem;
    font-weight: bold
}

.data-row {
    margin-left: 25px;
    margin-bottom: 10px
}

.data-row ul {
    text-decoration: none;
    list-style-type: none;
    padding: 0px;
    margin-left: 25px
}

.data-row ul li {
    display: inline;
    list-style-type: none;
    border: none;
    margin-right: 5px
}

.data-row ul li a {
    display: inline
}

.data-row img {
    max-width: 128px;
    height: auto;
    margin: auto;
    display: block
}

.main-panel {
    position: relative;
    z-index: 0
}

.list-author {
    margin: 0;
    font-size: 15px;
    font-size: 1.1rem
}

.list-citation {
    margin: 0;
    font-size: 13px;
    font-size: .9rem
}

.list-reference {
    display: inline;
    margin: 0 !important;
    font-size: 13px;
    font-size: .9rem
}

.list-supplementary {
    margin: 0;
    padding: 5px;
    border-right: 1px solid #e8e8e8;
    border-bottom: 1px solid #e8e8e8;
    border-left: 1px solid #e8e8e8
}

.list-supplementary:first-child {
    border-top: 1px solid #e8e8e8
}

.list-supplementary button.btn-link {
    margin-left: 5px;
    padding: 0;
    font-size: inherit;
    vertical-align: baseline;
    border: none
}

.browse-page-container {
    margin-top: 40px
}

.browse-page-container.search-page-container {
    margin-top: 0px
}

.search-list {
    position: relative;
    z-index: 0
}

.btn.btn-disclose, .btn-disclose.rf-RepeatingFieldset__add {
    position: relative;
    padding-top: 2px;
    padding-bottom: 2px;
    background-color: #f3f3f3;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none;
    line-height: 20px;
    border: 1px solid #ccc;
    z-index: 1
}

.btn.btn-disclose.active, .btn-disclose.active.rf-RepeatingFieldset__add {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
    border-bottom: transparent
}

.icon-disclose {
    position: relative;
    display: inline-block;
    top: 1px;
    font-size: 18px;
    width: 10px;
    line-height: 20px
}

.adv-search-form {
    position: relative;
    margin: 20px 0;
    z-index: 20
}

@media screen and (min-width: 768px) {
    .adv-search-form {
        margin: 0
    }
}

.adv-search-form .form-control, .adv-search-form .rf-Field textarea, .rf-Field .adv-search-form textarea, .adv-search-form .rf-Field input[type="text"], .rf-Field .adv-search-form input[type="text"], .adv-search-form .rf-Field input[type="password"], .rf-Field .adv-search-form input[type="password"], .adv-search-form .rf-Field input[type="datetime"], .rf-Field .adv-search-form input[type="datetime"], .adv-search-form .rf-Field input[type="datetime-local"], .rf-Field .adv-search-form input[type="datetime-local"], .adv-search-form .rf-Field input[type="date"], .rf-Field .adv-search-form input[type="date"], .adv-search-form .rf-Field input[type="month"], .rf-Field .adv-search-form input[type="month"], .adv-search-form .rf-Field input[type="time"], .rf-Field .adv-search-form input[type="time"], .adv-search-form .rf-Field input[type="week"], .rf-Field .adv-search-form input[type="week"], .adv-search-form .rf-Field input[type="number"], .rf-Field .adv-search-form input[type="number"], .adv-search-form .rf-Field input[type="email"], .rf-Field .adv-search-form input[type="email"], .adv-search-form .rf-Field input[type="url"], .rf-Field .adv-search-form input[type="url"], .adv-search-form .rf-Field input[type="search"], .rf-Field .adv-search-form input[type="search"], .adv-search-form .rf-Field input[type="tel"], .rf-Field .adv-search-form input[type="tel"], .adv-search-form .rf-Field input[type="color"], .rf-Field .adv-search-form input[type="color"], .adv-search-form .dropzone, .adv-search-form .item-picker {
    height: 26px !important;
    z-index: 0
}

.adv-search-form form {
    position: relative;
    top: -1px;
    padding: 15px 15px 0;
    background-color: #f3f3f3;
    border: 1px solid #ccc
}

.adv-search-form label[for=spacing] {
    display: none
}

@media screen and (min-width: 992px) {
    .adv-search-form label[for=spacing] {
        display: inline-block
    }
}

.adv-search-form .adv-search-submit {
    padding: 0 15px;
    height: 26px;
    line-height: 24px
}

@media screen and (min-width: 992px) {
    .adv-search-form .adv-search-submit {
        padding: 0;
        width: 100%
    }
}

.adv-search-autocomplete {
    position: absolute;
    z-index: 10;
    right: 10px;
    left: 10px;
    padding: 0;
    max-height: 300px;
    overflow-y: scroll;
    background-color: #fff;
    border: 1px solid #c0c0c0;
    list-style: none;
    -moz-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.5);
    -webkit-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.5);
    box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.5)
}

.adv-search-autocomplete li {
    margin: 0;
    padding: 5px 15px;
    font-size: 13px;
    cursor: pointer
}

.adv-search-autocomplete li:hover {
    background-color: #e0e0e0
}

.results-table-control {
    display: inline
}

.results-table-control .btn, .results-table-control .rf-RepeatingFieldset__add {
    margin-right: 20px;
    margin-left: 20px;
    margin-top: -5px
}

.results-table-control .dropdown-menu {
    padding-top: 5px;
    padding-bottom: 5px
}

.results-table-control .dropdown-menu > li > a {
    padding: 2px 20px 2px 20px;
    font-size: 0.95rem
}

.results-table-control .btn-attached {
    display: inline-block;
    margin-right: 5px
}

.search-title {
    text-align: center;
    margin-bottom: 30px
}

.multi-columns-row .first-in-row {
    clear: left
}

@media (min-width: 768px) {
    .multi-columns-row .col-lg-1:nth-child(12n+1), .multi-columns-row .col-lg-2:nth-child(6n+1), .multi-columns-row .col-lg-3:nth-child(4n+1), .multi-columns-row .col-lg-4:nth-child(3n+1), .multi-columns-row .col-lg-6:nth-child(2n+1), .multi-columns-row .col-md-1:nth-child(12n+1), .multi-columns-row .col-md-2:nth-child(6n+1), .multi-columns-row .col-md-3:nth-child(4n+1), .multi-columns-row .col-md-4:nth-child(3n+1), .multi-columns-row .col-md-6:nth-child(2n+1) {
        clear: none
    }

    .multi-columns-row .col-sm-1:nth-child(12n+1), .multi-columns-row .col-sm-2:nth-child(6n+1), .multi-columns-row .col-sm-3:nth-child(4n+1), .multi-columns-row .col-sm-4:nth-child(3n+1), .multi-columns-row .col-sm-6:nth-child(2n+1), .multi-columns-row .flexcol-sm-6:nth-child(2n+1) {
        clear: left
    }
}

@media (min-width: 992px) {
    .multi-columns-row .col-lg-1:nth-child(12n+1), .multi-columns-row .col-lg-2:nth-child(6n+1), .multi-columns-row .col-lg-3:nth-child(4n+1), .multi-columns-row .col-lg-4:nth-child(3n+1), .multi-columns-row .col-lg-6:nth-child(2n+1), .multi-columns-row .col-sm-1:nth-child(12n+1), .multi-columns-row .col-sm-2:nth-child(6n+1), .multi-columns-row .col-sm-3:nth-child(4n+1), .multi-columns-row .col-sm-4:nth-child(3n+1), .multi-columns-row .col-sm-6:nth-child(2n+1), .multi-columns-row .flexcol-sm-6:nth-child(2n+1) {
        clear: none
    }

    .multi-columns-row .col-md-1:nth-child(12n+1), .multi-columns-row .col-md-2:nth-child(6n+1), .multi-columns-row .col-md-3:nth-child(4n+1), .multi-columns-row .col-md-4:nth-child(3n+1), .multi-columns-row .col-md-6:nth-child(2n+1) {
        clear: left
    }
}

@media (min-width: 1200px) {
    .multi-columns-row .col-md-1:nth-child(12n+1), .multi-columns-row .col-md-2:nth-child(6n+1), .multi-columns-row .col-md-3:nth-child(4n+1), .multi-columns-row .col-md-4:nth-child(3n+1), .multi-columns-row .col-md-6:nth-child(2n+1), .multi-columns-row .col-sm-1:nth-child(12n+1), .multi-columns-row .col-sm-2:nth-child(6n+1), .multi-columns-row .col-sm-3:nth-child(4n+1), .multi-columns-row .col-sm-4:nth-child(3n+1), .multi-columns-row .col-sm-6:nth-child(2n+1), .multi-columns-row .flexcol-sm-6:nth-child(2n+1) {
        clear: none
    }

    .multi-columns-row .col-lg-1:nth-child(12n+1), .multi-columns-row .col-lg-2:nth-child(6n+1), .multi-columns-row .col-lg-3:nth-child(4n+1), .multi-columns-row .col-lg-4:nth-child(3n+1), .multi-columns-row .col-lg-6:nth-child(2n+1) {
        clear: left
    }
}

.type-Document.view-detail, .type-Characterization.view-detail {
    padding: 0
}

.type-Document.view-detail figure, .type-Characterization.view-detail figure {
    margin: 14px;
    padding: 10px;
    text-align: center
}

.type-Document.view-detail figcaption, .type-Characterization.view-detail figcaption {
    font-weight: bold;
    text-align: center;
    padding: 5px
}

.type-Characterization.view-detail header {
    margin: 0 15px
}

.type-Characterization.view-detail header h3 {
    margin-bottom: 0
}

.type-QualityMetric.view-detail {
    padding: 0
}

.type-QualityMetric.view-detail figure {
    margin: 14px;
    padding: 10px;
    text-align: center
}

.type-QualityMetric.view-detail figcaption {
    font-weight: bold;
    text-align: center;
    padding: 5px
}

.document-title, .characterization-title {
    padding: 5px;
    background-color: #fff;
    color: #333;
    border-bottom: 1px solid #c0c0c0;
    font-weight: bold;
    text-align: left;
    font-size: 14px;
    font-size: 1rem
}

.characterization-title {
    padding: 10px
}

.type-Characterization.view-detail.status-compliant figure {
    background-color: #dff0d8
}

.type-Characterization.view-detail.status-compliant figcaption {
    color: #3c763d
}

.type-Characterization.view-detail.status-not-compliant figure, .type-Document.view-detail.status-deleted figure, .status-deleted.type-Characterization.view-detail figure {
    background-color: #f2dede
}

.type-Characterization.view-detail.status-not-compliant figcaption, .type-Document.view-detail.status-deleted figcaption, .status-deleted.type-Characterization.view-detail figcaption {
    color: #a94442
}

.type-Characterization.view-detail.status-pending-dcc-review figure {
    background-color: #d9edf7
}

.type-Characterization.view-detail.status-pending-dcc-review figcaption {
    color: #31708f
}

.type-Characterization.view-detail.status-in-progress figure, .type-Characterization.view-detail.status-not-submitted-for-review-by-lab figure, .type-Characterization.view-detail.status-not-reviewed figure, .type-Document.view-detail.status-none figure, .status-none.type-Characterization.view-detail figure {
    background-color: #f7f7f9
}

.type-Characterization.view-detail.status-in-progress figcaption, .type-Characterization.view-detail.status-not-submitted-for-review-by-lab figcaption, .type-Characterization.view-detail.status-not-reviewed figcaption, .type-Document.view-detail.status-none figcaption, .status-none.type-Characterization.view-detail figcaption {
    color: #333
}

.type-Characterization.view-detail.type-AntibodyCharacterization {
    padding-top: 0;
    padding-left: 0;
    padding-right: 0
}

.type-Characterization.view-detail.type-AntibodyCharacterization h4 {
    margin: 0;
    padding: 5px 20px 8px;
    background-color: #41739f;
    color: #fff;
    font-size: 11px;
    font-size: .8rem;
    font-weight: bold
}

.type-Characterization.view-detail.type-AntibodyCharacterization .row, .type-Characterization.view-detail.type-AntibodyCharacterization .flexrow {
    padding-left: 30px;
    padding-right: 30px
}

.type-Characterization.view-detail.type-AntibodyCharacterization .panel-footer {
    padding: 0
}

.characterization-img {
    display: block;
    margin-left: auto;
    margin-right: auto;
    max-width: 100%;
    height: auto;
    max-height: 360px
}

.document-meta-data, .characterization-meta-data {
    margin: 0;
    padding: 10px
}

.document-meta-data .label, .characterization-meta-data .label {
    display: inline-block;
    font-size: 11px;
    font-size: .8rem
}

.characterization-meta-data {
    padding: 0
}

.characterization-status {
    margin-bottom: 8px;
    font-weight: bold;
    font-size: 21px;
    font-size: 1.5rem
}

.characterization-status .compliant, .characterization-status .pending-dcc-review, .characterization-status .not-compliant, .characterization-status .not-reviewed, .characterization-status .in-progress {
    top: -5px;
    position: relative
}

.characterization-status .compliant {
    color: #3c763d
}

.characterization-status .pending-dcc-review {
    color: #31708f
}

.characterization-status .not-compliant, .characterization-status .not-reviewed {
    color: #a94442
}

.characterization-status .in-progress {
    color: #f89406
}

.characterization-status-labels {
    display: block;
    font-weight: bold
}

@media screen and (min-width: 768px) {
    .characterization-status-labels {
        display: inline-block;
        margin-right: 5px
    }

    .characterization-status-labels .status-list li {
        height: 28px
    }
}

.label {
    display: table-cell;
    position: relative;
    text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.3);
    text-align: left;
    padding: .3em .5em .4em;
    font-size: 14px;
    font-size: 1rem;
    line-height: 1.1;
    background-color: #999
}

@media screen and (min-width: 768px) {
    .label {
        display: inline-block;
        font-size: 15px;
        font-size: 1.1rem
    }
}

.status-list {
    display: table;
    width: 100%;
    margin: 0;
    padding: 0
}

@media screen and (min-width: 768px) {
    .status-list {
        display: block;
        width: auto
    }
}

.status-list li {
    display: table-cell;
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
    vertical-align: bottom;
    border-left: 1px solid #606060
}

@media screen and (min-width: 768px) {
    .status-list li {
        display: inline-block
    }
}

.status-list li:first-child {
    -moz-border-radius-topleft: 4px;
    -webkit-border-top-left-radius: 4px;
    border-top-left-radius: 4px;
    -moz-border-radius-bottomleft: 4px;
    -webkit-border-bottom-left-radius: 4px;
    border-bottom-left-radius: 4px;
    border-left: none
}

.status-list li:last-child {
    -moz-border-radius-topright: 4px;
    -webkit-border-top-right-radius: 4px;
    border-top-right-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    -webkit-border-bottom-right-radius: 4px;
    border-bottom-right-radius: 4px
}

.status-list-title {
    display: block;
    font-size: 10px;
    font-size: .7rem;
    font-weight: normal;
    text-align: left
}

@media screen and (min-width: 768px) {
    .status-list-title {
        display: inline;
        font-size: 17px;
        font-size: 1.2rem
    }
}

.label.status-eligible-for-new-data {
    background-color: #4C994C
}

.label.status-eligible-for-new-data[href] {
    background-color: #3b773b
}

.label.status-pending-dcc-review {
    background-color: #4F689E
}

.label.status-pending-dcc-review[href] {
    background-color: #3e527c
}

.label.status-not-eligible-for-new-data {
    background-color: #B24342
}

.label.status-not-eligible-for-new-data[href] {
    background-color: #8d3534
}

.label.status-awaiting-lab-characterization {
    background-color: #E59545
}

.label.status-awaiting-lab-characterization[href] {
    background-color: #d97c1e
}

.label.status-compliant {
    background-color: #4C994C
}

.label.status-compliant[href] {
    background-color: #3b773b
}

.label.status-not-compliant {
    background-color: #B24342
}

.label.status-not-compliant[href] {
    background-color: #8d3534
}

.label.status-not-reviewed {
    background-color: #a0a0a0
}

.label.status-not-reviewed[href] {
    background-color: #878787
}

.label.status-exempt-from-standards {
    background-color: #e38000
}

.label.status-exempt-from-standards[href] {
    background-color: #b06300
}

.label.status-in-progress {
    background-color: #4F689E
}

.label.status-in-progress[href] {
    background-color: #3e527c
}

.label.status-started {
    background-color: #4F689E
}

.label.status-started[href] {
    background-color: #3e527c
}

.label.status-verified {
    background-color: #4F689E
}

.label.status-verified[href] {
    background-color: #3e527c
}

.label.status-submitted {
    background-color: #4F689E
}

.label.status-submitted[href] {
    background-color: #3e527c
}

.label.status-in-review {
    background-color: #4F689E
}

.label.status-submitted[href] {
    background-color: #3e527c
}

.label.status-proposed {
    background-color: #4F689E
}

.label.status-proposed[href] {
    background-color: #3e527c
}

.label.status-release-ready {
    background-color: #4F689E
}

.label.status-release-ready[href] {
    background-color: #3e527c
}

.label.status-released {
    background-color: #4C994C
}

.label.status-released[href] {
    background-color: #3b773b
}

.label.status-deleted {
    background-color: #E59545
}

.label.status-deleted[href] {
    background-color: #d97c1e
}

.label.status-revoked {
    background-color: #B24342
}

.label.status-revoked[href] {
    background-color: #8d3534
}

.label.status-pending {
    background-color: #E59545
}

.label.status-pending[href] {
    background-color: #d97c1e
}

.label.status-fail {
    background-color: #B24342
}

.label.status-fail[href] {
    background-color: #8d3534
}

.label.status-pass {
    background-color: #4C994C
}

.label.status-pass[href] {
    background-color: #3b773b
}

.label.status-audit-default {
    background-color: #4C994C
}

.label.status-audit-default[href] {
    background-color: #3b773b
}

.label.status-audit-dcc_action {
    background-color: #999
}

.label.status-audit-dcc_action[href] {
    background-color: gray
}

.label.status-audit-not_compliant {
    background-color: #4F689E
}

.label.status-audit-not_compliant[href] {
    background-color: #3e527c
}

.label.status-audit-warning {
    background-color: #E59545
}

.label.status-audit-warning[href] {
    background-color: #d97c1e
}

.label.status-audit-error {
    background-color: #B24342
}

.label.status-audit-error[href] {
    background-color: #8d3534
}

.badge.status-eligible-for-new-data {
    background-color: #4C994C
}

.badge.status-eligible-for-new-data[href] {
    background-color: #3b773b
}

.badge.status-pending-dcc-review {
    background-color: #4F689E
}

.badge.status-pending-dcc-review[href] {
    background-color: #3e527c
}

.badge.status-not-eligible-for-new-data {
    background-color: #B24342
}

.badge.status-not-eligible-for-new-data[href] {
    background-color: #8d3534
}

.badge.status-awaiting-lab-characterization {
    background-color: #E59545
}

.badge.status-awaiting-lab-characterization[href] {
    background-color: #d97c1e
}

.badge.status-compliant {
    background-color: #4C994C
}

.badge.status-compliant[href] {
    background-color: #3b773b
}

.badge.status-not-compliant {
    background-color: #B24342
}

.badge.status-not-compliant[href] {
    background-color: #8d3534
}

.badge.status-not-reviewed {
    background-color: #a0a0a0
}

.badge.status-not-reviewed[href] {
    background-color: #878787
}

.badge.status-exempt-from-standards {
    background-color: #e38000
}

.badge.status-exempt-from-standards[href] {
    background-color: #b06300
}

.badge.status-in-progress {
    background-color: #4F689E
}

.badge.status-in-progress[href] {
    background-color: #3e527c
}

.badge.status-started {
    background-color: #4F689E
}

.badge.status-started[href] {
    background-color: #3e527c
}

.badge.status-verified {
    background-color: #4F689E
}

.badge.status-verified[href] {
    background-color: #3e527c
}

.badge.status-submitted {
    background-color: #4F689E
}

.badge.status-submitted[href] {
    background-color: #3e527c
}

.badge.status-in-review {
    background-color: #4F689E
}

.badge.status-submitted[href] {
    background-color: #3e527c
}

.badge.status-proposed {
    background-color: #4F689E
}

.badge.status-proposed[href] {
    background-color: #3e527c
}

.badge.status-release-ready {
    background-color: #4F689E
}

.badge.status-release-ready[href] {
    background-color: #3e527c
}

.badge.status-released {
    background-color: #4C994C
}

.badge.status-released[href] {
    background-color: #3b773b
}

.badge.status-deleted {
    background-color: #E59545
}

.badge.status-deleted[href] {
    background-color: #d97c1e
}

.badge.status-revoked {
    background-color: #B24342
}

.badge.status-revoked[href] {
    background-color: #8d3534
}

.badge.status-pending {
    background-color: #E59545
}

.badge.status-pending[href] {
    background-color: #d97c1e
}

.badge.status-fail {
    background-color: #B24342
}

.badge.status-fail[href] {
    background-color: #8d3534
}

.badge.status-pass {
    background-color: #4C994C
}

.badge.status-pass[href] {
    background-color: #3b773b
}

.badge.status-audit-default {
    background-color: #4C994C
}

.badge.status-audit-default[href] {
    background-color: #3b773b
}

.badge.status-audit-dcc_action {
    background-color: #999
}

.badge.status-audit-dcc_action[href] {
    background-color: gray
}

.badge.status-audit-not_compliant {
    background-color: #4F689E
}

.badge.status-audit-not_compliant[href] {
    background-color: #3e527c
}

.badge.status-audit-warning {
    background-color: #E59545
}

.badge.status-audit-warning[href] {
    background-color: #d97c1e
}

.badge.status-audit-error {
    background-color: #B24342
}

.badge.status-audit-error[href] {
    background-color: #8d3534
}

.indicator.status-eligible-for-new-data {
    color: #00e500
}

.indicator.status-eligible-for-new-data-via-exemption {
    color: #e38000
}

.indicator.status-pending-dcc-review {
    color: #3af
}

.indicator.status-not-eligible-for-new-data {
    color: #cc0700
}

.indicator.status-awaiting-lab-characterization {
    color: #ebe310
}

.indicator.status-not-pursued {
    color: #d0d0d0
}

.indicator.status-not-reviewed {
    color: #1475c9
}

.file-pdf, .file-generic, .file-missing {
    display: block;
    margin-left: auto;
    margin-right: auto;
    max-width: 100%;
    height: auto;
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
    width: 80%;
    height: 80%;
    background-position: center center;
    background-repeat: no-repeat;
    background-size: 80% 80%
}

.file-pdf {
    background-image: url(/static/img/file-pdf.svg)
}

.no-svg .file-pdf {
    background-image: url(/static/img/file-pdf.png)
}

.file-generic {
    background-image: url(/static/img/file.svg)
}

.no-svg .file-generic {
    background-image: url(/static/img/file.png)
}

.file-missing {
    background-image: url(/static/img/file-broken.svg)
}

.no-svg .file-missing {
    background-image: url(/static/img/file-broken.png)
}

.status-indicators {
    white-space: nowrap
}

.facet-term-key {
    margin-right: 5px;
    font-size: 15px;
    font-size: 1.1rem
}

.attachment {
    display: table-cell;
    vertical-align: middle
}

.characterization-badge .status-list {
    display: inline-block;
    width: auto
}

.characterization-badge .status-list .label {
    display: inline-block;
    margin: 3px 0 3px -7px;
    width: 100%;
    padding: 0 17px 0 10px;
    text-align: center;
    font-size: 12px;
    font-size: .85rem;
    line-height: 24px
}

.dl-link {
    word-break: break-all
}

.type-Document {
    margin-top: 0
}

.type-Document.view-detail, .type-Characterization.view-detail {
    padding: 0
}

.type-Document.view-detail figure, .type-Characterization.view-detail figure {
    position: relative;
    display: block;
    float: none;
    width: 100%;
    height: 64px;
    padding: 3px;
    margin: 0;
    padding: 0;
    border-left: 1px solid #e8e8e8;
    background-color: #fff
}

.type-Document.view-detail figure .attachment, .type-Characterization.view-detail figure .attachment, .type-Document.view-detail figure div.file-missing, .type-Characterization.view-detail figure div.file-missing {
    position: absolute;
    display: table;
    top: 0;
    left: 0;
    width: 64px;
    height: 64px;
    padding: 3px
}

.type-Document.view-detail figure .attachment .attachment-button, .type-Characterization.view-detail figure .attachment .attachment-button, .type-Document.view-detail figure div.file-missing .attachment-button, .type-Characterization.view-detail figure div.file-missing .attachment-button {
    position: relative;
    display: table-cell;
    height: 58px;
    width: 58px;
    text-align: center;
    vertical-align: middle;
    border-radius: 5px;
    border: 1px solid #a0a0a0;
    background-color: #f0f0f0
}

.type-Document.view-detail figure .attachment .attachment-button:hover, .type-Characterization.view-detail figure .attachment .attachment-button:hover, .type-Document.view-detail figure div.file-missing .attachment-button:hover, .type-Characterization.view-detail figure div.file-missing .attachment-button:hover {
    background-color: #e0e0e0
}

.type-Document.view-detail figure .attachment.file-pdf, .type-Characterization.view-detail figure .attachment.file-pdf, .type-Document.view-detail figure .attachment.file-generic, .type-Characterization.view-detail figure .attachment.file-generic, .type-Document.view-detail figure .attachment.file-missing, .type-Characterization.view-detail figure .attachment.file-missing, .type-Document.view-detail figure div.file-missing.file-pdf, .type-Characterization.view-detail figure div.file-missing.file-pdf, .type-Document.view-detail figure div.file-missing.file-generic, .type-Characterization.view-detail figure div.file-missing.file-generic, .type-Document.view-detail figure div.file-missing.file-missing, .type-Characterization.view-detail figure div.file-missing.file-missing {
    height: 58px
}

.type-Document.view-detail figure .attachment img, .type-Characterization.view-detail figure .attachment img, .type-Document.view-detail figure div.file-missing img, .type-Characterization.view-detail figure div.file-missing img {
    display: inline-block;
    max-height: 51.2px;
    max-width: 51.2px;
    height: auto;
    width: auto
}

@media screen and (min-width: 768px) {
    .type-Document.view-detail figure, .type-Characterization.view-detail figure {
        width: 64px;
        float: right;
        margin: 0 0 0 5px
    }
}

.type-Document.view-detail h3, .type-Characterization.view-detail h3 {
    line-height: normal
}

.type-Document .panel-body {
    padding: 0
}

.type-Characterization {
    margin-top: 0
}

.type-Characterization.view-detail {
    padding: 0
}

.type-Characterization.view-detail figure {
    position: relative;
    display: block;
    float: none;
    width: 100%;
    height: 64px;
    padding: 3px;
    margin: 0;
    padding: 0;
    border-left: 1px solid #e8e8e8;
    background-color: #fff
}

.type-Characterization.view-detail figure .attachment, .type-Characterization.view-detail figure div.file-missing {
    position: absolute;
    display: table;
    top: 0;
    left: 0;
    width: 64px;
    height: 64px;
    padding: 3px
}

.type-Characterization.view-detail figure .attachment .attachment-button, .type-Characterization.view-detail figure div.file-missing .attachment-button {
    position: relative;
    display: table-cell;
    height: 58px;
    width: 58px;
    text-align: center;
    vertical-align: middle;
    border-radius: 5px;
    border: 1px solid #a0a0a0;
    background-color: #f0f0f0
}

.type-Characterization.view-detail figure .attachment .attachment-button:hover, .type-Characterization.view-detail figure div.file-missing .attachment-button:hover {
    background-color: #e0e0e0
}

.type-Characterization.view-detail figure .attachment.file-pdf, .type-Characterization.view-detail figure .attachment.file-generic, .type-Characterization.view-detail figure .attachment.file-missing, .type-Characterization.view-detail figure div.file-missing.file-pdf, .type-Characterization.view-detail figure div.file-missing.file-generic, .type-Characterization.view-detail figure div.file-missing.file-missing {
    height: 58px
}

.type-Characterization.view-detail figure .attachment img, .type-Characterization.view-detail figure div.file-missing img {
    display: inline-block;
    max-height: 51.2px;
    max-width: 51.2px;
    height: auto;
    width: auto
}

@media screen and (min-width: 768px) {
    .type-Characterization.view-detail figure {
        width: 64px;
        float: right;
        margin: 0 0 0 5px
    }
}

.type-Characterization.view-detail h3 {
    line-height: normal
}

.type-Characterization .panel-body {
    padding: 0
}

.type-Characterization.type-AntibodyCharacterization {
    margin-top: 0
}

.type-Characterization.type-AntibodyCharacterization.view-detail {
    padding: 0
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure {
    position: relative;
    display: block;
    float: none;
    width: 100%;
    height: 64px;
    padding: 3px;
    margin: 0;
    padding: 0;
    border-left: 1px solid #e8e8e8;
    background-color: #fff
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing {
    position: absolute;
    display: table;
    top: 0;
    left: 0;
    width: 64px;
    height: 64px;
    padding: 3px
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment .attachment-button, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing .attachment-button {
    position: relative;
    display: table-cell;
    height: 58px;
    width: 58px;
    text-align: center;
    vertical-align: middle;
    border-radius: 5px;
    border: 1px solid #a0a0a0;
    background-color: #f0f0f0
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment .attachment-button:hover, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing .attachment-button:hover {
    background-color: #e0e0e0
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment.file-pdf, .type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment.file-generic, .type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment.file-missing, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing.file-pdf, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing.file-generic, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing.file-missing {
    height: 58px
}

.type-Characterization.type-AntibodyCharacterization.view-detail figure .attachment img, .type-Characterization.type-AntibodyCharacterization.view-detail figure div.file-missing img {
    display: inline-block;
    max-height: 51.2px;
    max-width: 51.2px;
    height: auto;
    width: auto
}

@media screen and (min-width: 768px) {
    .type-Characterization.type-AntibodyCharacterization.view-detail figure {
        width: 64px;
        float: right;
        margin: 0 0 0 5px
    }
}

.type-Characterization.type-AntibodyCharacterization.view-detail h3 {
    line-height: normal
}

.type-QualityMetric {
    margin-top: 0
}

.type-QualityMetric.view-detail {
    padding: 0
}

.type-QualityMetric.view-detail figure {
    position: relative;
    display: block;
    float: none;
    width: 100%;
    height: 96px;
    padding: 3px;
    margin: 0;
    padding: 0;
    border-left: 1px solid #e8e8e8;
    background-color: #fff
}

.type-QualityMetric.view-detail figure .attachment, .type-QualityMetric.view-detail figure div.file-missing {
    position: absolute;
    display: table;
    top: 0;
    left: 0;
    width: 96px;
    height: 96px;
    padding: 3px
}

.type-QualityMetric.view-detail figure .attachment .attachment-button, .type-QualityMetric.view-detail figure div.file-missing .attachment-button {
    position: relative;
    display: table-cell;
    height: 90px;
    width: 90px;
    text-align: center;
    vertical-align: middle;
    border-radius: 5px;
    border: 1px solid #a0a0a0;
    background-color: #f0f0f0
}

.type-QualityMetric.view-detail figure .attachment .attachment-button:hover, .type-QualityMetric.view-detail figure div.file-missing .attachment-button:hover {
    background-color: #e0e0e0
}

.type-QualityMetric.view-detail figure .attachment.file-pdf, .type-QualityMetric.view-detail figure .attachment.file-generic, .type-QualityMetric.view-detail figure .attachment.file-missing, .type-QualityMetric.view-detail figure div.file-missing.file-pdf, .type-QualityMetric.view-detail figure div.file-missing.file-generic, .type-QualityMetric.view-detail figure div.file-missing.file-missing {
    height: 90px
}

.type-QualityMetric.view-detail figure .attachment img, .type-QualityMetric.view-detail figure div.file-missing img {
    display: inline-block;
    max-height: 76.8px;
    max-width: 76.8px;
    height: auto;
    width: auto
}

@media screen and (min-width: 768px) {
    .type-QualityMetric.view-detail figure {
        width: 96px;
        float: right;
        margin: 0 0 0 5px
    }
}

.type-QualityMetric.view-detail h3 {
    line-height: normal
}

.document-header {
    height: auto;
    border-bottom: 1px solid #e8e8e8;
    overflow: hidden
}

@media screen and (min-width: 768px) {
    .document-header {
        height: 64px
    }
}

.characterization-header {
    height: auto;
    border-bottom: 1px solid #e8e8e8;
    overflow: hidden
}

@media screen and (min-width: 768px) {
    .characterization-header {
        height: 64px
    }
}

.characterization-header.panel-body {
    padding: 0
}

.quality-metric-header {
    height: auto;
    overflow: hidden
}

.document-intro, .characterization-intro {
    padding: 5px
}

.document-intro h3, .characterization-intro h3 {
    margin: 0;
    font-size: 17px;
    font-size: 1.2rem
}

.document-intro p, .characterization-intro p {
    margin: 2px 0 0 0;
    font-size: 14px;
    font-size: 1rem;
    word-wrap: break-word
}

.characterization-intro {
    padding: 10px
}

.dl-bar {
    position: relative;
    height: 30px;
    padding: 0 10px 0 10px;
    line-height: 30px;
    border-bottom: 1px solid #e8e8e8;
    white-space: nowrap;
    overflow: hidden
}

.detail-switch {
    position: absolute;
    top: 0;
    bottom: 0;
    right: 0;
    width: 30px;
    height: 30px;
    background-color: #fff;
    border-left: 1px solid #e8e8e8
}

.detail-switch:hover {
    background-color: #f0f0f0
}

.detail-switch.open {
    transition: 0.1s linear;
    background-color: #c0c0c0
}

.detail-trigger {
    display: block;
    height: 30px;
    line-height: 30px;
    font-size: 1.4rem;
    cursor: pointer;
    text-align: center;
    transition: 0.1s linear
}

.detail-trigger.collapsed {
    transform: rotate(90deg)
}

.key-value-trigger {
    display: block;
    width: 100%;
    margin: 0;
    background-color: #fff;
    text-align: center;
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
    background-size: 100%;
    background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #ffffff));
    background-image: -moz-linear-gradient(top, #ffffff 0%, #ffffff 100%);
    background-image: -webkit-linear-gradient(top, #ffffff 0%, #ffffff 100%);
    background-image: linear-gradient(to bottom, #ffffff 0%, #ffffff 100%);
    background-image: -ms-linear-gradient(top, #fff 0%, #fff 100%);
    border-top: 1px solid #808080 !important;
    border-bottom: none;
    border-left: none;
    border-right: none;
    padding: 0 10px;
    line-height: 32px;
    color: #333333
}

.key-value-trigger:hover {
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2YyZjJmMiIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
    background-size: 100%;
    background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ffffff), color-stop(100%, #f2f2f2));
    background-image: -moz-linear-gradient(top, #ffffff 0%, #f2f2f2 100%);
    background-image: -webkit-linear-gradient(top, #ffffff 0%, #f2f2f2 100%);
    background-image: linear-gradient(to bottom, #ffffff 0%, #f2f2f2 100%);
    background-image: -ms-linear-gradient(top, #fff 0%, #f2f2f2 100%)
}

.key-value-trigger:focus {
    outline: none;
    -moz-box-shadow: 0 0 3px 2px #94bfe7 inset;
    -webkit-box-shadow: 0 0 3px 2px #94bfe7 inset;
    box-shadow: 0 0 3px 2px #94bfe7 inset
}

.key-value-trigger.panel-footer {
    padding: 0
}

.document-slider {
    display: none;
    margin: 0;
    padding: 10px 5px;
    border-bottom: 1px solid #e8e8e8
}

.document-slider.active {
    display: block
}

.document-slider > div {
    margin-top: 10px
}

.document-slider > div:first-child {
    margin-top: 0
}

.characterization-slider {
    display: none
}

.characterization-slider.active {
    display: block
}

.characterization-slider-shadow {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%;
    height: 40px;
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIgc3RvcC1vcGFjaXR5PSIwLjAiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiMwMDAwMDAiIHN0b3Atb3BhY2l0eT0iMC4zIi8+PC9saW5lYXJHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
    background-size: 100%;
    background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, rgba(0, 0, 0, 0)), color-stop(100%, rgba(0, 0, 0, 0.3)));
    background-image: -moz-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 100%);
    background-image: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 100%);
    background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0.3) 100%)
}

.characterization-slider-shadow.active {
    display: none
}

.status-line {
    vertical-align: top
}

.journal, .author {
    font-size: 14px;
    font-size: 1rem
}

.facet-charts {
    transition: opacity 0.75s;
    opacity: 1;
    margin-top: 45px
}

.facet-charts.loading {
    opacity: 0.125;
    text-align: center
}

.facet-charts.loading > i {
    font-size: 2rem;
    color: #000;
    position: relative
}

.facet-charts .facet-charts-description {
    height: 30px;
    line-height: 30px;
    font-weight: 500;
    position: relative
}

.facet-charts > .facet-chart-row-1 > div {
    transition: width .75s ease-out;
    position: relative
}

@media screen and (max-width: 767px) {
    .facet-charts {
        height: auto !important;
        margin-top: 20px
    }
}

.chart-container {
    transition: opacity .75s, transform .75s ease-out;
    opacity: 1
}

.chart-container .chart {
    position: relative;
    transition: transform .75s ease-out, top .75s
}

.chart-container.no-data {
    opacity: 0
}

.chart-container.no-data .chart {
    transform: scale3d(0.8, 0.8, 0.8)
}

.chart-container div.y-axis-bottom {
    position: absolute;
    bottom: 0;
    transition: opacity .5s
}

.chart {
    position: relative
}

.chart-breadcrumbs-container .crumbs-title {
    font-weight: 500;
    margin-bottom: 6px;
    font-size: 1rem
}

.chart-breadcrumbs {
    position: relative;
    height: 26px;
    line-height: 26px;
    margin: 0
}

.chart-breadcrumbs .field-group {
    display: inline-block;
    margin-right: 14px;
    position: relative;
    z-index: 1;
    transition: z-index .5s
}

.chart-breadcrumbs .field-group > .field-label {
    position: absolute;
    bottom: -24px;
    font-size: 0.85rem;
    line-height: 12px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    left: -3px;
    min-width: 100%;
    width: 100%;
    box-sizing: content-box;
    padding: 5px 3px 4px 3px;
    text-transform: capitalize;
    border-radius: 1px;
    border-top: 1px solid transparent;
    box-shadow: 0px 5px 3px -14px transparent;
    transition: box-shadow .5s, width .5s, background-color .5s, border-color .5s
}

.chart-breadcrumbs .field-group:last-child {
    margin-right: 0
}

.chart-breadcrumbs .field-group:last-child > .field-label {
    overflow: visible
}

.chart-breadcrumbs .field-group:hover {
    z-index: 10
}

.chart-breadcrumbs .field-group:hover > .field-label {
    z-index: 10;
    width: 150px;
    background-color: #fff;
    border-top-color: #888
}

.chart-breadcrumbs .field-group:before {
    content: '';
    position: absolute;
    left: -3px;
    right: -3px;
    bottom: -3px;
    height: 3px;
    border: 1px solid #ccc;
    border-top: none
}

.chart-breadcrumbs .field-group:not(:last-child):after {
    content: "&";
    position: absolute;
    font-size: 0.8rem;
    right: -10px;
    color: #555
}

.chart-breadcrumbs .chart-crumb {
    display: inline-block;
    margin-bottom: 2px;
    height: inherit;
    line-height: inherit;
    position: relative;
    transition: opacity 0.5s, background-color .5s;
    color: #fff;
    font-weight: 500;
    padding: 0 12px;
    background-color: #248bac
}

.chart-breadcrumbs .chart-crumb > .icon-container {
    padding-left: 7px;
    cursor: pointer;
    opacity: 0.5
}

.chart-breadcrumbs .chart-crumb > .icon-container:hover {
    opacity: 1
}

.chart-breadcrumbs:not(.sequential) .chart-crumb {
    border-radius: 3px;
    position: relative
}

.chart-breadcrumbs:not(.sequential) .chart-crumb:not(:last-of-type) {
    margin-right: 7px
}

.chart-breadcrumbs:not(.sequential) .chart-crumb:not(:last-of-type):after {
    content: "|";
    position: absolute;
    font-size: 0.8rem;
    right: -5px;
    color: #555
}

.chart-breadcrumbs.sequential {
    overflow: visible;
    margin-left: -12px
}

.chart-breadcrumbs.sequential:before {
    content: '';
    position: absolute;
    z-index: 1;
    height: 54px;
    width: 12px;
    background-color: #fff;
    left: 0;
    top: 0
}

.chart-breadcrumbs.sequential .chart-crumb {
    padding: 0 12px 0 25px
}

.chart-breadcrumbs.sequential .chart-crumb:not(:first-child) {
    padding-left: 25px
}

.chart-breadcrumbs.sequential .chart-crumb:not(:last-child):after {
    content: '';
    position: absolute;
    transform: rotateZ(45deg);
    height: 18px;
    width: 18px;
    box-sizing: content-box;
    border-top: 2px solid #fff;
    border-right: 2px solid #fff;
    z-index: 2;
    background-color: inherit;
    right: -11px;
    top: 3px;
    color: #bbb
}

.chart-breadcrumbs.sequential .chart-crumb:first-child {
    border-top-left-radius: 3px;
    border-bottom-left-radius: 3px
}

.chart-breadcrumbs.sequential .chart-crumb:last-child {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 3px
}

.chart-breadcrumbs [data-field="experiments_in_set.biosample.biosource.biosource_type"] {
    text-transform: capitalize
}

.rotated-labels-axis {
    position: relative;
    display: block
}

.rotated-labels-axis .rotated-label {
    opacity: 1;
    transition: opacity .5s, transform .75s ease-out;
    position: absolute
}

.rotated-labels-axis .rotated-label > .label-text {
    display: block;
    transform-origin: 100% 0;
    text-align: right;
    position: relative;
    font-size: 0.85rem;
    line-height: 14px;
    transition: width .75s ease-out, left .75s ease-out
}

.rotated-labels-axis .rotated-label > .label-text.auto-rotation {
    transition: transform 1s, left 1s;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}

.rotated-labels-axis .rotated-label > .label-text .inner {
    position: relative
}

.rotated-labels-axis .rotated-label > .label-text .color-indicator {
    font-size: 0.85rem;
    position: absolute;
    left: -14px;
    display: block;
    line-height: 14px;
    width: 12px;
    text-align: center;
    transition: transform .5s;
    transform: scale3d(0.5, 0.5, 0.5)
}

.rotated-labels-axis .rotated-label > .label-text .append {
    position: absolute;
    right: -10px;
    top: 50%;
    margin-top: -7px;
    opacity: 0.33;
    transition: opacity 0.5s
}

.rotated-labels-axis .rotated-label > .label-text .append > i.icon, .rotated-labels-axis .rotated-label > .label-text .append > i.tcell-sort, .rotated-labels-axis .rotated-label > .label-text .append > i.tcell-asc, .rotated-labels-axis .rotated-label > .label-text .append > i.tcell-desc {
    width: 20px
}

.rotated-labels-axis .rotated-label.expanded > .label-text.extra-long {
    background: '#fff'
}

.rotated-labels-axis .rotated-label.expanded > .label-text.extra-long:after {
    content: none
}

.rotated-labels-axis .rotated-label:hover > .label-text .append, .rotated-labels-axis .rotated-label.highlight > .label-text .append {
    opacity: 1
}

.rotated-labels-axis .rotated-label:hover > .label-text .color-indicator, .rotated-labels-axis .rotated-label.highlight > .label-text .color-indicator {
    font-size: 0.85rem;
    transform: scale3d(1, 1, 1)
}

.bar-plot-chart {
    display: block;
    position: absolute;
    transition: height .75s ease-out
}

.bar-plot-chart line.y-axis-top {
    stroke: #ccc;
    stroke-width: 1px
}

.bar-plot-chart line.y-axis-bottom {
    stroke: #aaa;
    stroke-width: 1px
}

.bar-plot-chart .bar-plot-left-axis {
    border-right: 1px solid #ddd;
    position: absolute;
    left: 0;
    top: 0;
    transition: height .75s ease-out;
    z-index: 0
}

.bar-plot-chart .bar-plot-left-axis .axis-step {
    position: absolute;
    left: 0;
    right: 0;
    text-align: right;
    z-index: 0
}

.bar-plot-chart .bar-plot-left-axis .axis-step:before {
    content: '';
    border-top: 1px solid #ddd;
    width: 10px;
    right: 0;
    bottom: 0;
    position: absolute
}

.bar-plot-chart .bar-plot-left-axis .axis-step .axis-bg-line {
    border-top: 1px dotted #f0f0f0;
    width: 1000px;
    right: -1000px;
    position: absolute;
    display: block;
    top: -1px;
    transition: width .75s
}

.bar-plot-chart .bar-plot-left-axis .axis-step[data-tick-index="0"] .axis-bg-line {
    border-color: #eee
}

.bar-plot-chart .bar-plot-left-axis .axis-step.last .axis-label {
    display: none
}

.bar-plot-chart .bar-plot-left-axis .axis-step.last:before {
    border-top-color: #ddd;
    width: 5px
}

.bar-plot-chart .bar-plot-left-axis .axis-step .axis-label {
    text-align: right;
    position: absolute;
    right: 15px;
    font-size: 0.75rem;
    top: -8px
}

.bar-plot-chart .chart-bar {
    transition: transform .75s ease-out, opacity .5s, width .75s ease-out;
    position: absolute
}

.bar-plot-chart .chart-bar .bar-top-label {
    display: block;
    text-align: center;
    width: 100%
}

.bar-plot-chart .chart-bar.larger-height .bar-top-label {
    position: absolute;
    top: 50%;
    margin-top: -10px;
    color: #fff;
    z-index: 2
}

.bar-plot-chart .chart-bar .bar-part {
    opacity: 1;
    transition: opacity 0.5s, height .75s ease-out, width .75s, border-color .5s ease-out, outline .5s, box-shadow .5s;
    transition: opacity 0.5s, height .75s ease-out, width .75s, border-color .5s ease-out, outline .5s, box-shadow .5s, -webkit-filter .5s;
    transition: opacity 0.5s, height .75s ease-out, width .75s, border-color .5s ease-out, outline .5s, box-shadow .5s, filter .5s;
    box-shadow: none;
    width: 100%;
    transform: translate3d(0, 0, 0)
}

.bar-plot-chart .chart-bar .bar-part.hover {
    cursor: pointer
}

.bar-plot-chart .chart-bar .bar-part.hover, .bar-plot-chart .chart-bar .bar-part.selected {
    box-shadow: inset 0 0 0 3px rgba(0, 0, 0, 0.25)
}

.bar-plot-chart .chart-bar.highlight > .bar-part:not(.highlight) {
    opacity: 0.33;
    filter: saturate(0%);
    -webkit-filter: saturate(0%)
}

.bar-plot-chart .chart-bar > rect {
    fill-opacity: 1;
    transition: fill-opacity .5s
}

.bar-plot-chart .silhouette {
    opacity: 0.75;
    pointer-events: none
}

.bar-plot-chart .silhouette .chart-bar {
    transition: none !important
}

.bar-plot-chart .silhouette .chart-bar .bar-part {
    transition: none !important
}

@media screen and (max-width: 767px) {
    .bar-plot-chart {
        position: relative
    }
}

.bar-plot-chart-controls-wrapper {
    position: relative
}

.bar-plot-chart-controls-wrapper .dropdown-heading {
    margin-bottom: 4px;
    margin-top: 10px;
    font-weight: 400
}

.bar-plot-chart-controls-wrapper .dropdown-heading:first-child {
    margin-top: 0
}

.bar-plot-chart-controls-wrapper .overlay {
    position: absolute;
    left: 0;
    right: 0;
    top: 0;
    z-index: 10
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label {
    position: absolute;
    transform: rotate3d(0, 0, 1, -90deg);
    text-align: center;
    transform-origin: 0 100%;
    z-index: 100
}

@media screen and (min-width: 1250px) {
    .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label {
        left: -5px
    }
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:first-child, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:first-child {
    padding-right: 5px
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child {
    padding-left: 3px
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group {
    width: 100%
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .dropdown-toggle.btn.btn-xs, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .dropdown-toggle.btn.btn-xs, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.btn, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.btn, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.rf-RepeatingFieldset__add, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.rf-RepeatingFieldset__add, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .dropdown-toggle.btn-xs.rf-RepeatingFieldset__add, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .dropdown-toggle.btn-xs.rf-RepeatingFieldset__add {
    width: 100%;
    padding-right: 20px;
    text-align: left;
    padding-left: 10px
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .dropdown-toggle.btn.btn-xs span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .dropdown-toggle.btn.btn-xs span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.btn span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.btn span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.rf-RepeatingFieldset__add span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .btn-group-xs > .dropdown-toggle.rf-RepeatingFieldset__add span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .row > div:last-child .dropdown.btn-group .dropdown-toggle.btn-xs.rf-RepeatingFieldset__add span.caret, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label > .flexrow > div:last-child .dropdown.btn-group .dropdown-toggle.btn-xs.rf-RepeatingFieldset__add span.caret {
    position: absolute;
    right: 10px
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .dropdown-heading {
    margin: 0;
    line-height: 22px;
    white-space: nowrap;
    text-align: right
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .dropdown-toggle.btn.btn-xs, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .btn-group-xs > .dropdown-toggle.btn, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .btn-group-xs > .dropdown-toggle.rf-RepeatingFieldset__add, .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .dropdown-toggle.btn-xs.rf-RepeatingFieldset__add {
    padding-left: 8px;
    padding-right: 8px
}

.bar-plot-chart-controls-wrapper .overlay .y-axis-top-label .dropdown-menu {
    transform: rotate3d(0, 0, 1, 90deg);
    top: 54px;
    left: 10px;
    z-index: 100
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom {
    position: absolute;
    top: 3px;
    right: 0px;
    font-size: 1.35rem;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom .text {
    font-size: 0.85rem;
    line-height: 0.9rem;
    margin-right: 10px;
    display: inline-block;
    margin-top: -5px;
    vertical-align: baseline;
    text-align: right
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom i.icon, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom i.tcell-sort, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom i.tcell-asc, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom i.tcell-desc {
    vertical-align: middle;
    margin-right: 7px;
    font-size: 15px;
    transition: transform .75s ease-out, opacity .75s ease-out
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom > span.toggle-container {
    vertical-align: middle
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom.no-click {
    cursor: default;
    pointer-events: none
}

.bar-plot-chart-controls-wrapper .overlay .toggle-zoom.no-click i.icon, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom.no-click i.tcell-sort, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom.no-click i.tcell-asc, .bar-plot-chart-controls-wrapper .overlay .toggle-zoom.no-click i.tcell-desc {
    opacity: 0.25;
    transform: scale3d(0.8, 0.8, 0.8)
}

.bar-plot-chart-controls-wrapper .x-axis-right-label {
    position: relative
}

.bar-plot-chart-controls-wrapper .x-axis-right-label h6, .bar-plot-chart-controls-wrapper .x-axis-right-label h5, .bar-plot-chart-controls-wrapper .x-axis-right-label h4 {
    font-weight: 500;
    margin-bottom: 3px
}

.bar-plot-chart-controls-wrapper .dropdown {
    text-align: left
}

.bar-plot-chart-controls-wrapper .chart-aside .show-type-change-section {
    padding-bottom: 10px
}

.bar-plot-chart-controls-wrapper .chart-aside .x-axis-right-label > .row > div:last-child, .bar-plot-chart-controls-wrapper .chart-aside .x-axis-right-label > .flexrow > div:last-child {
    padding-left: 5px
}

.bar-plot-chart-controls-wrapper .chart-aside .x-axis-right-label > .row > div:first-child, .bar-plot-chart-controls-wrapper .chart-aside .x-axis-right-label > .flexrow > div:first-child {
    padding-right: 5px
}

.bar-plot-chart-controls-wrapper .chart-aside .x-axis-right-label .dropdown-heading {
    margin: 0;
    line-height: 33px;
    white-space: nowrap;
    text-align: right;
    font-weight: 400
}

.bar-plot-chart-controls-wrapper .chart-aside .dropdown {
    width: 100%
}

.bar-plot-chart-controls-wrapper .chart-aside .dropdown > button {
    width: 100%;
    text-align: left;
    overflow: hidden;
    text-overflow: ellipsis
}

.bar-plot-chart-controls-wrapper .chart-aside .dropdown > button span.caret {
    position: absolute
}

.bar-plot-chart-controls-wrapper .chart-aside .dropdown.btn-group-xs > button {
    overflow-x: hidden;
    text-overflow: ellipsis
}

.bar-plot-chart-controls-wrapper .chart-aside .legend-container {
    margin-bottom: 8px;
    border-bottom: 1px dotted #eee;
    overflow-y: auto;
    overflow-x: hidden
}

.bar-plot-chart-controls-wrapper .dropdown-title-container {
    vertical-align: middle;
    text-align: left;
    display: inline-block;
    padding-right: 5px;
    min-width: 120px
}

.bar-plot-chart-controls-wrapper .dropdown-title-container > small {
    font-weight: 400
}

.bar-plot-chart-controls-wrapper .dropdown-title-container h4, .bar-plot-chart-controls-wrapper .dropdown-title-container h5, .bar-plot-chart-controls-wrapper .dropdown-title-container h6 {
    margin: 0;
    font-weight: 600
}

.bar-plot-chart-controls-wrapper .dropdown-open-title {
    font-weight: 400;
    line-height: 1rem;
    font-size: 1.1rem;
    vertical-align: text-bottom
}

.bar-plot-chart-controls-wrapper .controls {
    text-align: right
}

.bar-plot-chart-controls-wrapper .controls .btn-toolbar {
    display: inline-block
}

@media screen and (max-width: 767px) {
    .bar-plot-chart-controls-wrapper {
        position: relative
    }

    .bar-plot-chart-controls-wrapper .overlay .y-axis-top-label {
        left: 10px
    }

    .bar-plot-chart-controls-wrapper .chart-aside {
        height: auto !important;
        margin-top: 30px
    }

    .bar-plot-chart-controls-wrapper .chart-aside .legend-container {
        height: auto !important;
        overflow: visible !important
    }
}

.chart-container-sunburst {
    position: relative
}

.fetching-view {
    display: block;
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    text-align: center;
    opacity: 1;
    background-color: rgba(255, 255, 255, 0.75);
    transition: opacity .5s;
    z-index: 10
}

.fetching-view.invisible {
    opacity: 0;
    z-index: -1
}

.fetching-view > .inner {
    top: 50%;
    margin-top: -20px;
    position: absolute;
    left: 0;
    right: 0;
    text-align: center
}

.fetching-view > .inner > i.icon, .fetching-view > .inner > i.tcell-sort, .fetching-view > .inner > i.tcell-asc, .fetching-view > .inner > i.tcell-desc {
    color: #888;
    font-size: 1.5rem
}

.chart-container-sunburst .chart, .chart-sunburst.chart-zoombox {
    position: relative
}

.chart-container-sunburst .chart path, .chart-sunburst.chart-zoombox path {
    stroke: #fff;
    transition: opacity 1s;
    opacity: 1;
    position: relative
}

.chart-container-sunburst .chart path.removing, .chart-sunburst.chart-zoombox path.removing {
    opacity: 0 !important;
    z-index: -1;
    transition: opacity .75s !important
}

.chart-container-sunburst .chart path.root-node, .chart-sunburst.chart-zoombox path.root-node {
    fill: #eee !important
}

.chart-container-sunburst .chart path.filtered-out, .chart-sunburst.chart-zoombox path.filtered-out {
    opacity: 0.1 !important;
    transition: opacity 1s !important
}

.chart-container-sunburst .chart path.term-is-not-set, .chart-sunburst.chart-zoombox path.term-is-not-set {
    opacity: 0.4
}

.chart-container-sunburst .chart g.field.highlight path, .chart-sunburst.chart-zoombox g.field.highlight path {
    opacity: 0.125
}

.chart-container-sunburst .chart g.field.highlight path.highlight, .chart-sunburst.chart-zoombox g.field.highlight path.highlight {
    opacity: 1
}

.chart-container-sunburst .chart .y-axis-top, .chart-sunburst.chart-zoombox .y-axis-top {
    position: relative;
    top: 0;
    left: 0;
    right: 0;
    height: 50px
}

.chart-container-sunburst .chart .y-axis-top .top-label, .chart-sunburst.chart-zoombox .y-axis-top .top-label {
    position: absolute;
    height: inherit;
    text-align: center;
    opacity: 0
}

.chart-container-sunburst .chart .y-axis-top .top-label.active, .chart-sunburst.chart-zoombox .y-axis-top .top-label.active {
    opacity: 0.5;
    cursor: pointer
}

.chart-container-sunburst .chart .y-axis-top .top-label.active:hover, .chart-sunburst.chart-zoombox .y-axis-top .top-label.active:hover {
    opacity: 0.75
}

.chart-container-sunburst .chart circle.bounding-circle, .chart-sunburst.chart-zoombox circle.bounding-circle {
    opacity: 0
}

.chart-container-sunburst .chart .explanation, .chart-sunburst.chart-zoombox .explanation {
    color: #888;
    opacity: 1;
    transition: opacity .3s;
    padding-top: 14px
}

.chart-container-sunburst .chart .explanation.align-to-right, .chart-sunburst.chart-zoombox .explanation.align-to-right {
    text-align: right;
    position: absolute;
    right: 0;
    bottom: 0;
    padding-top: 2px;
    border-top: 1px solid #ddd
}

.chart-container-sunburst .chart .explanation.invisible, .chart-sunburst.chart-zoombox .explanation.invisible {
    opacity: 0;
    transition: opacity 1s
}

.chart-container-sunburst .chart .explanation .experiments-count, .chart-sunburst.chart-zoombox .explanation .experiments-count {
    font-size: 1.5rem;
    line-height: 2rem;
    font-weight: 300;
    color: #646464;
    transition: color 0.3s
}

.chart-container-sunburst .chart .explanation .experiments-count.invisible, .chart-sunburst.chart-zoombox .explanation .experiments-count.invisible {
    opacity: 0;
    transition: opacity 1s
}

.chart-container-sunburst .chart .explanation .experiments-count.half-visible, .chart-sunburst.chart-zoombox .explanation .experiments-count.half-visible {
    color: rgba(100, 100, 100, 0.66)
}

.chart-container-sunburst .chart .explanation .experiments-count:not(.align-to-right), .chart-sunburst.chart-zoombox .explanation .experiments-count:not(.align-to-right) {
    display: inline-block
}

.chart-container-sunburst .chart .explanation .experiments-count-label, .chart-sunburst.chart-zoombox .explanation .experiments-count-label {
    position: relative;
    display: inline-block;
    font-size: 1.125rem;
    line-height: 1rem;
    margin-left: 7px;
    top: -2px;
    transition: opacity 1s;
    opacity: 0.66;
    font-weight: 300
}

.chart-container-sunburst .chart .explanation .experiments-count-label.align-to-right, .chart-sunburst.chart-zoombox .explanation .experiments-count-label.align-to-right {
    display: block;
    margin-left: 0;
    top: -1px
}

.facet-charts.show-small .chart-container-sunburst .chart .explanation .experiments-count-label, .facet-charts.show-small .chart-sunburst.chart-zoombox .explanation .experiments-count-label {
    font-size: .975rem
}

.chart-container-sunburst .chart .explanation-old, .chart-sunburst.chart-zoombox .explanation-old {
    position: absolute;
    top: 50%;
    left: 50%;
    margin-top: -100px;
    width: 140px;
    text-align: center;
    color: #888;
    z-index: -1;
    opacity: 1;
    transition: opacity .3s
}

.chart-container-sunburst .chart .explanation-old.invisible, .chart-sunburst.chart-zoombox .explanation-old.invisible {
    opacity: 0;
    transition: opacity 1s
}

.chart-container-sunburst .chart .explanation-old .experiments-count, .chart-sunburst.chart-zoombox .explanation-old .experiments-count {
    font-size: 1.5rem;
    line-height: 2rem;
    font-weight: 300;
    color: #646464;
    transition: color 0.3s
}

.facet-charts.show-large .chart-container-sunburst .chart .explanation-old .experiments-count, .facet-charts.show-large .chart-sunburst.chart-zoombox .explanation-old .experiments-count {
    font-size: 2.5rem;
    font-weight: 300;
    line-height: 3rem
}

.chart-container-sunburst .chart .explanation-old .experiments-count.invisible, .chart-sunburst.chart-zoombox .explanation-old .experiments-count.invisible {
    opacity: 0;
    transition: opacity 1s
}

.chart-container-sunburst .chart .explanation-old .experiments-count.half-visible, .chart-sunburst.chart-zoombox .explanation-old .experiments-count.half-visible {
    color: rgba(100, 100, 100, 0.66)
}

.chart-container-sunburst .chart .explanation-old .experiments-count:after, .chart-sunburst.chart-zoombox .explanation-old .experiments-count:after {
    content: "Experiments";
    position: relative;
    font-size: 1.125rem;
    line-height: 1rem;
    display: block;
    width: 100%;
    text-align: center
}

.facet-charts.show-small .chart-container-sunburst .chart .explanation-old .experiments-count:after, .facet-charts.show-small .chart-sunburst.chart-zoombox .explanation-old .experiments-count:after {
    font-size: .975rem
}

.chart-container-sunburst:hover .chart .explanation .experiments-count-label {
    opacity: 1
}

.legend-expand-container.expanded {
    position: absolute;
    top: 0;
    z-index: 10;
    background: #fff;
    box-shadow: 0 0 10px rgba(0, 0, 0, 0.33)
}

.chart-color-legend {
    padding: 9px 12px 9px;
    background-color: #fff;
    min-width: 160px;
    opacity: 1;
    transition: opacity .75s
}

.chart-color-legend > .expand-toggle {
    float: right;
    width: 20px;
    line-height: 20px;
    margin-right: -2px;
    opacity: 0.33;
    cursor: pointer
}

.chart-color-legend > .expand-toggle:hover {
    opacity: 1
}

.chart-color-legend.expanded {
    background: #fff;
    padding-top: 11px
}

.chart-color-legend.expanded > .expand-toggle {
    opacity: 1
}

.chart-color-legend .legend-title {
    margin-bottom: 1px;
    margin-top: 0px
}

.chart-color-legend .highlight .color-patch {
    opacity: 0.125
}

.chart-color-legend .highlight .color-patch.highlight {
    opacity: 1
}

.chart-color-legend .field .legend-field-title {
    margin-top: 1px
}

.chart-color-legend .field > .color-patch {
    width: 10px;
    height: 10px;
    border-radius: 50%
}

.chart-color-legend .field .term {
    font-size: 0.85rem
}

.color-patch {
    display: inline-block;
    height: 12px;
    width: 12px;
    margin-right: 6px;
    position: relative;
    top: 1px;
    background-color: transparent;
    transition: opacity .25s, background-color .5s ease-out
}

.worfklow-chart-outer-container .workflow-chart-inner-container {
    position: relative;
    height: 100%;
    width: 100%;
    overflow-y: hidden;
    overflow-x: visible
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container-wrapper {
    overflow-x: auto;
    overflow-y: visible
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container {
    overflow: hidden;
    position: relative;
    transition: height .5s ease-out
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper {
    position: absolute;
    left: 0;
    top: 0
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper {
    pointer-events: none
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer {
    pointer-events: inherit;
    position: relative
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node {
    pointer-events: all;
    position: absolute;
    transition: top .5s ease-out, left .5s ease-out, width .5s ease-out, opacity .5s .25s ease-out;
    transform: translate3d(0, 0, 0);
    cursor: pointer
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element {
    background-color: #ddd;
    white-space: nowrap
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element > .node-name {
    padding-left: 2px;
    padding-right: 5px;
    display: inline-block;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element i.icon.icon-fw, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element i.icon-fw.tcell-sort, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element i.icon-fw.tcell-asc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .node-visible-element i.icon-fw.tcell-desc {
    margin-right: 5px;
    margin-left: 1px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .below-node-title {
    pointer-events: none;
    position: absolute;
    left: 0px;
    transform: translate3d(0px, 0px, 0);
    transition: opacity .25s ease-out, transform .33s ease-out;
    opacity: 1;
    font-size: 75%;
    line-height: 12px;
    background: rgba(255, 255, 255, 0.95)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .above-node-title {
    top: -16px;
    box-shadow: -1px -2px 9px 3px rgba(255, 255, 255, 0.95)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .below-node-title {
    bottom: -16px;
    transform: translate3d(0px, 0px, 0);
    box-shadow: -1px 2px 7px 2px rgba(255, 255, 255, 0.95)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node > .inner .below-node-title .lighter {
    opacity: 0.66
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-selected="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-related="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node:hover > .inner .above-node-title {
    transform: translate3d(0px, -6px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-selected="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-related="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node:hover > .inner .below-node-title {
    transform: translate3d(0px, 6px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-selected="true"] > .inner .below-node-title .lighter, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node[data-node-related="true"] > .inner .below-node-title .lighter, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node:hover > .inner .below-node-title .lighter {
    opacity: 1
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.disabled {
    opacity: 0.33
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.disabled.node-type-input:before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.disabled.node-type-output:before {
    background-color: #ddd !important
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-step {
    margin-top: -20px;
    outline: 2px solid transparent;
    outline-offset: 4px;
    transition: top .5s ease-out, left .5s ease-out, width .5s ease-out, opacity .5s .25s ease-out, outline-color .2s
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-step > .inner .node-visible-element {
    height: 40px;
    line-height: 18px;
    padding-top: 10px;
    padding-bottom: 10px;
    background-color: #b0c4da;
    border-radius: 2px;
    border: 1px solid rgba(0, 0, 0, 0.2)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-step > .inner .node-visible-element > .node-name {
    padding-left: 10px;
    padding-right: 4px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-step:hover {
    outline-color: #ddd
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-step[data-node-selected="true"] {
    outline-color: #000
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group {
    margin-top: -14px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input:before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output:before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:before {
    display: block;
    content: ' ';
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    background-color: #e0e0e0;
    transform: skewX(25deg);
    z-index: 1;
    outline: 2px solid transparent;
    outline-offset: 4px;
    transition: outline-color .2s, outline-width .2s
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element {
    height: 28px;
    line-height: 18px;
    padding-top: 5px;
    padding-bottom: 5px;
    display: inline-block;
    vertical-align: middle;
    position: relative;
    z-index: 5;
    background-color: transparent;
    width: 100%;
    transition: opacity .5s .25s ease-out
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name {
    padding-left: 7px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name.mono-text, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name.mono-text, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text {
    transform: translateY(-1px);
    transform: translateY(-0.5px)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.icon, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.icon, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.icon, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.icon, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc {
    transform: translateY(1px);
    transform: translateY(0.5px)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .above-node-title {
    transform: translate3d(-6px, 0px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .below-node-title {
    transform: translate3d(6px, 0px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-selected="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-related="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input:hover > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-selected="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-related="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output:hover > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-selected="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-related="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:hover > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-selected="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-related="true"] > .inner .above-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:hover > .inner .above-node-title {
    transform: translate3d(-6px, -6px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-selected="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-related="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input:hover > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-selected="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-related="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output:hover > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-selected="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-related="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:hover > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-selected="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-related="true"] > .inner .below-node-title, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:hover > .inner .below-node-title {
    transform: translate3d(6px, 5px, 0)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input:hover:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output:hover:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:hover:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:hover:not(.disabled):before {
    outline-color: #ddd
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-selected="true"]:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-selected="true"]:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-selected="true"]:not(.disabled):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-selected="true"]:not(.disabled):before {
    outline-color: #000
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before {
    outline-color: rgba(0, 0, 0, 0.55);
    outline-width: 1px;
    outline-style: dashed
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-global="true"]:before {
    background-color: #d5eac3
}

.workflow-viewing-basic .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-global="true"]:after {
    content: '';
    top: 50%;
    margin-top: -1px;
    height: 1px;
    width: 10px;
    background-color: #555;
    position: absolute;
    right: -15px
}

.workflow-viewing-basic .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output[data-node-global="true"][data-node-selected="true"]:after {
    height: 2px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output.current-context:before {
    background-color: #ffb3b3;
    transition: outline-offset .5s
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output.current-context:not([data-node-selected="true"]):not(:hover):before {
    outline-offset: 9px;
    outline-color: rgba(0, 0, 0, 0.75);
    outline-style: dotted;
    outline-width: 1px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output.current-context .node-name {
    font-weight: 500
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-global="true"]:before {
    background-color: #cdc5f3
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-global="true"][data-node-type-detail="Workflow Parameter"]:before {
    background-color: #cfdff1
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-global="true"]:after {
    content: "\f111";
    font-family: FontAwesome;
    top: 50%;
    font-size: 0.5rem;
    margin-top: -3px;
    height: 10px;
    width: 10px;
    text-align: center;
    position: absolute;
    left: -15px;
    opacity: 0.75;
    transition: left .25s, opacity .25s
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input[data-node-global="true"][data-node-selected="true"]:after {
    opacity: 1;
    left: -20px;
    font-size: 0.66rem;
    margin-top: -5px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input.node-item-type-file-reference:before {
    background-color: #e7e3f9
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group {
    margin-top: -25.2px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner {
    font-weight: 500
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group > .inner .node-visible-element, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group > .inner .node-visible-element {
    height: 50.4px;
    padding-top: 16.2px;
    padding-bottom: 16.2px;
    padding-left: 7px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:before, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:before {
    background-color: #b0da8b;
    border-radius: 5px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:after, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:after {
    content: "\f111";
    font-family: FontAwesome;
    top: 50%;
    font-size: 0.5rem;
    margin-top: -3px;
    height: 10px;
    width: 10px;
    text-align: center;
    position: absolute;
    left: -15px;
    opacity: 0.75;
    transition: left .25s, opacity .25s
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group[data-node-selected="true"]:after, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group[data-node-selected="true"]:after {
    opacity: 1;
    left: -20px;
    font-size: 0.66rem;
    margin-top: -5px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-input-group:after, .worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .nodes-layer-wrapper .nodes-layer .node.node-type-output-group:after {
    content: "\f141"
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper {
    pointer-events: none
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer {
    pointer-events: inherit
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path.pathArrow-marker {
    fill: #333;
    stroke: none
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path {
    pointer-events: all;
    stroke: #888;
    stroke: rgba(58, 58, 58, 0.75);
    fill: none;
    stroke-width: 1px;
    stroke-width: 1.5px;
    transition: stroke-width .3s, opacity .5s .25s ease-out
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path:hover {
    stroke: #000;
    stroke-width: 2px
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path[data-edge-selected="true"] {
    stroke-width: 3px;
    stroke: #000
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path[data-edge-related="true"]:not([data-edge-selected="true"]) {
    stroke-width: 3px;
    stroke: rgba(0, 0, 0, 0.75)
}

.worfklow-chart-outer-container .workflow-chart-inner-container .scroll-container .edges-layer-wrapper .edges-layer path.disabled {
    stroke-width: 1px;
    opacity: 0.33
}

.workflow-legend-container > .inner {
    position: relative;
    min-height: 80px
}

.workflow-legend-container > .inner .node-default {
    background-color: #ddd
}

.workflow-legend-container > .inner .node-type-step {
    background-color: #b0c4da
}

.workflow-legend-container > .inner .node-type-io-default {
    background-color: #e0e0e0
}

.workflow-legend-container > .inner .node-type-global-input {
    background-color: #cdc5f3
}

.workflow-legend-container > .inner .node-type-global-group {
    background-color: #b0da8b
}

.workflow-legend-container > .inner .node-type-global-output {
    background-color: #d5eac3
}

.workflow-legend-container > .inner .node-type-parameter {
    background-color: #cfdff1
}

.workflow-legend-container > .inner .node-type-input-file-reference {
    background-color: #e7e3f9
}

.workflow-legend-container > .inner .node-type-global-context {
    background-color: #ffb3b3
}

.workflow-legend-container > .inner .node-disabled {
    background-color: #ddd;
    opacity: 0.5
}

.workflow-legend-container > .inner .node {
    pointer-events: all;
    position: absolute;
    transition: top .5s ease-out, left .5s ease-out, width .5s ease-out, opacity .5s .25s ease-out;
    transform: translate3d(0, 0, 0);
    cursor: pointer
}

.workflow-legend-container > .inner .node > .inner .node-visible-element {
    background-color: #ddd;
    white-space: nowrap
}

.workflow-legend-container > .inner .node > .inner .node-visible-element > .node-name {
    padding-left: 2px;
    padding-right: 5px;
    display: inline-block;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis
}

.workflow-legend-container > .inner .node > .inner .node-visible-element i.icon.icon-fw, .workflow-legend-container > .inner .node > .inner .node-visible-element i.icon-fw.tcell-sort, .workflow-legend-container > .inner .node > .inner .node-visible-element i.icon-fw.tcell-asc, .workflow-legend-container > .inner .node > .inner .node-visible-element i.icon-fw.tcell-desc {
    margin-right: 5px;
    margin-left: 1px
}

.workflow-legend-container > .inner .node > .inner .above-node-title, .workflow-legend-container > .inner .node > .inner .below-node-title {
    pointer-events: none;
    position: absolute;
    left: 0px;
    transform: translate3d(0px, 0px, 0);
    transition: opacity .25s ease-out, transform .33s ease-out;
    opacity: 1;
    font-size: 75%;
    line-height: 12px;
    background: rgba(255, 255, 255, 0.95)
}

.workflow-legend-container > .inner .node > .inner .above-node-title {
    top: -16px;
    box-shadow: -1px -2px 9px 3px rgba(255, 255, 255, 0.95)
}

.workflow-legend-container > .inner .node > .inner .below-node-title {
    bottom: -16px;
    transform: translate3d(0px, 0px, 0);
    box-shadow: -1px 2px 7px 2px rgba(255, 255, 255, 0.95)
}

.workflow-legend-container > .inner .node > .inner .below-node-title .lighter {
    opacity: 0.66
}

.workflow-legend-container > .inner .node[data-node-selected="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node[data-node-related="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node:hover > .inner .above-node-title {
    transform: translate3d(0px, -6px, 0)
}

.workflow-legend-container > .inner .node[data-node-selected="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node[data-node-related="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node:hover > .inner .below-node-title {
    transform: translate3d(0px, 6px, 0)
}

.workflow-legend-container > .inner .node[data-node-selected="true"] > .inner .below-node-title .lighter, .workflow-legend-container > .inner .node[data-node-related="true"] > .inner .below-node-title .lighter, .workflow-legend-container > .inner .node:hover > .inner .below-node-title .lighter {
    opacity: 1
}

.workflow-legend-container > .inner .node.disabled {
    opacity: 0.33
}

.workflow-legend-container > .inner .node.disabled.node-type-input:before, .workflow-legend-container > .inner .node.disabled.node-type-output:before {
    background-color: #ddd !important
}

.workflow-legend-container > .inner .node.node-type-step {
    margin-top: -20px;
    outline: 2px solid transparent;
    outline-offset: 4px;
    transition: top .5s ease-out, left .5s ease-out, width .5s ease-out, opacity .5s .25s ease-out, outline-color .2s
}

.workflow-legend-container > .inner .node.node-type-step > .inner .node-visible-element {
    height: 40px;
    line-height: 18px;
    padding-top: 10px;
    padding-bottom: 10px;
    background-color: #b0c4da;
    border-radius: 2px;
    border: 1px solid rgba(0, 0, 0, 0.2)
}

.workflow-legend-container > .inner .node.node-type-step > .inner .node-visible-element > .node-name {
    padding-left: 10px;
    padding-right: 4px
}

.workflow-legend-container > .inner .node.node-type-step:hover {
    outline-color: #ddd
}

.workflow-legend-container > .inner .node.node-type-step[data-node-selected="true"] {
    outline-color: #000
}

.workflow-legend-container > .inner .node.node-type-input, .workflow-legend-container > .inner .node.node-type-output, .workflow-legend-container > .inner .node.node-type-input-group, .workflow-legend-container > .inner .node.node-type-output-group {
    margin-top: -14px
}

.workflow-legend-container > .inner .node.node-type-input:before, .workflow-legend-container > .inner .node.node-type-output:before, .workflow-legend-container > .inner .node.node-type-input-group:before, .workflow-legend-container > .inner .node.node-type-output-group:before {
    display: block;
    content: ' ';
    position: absolute;
    left: 0;
    top: 0;
    bottom: 0;
    right: 0;
    background-color: #e0e0e0;
    transform: skewX(25deg);
    z-index: 1;
    outline: 2px solid transparent;
    outline-offset: 4px;
    transition: outline-color .2s, outline-width .2s
}

.workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element {
    height: 28px;
    line-height: 18px;
    padding-top: 5px;
    padding-bottom: 5px;
    display: inline-block;
    vertical-align: middle;
    position: relative;
    z-index: 5;
    background-color: transparent;
    width: 100%;
    transition: opacity .5s .25s ease-out
}

.workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name {
    padding-left: 7px
}

.workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name.mono-text, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name.mono-text, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text {
    transform: translateY(-1px);
    transform: translateY(-0.5px)
}

.workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.icon, .workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .workflow-legend-container > .inner .node.node-type-input > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.icon, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .workflow-legend-container > .inner .node.node-type-output > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.icon, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.icon, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-sort, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-asc, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element > .node-name.mono-text > i.tcell-desc {
    transform: translateY(1px);
    transform: translateY(0.5px)
}

.workflow-legend-container > .inner .node.node-type-input > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input-group > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output-group > .inner .above-node-title {
    transform: translate3d(-6px, 0px, 0)
}

.workflow-legend-container > .inner .node.node-type-input > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input-group > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output-group > .inner .below-node-title {
    transform: translate3d(6px, 0px, 0)
}

.workflow-legend-container > .inner .node.node-type-input[data-node-selected="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input[data-node-related="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input:hover > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output[data-node-selected="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output[data-node-related="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output:hover > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input-group[data-node-selected="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input-group[data-node-related="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-input-group:hover > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output-group[data-node-selected="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output-group[data-node-related="true"] > .inner .above-node-title, .workflow-legend-container > .inner .node.node-type-output-group:hover > .inner .above-node-title {
    transform: translate3d(-6px, -6px, 0)
}

.workflow-legend-container > .inner .node.node-type-input[data-node-selected="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input[data-node-related="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input:hover > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output[data-node-selected="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output[data-node-related="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output:hover > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input-group[data-node-selected="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input-group[data-node-related="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-input-group:hover > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output-group[data-node-selected="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output-group[data-node-related="true"] > .inner .below-node-title, .workflow-legend-container > .inner .node.node-type-output-group:hover > .inner .below-node-title {
    transform: translate3d(6px, 5px, 0)
}

.workflow-legend-container > .inner .node.node-type-input:hover:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-output:hover:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-input-group:hover:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-output-group:hover:not(.disabled):before {
    outline-color: #ddd
}

.workflow-legend-container > .inner .node.node-type-input[data-node-selected="true"]:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-output[data-node-selected="true"]:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-input-group[data-node-selected="true"]:not(.disabled):before, .workflow-legend-container > .inner .node.node-type-output-group[data-node-selected="true"]:not(.disabled):before {
    outline-color: #000
}

.workflow-legend-container > .inner .node.node-type-input[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .workflow-legend-container > .inner .node.node-type-output[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .workflow-legend-container > .inner .node.node-type-input-group[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before, .workflow-legend-container > .inner .node.node-type-output-group[data-node-related="true"]:not(.disabled):not([data-node-selected="true"]):before {
    outline-color: rgba(0, 0, 0, 0.55);
    outline-width: 1px;
    outline-style: dashed
}

.workflow-legend-container > .inner .node.node-type-output[data-node-global="true"]:before {
    background-color: #d5eac3
}

.workflow-viewing-basic .workflow-legend-container > .inner .node.node-type-output[data-node-global="true"]:after {
    content: '';
    top: 50%;
    margin-top: -1px;
    height: 1px;
    width: 10px;
    background-color: #555;
    position: absolute;
    right: -15px
}

.workflow-viewing-basic .workflow-legend-container > .inner .node.node-type-output[data-node-global="true"][data-node-selected="true"]:after {
    height: 2px
}

.workflow-legend-container > .inner .node.node-type-output.current-context:before {
    background-color: #ffb3b3;
    transition: outline-offset .5s
}

.workflow-legend-container > .inner .node.node-type-output.current-context:not([data-node-selected="true"]):not(:hover):before {
    outline-offset: 9px;
    outline-color: rgba(0, 0, 0, 0.75);
    outline-style: dotted;
    outline-width: 1px
}

.workflow-legend-container > .inner .node.node-type-output.current-context .node-name {
    font-weight: 500
}

.workflow-legend-container > .inner .node.node-type-input[data-node-global="true"]:before {
    background-color: #cdc5f3
}

.workflow-legend-container > .inner .node.node-type-input[data-node-global="true"][data-node-type-detail="Workflow Parameter"]:before {
    background-color: #cfdff1
}

.workflow-legend-container > .inner .node.node-type-input[data-node-global="true"]:after {
    content: "\f111";
    font-family: FontAwesome;
    top: 50%;
    font-size: 0.5rem;
    margin-top: -3px;
    height: 10px;
    width: 10px;
    text-align: center;
    position: absolute;
    left: -15px;
    opacity: 0.75;
    transition: left .25s, opacity .25s
}

.workflow-legend-container > .inner .node.node-type-input[data-node-global="true"][data-node-selected="true"]:after {
    opacity: 1;
    left: -20px;
    font-size: 0.66rem;
    margin-top: -5px
}

.workflow-legend-container > .inner .node.node-type-input.node-item-type-file-reference:before {
    background-color: #e7e3f9
}

.workflow-legend-container > .inner .node.node-type-input-group, .workflow-legend-container > .inner .node.node-type-output-group {
    margin-top: -25.2px
}

.workflow-legend-container > .inner .node.node-type-input-group > .inner, .workflow-legend-container > .inner .node.node-type-output-group > .inner {
    font-weight: 500
}

.workflow-legend-container > .inner .node.node-type-input-group > .inner .node-visible-element, .workflow-legend-container > .inner .node.node-type-output-group > .inner .node-visible-element {
    height: 50.4px;
    padding-top: 16.2px;
    padding-bottom: 16.2px;
    padding-left: 7px
}

.workflow-legend-container > .inner .node.node-type-input-group:before, .workflow-legend-container > .inner .node.node-type-output-group:before {
    background-color: #b0da8b;
    border-radius: 5px
}

.workflow-legend-container > .inner .node.node-type-input-group:after, .workflow-legend-container > .inner .node.node-type-output-group:after {
    content: "\f111";
    font-family: FontAwesome;
    top: 50%;
    font-size: 0.5rem;
    margin-top: -3px;
    height: 10px;
    width: 10px;
    text-align: center;
    position: absolute;
    left: -15px;
    opacity: 0.75;
    transition: left .25s, opacity .25s
}

.workflow-legend-container > .inner .node.node-type-input-group[data-node-selected="true"]:after, .workflow-legend-container > .inner .node.node-type-output-group[data-node-selected="true"]:after {
    opacity: 1;
    left: -20px;
    font-size: 0.66rem;
    margin-top: -5px
}

.workflow-legend-container > .inner .node.node-type-input-group:after, .workflow-legend-container > .inner .node.node-type-output-group:after {
    content: "\f141"
}

.workflow-legend-container > .inner svg {
    width: 100%
}

.workflow-legend-container > .inner svg path.pathArrow-marker {
    fill: #333;
    stroke: none
}

.workflow-legend-container > .inner svg path {
    pointer-events: all;
    stroke: #888;
    stroke: rgba(58, 58, 58, 0.75);
    fill: none;
    stroke-width: 1px;
    stroke-width: 1.5px;
    transition: stroke-width .3s, opacity .5s .25s ease-out
}

.workflow-legend-container > .inner svg path:hover {
    stroke: #000;
    stroke-width: 2px
}

.workflow-legend-container > .inner svg path[data-edge-selected="true"] {
    stroke-width: 3px;
    stroke: #000
}

.workflow-legend-container > .inner svg path[data-edge-related="true"]:not([data-edge-selected="true"]) {
    stroke-width: 3px;
    stroke: rgba(0, 0, 0, 0.75)
}

.workflow-legend-container > .inner svg path.disabled {
    stroke-width: 1px;
    opacity: 0.33
}

.workflow-view-controls-container {
    font-size: 1rem;
    margin-bottom: 8px;
    padding-top: 10px;
    padding-left: 5px;
    float: right;
    padding-top: 17px
}

.workflow-view-controls-container button.toggle-open-button:active, .workflow-view-controls-container button.toggle-open-button:focus, .workflow-view-controls-container button.toggle-open-button.focus, .workflow-view-controls-container button.toggle-open-button:focus.active, .workflow-view-controls-container button.toggle-open-button.focus:active, .workflow-view-controls-container button.toggle-open-button.focus:focus {
    outline: none
}

.workflow-view-controls-container > .inner-panel {
    float: left
}

.workflow-view-controls-container > .inner-panel > div.inline-block {
    vertical-align: middle;
    line-height: 20px;
    height: 34px
}

.workflow-view-controls-container > .inner-panel > div.inline-block button#rowspacingtype-select {
    min-width: 120px
}

.workflow-view-controls-container > .inner-panel:not(.constant-panel) > div.inline-block.show-params-checkbox-container {
    padding: 8px 12px 6px 0;
    vertical-align: middle;
    font-size: 0.9rem;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}

.workflow-view-controls-container > .inner-panel:not(.constant-panel) > div.inline-block.show-params-checkbox-container div.checkbox {
    margin: 0
}

.workflow-view-controls-container > .inner-panel:not(.constant-panel) > div.inline-block.show-params-checkbox-container div.checkbox input[type="checkbox"] {
    margin-top: 3px
}

@media screen and (max-width: 1199px) {
    .workflow-view-controls-container > .inner-panel:not(.constant-panel) > div.inline-block {
        display: block
    }

    .workflow-view-controls-container > .inner-panel:not(.constant-panel) > div.inline-block.show-params-checkbox-container {
        padding-top: 5px;
        padding-bottom: 5px;
        height: auto
    }
}

.workflow-view-controls-container > .inner-panel.constant-panel > div.inline-block {
    display: table-cell;
    padding-left: 3px
}

@media screen and (min-width: 1200px) {
    .workflow-view-controls-container > .inner-panel > div.inline-block {
        display: table-cell;
        padding-left: 3px
    }
}

@media screen and (max-width: 1199px) {
    .workflow-view-controls-container {
        float: left
    }

    .workflow-view-controls-container > .inner-panel:first-child {
        padding-right: 10px
    }
}

.cursor-component-container {
    z-index: 1000;
    position: absolute;
    top: 0;
    left: 0;
    opacity: 1;
    transition: opacity .25s, transform .05s linear, margin-left 0s .05s
}

.cursor-component-container:not(.sticky) {
    pointer-events: none
}

.cursor-component-container .mosaic-cursor-body {
    background-color: #fff;
    box-shadow: 0px 1px 6px rgba(0, 0, 0, 0.3);
    border-radius: 5px;
    overflow: hidden
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs {
    padding: 6px 10px 5px;
    border-bottom: 1px dotted #ddd
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb-header {
    font-size: 0.825rem;
    padding-bottom: 7px;
    margin-bottom: 6px;
    border-bottom: 1px dotted #ccc
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs.no-children {
    padding-bottom: 0;
    border-bottom: none
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs.no-children .crumb-header {
    margin-bottom: 0
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb {
    position: relative;
    font-size: 0.75rem;
    padding-top: 1px
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb > * {
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb .field {
    font-weight: 300;
    padding-right: 0;
    position: relative
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb .field:after {
    content: ':'
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb:not([data-depth="0"]) .field:before {
    content: '>';
    position: absolute;
    margin-left: -10px;
    font-weight: 200;
    color: #aaa
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb .name {
    padding-left: 5px;
    padding-right: 0px
}

.cursor-component-container .mosaic-cursor-body .detail-crumbs .crumb .count {
    padding-left: 5px;
    overflow: visible
}

.cursor-component-container .mosaic-cursor-body > .field-title {
    padding: 7px 10px 1px;
    margin: 0;
    font-weight: 300
}

.cursor-component-container .mosaic-cursor-body > .field-title .descendent-prefix {
    width: 10px;
    float: left;
    display: block;
    margin-top: 2px
}

.cursor-component-container .mosaic-cursor-body > .details-title {
    padding: 0 10px 7px;
    border-bottom: 1px solid #ddd;
    font-size: 1.2rem;
    margin: 0;
    font-weight: 300
}

.cursor-component-container .mosaic-cursor-body > .details-title .term-color-indicator {
    float: left;
    position: relative;
    font-size: 0.85rem;
    top: 5px;
    padding-right: 6px;
    padding-left: 2px;
    transition: color .5s;
    height: 25px
}

.cursor-component-container .mosaic-cursor-body > .details-title .primary-count {
    margin-left: 10px
}

.cursor-component-container .mosaic-cursor-body .actions.buttons-container {
    margin-left: 0;
    margin-right: 0
}

.cursor-component-container .mosaic-cursor-body .actions.buttons-container > .button-container {
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    padding-top: 3px
}

.cursor-component-container .mosaic-cursor-body .details.row, .cursor-component-container .mosaic-cursor-body .details.flexrow {
    font-size: 0.85rem;
    padding-top: 5px;
    padding-bottom: 5px;
    padding-left: 10px;
    padding-right: 10px
}

.cursor-component-container .mosaic-cursor-body .details.row .count-val, .cursor-component-container .mosaic-cursor-body .details.flexrow .count-val {
    font-weight: 500;
    text-align: right
}

.cursor-zoom-magnifier-container {
    background-color: #fff;
    box-shadow: 1px 1px 6px rgba(0, 0, 0, 0.3);
    z-index: 1000;
    position: absolute;
    top: 0;
    left: 0;
    border-radius: 50%;
    overflow: hidden;
    opacity: 1;
    transition: opacity .25s, transform .05s linear
}

.cursor-zoom-magnifier-container .cursor-zoom-magnifier {
    position: static
}

.cursor-zoom-magnifier-container .cursor-zoom-magnifier > .inner {
    position: absolute;
    top: 0;
    left: 0;
    transition: transform .05s linear
}

.__react_component_tooltip {
    z-index: 9999 !important
}

.stacked-block-viz-container .header-for-viz {
    display: flex
}

.stacked-block-viz-container .header-for-viz .column-group-header {
    text-align: center
}

.stacked-block-viz-container .header-for-viz .column-group-header > .inner {
    display: inline-block;
    white-space: nowrap;
    transform-origin: 0 0;
    transform: rotate(-45deg);
    width: 20px
}

.stacked-block-viz-container .blocks-container {
    display: flex
}

.stacked-block-viz-container .blocks-container .stacked-block {
    display: inline-block;
    background-color: #707070;
    text-align: center;
    border: 1px solid transparent;
    color: #fff
}

.stacked-block-viz-container .blocks-container .stacked-block.cellType-submitted {
    background-color: #53a74e !important
}

.stacked-block-viz-container .blocks-container .stacked-block.cellType-planned {
    background-color: rgba(191, 191, 191, 0.5) !important
}

.stacked-block-viz-container .blocks-container .stacked-block.cellType-in-submission {
    background-color: rgba(191, 191, 191, 0.5) !important;
    overflow: hidden
}

.stacked-block-viz-container .blocks-container .stacked-block.cellType-in-submission:before {
    content: '';
    display: block;
    width: 150%;
    height: 150%;
    background-color: #53a74e;
    transform: rotate3d(0, 0, 1, 45deg) translate3d(-74%, 0px, 0px)
}

.stacked-block-viz-container .blocks-container .stacked-block.cellType-none {
    background-color: transparent !important
}

.stacked-block-viz-container .blocks-container .stacked-block.multiple-sets {
    box-shadow: -3px 3px 0px #444;
    transform: translate(1px, -1px) scale(0.925)
}

@media screen and (max-width: 480px) {
    .stacked-block-viz-container .blocks-container .stacked-block {
        width: 100% !important
    }
}

.stacked-block-viz-container .blocks-container .block-container-group {
    text-align: center
}

.stacked-block-viz-container .blocks-container .block-container-group:not(:first-child) {
    border-left: 1px solid #eee
}

.stacked-block-viz-container .grouping {
    border: none;
    position: relative
}

.stacked-block-viz-container .grouping.may-collapse > .row > .label-section > h4 > span, .stacked-block-viz-container .grouping.may-collapse > .flexrow > .label-section > h4 > span {
    cursor: pointer
}

.stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) > .row > .list-section > .blocks-container, .stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) > .flexrow > .list-section > .blocks-container, .stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) + .stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) > .row > .list-section > .blocks-container, .stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) + .stacked-block-viz-container .grouping:not(.open):not(:first-child):not(.depth-0) > .flexrow > .list-section > .blocks-container {
    border-top: 1px solid #eee
}

.stacked-block-viz-container .grouping.open + .grouping:not(.open):not(:first-child):not(.depth-0) > .row > .list-section > .blocks-container, .stacked-block-viz-container .grouping.open + .grouping:not(.open):not(:first-child):not(.depth-0) > .flexrow > .list-section > .blocks-container {
    border-top: none
}

.stacked-block-viz-container .grouping .label-section > h4 {
    margin-top: 0px;
    margin-bottom: 2px
}

.stacked-block-viz-container .grouping.depth-0 {
    margin-bottom: 0px
}

.stacked-block-viz-container .grouping.depth-0 > .row > .label-section > h4, .stacked-block-viz-container .grouping.depth-0 > .flexrow > .label-section > h4 {
    margin-top: 5px
}

.stacked-block-viz-container .grouping.depth-0 > .row > .list-section, .stacked-block-viz-container .grouping.depth-0 > .flexrow > .list-section {
    padding-top: 10px
}

.stacked-block-viz-container .grouping.depth-0 > .row > .list-section > .group-value, .stacked-block-viz-container .grouping.depth-0 > .flexrow > .list-section > .group-value {
    font-size: 1.3rem
}

.stacked-block-viz-container .grouping.depth-0.open > .row > .list-section, .stacked-block-viz-container .grouping.depth-0.open > .flexrow > .list-section, .stacked-block-viz-container .grouping.depth-0:first-child > .row > .list-section, .stacked-block-viz-container .grouping.depth-0:first-child > .flexrow > .list-section {
    padding-top: 80px
}

@media screen and (min-width: 768px) {
    .stacked-block-viz-container .grouping:not(.depth-0) > .row > div, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > div {
        float: none !important;
        display: inline-block;
        vertical-align: middle
    }
}

.stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > h4, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > h4 {
    font-size: 1rem
}

.stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > h4 i.icon.icon-fw, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > h4 i.icon.icon-fw, .stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > h4 i.icon-fw.tcell-sort, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > h4 i.icon-fw.tcell-sort, .stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > h4 i.icon-fw.tcell-asc, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > h4 i.icon-fw.tcell-asc, .stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > h4 i.icon-fw.tcell-desc, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > h4 i.icon-fw.tcell-desc {
    min-width: 20px
}

.stacked-block-viz-container .grouping:not(.depth-0) > .row > .label-section > small, .stacked-block-viz-container .grouping:not(.depth-0) > .flexrow > .label-section > small {
    display: inline-block;
    padding-top: 4px
}

.stacked-block-viz-container .grouping:not(.depth-0).open > .row, .stacked-block-viz-container .grouping:not(.depth-0).open > .flexrow {
    display: none
}

.stacked-block-viz-container .grouping:not(.depth-0).open > .close-button {
    position: absolute;
    width: 20px;
    text-align: center;
    z-index: 10;
    top: 1px;
    bottom: 0;
    cursor: pointer;
    background: #f7f7f7
}

.stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.icon, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-sort, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-asc, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-desc {
    position: absolute;
    height: 20px;
    width: 20px;
    line-height: 24px;
    top: 50%;
    margin-top: -10px;
    left: 0
}

@media screen and (max-width: 480px) {
    .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button {
        position: relative;
        height: 30px;
        line-height: 34px;
        float: left;
        margin-right: 10px
    }

    .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.icon, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-sort, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-asc, .stacked-block-viz-container .grouping:not(.depth-0).open > .close-button > i.tcell-desc {
        position: relative
    }
}

.stacked-block-viz-container .grouping:not(.depth-0).open + .open > .close-button {
    top: 0
}

.stacked-block-viz-container .grouping:not(.depth-0).open.depth-1 > .close-button {
    left: 23px
}

.stacked-block-viz-container .grouping:not(.depth-0).open.depth-2 > .close-button {
    left: 50px
}

.stacked-block-viz-container .grouping:not(.depth-0).open.depth-3 > .close-button {
    left: 77px
}

.stacked-block-viz-container .grouping:not(.depth-0).open.depth-4 > .close-button {
    left: 104px
}

.stacked-block-viz-container .grouping:not(.depth-0).open.depth-5 > .close-button {
    left: 131px
}

.stacked-block-viz-container .grouping:not(.depth-0).open:not(:last-child) {
    border-bottom: 1px solid #ddd
}

.stacked-block-viz-container .grouping:not(.depth-0).open > .child-blocks {
    border-top: 1px solid #ddd
}

.stacked-block-viz-container .grouping:not(.depth-0).open + .open > .child-blocks {
    border-top: none
}

.stacked-block-viz-container .grouping.open > .close-button {
    position: absolute;
    width: 20px;
    text-align: center;
    z-index: 10;
    top: 1px;
    bottom: 0;
    cursor: pointer;
    background: #f7f7f7
}

.stacked-block-viz-container .grouping.open > .close-button > i.icon, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-sort, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-asc, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-desc {
    position: absolute;
    height: 20px;
    width: 20px;
    line-height: 24px;
    top: 50%;
    margin-top: -10px;
    left: 0
}

@media screen and (max-width: 480px) {
    .stacked-block-viz-container .grouping.open > .close-button {
        position: relative;
        height: 30px;
        line-height: 34px;
        float: left;
        margin-right: 10px
    }

    .stacked-block-viz-container .grouping.open > .close-button > i.icon, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-sort, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-asc, .stacked-block-viz-container .grouping.open > .close-button > i.tcell-desc {
        position: relative
    }
}

.stacked-block-viz-container .grouping.open + .open > .close-button {
    top: 0
}

.stacked-block-viz-container .grouping.open.depth-1 > .close-button {
    left: 27px
}

.stacked-block-viz-container .grouping.open.depth-2 > .close-button {
    left: 54px
}

.stacked-block-viz-container .grouping.open.depth-3 > .close-button {
    left: 81px
}

.stacked-block-viz-container .grouping.open.depth-4 > .close-button {
    left: 108px
}

.stacked-block-viz-container .grouping.open.depth-5 > .close-button {
    left: 135px
}

@media screen and (min-width: 768px) {
    .stacked-block-viz-container .grouping.depth-1 > .row > .label-section, .stacked-block-viz-container .grouping.depth-1 > .flexrow > .label-section {
        padding-left: 37px
    }

    .stacked-block-viz-container .grouping.depth-2 > .row > .label-section, .stacked-block-viz-container .grouping.depth-2 > .flexrow > .label-section {
        padding-left: 64px
    }

    .stacked-block-viz-container .grouping.depth-3 > .row > .label-section, .stacked-block-viz-container .grouping.depth-3 > .flexrow > .label-section {
        padding-left: 91px
    }

    .stacked-block-viz-container .grouping.depth-4 > .row > .label-section, .stacked-block-viz-container .grouping.depth-4 > .flexrow > .label-section {
        padding-left: 118px
    }

    .stacked-block-viz-container .grouping.depth-5 > .row > .label-section, .stacked-block-viz-container .grouping.depth-5 > .flexrow > .label-section {
        padding-left: 145px
    }
}

.audit-indicators {
    margin-top: 5px;
    vertical-align: top;
    padding: 0 5px;
    background: #fff;
    font-size: 14px;
    font-size: 1rem
}

@media screen and (min-width: 768px) {
    .audit-indicators {
        display: inline-block;
        margin: 0;
        height: 28px
    }
}

.search-meta .audit-indicators {
    margin: 5px 0 5px 5px
}

.audit-indicators.audit-search {
    font-size: 12px;
    font-size: .85rem;
    height: 28px
}

.audit-activeicon-error, .audit-activeicon-warning, .audit-activeicon-not_compliant, .audit-activeicon-dcc_action, .audit-activeicon-ok, .audit-icon-error, .audit-icon-error-badged, .audit-icon-warning, .audit-icon-warning-badged, .audit-icon-not_compliant, .audit-icon-not_compliant-badged, .audit-icon-dcc_action, .audit-icon-dcc_action-badged, .audit-icon-ok, .audit-icon-ok-badged {
    display: inline-block;
    line-height: 32px;
    font-size: 18px;
    font-size: 1.3rem;
    text-align: center;
    border: none;
    background-color: transparent;
    vertical-align: middle
}

.audit-activeicon-error:first-child, .audit-activeicon-warning:first-child, .audit-activeicon-not_compliant:first-child, .audit-activeicon-dcc_action:first-child, .audit-activeicon-ok:first-child, .audit-icon-error:first-child, .audit-icon-error-badged:first-child, .audit-icon-warning:first-child, .audit-icon-warning-badged:first-child, .audit-icon-not_compliant:first-child, .audit-icon-not_compliant-badged:first-child, .audit-icon-dcc_action:first-child, .audit-icon-dcc_action-badged:first-child, .audit-icon-ok:first-child, .audit-icon-ok-badged:first-child {
    margin-left: 0
}

.audit-search .audit-activeicon-error, .audit-search .audit-activeicon-warning, .audit-search .audit-activeicon-not_compliant, .audit-search .audit-activeicon-dcc_action, .audit-search .audit-activeicon-ok, .audit-search .audit-icon-error, .audit-search .audit-icon-error-badged, .audit-search .audit-icon-warning, .audit-search .audit-icon-warning-badged, .audit-search .audit-icon-not_compliant, .audit-search .audit-icon-not_compliant-badged, .audit-search .audit-icon-dcc_action, .audit-search .audit-icon-dcc_action-badged, .audit-search .audit-icon-ok, .audit-search .audit-icon-ok-badged {
    font-size: 12px;
    font-size: .85rem;
    line-height: 24px
}

.audit-activeicon-error, .audit-activeicon-warning, .audit-activeicon-not_compliant, .audit-activeicon-dcc_action, .audit-activeicon-ok {
    margin: 0 5px 2px 0
}

.btn-audit {
    display: inline-block;
    margin: 0 10px;
    height: 26px
}

.audit-search .btn-audit {
    margin: 0 6px;
    height: 24px
}

.audit-detail-trigger-error, .audit-detail-trigger-warning, .audit-detail-trigger-not_compliant, .audit-detail-trigger-dcc_action, .audit-detail-trigger-ok {
    display: inline-block;
    height: 40px;
    width: 40px;
    float: left;
    margin-right: 10px;
    border-right: 1px solid #a0a0a0
}

.audit-detail-trigger-error:hover, .audit-detail-trigger-warning:hover, .audit-detail-trigger-not_compliant:hover, .audit-detail-trigger-dcc_action:hover, .audit-detail-trigger-ok:hover, .audit-detail-trigger-error:focus, .audit-detail-trigger-warning:focus, .audit-detail-trigger-not_compliant:focus, .audit-detail-trigger-dcc_action:focus, .audit-detail-trigger-ok:focus {
    text-decoration: none;
    color: #000
}

.collapsed.audit-detail-trigger-error, .collapsed.audit-detail-trigger-warning, .collapsed.audit-detail-trigger-not_compliant, .collapsed.audit-detail-trigger-dcc_action, .collapsed.audit-detail-trigger-ok {
    transform: rotate(-90deg)
}

.audit-detail-trigger-icon {
    display: block;
    height: 40px;
    width: 40px;
    line-height: 40px;
    font-size: 1.6rem;
    cursor: pointer;
    text-align: center;
    text-decoration: none;
    color: #000;
    transition: transform 0.1s linear;
    transform: rotate(0deg)
}

.audit-detail-trigger-icon:hover, .audit-detail-trigger-icon:focus {
    text-decoration: none;
    color: #000
}

.audit-detail-trigger-icon.collapsed {
    transform: rotate(-90deg);
    text-decoration: none
}

.audit-detail-category-name {
    font-weight: bold;
    font-size: 1.1rem;
    color: #606060
}

.audit-detail-info {
    padding: 5px 10px;
    line-height: 30px
}

.audit-icon-error {
    color: #bd0000
}

.audit-icon-error-badged {
    color: #fff;
    font-size: 0.7rem;
    line-height: 1;
    padding: 0 5px
}

.audit-activeicon-error {
    color: #bd0000;
    font-size: 17px;
    font-size: 1.2rem;
    height: 26px;
    line-height: 28px
}

.btn-audit-error {
    color: #bd0000
}

.btn-audit-error:hover, .btn-audit-error:focus {
    color: #bd0000
}

.audit-detail-error {
    border-top: 1px solid #a0a0a0;
    background-color: #ffd5d5
}

.audit-detail-error:first-child {
    border-top: none
}

.audit-detail-trigger-error:hover {
    background-color: #ffa2a2
}

.audit-level-error {
    margin-left: 5px !important;
    color: #bd0000
}

.audit-item-error {
    padding: 5px 10px 5px 50px;
    background-color: #ffa2a2;
    border-top: 1px solid #a0a0a0;
    font-weight: bold
}

.audit-icon-warning {
    color: #e29302
}

.audit-icon-warning-badged {
    color: #fff;
    font-size: 0.7rem;
    line-height: 1;
    padding: 0 5px
}

.audit-activeicon-warning {
    color: #e29302;
    font-size: 17px;
    font-size: 1.2rem;
    height: 26px;
    line-height: 28px
}

.btn-audit-warning {
    color: #e29302
}

.btn-audit-warning:hover, .btn-audit-warning:focus {
    color: #e29302
}

.audit-detail-warning {
    border-top: 1px solid #a0a0a0;
    background-color: #fff5e2
}

.audit-detail-warning:first-child {
    border-top: none
}

.audit-detail-trigger-warning:hover {
    background-color: #ffe3af
}

.audit-level-warning {
    margin-left: 5px !important;
    color: #af7202
}

.audit-item-warning {
    padding: 5px 10px 5px 50px;
    background-color: #ffe3af;
    border-top: 1px solid #a0a0a0;
    font-weight: bold
}

.audit-icon-not_compliant {
    color: #ff8000
}

.audit-icon-not_compliant-badged {
    color: #fff;
    font-size: 0.7rem;
    line-height: 1;
    padding: 0 5px
}

.audit-activeicon-not_compliant {
    color: #ff8000;
    font-size: 17px;
    font-size: 1.2rem;
    height: 26px;
    line-height: 28px
}

.btn-audit-not_compliant {
    color: #ff8000
}

.btn-audit-not_compliant:hover, .btn-audit-not_compliant:focus {
    color: #ff8000
}

.audit-detail-not_compliant {
    border-top: 1px solid #a0a0a0;
    background-color: #fff4e8
}

.audit-detail-not_compliant:first-child {
    border-top: none
}

.audit-detail-trigger-not_compliant:hover {
    background-color: #ffdab5
}

.audit-level-not_compliant {
    margin-left: 5px !important;
    color: #c60
}

.audit-item-not_compliant {
    padding: 5px 10px 5px 50px;
    background-color: #ffdab5;
    border-top: 1px solid #a0a0a0;
    font-weight: bold
}

.audit-icon-dcc_action {
    color: #a0a0a0
}

.audit-icon-dcc_action-badged {
    color: #fff;
    font-size: 0.7rem;
    line-height: 1;
    padding: 0 5px
}

.audit-activeicon-dcc_action {
    color: #a0a0a0;
    font-size: 17px;
    font-size: 1.2rem;
    height: 26px;
    line-height: 28px
}

.btn-audit-dcc_action {
    color: #a0a0a0
}

.btn-audit-dcc_action:hover, .btn-audit-dcc_action:focus {
    color: #a0a0a0
}

.audit-detail-dcc_action {
    border-top: 1px solid #a0a0a0;
    background-color: #fbf9f9
}

.audit-detail-dcc_action:first-child {
    border-top: none
}

.audit-detail-trigger-dcc_action:hover {
    background-color: #e7dada
}

.audit-level-dcc_action {
    margin-left: 5px !important;
    color: #878787
}

.audit-item-dcc_action {
    padding: 5px 10px 5px 50px;
    background-color: #e7dada;
    border-top: 1px solid #a0a0a0;
    font-weight: bold
}

.audit-icon-ok {
    color: #4C994C
}

.audit-icon-ok-badged {
    color: #fff;
    font-size: 0.7rem;
    line-height: 1;
    padding: 0 5px
}

.audit-activeicon-ok {
    color: #4C994C;
    font-size: 17px;
    font-size: 1.2rem;
    height: 26px;
    line-height: 28px
}

.btn-audit-ok {
    color: #4C994C
}

.btn-audit-ok:hover, .btn-audit-ok:focus {
    color: #4C994C
}

.audit-detail-ok {
    border-top: 1px solid #a0a0a0;
    background-color: #e3fee3
}

.audit-detail-ok:first-child {
    border-top: none
}

.audit-detail-trigger-ok:hover {
    background-color: #b3fbb3
}

.audit-level-ok {
    margin-left: 5px !important;
    color: #3b773b
}

.audit-item-ok {
    padding: 5px 10px 5px 50px;
    background-color: #b3fbb3;
    border-top: 1px solid #a0a0a0;
    font-weight: bold
}

.audit-details-section {
    position: relative
}

.audit-details-decoration {
    position: absolute;
    z-index: 1;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    box-shadow: 0px 2px 8px rgba(0, 0, 0, 0.3) inset;
    pointer-events: none
}

.audit-category {
    display: inline
}

.audit-link {
    display: block
}

.btn-info-audit {
    display: inline-block;
    margin-left: 10px;
    vertical-align: middle;
    font-size: 1.2rem
}

.btn-info-audit .icon, .btn-info-audit .tcell-sort, .btn-info-audit .tcell-asc, .btn-info-audit .tcell-desc {
    color: #a0a0a0
}

.btn-info-audit .icon:hover, .btn-info-audit .tcell-sort:hover, .btn-info-audit .tcell-asc:hover, .btn-info-audit .tcell-desc:hover {
    color: #428bca
}

.audits-view {
    overflow: hidden
}

.audits-view > div > div h3 {
    margin-top: 7px
}

.audits-view .audits-view-ERROR h3 i.icon, .audits-view .audits-view-ERROR h3 i.tcell-sort, .audits-view .audits-view-ERROR h3 i.tcell-asc, .audits-view .audits-view-ERROR h3 i.tcell-desc {
    color: #bd0000
}

.audits-view .audits-view-WARNING h3 i.icon, .audits-view .audits-view-WARNING h3 i.tcell-sort, .audits-view .audits-view-WARNING h3 i.tcell-asc, .audits-view .audits-view-WARNING h3 i.tcell-desc {
    color: #e29302
}

.audits-view .audits-view-INTERNAL_ACTION h3 i.icon, .audits-view .audits-view-INTERNAL_ACTION h3 i.tcell-sort, .audits-view .audits-view-INTERNAL_ACTION h3 i.tcell-asc, .audits-view .audits-view-INTERNAL_ACTION h3 i.tcell-desc {
    color: #d0d0d0
}

.audits-view .audits-container {
    overflow: hidden
}

.audits-view .audits-container > .audit-grouping:last-child {
    margin-bottom: 20px
}

.audits-view .audits-container .audit-category {
    text-transform: capitalize;
    display: block
}

.audits-view .audits-container .audit-category i.toggle-open.icon, .audits-view .audits-container .audit-category i.toggle-open.tcell-sort, .audits-view .audits-container .audit-category i.toggle-open.tcell-asc, .audits-view .audits-container .audit-category i.toggle-open.tcell-desc {
    font-size: 1.1rem;
    margin-right: 5px;
    cursor: pointer
}

.audits-view .audits-container .audit-item > div > span > h4, .audits-view .audits-container .audit-item > div > h5 {
    margin-top: 5px
}

.audits-view .audits-container .audit-item .audit-detail ul {
    margin-bottom: 0px
}

.audits-view .audits-container .audit-item .audit-detail ul li {
    padding: 10px 0
}

.audits-view .audits-container .audit-item .audit-detail ul li:not(:last-child) {
    border-bottom: 1px solid #eee
}

.audits-view .audits-container .audit-item .audit-detail ul li:first-child {
    padding-top: 5px
}

.audits-view .audits-container .audit-item .audit-detail ul li code {
    white-space: normal
}

g.pipeline-node-file {
    fill: #FFF5BA
}

g.pipeline-node-file.active {
    fill: #e5d46e
}

g.pipeline-node-file.active rect, g.pipeline-node-file.active ellipse {
    stroke: #606060;
    stroke-width: 3px
}

g.pipeline-node-file.active line {
    stroke: #606060;
    stroke-width: 1px
}

g.pipeline-node-file.error {
    fill: #ffc0c0
}

g.pipeline-node-file:hover {
    cursor: pointer
}

g.pipeline-node-file text {
    fill: #000
}

g.pipeline-node-analysis-step {
    fill: #D3E9FF
}

g.pipeline-node-analysis-step.active {
    fill: #83b6e9
}

g.pipeline-node-analysis-step.active rect, g.pipeline-node-analysis-step.active ellipse {
    stroke: #606060;
    stroke-width: 3px
}

g.pipeline-node-analysis-step.active line {
    stroke: #606060;
    stroke-width: 1px
}

g.pipeline-node-analysis-step.error {
    fill: #ffc0c0
}

g.pipeline-node-analysis-step:hover {
    cursor: pointer
}

g.pipeline-node-analysis-step text {
    fill: #000
}

g.pipeline-node-quality-metric {
    fill: #f0e0f8
}

g.pipeline-node-quality-metric.active {
    fill: #c1a2d0
}

g.pipeline-node-quality-metric.active rect, g.pipeline-node-quality-metric.active ellipse {
    stroke: #606060;
    stroke-width: 3px
}

g.pipeline-node-quality-metric.active line {
    stroke: #606060;
    stroke-width: 1px
}

g.pipeline-node-quality-metric.error {
    fill: #ffc0c0
}

g.pipeline-node-quality-metric:hover {
    cursor: pointer
}

g.pipeline-node-quality-metric text {
    fill: #000
}

g.label {
    font-size: 11.9px;
    font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
    font-weight: bold;
    fill: #000
}

g.node rect, g.node ellipse {
    stroke: #a0a0a0;
    stroke-width: 1.5px
}

g.node.contributing {
    stroke-dasharray: 4, 2
}

g.node line {
    stroke: #a0a0a0;
    stroke-width: .5px
}

g.subnodes text {
    font-size: 10px;
    font-weight: bold;
    pointer-events: none
}

g.cluster rect {
    fill: #f0f8f0;
    stroke: #c0c0c0
}

g.cluster text {
    font-size: 14px;
    fill: #000
}

g.edgePath path {
    stroke: #c0c0c0;
    stroke-width: 1.5px
}

.graph-display {
    position: relative;
    overflow: scroll;
    background-color: #f8f8f8
}

.graph-display svg {
    display: block;
    margin: 0 auto
}

.select-note {
    font-style: italic;
    color: #c0c0c0
}

.graph-dl {
    margin: 0;
    padding: 5px;
    border-bottom: 1px solid #e8e8e8
}

.step-info, .selected-step {
    padding: 15px 30px;
    border: 1px solid #e0e0e0
}

.selected-step {
    background-color: #e8f0e8
}

.graph-node-info hr {
    margin: 0 !important
}

.btn-orient-wrapper {
    padding: 1px 4px
}

.btn-orient-horizontal, .btn-orient-vertical {
    display: block;
    width: 36px;
    height: 22px;
    margin: 2px 4px;
    background-repeat: no-repeat;
    background-position: center center;
    background-size: 36px 22px;
    overflow: hidden
}

.btn-orient-horizontal {
    background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIzNiIgaGVpZ2h0PSIyMiIgdmlld0JveD0iMCAwIDM2IDIyIj48c3R5bGUgdHlwZT0idGV4dC9jc3MiPi5zdDB7ZmlsbDojRkZGRkZGO308L3N0eWxlPjxwYXRoIGNsYXNzPSJzdDAiIGQ9Ik0zNC4yIDcuOWgtOS42Yy0uOCAwLTEuNS42LTEuNyAxLjNMMjEgNi40bC0uNSAxTDEzLjIgNHYtLjljMC0xLS44LTEuOC0xLjgtMS44SDEuOGMtMSAwLTEuOC44LTEuOCAxLjh2Mi42YzAgMSAuOCAxLjggMS44IDEuOGg5LjZjMSAwIDEuOC0uOCAxLjgtMS44di0uM2w2LjcgMy4yLS41IDEgMy40LS4zdjNjMCAuMiAwIC4zLjEuNGwtMy40LS4zLjUgMS02LjcgMy4ydi0uNGMwLTEtLjgtMS44LTEuOC0xLjhIMS44Yy0xIDAtMS44LjgtMS44IDEuOHYyLjZjMCAxIC44IDEuOCAxLjggMS44aDkuNmMxIDAgMS44LS44IDEuOC0xLjhWMThsNy4zLTMuNC41IDEgMS45LTIuOGMuMi43LjkgMS4zIDEuNyAxLjNoOS42YzEgMCAxLjgtLjggMS44LTEuOFY5LjdjMC0xLS44LTEuOC0xLjgtMS44ek0xMiA1LjdjMCAuMy0uMy42LS42LjZIMS44Yy0uMyAwLS42LS4zLS42LS42VjMuMWMwLS4zLjMtLjYuNi0uNmg5LjZjLjMgMCAuNi4zLjYuNnYyLjZ6bTAgMTMuMmMwIC4zLS4zLjYtLjYuNkgxLjhjLS4zIDAtLjYtLjMtLjYtLjZ2LTIuNmMwLS4zLjMtLjYuNi0uNmg5LjZjLjMgMCAuNi4zLjYuNnYyLjZ6bTIyLjgtNi42YzAgLjMtLjMuNi0uNi42aC05LjZjLS4zIDAtLjYtLjMtLjYtLjZWOS43YzAtLjMuMy0uNi42LS42aDkuNmMuMyAwIC42LjMuNi42djIuNnoiLz48L3N2Zz4=)
}

.btn-orient-vertical {
    background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIzNiIgaGVpZ2h0PSIyMiIgdmlld0JveD0iMCAwIDM2IDIyIj48c3R5bGUgdHlwZT0idGV4dC9jc3MiPi5zdDB7ZmlsbDojRkZGRkZGO308L3N0eWxlPjxwYXRoIGNsYXNzPSJzdDAiIGQ9Ik0zMi42IDBIMjNjLTEgMC0xLjguOC0xLjggMS44djIuNmMwIDEgLjggMS44IDEuOCAxLjhoMy44bC00LjEgNi43LTEtLjYtLjEgMy41IDMtMS43LTEtLjYgNC41LTcuM2g0LjRjMSAwIDEuOC0uOCAxLjgtMS44VjEuOGMuMS0xLS43LTEuOC0xLjctMS44em0uNiA0LjRjMCAuMy0uMy42LS42LjZIMjNjLS4zIDAtLjYtLjMtLjYtLjZWMS44YzAtLjMuMy0uNi42LS42aDkuNmMuMyAwIC42LjMuNi42djIuNnpNMjIuOCAxNS44aC05LjZjLTEgMC0xLjguOC0xLjggMS44djIuNmMwIDEgLjggMS44IDEuOCAxLjhoOS42YzEgMCAxLjgtLjggMS44LTEuOHYtMi42YzAtMS0uOC0xLjgtMS44LTEuOHptLjYgNC40YzAgLjMtLjMuNi0uNi42aC05LjZjLS4zIDAtLjYtLjMtLjYtLjZ2LTIuNmMwLS4zLjMtLjYuNi0uNmg5LjZjLjMgMCAuNi4zLjYuNnYyLjZ6TTE0LjMgMTUuOGwtLjEtMy41LTEgLjYtNC02LjdIMTNjMSAwIDEuOC0uOCAxLjgtMS44VjEuOEMxNC44LjggMTQgMCAxMyAwSDMuNGMtMSAwLTEuOC44LTEuOCAxLjh2Mi42YzAgMSAuOCAxLjggMS44IDEuOGg0LjRsNC41IDcuMy0xIC42IDMgMS43em0tLjctMTEuNGMwIC4zLS4zLjYtLjYuNkgzLjRjLS4zIDAtLjYtLjMtLjYtLjZWMS44YzAtLjMuMy0uNi42LS42SDEzYy4zIDAgLjYuMy42LjZ2Mi42eiIvPjwvc3ZnPg==)
}

.no-svg .btn-orient-horizontal {
    background-image: url(/static/img/orientation-icons.png);
    background-position: 0 0;
    background-size: 36px 44px
}

.no-svg .btn-orient-vertical {
    background-image: url(/static/img/orientation-icons.png);
    background-position: 0 -22px;
    background-size: 36px 44px
}

g.pipeline-node-qc-metric circle {
    stroke-width: 2px;
    stroke: #a0a0a0;
    fill: #80ffc0
}

g.pipeline-node-qc-metric text {
    font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
    font-weight: bold;
    fill: #000
}

g.pipeline-node-qc-metric.active circle {
    stroke: #404040;
    fill: #008041
}

g.pipeline-node-qc-metric.active text {
    fill: #fff
}

.quality-metrics-title {
    padding-bottom: 5px;
    border-bottom: 1px solid #e0e0e0
}

.tooltip-trigger {
    display: inline-block;
    position: relative;
    cursor: default
}

.tooltip {
    position: absolute;
    left: 50%;
    margin-right: -300px;
    visibility: hidden;
    transform: translateX(-50%);
    white-space: normal;
    text-align: center;
    opacity: 1;
    z-index: 100
}

.no-csstransforms .tooltip {
    left: 0;
    padding: 0
}

.tooltip.tooltip-open {
    visibility: visible
}

.tooltip-inner {
    padding: 2px 5px;
    border-right: 1px solid #fff;
    border-bottom: 1px solid #fff;
    border-left: 1px solid #fff;
    background-color: #41739f;
    -moz-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    max-width: 300px;
    cursor: auto;
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif
}

.tooltip.bottom .tooltip-arrow {
    border-bottom-color: #41739f
}

.tooltip-status {
    position: absolute;
    visibility: hidden;
    top: 20px;
    left: 15px;
    padding: 2px 5px;
    z-index: 100;
    border: 1px solid #fff;
    background-color: #41739f;
    -moz-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.3);
    color: #fff;
    text-align: center;
    white-space: nowrap;
    font-size: 13px;
    font-size: .9rem;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    border-radius: 4px
}

.tooltip-status span:last-child {
    font-weight: normal
}

.tooltip-status.tooltipopen {
    visibility: visible
}

.tooltip-status-trigger {
    position: relative;
    margin-left: 5px;
    font-size: 17px;
    font-size: 1.2rem;
    cursor: default
}

.no-csstransforms .tooltip-arrow {
    display: none
}

.__react_component_tooltip {
    max-width: 630px
}

@media screen and (max-width: 767px) {
    .__react_component_tooltip {
        max-width: 400px
    }
}

@media screen and (max-width: 991px) {
    .__react_component_tooltip {
        max-width: 500px
    }
}

@media screen and (max-width: 1199px) {
    .__react_component_tooltip {
        max-width: 600px
    }
}

.__react_component_tooltip h1, .__react_component_tooltip h2, .__react_component_tooltip h3, .__react_component_tooltip h4, .__react_component_tooltip h5, .__react_component_tooltip h6 {
    color: #fff;
    margin-top: 5px;
    margin-bottom: 5px
}

.__react_component_tooltip small + h2, .__react_component_tooltip small + h3, .__react_component_tooltip small + h4, .__react_component_tooltip small + h5, .__react_component_tooltip small + h6 {
    margin-top: 0
}

.__react_component_tooltip.has-links-or-buttons {
    pointer-events: all !important
}

.__react_component_tooltip.has-links-or-buttons:hover {
    visibility: visible;
    opacity: 1
}

.badge-encode {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-encode.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-encode {
    background-image: url(/static/img/badge-encode.png)
}

.badge-encode.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-encode2 {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-encode2.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-encode2 {
    background-image: url(/static/img/badge-encode2.png)
}

.badge-encode2.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-encode3 {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-encode3.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-encode3 {
    background-image: url(/static/img/badge-encode3.png)
}

.badge-encode3.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-encode4 {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-encode4.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-encode4 {
    background-image: url(/static/img/badge-encode4.png)
}

.badge-encode4.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-roadmap {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-roadmap.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-roadmap {
    background-image: url(/static/img/badge-roadmap.png)
}

.badge-roadmap.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-modencode {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-modencode.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-modencode {
    background-image: url(/static/img/badge-modencode.png)
}

.badge-modencode.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-modern {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-modern.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-modern {
    background-image: url(/static/img/badge-modern.png)
}

.badge-modern.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-ggr {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-ggr.png);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-ggr {
    background-image: url(/static/img/badge-ggr.png)
}

.badge-ggr.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.badge-mouseencode {
    display: block;
    height: 80px;
    margin-top: 10px;
    background-image: url(/static/img/badge-mouseencode.svg);
    background-repeat: no-repeat;
    background-position: 0 0;
    background-size: contain
}

.no-svg .badge-mouseencode {
    background-image: url(/static/img/badge-mouseencode.png)
}

.badge-mouseencode.badge-heading {
    position: absolute;
    margin-top: 0;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    height: auto;
    background-position: top right
}

.block {
    margin-bottom: 10px
}

@media screen and (min-width: 992px) {
    .block {
        margin-bottom: 10px
    }
}

.block.richtextblock {
    background-color: #fff
}

@media screen and (min-width: 992px) {
    .block.richtextblock :target {
        margin-top: -40px !important;
        padding-top: 40px !important
    }
}

.block.richtextblock, .block .teaser .caption {
    line-height: 1.6
}

.block.richtextblock pre, .block .teaser .caption pre {
    display: block;
    overflow: auto;
    padding: 5px 10px;
    word-wrap: normal;
    background-color: #f8f8f8;
    border: 1px solid #e0e0e0 !important;
    margin: 10px 0;
    white-space: pre;
    border: none
}

.block.richtextblock code, .block .teaser .caption code {
    border: 1px solid #e0e0e0
}

.block.richtextblock h1, .block.richtextblock h2, .block.richtextblock h3, .block.richtextblock h4, .block.richtextblock h5, .block.richtextblock h6, .block .teaser .caption h1, .block .teaser .caption h2, .block .teaser .caption h3, .block .teaser .caption h4, .block .teaser .caption h5, .block .teaser .caption h6 {
    margin-top: 20px;
    color: #000
}

.block.richtextblock h1:first-child, .block.richtextblock h2:first-child, .block.richtextblock h3:first-child, .block.richtextblock h4:first-child, .block.richtextblock h5:first-child, .block.richtextblock h6:first-child, .block .teaser .caption h1:first-child, .block .teaser .caption h2:first-child, .block .teaser .caption h3:first-child, .block .teaser .caption h4:first-child, .block .teaser .caption h5:first-child, .block .teaser .caption h6:first-child {
    margin-top: 0
}

.block.richtextblock h1:last-child, .block.richtextblock h2:last-child, .block.richtextblock h3:last-child, .block.richtextblock h4:last-child, .block.richtextblock h5:last-child, .block.richtextblock h6:last-child, .block .teaser .caption h1:last-child, .block .teaser .caption h2:last-child, .block .teaser .caption h3:last-child, .block .teaser .caption h4:last-child, .block .teaser .caption h5:last-child, .block .teaser .caption h6:last-child {
    margin-bottom: 0
}

.block.richtextblock p, .block .teaser .caption p {
    margin-bottom: 1em
}

.block.richtextblock p:last-child, .block .teaser .caption p:last-child {
    margin-bottom: 0
}

.block.richtextblock ul, .block.richtextblock ol, .block .teaser .caption ul, .block .teaser .caption ol {
    margin: .3em 0;
    overflow: hidden
}

.block.richtextblock ul li, .block.richtextblock ol li, .block .teaser .caption ul li, .block .teaser .caption ol li {
    margin: .4em 0
}

.block.richtextblock ul li:last-child, .block.richtextblock ol li:last-child, .block .teaser .caption ul li:last-child, .block .teaser .caption ol li:last-child {
    margin-bottom: 1em
}

.block.richtextblock blockquote, .block .teaser .caption blockquote {
    padding: 0;
    margin: 0 0 1em 20px;
    border: none
}

.block.richtextblock blockquote:last-child, .block .teaser .caption blockquote:last-child {
    margin-bottom: 0
}

@media screen and (min-width: 768px) {
    .block.richtextblock blockquote, .block .teaser .caption blockquote {
        margin-left: 50px
    }
}

.block.richtextblock hr, .block .teaser .caption hr {
    margin-top: 2em;
    margin-bottom: 2em
}

.block.richtextblock dl:last-child, .block .teaser .caption dl:last-child {
    margin-bottom: 0
}

.block.richtextblock dl dt, .block .teaser .caption dl dt {
    margin-top: 1em
}

.block.richtextblock dl dt:first-child, .block .teaser .caption dl dt:first-child {
    margin-top: 0
}

.block.richtextblock dl dd, .block .teaser .caption dl dd {
    margin: .3em 0 .3em 20px;
    padding-left: 10px;
    border-left: 3px solid #e0e0e0
}

.block.richtextblock cite, .block .teaser .caption cite {
    display: block;
    margin-top: -0.5em;
    margin-bottom: 0.5em;
    color: #808080;
    line-height: 1.5;
    font-size: 13px;
    font-size: .9rem
}

.block.richtextblock a[name], .block .teaser .caption a[name] {
    pointer-events: none;
    color: #000;
    text-decoration: none
}

.block.teaserblock {
    padding: 0
}

.block .teaser .caption h1, .block .teaser .caption h2, .block .teaser .caption h3, .block .teaser .caption h4, .block .teaser .caption h5, .block .teaser .caption h6 {
    color: #000
}

@media screen and (min-width: 992px) {
    .col-md-12 .block .teaser .caption {
        padding: 20px
    }
}

a.url {
    word-break: break-all
}

.fig {
    display: block;
    width: 100%;
    margin: 0 0 1em;
    line-height: 0
}

@media screen and (min-width: 768px) {
    .fig.fig-width-25 {
        width: 25%
    }

    .fig.fig-width-50 {
        width: 50%
    }

    .fig.fig-width-75 {
        width: 75%
    }

    .fig.fig-width-100 {
        width: 100%
    }
}

.fig img {
    display: block;
    width: 100%
}

.fig.fig-align-center {
    margin-left: auto;
    margin-right: auto
}

.fig.fig-align-right {
    float: right;
    margin-left: 20px
}

.fig.fig-align-left {
    float: left;
    margin-right: 20px
}

.fig figcaption {
    font-size: 13px;
    font-size: .9rem;
    color: #808080;
    line-height: 1.5
}

img.fig-align-right {
    display: block;
    width: 100%;
    margin-bottom: 1em
}

@media screen and (min-width: 992px) {
    .col-md-12 img.fig-align-right {
        float: right;
        margin-left: 10px;
        width: auto
    }

    .col-md-12 img.fig-align-right.fig-width-25 {
        width: 25%
    }

    .col-md-12 img.fig-align-right.fig-width-50 {
        width: 50%
    }

    .col-md-12 img.fig-align-right.fig-width-75 {
        width: 75%
    }
}

img.fig-align-left {
    display: block;
    width: 100%;
    margin-bottom: 1em
}

@media screen and (min-width: 992px) {
    .col-md-12 img.fig-align-left {
        float: left;
        margin-right: 10px;
        margin-bottom: 10px;
        width: 50%
    }

    .col-md-12 img.fig-align-left.fig-width-25 {
        width: 25%
    }

    .col-md-12 img.fig-align-left.fig-width-50 {
        width: 50%
    }

    .col-md-12 img.fig-align-left.fig-width-75 {
        width: 75%
    }
}

img.fig-align-center {
    display: block;
    width: 100%;
    margin-bottom: 1em
}

@media screen and (min-width: 992px) {
    .col-md-12 img.fig-align-center {
        width: auto;
        margin: 0 auto 1em
    }

    .col-md-12 img.fig-align-center.fig-width-25 {
        width: 25%
    }

    .col-md-12 img.fig-align-center.fig-width-50 {
        width: 50%
    }

    .col-md-12 img.fig-align-center.fig-width-75 {
        width: 75%
    }

    .col-md-12 img.fig-align-center.fig-width-100 {
        width: 100%
    }
}

.img-link {
    display: block
}

.img-link:hover {
    text-decoration: none
}

.teaser {
    position: relative;
    padding: 5;
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
    border: 4px solid #fff
}

.img-link .teaser:hover {
    border-color: #0a253d
}

.teaser.thumbnail {
    margin-bottom: 0
}

@media screen and (min-width: 768px) {
    .col-md-12 .teaser .caption {
        float: right;
        width: 33.33%;
        padding: 0 20px !important;
        line-height: 1.6
    }
}

.teaser figure {
    margin-bottom: 0
}

@media screen and (min-width: 768px) {
    .col-md-12 .teaser figure {
        float: left;
        width: 66.66%
    }
}

.teaser figcaption {
    display: none
}

.teaser p {
    margin: 0;
    font-weight: normal
}

.teaser-font-13 p {
    font-size: 13px !important;
    font-size: .9rem !important
}

.teaser-font-12 p {
    font-size: 12px !important;
    font-size: .85rem !important
}

.teaser-font-11 p {
    font-size: 11px !important;
    font-size: .8rem !important
}

.item-page-container h1.page-title {
    margin-bottom: 2px
}

.item-label-title {
    font-weight: 300;
    height: 36px;
    margin: 0;
    padding-left: 13px
}

.item-label-title > span:not(:last-child) {
    padding-right: 5px;
    margin-right: 5px;
    border-right: 1px solid #ccc
}

.item-label-title .accession {
    font-weight: 500;
    font-size: 1.15rem
}

.item-label-extra {
    font-weight: 300
}

.item-label-extra .icon[class*=" ss-"], .item-label-extra [class*=" ss-"].tcell-sort, .item-label-extra [class*=" ss-"].tcell-asc, .item-label-extra [class*=" ss-"].tcell-desc {
    margin-bottom: -4px;
    vertical-align: middle
}

.item-label-extra .icon[class*=" sbt-"], .item-label-extra [class*=" sbt-"].tcell-sort, .item-label-extra [class*=" sbt-"].tcell-asc, .item-label-extra [class*=" sbt-"].tcell-desc {
    margin-top: -2px;
    vertical-align: middle
}

@media screen and (max-width: 767px) {
    .item-label-extra.text-right {
        text-align: left !important
    }
}

.flexible-description-box {
    box-sizing: border-box;
    padding: 0;
    margin: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    transition: height .4s
}

.flexible-description-box .description-expand-button {
    padding: 0px;
    width: 24px;
    height: 24px;
    margin-left: 6px;
    box-sizing: border-box;
    border: none;
    background: none;
    outline: none
}

.flexible-description-box p {
    overflow: inherit;
    text-overflow: inherit
}

.flexible-description-box p:last-child {
    margin-bottom: 0
}

.item-page-heading {
    border-radius: 2px;
    border: 1px solid #eee;
    min-height: 42px;
    padding: 10px 15px 8px
}

.item-page-heading h4 {
    font-weight: 500
}

.item-page-heading h4 small {
    vertical-align: top;
    line-height: inherit;
    letter-spacing: normal
}

.flexcol-heading, .item-page-heading, .submission-page-heading {
    position: relative;
    background-color: #f4f4f4
}

.flexcol-heading h1, .flexcol-heading h2, .flexcol-heading h3, .flexcol-heading h4, .flexcol-heading h5, .flexcol-heading h6, .item-page-heading h1, .item-page-heading h2, .item-page-heading h3, .item-page-heading h4, .item-page-heading h5, .item-page-heading h6, .submission-page-heading h1, .submission-page-heading h2, .submission-page-heading h3, .submission-page-heading h4, .submission-page-heading h5, .submission-page-heading h6 {
    margin: 0
}

.flexcol-heading.experiment-heading h1, .flexcol-heading.experiment-heading h2, .flexcol-heading.experiment-heading h3, .flexcol-heading.experiment-heading h4, .flexcol-heading.experiment-heading h5, .flexcol-heading.experiment-heading h6, .item-page-heading.experiment-heading h1, .item-page-heading.experiment-heading h2, .item-page-heading.experiment-heading h3, .item-page-heading.experiment-heading h4, .item-page-heading.experiment-heading h5, .item-page-heading.experiment-heading h6, .submission-page-heading.experiment-heading h1, .submission-page-heading.experiment-heading h2, .submission-page-heading.experiment-heading h3, .submission-page-heading.experiment-heading h4, .submission-page-heading.experiment-heading h5, .submission-page-heading.experiment-heading h6 {
    line-height: 20px
}

.item-header-indicators {
    margin-top: 8px;
    margin-bottom: 8px
}

.item-header-indicators .expset-indicator {
    display: inline-block;
    box-sizing: border-box;
    line-height: 20px;
    color: #000;
    font-weight: 400;
    padding-left: 10px;
    padding-right: 10px;
    text-transform: capitalize;
    color: #444
}

.item-header-indicators .expset-indicator.right, .item-header-indicators .expset-indicator .left {
    max-width: 50%;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}

.item-header-indicators .expset-indicator.right:after, .item-header-indicators .expset-indicator .left:after {
    content: "";
    display: block;
    position: absolute;
    height: 100%;
    top: 0
}

.item-header-indicators .expset-indicator.right {
    padding-left: 21px;
    padding-right: 0
}

.item-header-indicators .expset-indicator.right:after {
    margin-left: -11px;
    border-left: 1px solid rgba(0, 0, 0, 0.125)
}

.item-header-indicators .expset-indicator.right:last-child {
    padding-left: 0;
    margin-left: 0
}

.item-header-indicators .expset-indicator.right:last-child:after {
    display: none
}

.item-header-indicators .expset-indicator.left {
    padding-right: 21px;
    padding-left: 0;
    max-width: 50%
}

.item-header-indicators .expset-indicator.left:after {
    margin-right: -10px;
    border-right: 1px solid rgba(0, 0, 0, 0.125)
}

.item-header-indicators .expset-indicator.left:last-child {
    padding-right: 0;
    margin-right: 0
}

.item-header-indicators .expset-indicator.left:last-child:after {
    display: none
}

.item-header-indicators .expset-indicator.expset-status:before {
    content: "";
    width: 9px;
    height: 9px;
    display: inline-block;
    position: relative;
    margin-right: 7px;
    border-radius: 50%
}

.item-header-indicators .expset-indicator.expset-status[data-status="released"]:before {
    color: #fff;
    background-color: #308756
}

.item-header-indicators .expset-indicator.expset-status[data-status="current"]:before {
    color: #fff;
    background-color: #308756
}

.item-header-indicators .expset-indicator.expset-status[data-status="revoked"]:before {
    color: #fff;
    background-color: #812423
}

.item-header-indicators .expset-indicator.expset-status[data-status="deleted"]:before {
    color: #fff;
    background-color: #a90d0b
}

.item-header-indicators .expset-indicator.expset-status[data-status="replaced"]:before {
    color: #fff;
    background-color: #47419a
}

.item-header-indicators .expset-indicator.expset-status[data-status="in review by lab"]:before {
    color: #fff;
    background-color: #d8bd22
}

.item-header-indicators .expset-indicator.expset-status[data-status="submission in progress"]:before {
    color: #fff;
    background-color: #d8bd22
}

.item-header-indicators .expset-indicator.expset-status[data-status="released to project"]:before {
    color: #fff;
    background-color: #397855
}

.item-header-indicators .expset-indicator.expset-status[data-status="unspecified"]:before {
    color: #fff;
    background-color: #7b7b7b;
    display: none
}

.item-page-container .info-area {
    margin-top: 17px;
    padding-bottom: 7px
}

.item-page-container .rc-tabs-tabpane .info-area {
    overflow: hidden;
    border-bottom: none
}

.item-page-container .item-info-area {
    margin-bottom: 20px;
    min-height: 120px
}

.item-page-detail {
    margin-bottom: 12px
}

.item-page-detail .expandable-list {
    overflow: hidden
}

@media screen and (min-width: 768px) {
    .item-page-detail .list-item {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex
    }
}

.item-page-detail .list-item .item-label > div, .item-page-detail .list-item .item-value > div {
    min-height: 26px;
    height: 100%;
    word-break: break-all;
    padding-top: 8px
}

.item-page-detail .list-item .item-label {
    font-weight: 500;
    flex-grow: 1
}

@media screen and (min-width: 768px) {
    .item-page-detail .list-item .item-label > div {
        border-bottom: 1px solid #eee;
        padding-bottom: 8px
    }
}

.item-page-detail .list-item .item-value {
    flex-grow: 2
}

.item-page-detail .list-item .item-value > div {
    border-bottom: 1px solid #eee;
    padding-bottom: 8px
}

.item-page-detail .list-item ol {
    padding-left: 20px;
    margin-bottom: 0
}

.item-page-detail .list-item .subitem-toggle {
    display: inline-block
}

.item-page-detail .list-item .subitem-toggle > .link {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    color: #00cca3;
    cursor: pointer
}

.item-page-detail .list-item .subitem-toggle > .link:hover {
    color: #00cca3;
    text-shadow: 0 0 0
}

.item-page-detail .list-item .subitem-toggle > i.icon, .item-page-detail .list-item .subitem-toggle > i.tcell-sort, .item-page-detail .list-item .subitem-toggle > i.tcell-asc, .item-page-detail .list-item .subitem-toggle > i.tcell-desc {
    width: 20px
}

.item-page-detail .list-item li > span > .subitem-toggle > i.icon, .item-page-detail .list-item li > span > .subitem-toggle > i.tcell-sort, .item-page-detail .list-item li > span > .subitem-toggle > i.tcell-asc, .item-page-detail .list-item li > span > .subitem-toggle > i.tcell-desc {
    width: 20px;
    margin-left: -20px;
    background-color: #fff
}

.item-page-detail .list-item .data-display, .item-page-detail .list-item .sub-panel {
    padding: 0;
    padding-top: 15px
}

.item-page-detail .list-item .data-display > .sub-descriptions > .list-item:last-child > div.item-label > .inner, .item-page-detail .list-item .data-display > .sub-descriptions > .list-item:last-child > div.item-value > .inner, .item-page-detail .list-item .sub-panel > .sub-descriptions > .list-item:last-child > div.item-label > .inner, .item-page-detail .list-item .sub-panel > .sub-descriptions > .list-item:last-child > div.item-value > .inner {
    border-bottom: none
}

.item-page-detail .list-item.array-group-row:not(.last-item):not(.open) > .item-label > .inner, .item-page-detail .list-item.array-group-row:not(.last-item):not(.open) .item-value > .inner {
    border-bottom-color: transparent;
    padding-bottom: 2px;
    min-height: 20px
}

.item-page-detail .list-item.array-group-row:not(.first-item) > .item-label > .inner, .item-page-detail .list-item.array-group-row:not(.first-item) .item-value > .inner {
    padding-top: 2px
}

.item-page-detail .list-item.array-group-row > .item-label .label-number {
    transition: transform .3s ease-out, color .3s ease-out;
    transform: scale3d(0.85, 0.85, 0.85) translate3d(16px, 1px, 0);
    transform-origin: 100% 25%;
    margin-top: -1px;
    color: #888
}

.item-page-detail .list-item.array-group-row > .item-label .label-number .number-icon {
    opacity: 0;
    transition: opacity .3s ease-out
}

.item-page-detail .list-item.array-group-row > .item-label .label-number.active {
    color: #000;
    transform: scale3d(1, 1, 1)
}

.item-page-detail .list-item.array-group-row > .item-label .label-number.active .number-icon {
    opacity: 1
}

.item-page-detail .list-item.array-group-row > .item-label span.dim-duplicate {
    color: transparent;
    transition: color .3s ease-out;
    white-space: nowrap;
    overflow-x: hidden;
    text-overflow: ellipsis
}

.item-page-detail .list-item.array-group-row > .item-label span.dim-duplicate i.icon, .item-page-detail .list-item.array-group-row > .item-label span.dim-duplicate i.tcell-sort, .item-page-detail .list-item.array-group-row > .item-label span.dim-duplicate i.tcell-asc, .item-page-detail .list-item.array-group-row > .item-label span.dim-duplicate i.tcell-desc {
    display: none
}

.item-page-detail .list-item.open > .item-label > .inner {
    border-bottom-color: transparent
}

.item-page-detail .list-item.open > .item-label > .inner span.dim-duplicate {
    color: #bbb
}

.item-page-detail .list-item.open > .item-value > .inner {
    border-bottom-color: transparent
}

.item-page-detail .list-item .detail-embedded-table-container {
    overflow-x: auto
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table {
    min-width: 100%
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr th {
    white-space: normal;
    word-break: normal;
    padding: 7px 4px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr th.has-children > .tooltip-info-container {
    padding-left: 36px;
    border-bottom: 1px solid #ddd;
    padding-bottom: 7px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr th .sub-list-keys-header {
    margin-left: -4px;
    margin-right: -4px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr th .sub-list-keys-header > div.inline-block {
    padding: 5px 8px 0px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr th .sub-list-keys-header div.child-list-row-number {
    width: 36px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr td {
    word-break: normal;
    padding: 7px 8px
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr td.child-list-row-container {
    padding: 0;
    border-left: 1px dotted #ccc;
    border-right: 1px dotted #ccc;
    border-bottom: 1px solid #ddd
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr td.no-word-break {
    white-space: nowrap
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table tr:not(:last-child) {
    border-bottom: 1px solid #eee
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table .child-list-row > div {
    padding: 5px 8px;
    text-align: center
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table .child-list-row:not(:last-child) {
    border-bottom: 1px dotted #eee
}

.item-page-detail .list-item .detail-embedded-table-container table.detail-embedded-table .child-list-row div.child-list-row-number {
    width: 36px
}

@media screen and (max-width: 767px) {
    .item-page-detail .array-group .array-group-row.list-item:not(.first-item) .item-label {
        display: none
    }
}

.item-page-detail .sub-panel {
    padding-left: 40px;
    padding-bottom: 0;
    margin-bottom: 8px;
    border-bottom: 1px dotted #bbb;
    border-left: 1px dotted #aaa
}

.item-page-detail .sub-panel .item-label .tooltip-info-container {
    white-space: nowrap;
    overflow-x: hidden;
    text-overflow: ellipsis
}

.json-tree-wrapper {
    border-radius: 4px;
    overflow: hidden
}

.json-tree-wrapper > ul {
    padding: 8px 16px 16px !important;
    margin: 0 !important
}

.expandable-list {
    margin-bottom: 10px
}

.expandable-list ul {
    margin-bottom: 0px
}

.files-in-set-table-title {
    font-weight: 300;
    padding-bottom: 10px;
    margin-bottom: 2px;
    border-bottom: 1px solid #f4f4f4;
    margin-top: 20px
}

.files-in-set-table {
    margin-bottom: 20px
}

.files-in-set-table .row > div, .files-in-set-table .flexrow > div {
    padding-top: 5px;
    padding-bottom: 5px
}

.files-in-set-table .row h6.accession, .files-in-set-table .flexrow h6.accession {
    margin: 0;
    font-size: 0.925rem;
    font-weight: 400
}

.files-in-set-table .row h6.accession > a, .files-in-set-table .flexrow h6.accession > a {
    color: #777
}

.files-in-set-table .row h6.accession > a:hover, .files-in-set-table .flexrow h6.accession > a:hover {
    color: #000
}

.files-in-set-table .row > .title, .files-in-set-table .flexrow > .title {
    vertical-align: middle;
    text-align: left;
    padding-top: 10px
}

.files-in-set-table .row > .description, .files-in-set-table .flexrow > .description {
    padding-top: 1px;
    padding-bottom: 0px
}

.files-in-set-table .row > .lab, .files-in-set-table .flexrow > .lab {
    text-align: right
}

.files-in-set-table .row > .lab .lab-icon.no-lab, .files-in-set-table .flexrow > .lab .lab-icon.no-lab {
    opacity: 0.125
}

.files-in-set-table .row > .lab a.lab-icon, .files-in-set-table .flexrow > .lab a.lab-icon {
    color: #555;
    transition: color .5s
}

.files-in-set-table .row > .lab a.lab-icon:hover, .files-in-set-table .flexrow > .lab a.lab-icon:hover {
    color: #000
}

.files-in-set-table .row > .submitter small, .files-in-set-table .flexrow > .submitter small {
    line-height: 1rem;
    color: #777
}

.files-in-set-table .row > div.divider-column, .files-in-set-table .flexrow > div.divider-column {
    padding-bottom: 0;
    padding-top: 0
}

.files-in-set-table .row > div.divider-column > .divider, .files-in-set-table .flexrow > div.divider-column > .divider {
    border-bottom: 1px solid #f4f4f4;
    height: 1px
}

.files-in-set-table .row.header-row, .files-in-set-table .header-row.flexrow {
    user-select: none
}

.files-in-set-table .row.header-row > div, .files-in-set-table .header-row.flexrow > div {
    font-weight: 500
}

.files-in-set-table .row.header-row > div.divider-column > .divider, .files-in-set-table .header-row.flexrow > div.divider-column > .divider {
    border-bottom: 1px solid #ddd
}

.files-in-set-table .row.header-row > .download-button-title > i.icon, .files-in-set-table .header-row.flexrow > .download-button-title > i.icon, .files-in-set-table .row.header-row > .download-button-title > i.tcell-sort, .files-in-set-table .header-row.flexrow > .download-button-title > i.tcell-sort, .files-in-set-table .row.header-row > .download-button-title > i.tcell-asc, .files-in-set-table .header-row.flexrow > .download-button-title > i.tcell-asc, .files-in-set-table .row.header-row > .download-button-title > i.tcell-desc, .files-in-set-table .header-row.flexrow > .download-button-title > i.tcell-desc {
    width: 32px;
    text-align: center
}

.files-in-set-table .row.header-row > .download-button-title > span.file, .files-in-set-table .header-row.flexrow > .download-button-title > span.file {
    display: inline-block;
    min-width: 100px;
    text-align: left
}

.files-in-set-table .row.header-row > .download-button-title > span.docs, .files-in-set-table .header-row.flexrow > .download-button-title > span.docs {
    width: 33px;
    margin-left: 6px;
    display: inline-block;
    text-align: center
}

.files-in-set-table .row > .download-button, .files-in-set-table .flexrow > .download-button {
    position: relative;
    z-index: 10
}

.files-in-set-table .row > .download-button > a.btn.button-dl-doc, .files-in-set-table .flexrow > .download-button > a.btn.button-dl-doc, .files-in-set-table .row > .download-button > a.button-dl-doc.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > a.button-dl-doc.rf-RepeatingFieldset__add, .files-in-set-table .row > .download-button > button.btn.button-dl-doc, .files-in-set-table .flexrow > .download-button > button.btn.button-dl-doc, .files-in-set-table .row > .download-button > button.button-dl-doc.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > button.button-dl-doc.rf-RepeatingFieldset__add {
    margin-left: 5px
}

.files-in-set-table .row > .download-button > a.btn.button-dl-doc.disabled, .files-in-set-table .flexrow > .download-button > a.btn.button-dl-doc.disabled, .files-in-set-table .row > .download-button > a.button-dl-doc.disabled.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > a.button-dl-doc.disabled.rf-RepeatingFieldset__add, .files-in-set-table .row > .download-button > button.btn.button-dl-doc.disabled, .files-in-set-table .flexrow > .download-button > button.btn.button-dl-doc.disabled, .files-in-set-table .row > .download-button > button.button-dl-doc.disabled.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > button.button-dl-doc.disabled.rf-RepeatingFieldset__add {
    opacity: 0.33
}

.files-in-set-table .row > .download-button > a.btn.button-dl-file, .files-in-set-table .flexrow > .download-button > a.btn.button-dl-file, .files-in-set-table .row > .download-button > a.button-dl-file.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > a.button-dl-file.rf-RepeatingFieldset__add, .files-in-set-table .row > .download-button > button.btn.button-dl-file, .files-in-set-table .flexrow > .download-button > button.btn.button-dl-file, .files-in-set-table .row > .download-button > button.button-dl-file.rf-RepeatingFieldset__add, .files-in-set-table .flexrow > .download-button > button.button-dl-file.rf-RepeatingFieldset__add {
    min-width: 100px
}

@media screen and (max-width: 991px) {
    .files-in-set-table .row > .download-button, .files-in-set-table .flexrow > .download-button {
        margin-bottom: -50px
    }
}

@media screen and (max-width: 767px) {
    .files-in-set-table .row > .download-button > .button-dl-file, .files-in-set-table .flexrow > .download-button > .button-dl-file {
        margin-bottom: 5px
    }
}

@media screen and (min-width: 992px) {
    .files-in-set-table-title {
        margin-top: 20px
    }

    .files-in-set-table .row > div, .files-in-set-table .flexrow > div, .files-in-set-table .row h6, .files-in-set-table .flexrow h6 {
        line-height: 30px
    }

    .files-in-set-table .row h6.accession, .files-in-set-table .flexrow h6.accession {
        text-align: right
    }

    .files-in-set-table .row > .title, .files-in-set-table .flexrow > .title {
        padding-top: 5px;
        padding-bottom: 5px;
        text-align: right
    }

    .files-in-set-table .row > .description, .files-in-set-table .flexrow > .description {
        min-height: 30px;
        padding-top: 12px;
        padding-bottom: 12px;
        line-height: normal
    }

    .files-in-set-table .row > .download-button, .files-in-set-table .flexrow > .download-button {
        height: 40px;
        padding-top: 3px;
        padding-bottom: 3px
    }

    .files-in-set-table.smaller-version .title h6 {
        margin: 0
    }
}

.formatted-info-panel {
    padding: 0 10px 12px;
    margin-bottom: 5px
}

.formatted-info-panel.has-border {
    padding: 8px 18px 15px
}

.formatted-info-panel.no-icon {
    padding: 0;
    margin-bottom: 0
}

.formatted-info-panel.no-icon.loading {
    min-height: 36.5px
}

.formatted-info-panel > h6 {
    margin-left: -10px;
    font-weight: 500;
    color: #646464;
    margin-bottom: 7px;
    margin-top: 0px
}

.formatted-info-panel > h6:after {
    content: "\f105";
    font-family: "FontAwesome";
    padding-left: 6px
}

.formatted-info-panel .row .icon-container, .formatted-info-panel .flexrow .icon-container {
    max-width: 50px
}

.formatted-info-panel h5 {
    margin-bottom: 0;
    margin-top: 2px;
    font-weight: 600;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    word-break: normal
}

.formatted-info-panel h5 a {
    overflow: inherit;
    text-overflow: inherit
}

.formatted-info-panel h5.no-link {
    font-weight: 500
}

.formatted-info-panel.error-block.no-icon h5:before {
    content: "\f06a";
    font-family: FontAwesome;
    margin-right: 6px;
    color: #999
}

.formatted-info-panel div.more-details {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}

.formatted-info-panel div.more-details.error-message {
    white-space: pre-line;
    white-space: normal;
    opacity: 0.5
}

.formatted-info-panel .icon-container {
    text-align: center;
    padding-top: 4px;
    font-size: 20px
}

.formatted-info-panel .icon-container.col-xs-2 {
    padding-right: 0px;
    padding-left: 5px
}

.formatted-info-panel.loading > li, .formatted-info-panel.loading > .row, .formatted-info-panel.loading > .flexrow, .formatted-info-panel-list.loading > li, .formatted-info-panel-list.loading > .row, .formatted-info-panel-list.loading > .flexrow {
    opacity: 1
}

.formatted-info-panel.loaded > li, .formatted-info-panel.loaded > .row, .formatted-info-panel.loaded > .flexrow, .formatted-info-panel-list.loaded > li, .formatted-info-panel-list.loaded > .row, .formatted-info-panel-list.loaded > .flexrow {
    opacity: 0;
    transition: opacity 0s
}

.formatted-info-panel.loaded.transitioned > li, .formatted-info-panel.loaded.transitioned > .row, .formatted-info-panel.loaded.transitioned > .flexrow, .formatted-info-panel-list.loaded.transitioned > li, .formatted-info-panel-list.loaded.transitioned > .row, .formatted-info-panel-list.loaded.transitioned > .flexrow {
    opacity: 1;
    transition: opacity .5s
}

.publications-block ul {
    margin-bottom: 0;
    padding-left: 10px
}

.publications-block.single-item ul {
    margin-bottom: 1px;
    margin-top: 7px
}

.publications-block .details {
    padding-top: 3px
}

.publications-block .details > .details-row {
    margin-top: 7px
}

.publications-block h6.publication-label {
    font-weight: 500;
    color: #646464;
    margin-bottom: 7px;
    margin-top: 0px
}

.publications-block h6.publication-label:after {
    content: "\f105";
    font-family: "FontAwesome";
    padding-left: 6px
}

.publications-block .label-col {
    user-select: none
}

.publications-block .label-col span {
    position: relative
}

.publications-block .label-col span .icon.abstract-toggle, .publications-block .label-col span .abstract-toggle.tcell-sort, .publications-block .label-col span .abstract-toggle.tcell-asc, .publications-block .label-col span .abstract-toggle.tcell-desc {
    cursor: pointer;
    color: #888;
    position: absolute;
    left: -20px;
    top: 2px
}

.publications-block .icon-container {
    text-align: center;
    padding-top: 4px;
    font-size: 20px
}

.publications-block .icon-container.col-xs-2 {
    padding-right: 0px;
    padding-left: 5px
}

.item-page-container .rc-tabs-content .overview-blocks > div > .inner {
    padding: 15px 0 5px
}

.item-page-container .rc-tabs-content .overview-blocks > div > .inner h5 {
    margin-top: 0;
    margin-bottom: 5px;
    font-weight: 500
}

.item-page-container .rc-tabs-content .overview-blocks > div > .inner ol {
    margin-bottom: 0
}

.exp-table-section h3 span.exp-number {
    padding-top: 5px
}

.exp-table-section .exp-table-container {
    overflow-x: auto;
    display: block;
    border-bottom: 1px solid #888
}

.workflow-view-container h3.tab-section-title {
    padding-top: 0;
    min-height: 67px
}

.workflow-view-container h3.tab-section-title > span:first-child {
    display: block;
    padding-top: 27px;
    float: left;
    padding-right: 20px
}

.workflow-view-container .graph-wrapper {
    opacity: 1;
    transition: opacity .5s ease-out
}

.workflow-view-container.full-screen-view {
    position: fixed;
    left: 0;
    right: 0;
    top: 0;
    bottom: 0;
    z-index: 10000;
    background: #fff;
    overflow-y: auto
}

@media (min-width: 992px) {
    .workflow-view-container.full-screen-view {
        top: 41px;
        z-index: 1000
    }
}

.workflow-view-container.full-screen-view > .graph-wrapper {
    padding-left: 20px;
    padding-right: 20px
}

.workflow-view-container.full-screen-view > .tab-section-title, .workflow-view-container.full-screen-view .detail-pane {
    margin: 0 auto;
    padding-left: 20px;
    padding-right: 20px
}

@media (min-width: 768px) {
    .workflow-view-container.full-screen-view > .tab-section-title, .workflow-view-container.full-screen-view .detail-pane {
        max-width: 740px
    }
}

@media (min-width: 992px) {
    .workflow-view-container.full-screen-view > .tab-section-title, .workflow-view-container.full-screen-view .detail-pane {
        max-width: 960px;
        padding-left: 0;
        padding-right: 0
    }
}

@media (min-width: 1200px) {
    .workflow-view-container.full-screen-view > .tab-section-title, .workflow-view-container.full-screen-view .detail-pane {
        max-width: 1160px
    }
}

.workflow-chart-inner-container .detail-pane > h5 {
    margin-bottom: 0px
}

.workflow-chart-inner-container .detail-pane > h5 + h4 {
    margin-top: 4px;
    margin-bottom: 0
}

.workflow-chart-inner-container .detail-pane > .detail-pane-body {
    overflow-x: hidden
}

.workflow-chart-inner-container .detail-pane .information {
    margin-top: 12px;
    padding-top: 0;
    border-top: 1px solid #ccc
}

.workflow-chart-inner-container .detail-pane .information > hr {
    margin-bottom: 0;
    margin-top: 0
}

.workflow-chart-inner-container .detail-pane .information + hr {
    border-color: #ccc;
    margin-top: 0
}

.workflow-chart-inner-container .detail-pane .information > .row > .box, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box {
    padding-top: 12px;
    padding-bottom: 10px;
    min-height: 70px
}

.workflow-chart-inner-container .detail-pane .information > .row > .box > h3, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h3, .workflow-chart-inner-container .detail-pane .information > .row > .box > h4, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h4, .workflow-chart-inner-container .detail-pane .information > .row > .box > h5, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h5 {
    margin-bottom: 0;
    margin-top: 0;
    line-height: 28px
}

.workflow-chart-inner-container .detail-pane .information > .row > .box > h3 > pre, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h3 > pre, .workflow-chart-inner-container .detail-pane .information > .row > .box > h3 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h3 > code, .workflow-chart-inner-container .detail-pane .information > .row > .box > h4 > pre, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h4 > pre, .workflow-chart-inner-container .detail-pane .information > .row > .box > h4 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h4 > code, .workflow-chart-inner-container .detail-pane .information > .row > .box > h5 > pre, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h5 > pre, .workflow-chart-inner-container .detail-pane .information > .row > .box > h5 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h5 > code {
    margin-top: 5px;
    line-height: 23px
}

.workflow-chart-inner-container .detail-pane .information > .row > .box > h3 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h3 > code, .workflow-chart-inner-container .detail-pane .information > .row > .box > h4 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h4 > code, .workflow-chart-inner-container .detail-pane .information > .row > .box > h5 > code, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > h5 > code {
    display: inline-block;
    padding-top: 0;
    padding-bottom: 0
}

.workflow-chart-inner-container .detail-pane .information > .row > .box > .download-button, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box > .download-button {
    margin-top: 6px
}

.workflow-chart-inner-container .detail-pane .information > .row > .box.buttons-container, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box.buttons-container {
    text-align: left
}

@media screen and (min-width: 768px) {
    .workflow-chart-inner-container .detail-pane .information > .row > .box.buttons-container, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box.buttons-container {
        text-align: right
    }
}

.workflow-chart-inner-container .detail-pane .information > .row > .box.steps-in-workflow a:not(:last-child), .workflow-chart-inner-container .detail-pane .information > .flexrow > .box.steps-in-workflow a:not(:last-child) {
    margin-right: 5px
}

.workflow-chart-inner-container .detail-pane .information > .row > .box.steps-in-workflow a:not(:last-child):after, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box.steps-in-workflow a:not(:last-child):after {
    content: ',';
    color: #000;
    text-decoration: none
}

.workflow-chart-inner-container .detail-pane .information > .row > .box.steps-in-workflow a:not(:last-child):hover:after, .workflow-chart-inner-container .detail-pane .information > .flexrow > .box.steps-in-workflow a:not(:last-child):hover:after {
    text-decoration: none
}

.workflow-chart-inner-container .detail-pane .information .description-box-container {
    padding-top: 2px
}

.workflow-chart-inner-container .detail-pane .information .file-title > h3.node-file-title {
    overflow: hidden
}

.workflow-chart-inner-container .detail-pane .information .file-title .download-button-container {
    position: absolute;
    right: 10px;
    top: 40px
}

@media screen and (max-width: 1199px) {
    .workflow-chart-inner-container .detail-pane .information .file-title .download-button-container.exists + h3.node-file-title {
        padding-right: 30px
    }
}

.metrics-view .metrics-view-item .inner {
    padding-top: 9px;
    padding-bottom: 9px;
    border-bottom: 1px solid #f4f4f4
}

.metrics-view .metrics-view-item .inner .icon-exclamation-circle, .metrics-view .metrics-view-item .inner .audit-icon-warning, .metrics-view .metrics-view-item .inner .audit-icon-warning-badged, .metrics-view .metrics-view-item .inner .audit-activeicon-warning {
    color: #bd0000
}

.metrics-view .metrics-view-item .inner .icon-warning, .metrics-view .metrics-view-item .inner .audit-icon-error, .metrics-view .metrics-view-item .inner .audit-icon-error-badged, .metrics-view .metrics-view-item .inner .audit-activeicon-error {
    color: #e29302
}

.metrics-view .metrics-view-item .inner .icon-check, .metrics-view .metrics-view-item .inner .audit-icon-ok, .metrics-view .metrics-view-item .inner .audit-icon-ok-badged, .metrics-view .metrics-view-item .inner .audit-activeicon-ok {
    color: green
}

.metrics-view .metrics-view-item h1, .metrics-view .metrics-view-item h2, .metrics-view .metrics-view-item h3, .metrics-view .metrics-view-item h4, .metrics-view .metrics-view-item h5, .metrics-view .metrics-view-item h6 {
    margin: 0
}

.item-page-container.type-File .rc-tabs-content .file-download-container {
    border-top: 1px solid #eee;
    margin-top: 20px;
    padding-top: 20px
}

@media screen and (min-width: 992px) {
    .item-page-container.type-File .rc-tabs-content .file-download-container {
        float: right;
        padding-top: 16px;
        margin-top: 0;
        border-top: none
    }
}

.fourDN-header {
    font-family: "Mada", "Work Sans", Helvetica, Arial, sans-serif;
    font-weight: 300;
    margin-bottom: 20px;
    margin-top: 20px;
    padding-bottom: 15px;
    border-bottom: 1px solid #f4f4f4;
    font-size: 32px;
    letter-spacing: -1px;
    line-height: 38px;
    position: relative
}

.fourDN-header[id]:before {
    content: '';
    position: relative;
    top: -150px
}

h4.fourDN-header {
    font-size: 24px;
    margin-bottom: 10px;
    padding-bottom: 8px
}

h5.fourDN-header {
    font-size: 20px
}

.fourDN-banner {
    margin-top: 40px;
    margin-bottom: 40px
}

.fourDN-banner > h4 {
    font-size: 1.4em;
    color: #999999
}

.fourDN-banner > h4 > div {
    display: inline-block
}

.fourDN-section {
    padding-bottom: 10px;
    margin-top: 20px
}

.fourDN-section.announcement {
    padding-bottom: 10px;
    margin-top: 20px
}

.fourDN-section.announcement .announcement-title {
    font-weight: 300;
    font-size: 1.35rem;
    border-bottom: 2px solid #168369;
    padding-bottom: 5px;
    margin-bottom: 5px
}

.fourDN-section.announcement .announcement-title i.icon.icon-minus, .fourDN-section.announcement .announcement-title i.icon-minus.tcell-sort, .fourDN-section.announcement .announcement-title i.icon-minus.tcell-asc, .fourDN-section.announcement .announcement-title i.icon-minus.tcell-desc, .fourDN-section.announcement .announcement-title i.icon.icon-plus, .fourDN-section.announcement .announcement-title i.icon-plus.tcell-sort, .fourDN-section.announcement .announcement-title i.icon-plus.tcell-asc, .fourDN-section.announcement .announcement-title i.icon-plus.tcell-desc {
    margin-right: 5px
}

.fourDN-section.announcement .announcement-subtitle {
    color: #999;
    font-weight: 400;
    font-size: 0.9rem
}

.fourDN-section.announcement .announcement-content {
    margin-top: 10px;
    font-size: 1.25rem
}

.fourDN-section-toggle {
    color: #555;
    text-decoration: none !important
}

.fourDN-section-toggle:hover, .fourDN-section-toggle:focus {
    color: #000000
}

.fourDN-section-info {
    color: #999 !important;
    font-weight: 300;
    font-size: 1.2em
}

.fourDN-content {
    line-height: 130%;
    font-size: 1.375rem
}

.fourDN-content > h2, .fourDN-content > div > h2 {
    font-weight: 400;
    margin: 30px 0
}

.fourDN-content > h3, .fourDN-content > div > h3 {
    margin-top: 25px;
    margin-bottom: 15px
}

.fourDN-content > h4, .fourDN-content > div > h4 {
    margin-top: 20px
}

.fourDN-content img {
    max-width: 100%
}

.help-entry.static-section-entry .fourDN-content {
    font-family: "Yrsa", "Times New Roman", Georgia, Times, serif
}

.fourDN-content-panel {
    margin-top: 0px !important
}

.table-of-contents {
    position: relative
}

@media screen and (min-width: 1200px) {
    .table-of-contents {
        position: fixed;
        margin: 0 -10px;
        padding: 0 10px;
        top: 115px;
        transition: top .75s, max-height .75s, margin-top .75s ease-out;
        overflow-y: auto
    }

    body.scrolled-past-top .table-of-contents {
        top: 70px
    }
}

.table-of-contents .toc-title {
    font-weight: 400;
    border-bottom: 1px solid #ddd;
    padding-bottom: 10px;
    margin-bottom: 0
}

.table-of-contents ol {
    padding-left: 20px
}

.table-of-contents ol > li {
    line-height: 1.25rem;
    transition: font-weight .5s .25s, color .5s .25s;
    color: #888;
    position: relative
}

.table-of-contents ol > li[data-depth="0"] {
    padding-top: 0
}

.table-of-contents ol > li[data-depth="1"]:first-child a {
    border-top: none
}

.table-of-contents ol > li[data-depth="3"], .table-of-contents ol > li[data-depth="4"], .table-of-contents ol > li[data-depth="5"], .table-of-contents ol > li[data-depth="6"] {
    font-size: 0.9rem
}

.table-of-contents ol > li:last-child {
    margin-bottom: 0
}

.table-of-contents ol > li .top-of-page {
    display: block;
    border-bottom: 1px solid #eee;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    color: #999
}

.table-of-contents ol > li .top-of-page > a {
    padding-top: 10px;
    padding-bottom: 10px
}

.table-of-contents ol > li .top-of-page > small {
    display: none;
    line-height: 1rem
}

.table-of-contents ol > li .top-of-page > small:before {
    content: "|";
    margin: 0 7px 0 3px;
    color: #ccc
}

.table-of-contents ol > li .top-of-page:hover > small {
    display: inline;
    opacity: 1
}

.table-of-contents ol > li .top-of-page i.icon, .table-of-contents ol > li .top-of-page i.tcell-sort, .table-of-contents ol > li .top-of-page i.tcell-asc, .table-of-contents ol > li .top-of-page i.tcell-desc {
    color: #888;
    text-align: center;
    width: 20px;
    position: relative;
    z-index: 2;
    float: left;
    padding-top: 0px;
    padding-bottom: 0px;
    height: 33px;
    line-height: 33px
}

.table-of-contents ol > li a {
    display: block;
    transition: color .5s .25s;
    font-weight: 400;
    padding: 5px 0px 7px 22px;
    border-top: 1px dotted transparent;
    border-bottom: 1px dotted transparent;
    margin-bottom: 0;
    margin-top: 0;
    margin-left: -20px
}

.table-of-contents ol > li a:focus {
    text-decoration: none;
    color: #428bca
}

.table-of-contents ol > li a:hover {
    text-decoration: none;
    color: #042d50;
    transition: color 0s
}

.table-of-contents ol > li > div.title-link-wrapper {
    position: relative
}

.table-of-contents ol > li > div.title-link-wrapper > a {
    display: inline-block;
    vertical-align: middle
}

.table-of-contents ol > li > div.title-link-wrapper > i.icon, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-sort, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-asc, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-desc {
    position: absolute;
    left: -40px;
    top: 50%;
    margin-top: -9px;
    font-size: 0.85rem;
    cursor: pointer;
    width: 15px;
    height: 15px;
    line-height: 16px;
    vertical-align: middle;
    text-align: center;
    transform: scale3d(1, 1, 1);
    transition: transform .3s, color .3s;
    left: -70px;
    margin-left: 14%
}

.table-of-contents ol > li > div.title-link-wrapper > i.icon:hover, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-sort:hover, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-asc:hover, .table-of-contents ol > li > div.title-link-wrapper > i.tcell-desc:hover {
    cursor: pointer;
    color: #000;
    transform: scale3d(1.2, 1.2, 1.2)
}

.table-of-contents ol > li.active {
    font-weight: 700;
    color: #000
}

.table-of-contents ol > li.active > * {
    font-weight: 400
}

.table-of-contents ol > li.active > a, .table-of-contents ol > li.active > span > a, .table-of-contents ol > li:focus > a, .table-of-contents ol > li:focus > span > a {
    color: #000
}

.table-of-contents > ol.inner > li:first-child {
    margin-top: 8px
}

.table-of-contents > ol.inner > li:first-child a {
    border-top: none
}

.home-announcements {
    padding: 5px !important;
    margin-top: 30px
}

.homepage-links-row .links-wrapper {
    display: flex
}

.homepage-links-row .links-wrapper .link-block > a {
    background: #f8f8f8;
    padding: 8px 10px;
    display: block;
    font-weight: 400;
    height: 100%;
    border: 1px solid rgba(0, 0, 0, 0.05)
}

.homepage-links-row .links-wrapper .link-block > a:hover {
    background-color: #f4f4f4
}

.homepage-links-row .links-wrapper .link-block > a > span {
    display: inline-block;
    vertical-align: middle
}

.homepage-links-row .links-wrapper .link-block:not(:first-child) {
    border-left: 1px solid #eee
}

.home-content-area {
    margin-top: 40px
}

.error-page {
    margin-top: 50px
}

.slide-display {
    padding: 20px 0px 20px 0px
}

.slide-display > img {
    display: block;
    margin: auto
}

.slide-display > .slide-controls {
    text-align: center
}

.page-container > .row.first-row, .page-container > .first-row.flexrow {
    margin-top: 29px
}

.panel.user-info, .user-info.panel-full, .user-info.table-panel, .panel.user-work-info, .user-work-info.panel-full, .user-work-info.table-panel {
    margin-bottom: 0
}

.panel.user-info #email, .user-info.panel-full #email, .user-info.table-panel #email, .panel.user-work-info #email, .user-work-info.panel-full #email, .user-work-info.table-panel #email {
    font-weight: 500
}

.panel.user-info .formatted-info-panel.no-details.no-icon.no-label, .user-info.panel-full .formatted-info-panel.no-details.no-icon.no-label, .user-info.table-panel .formatted-info-panel.no-details.no-icon.no-label, .panel.user-work-info .formatted-info-panel.no-details.no-icon.no-label, .user-work-info.panel-full .formatted-info-panel.no-details.no-icon.no-label, .user-work-info.table-panel .formatted-info-panel.no-details.no-icon.no-label {
    display: inline-block;
    padding: 0;
    vertical-align: text-top;
    max-width: 85%;
    word-break: break-word
}

.panel.user-info .formatted-info-panel .block-title, .user-info.panel-full .formatted-info-panel .block-title, .user-info.table-panel .formatted-info-panel .block-title, .panel.user-info .formatted-info-panel .block-title a, .user-info.panel-full .formatted-info-panel .block-title a, .user-info.table-panel .formatted-info-panel .block-title a, .panel.user-work-info .formatted-info-panel .block-title, .user-work-info.panel-full .formatted-info-panel .block-title, .user-work-info.table-panel .formatted-info-panel .block-title, .panel.user-work-info .formatted-info-panel .block-title a, .user-work-info.panel-full .formatted-info-panel .block-title a, .user-work-info.table-panel .formatted-info-panel .block-title a {
    font-weight: 600
}

.panel.user-info, .user-info.panel-full, .user-info.table-panel {
    transform: rotateZ(0deg) scale3d(1, 1, 1) translateX(0);
    opacity: 1;
    left: 0px;
    transition: transform 1.2s ease-out, opacity 1.5s ease-out, left 1.2s ease-out;
    position: relative;
    z-index: 2;
    background-color: #fff
}

.panel.user-info.transition, .user-info.transition.panel-full, .user-info.transition.table-panel {
    transform: rotateZ(-900deg) scale3d(0.1, 0.1, 0.1) translateX(-1200px);
    opacity: 0;
    left: -900px
}

.panel.user-info .user-title-row-container, .user-info.panel-full .user-title-row-container, .user-info.table-panel .user-title-row-container {
    margin-bottom: 20px;
    border-bottom: 1px solid #eee
}

.panel.user-info .user-title-col, .user-info.panel-full .user-title-col, .user-info.table-panel .user-title-col {
    padding-bottom: 17px
}

.panel.user-info .user-title, .user-info.panel-full .user-title, .user-info.table-panel .user-title {
    margin-top: 0px;
    margin-bottom: 0px;
    font-weight: 300;
    font-size: 2.6rem
}

.panel.user-info .user-title .editable-field-entry, .user-info.panel-full .user-title .editable-field-entry, .user-info.table-panel .user-title .editable-field-entry {
    text-overflow: ellipsis
}

.panel.user-info .user-title .editable-field-entry .value, .user-info.panel-full .user-title .editable-field-entry .value, .user-info.table-panel .user-title .editable-field-entry .value {
    word-break: break-word
}

.panel.user-info .user-title .editable-field-entry .value .edit-button, .user-info.panel-full .user-title .editable-field-entry .value .edit-button, .user-info.table-panel .user-title .editable-field-entry .value .edit-button {
    font-size: 1rem
}

@media screen and (min-width: 768px) {
    .panel.user-info .user-title-col, .user-info.panel-full .user-title-col, .user-info.table-panel .user-title-col {
        padding-top: 15px;
        min-height: 85px;
        padding-bottom: 30px
    }

    .panel.user-info .user-title, .user-info.panel-full .user-title, .user-info.table-panel .user-title {
        text-overflow: ellipsis
    }
}

@media screen and (max-width: 767px) {
    .panel.user-info .user-title-col, .user-info.panel-full .user-title-col, .user-info.table-panel .user-title-col {
        padding-top: 2px
    }

    .panel.user-info .user-title, .user-info.panel-full .user-title, .user-info.table-panel .user-title {
        font-size: 2rem;
        font-weight: 400;
        margin-right: 70px
    }
}

.panel.user-info img.gravatar, .user-info.panel-full img.gravatar, .user-info.table-panel img.gravatar {
    width: 70px;
    height: 70px;
    float: right;
    border-radius: 3px
}

@media screen and (max-width: 767px) {
    .panel.user-info img.gravatar, .user-info.panel-full img.gravatar, .user-info.table-panel img.gravatar {
        width: 94px;
        height: 70px;
        position: relative;
        z-index: 2;
        margin-bottom: -30px;
        margin-top: 5px;
        border-left: 24px solid #FFF
    }
}

@media screen and (min-width: 768px) {
    .editing .user-title .editable-field-entry.inline:not(.editing) {
        display: inline-block
    }
}

.panel.user-work-info > .block-title, .user-work-info.panel-full > .block-title, .user-work-info.table-panel > .block-title {
    margin-bottom: 20px;
    padding-bottom: 15px;
    border-bottom: 1px solid #eee;
    padding-top: 0
}

.panel.user-work-info > .block-title > i.icon.icon-fw, .user-work-info.panel-full > .block-title > i.icon.icon-fw, .user-work-info.table-panel > .block-title > i.icon.icon-fw, .panel.user-work-info > .block-title > i.icon-fw.tcell-sort, .user-work-info.panel-full > .block-title > i.icon-fw.tcell-sort, .user-work-info.table-panel > .block-title > i.icon-fw.tcell-sort, .panel.user-work-info > .block-title > i.icon-fw.tcell-asc, .user-work-info.panel-full > .block-title > i.icon-fw.tcell-asc, .user-work-info.table-panel > .block-title > i.icon-fw.tcell-asc, .panel.user-work-info > .block-title > i.icon-fw.tcell-desc, .user-work-info.panel-full > .block-title > i.icon-fw.tcell-desc, .user-work-info.table-panel > .block-title > i.icon-fw.tcell-desc {
    margin-right: 5px;
    font-size: 1.5rem
}

.access-keys-container {
    padding-top: 15px
}

.access-keys-container > h3 {
    margin-bottom: 17px
}

.access-keys-container table.access-keys-table {
    margin-bottom: 20px
}

.access-keys-container table.access-keys-table tr td {
    border-bottom: 1px solid #eee
}

.access-keys-container table.access-keys-table tr td.access-key-buttons {
    width: 140px
}

.access-keys-container table.access-keys-table tr td.access-key-buttons .btn.btn-xs, .access-keys-container table.access-keys-table tr td.access-key-buttons .btn-group-xs > .btn, .access-keys-container table.access-keys-table tr td.access-key-buttons .btn-group-xs > .rf-RepeatingFieldset__add, .access-keys-container table.access-keys-table tr td.access-key-buttons .btn-xs.rf-RepeatingFieldset__add {
    margin: 0 4px
}

.access-keys-container #add-access-key.btn, .access-keys-container #add-access-key.rf-RepeatingFieldset__add {
    float: right;
    min-width: 180px
}

.access-keys-container .no-access-keys > hr:first-child {
    margin-top: 0;
    margin-bottom: 17px
}

@media screen and (min-width: 1200px) {
    #content.container > .static-page.row #nofic-matrix-1, #content.container > .static-page.flexrow #nofic-matrix-1, #content.container > .static-page.row #nofic-matrix-2, #content.container > .static-page.flexrow #nofic-matrix-2, #content.container > .static-page.row #nofic-matrix-3, #content.container > .static-page.flexrow #nofic-matrix-3, #content.container > .static-page.row #nofic-matrix-4, #content.container > .static-page.flexrow #nofic-matrix-4 {
        position: relative;
        float: left;
        width: 50%;
        margin-top: 0px;
        margin-bottom: 20px
    }

    #content.container > .static-page.row #nofic-matrix-1, #content.container > .static-page.flexrow #nofic-matrix-1 {
        padding-right: 15px
    }

    #content.container > .static-page.row #nofic-matrix-2, #content.container > .static-page.flexrow #nofic-matrix-2, #content.container > .static-page.row #nofic-matrix-3, #content.container > .static-page.flexrow #nofic-matrix-3, #content.container > .static-page.row #nofic-matrix-4, #content.container > .static-page.flexrow #nofic-matrix-4 {
        padding-left: 15px
    }

    body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.row #nofic-matrix-2, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.flexrow #nofic-matrix-2, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.row #nofic-matrix-3, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.flexrow #nofic-matrix-3, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.row #nofic-matrix-4, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.flexrow #nofic-matrix-4 {
        float: right
    }

    body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.row #nofic-matrix-2 > div:first-child, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.flexrow #nofic-matrix-2 > div:first-child, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.row #nofic-matrix-3 > div:first-child, body[data-path="/joint-analysis-data-plans"] #content.container > .static-page.flexrow #nofic-matrix-3 > div:first-child {
        border-bottom: 1px solid #bbb
    }
}

#content.container div.rm-cell.cellType-submitted, #content.container div.color-patch.cellType-submitted, #legend.static-section-entry div.rm-cell.cellType-submitted, #legend.static-section-entry div.color-patch.cellType-submitted {
    background-color: #53a74e !important
}

#content.container div.rm-cell.cellType-planned, #content.container div.color-patch.cellType-planned, #legend.static-section-entry div.rm-cell.cellType-planned, #legend.static-section-entry div.color-patch.cellType-planned {
    background-color: rgba(191, 191, 191, 0.5) !important
}

#content.container div.rm-cell.cellType-in-submission, #content.container div.color-patch.cellType-in-submission, #legend.static-section-entry div.rm-cell.cellType-in-submission, #legend.static-section-entry div.color-patch.cellType-in-submission {
    background-color: rgba(191, 191, 191, 0.5) !important;
    overflow: hidden
}

#content.container div.rm-cell.cellType-in-submission:before, #content.container div.color-patch.cellType-in-submission:before, #legend.static-section-entry div.rm-cell.cellType-in-submission:before, #legend.static-section-entry div.color-patch.cellType-in-submission:before {
    content: '';
    display: block;
    width: 150%;
    height: 150%;
    background-color: #53a74e;
    transform: rotate3d(0, 0, 1, 45deg) translate3d(-74%, 0px, 0px)
}

#content.container div.rm-cell.cellType-none, #content.container div.color-patch.cellType-none, #legend.static-section-entry div.rm-cell.cellType-none, #legend.static-section-entry div.color-patch.cellType-none {
    background-color: transparent !important
}

#legend.static-section-entry {
    margin-bottom: 10px;
    padding-bottom: 10px;
    border-bottom: 1px solid #eee
}

#legend.static-section-entry .section-joint-anlysis-data-legend {
    font-size: 1rem
}

#legend.static-section-entry .section-joint-anlysis-data-legend > .col-sm-3 {
    text-align: center
}

#legend.static-section-entry .section-joint-anlysis-data-legend .color-patch {
    height: 10px;
    width: 10px;
    display: inline-block;
    margin-right: 5px
}

.block {
    padding: .5em
}

.layout.editable {
    position: relative
}

.layout.editable .row, .layout.editable .flexrow {
    position: relative;
    margin-top: -5px;
    margin-bottom: -5px;
    padding-top: 5px;
    padding-bottom: 5px;
    outline: dashed 1px red
}

.layout.editable [class^="col"] {
    outline: dashed 1px blue
}

.layout.editable .block {
    position: relative;
    min-height: 20px
}

.layout.editable .block.dragging {
    opacity: .5
}

.layout.editable .block.hover {
    outline: dashed 1px #428bca
}

.layout.editable .block.hover[draggable="true"] {
    cursor: move
}

.layout.editable .block.hover .block-toolbar {
    display: block
}

.layout.editable .block .block-toolbar {
    position: absolute;
    z-index: 1;
    top: 3px;
    right: 3px;
    text-align: right;
    display: none
}

.layout.editable .block .block-toolbar a {
    text-decoration: none;
    cursor: pointer
}

.drop-top:before {
    content: " ";
    display: block !important;
    width: 100%;
    border-top: solid 3px #428bca;
    margin-top: -3px;
    position: absolute;
    top: 0;
    left: 0
}

.drop-bottom:after {
    content: " ";
    display: block !important;
    width: 100%;
    border-bottom: solid 3px #428bca;
    margin-bottom: -3px;
    position: absolute;
    bottom: 0;
    left: 0
}

.row.drop-bottom:after, .drop-bottom.flexrow:after {
    display: table !important;
    position: static
}

.drop-left:before {
    content: " ";
    display: block !important;
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    border-left: solid 3px #428bca
}

.drop-right:before {
    content: " ";
    display: block !important;
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    border-right: solid 3px #428bca
}

.layout-toolbar {
    z-index: 1030
}

.layout-toolbar .navbar-left .btn, .layout-toolbar .navbar-left .rf-RepeatingFieldset__add {
    cursor: move
}

.layout-toolbar.navbar-fixed-top {
    z-index: 1031
}

.layout-toolbar.navbar-fixed-top .col-md-12 {
    outline: 0
}

.modal-dialog {
    width: 900px
}

@media (min-width: 768px) {
    .footer-row {
        margin-left: 0;
        margin-right: 0
    }

    #page-footer {
        height: 50px
    }

    .page-footer {
        height: 50px
    }

    .app-version {
        margin: 0 0 8px;
        text-align: center;
        display: block;
        padding: 15px 15px
    }
}

@media (min-width: 768px) and (min-width: 768px) {
    .app-version {
        text-align: left
    }
}

@media (min-width: 768px) {
    html, body {
        height: 100%
    }

    #layout {
        clear: both;
        min-height: 100%;
        height: auto !important;
        height: 100%;
        margin-bottom: -50px
    }

    #layout #layout-footer {
        height: 50px
    }

    #page-footer {
        clear: both;
        position: relative;
        height: 50px
    }

    .footer-links {
        list-style: none outside none;
        margin-left: -5px;
        padding-left: 0
    }

    .footer-links li {
        display: inline-block;
        padding-left: 10px;
        padding-right: 10px
    }

    .footer-links a {
        display: inline;
        margin: 0;
        padding: 0;
        background-color: transparent
    }

    .footer-links a:hover {
        text-decoration: underline;
        background-color: transparent
    }

    .footer-links a:active {
        background-color: transparent
    }
}

.btn, .rf-RepeatingFieldset__add {
    font-weight: 500
}

.btn-link {
    font-weight: normal;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    box-shadow: none
}

.btn-svgicon {
    line-height: 0.9;
    margin-right: 0 !important;
    border-radius: 0
}

.btn-svgicon .svg-icon {
    fill: #fff
}

.btn-svgicon:first-child {
    border-top-left-radius: 2px;
    border-bottom-left-radius: 2px
}

.btn-svgicon:last-child {
    border-top-right-radius: 2px;
    border-bottom-right-radius: 2px
}

.btn-xs.rounded, .btn-group-xs > .rounded.btn, .btn-group-xs > .rounded.rf-RepeatingFieldset__add, .btn-xs.ext-padding, .btn-group-xs > .ext-padding.btn, .btn-group-xs > .ext-padding.rf-RepeatingFieldset__add {
    padding-left: 7px;
    padding-right: 7px
}

.btn-xs.rounded, .btn-group-xs > .rounded.btn, .btn-group-xs > .rounded.rf-RepeatingFieldset__add {
    border-radius: 11px
}

.btn-outline-primary, .btn-outline-secondary, .btn-outline-default, .btn-outline-success, .btn-outline-info, .btn-outline-warning, .btn-outline-danger, .btn-outline-white {
    background-image: none;
    background-color: transparent
}

.btn-outline-primary {
    color: #428bca;
    border-color: #428bca
}

.btn-outline-primary:hover {
    color: #fff;
    background-color: #428bca
}

.btn-outline-default {
    color: #333;
    border-color: #333
}

.btn-outline-default:hover {
    color: #fff;
    background-color: #333
}

.btn-outline-secondary {
    color: #ccc;
    border-color: #ccc
}

.btn-outline-secondary:hover {
    color: #fff;
    background-color: #ccc
}

.btn-outline-success {
    color: #4C994C;
    border-color: #4C994C
}

.btn-outline-success:hover {
    color: #fff;
    background-color: #4C994C
}

.btn-outline-info {
    color: #4F689E;
    border-color: #4F689E
}

.btn-outline-info:hover {
    color: #fff;
    background-color: #4F689E
}

.btn-outline-warning {
    color: #E59545;
    border-color: #E59545
}

.btn-outline-warning:hover {
    color: #fff;
    background-color: #E59545
}

.btn-outline-danger {
    color: #B24342;
    border-color: #B24342
}

.btn-outline-danger:hover {
    color: #fff;
    background-color: #B24342
}

.btn-outline-white {
    color: #fff;
    border-color: #fff
}

.btn-outline-white:hover, .btn-outline-white:focus {
    color: #333;
    background-color: #fff
}

.clearfix:before, .key-value-flex dd:before, .clearfix:after, .key-value-flex dd:after {
    content: " ";
    display: table
}

.clearfix:after, .key-value-flex dd:after {
    clear: both
}

.center-block {
    display: block;
    margin-left: auto;
    margin-right: auto
}

.pull-right {
    float: right !important
}

.pull-left {
    display: block;
    float: left !important
}

.hide {
    display: none !important
}

.show {
    display: block !important
}

.invisible {
    visibility: hidden
}

.text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0
}

.hidden {
    display: none !important;
    visibility: hidden !important
}

.affix {
    position: fixed
}

@-ms-viewport {
    width: device-width
}

.visible-xs, .visible-sm, .visible-md, .visible-lg {
    display: none !important
}

@media (max-width: 767px) {
    .visible-xs {
        display: block !important
    }

    table.visible-xs {
        display: table
    }

    tr.visible-xs {
        display: table-row !important
    }

    th.visible-xs, td.visible-xs {
        display: table-cell !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .visible-sm {
        display: block !important
    }

    table.visible-sm {
        display: table
    }

    tr.visible-sm {
        display: table-row !important
    }

    th.visible-sm, td.visible-sm {
        display: table-cell !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .visible-md {
        display: block !important
    }

    table.visible-md {
        display: table
    }

    tr.visible-md {
        display: table-row !important
    }

    th.visible-md, td.visible-md {
        display: table-cell !important
    }
}

@media (min-width: 1200px) {
    .visible-lg {
        display: block !important
    }

    table.visible-lg {
        display: table
    }

    tr.visible-lg {
        display: table-row !important
    }

    th.visible-lg, td.visible-lg {
        display: table-cell !important
    }
}

@media (max-width: 767px) {
    .hidden-xs {
        display: none !important
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .hidden-sm {
        display: none !important
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .hidden-md {
        display: none !important
    }
}

@media (min-width: 1200px) {
    .hidden-lg {
        display: none !important
    }
}

.visible-print {
    display: none !important
}

@media print {
    .visible-print {
        display: block !important
    }

    table.visible-print {
        display: table
    }

    tr.visible-print {
        display: table-row !important
    }

    th.visible-print, td.visible-print {
        display: table-cell !important
    }
}

@media print {
    .hidden-print {
        display: none !important
    }
}
